<?php
if ( !defined( 'ABSPATH' ) ) exit;



require_once('templates/template-functions.php');
$action = postValue('action');
$csrfCheckResult = OpenDrive::i()->verifyCSRFToken();

if (!$csrfCheckResult) {
	if(isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest'){
		header('CSRF Token error', true, 403);
		exit;
	}

	wp_redirect(site_url());
	exit;
}
if ( $action != '' )
{
	$result = array();
	$error = false;
	$error_message = '';
	$csrfToken = null;

	if($csrfCheckResult === 2) $csrfToken = OpenDrive::i()->createCSRFToken();

	switch ($action)
	{
		case 'notepad-create':
			{
				$notepad_name = postValue('name');
				$result = OpenDrive::i()->apiClient()->create_notepad($notepad_name);
				$error = OpenDrive::i()->apiClient()->error;
				break;				
			}
		case 'notepad-archive':
			{
				$notepad_id = postValue('notepad_id');
				$result = OpenDrive::i()->apiClient()->archive_notepad($notepad_id);
				break;				
			}	
		case 'notepad-trash':
			{
				$notepad_id = postValue('notepad_id');
				$result = OpenDrive::i()->apiClient()->trash_notepad($notepad_id);
				break;				
			}
		case 'notepad-delete-trashed':
			{
				$notepad_id = postValue('notepad_id');
				$result = OpenDrive::i()->apiClient()->delete_trashed_notepad($notepad_id);
				break;
			}
		case 'notepad-restore-trashed':
			{
				$notepad_id = postValue('notepad_id');
				$result = OpenDrive::i()->apiClient()->restore_trashed_notepad($notepad_id);
				break;
			}
		case 'notepad-restore-archived':
			{
				$notepad_id = postValue('notepad_id');
				$result = OpenDrive::i()->apiClient()->restore_archived_notepad($notepad_id);
				break;
			}
		case 'notepad-update':
			{
				$notepad_id = postValue('notepad_id');
				$name = postValue('notepad_name');
				
				$result = OpenDrive::i()->apiClient()->update_notepad($notepad_id, $name);
				break;	
			}
		case 'notelist-update-orders':
			{
				if ( isset($_POST['orders']) )
				{
					$new_orders = array_flip(array_filter($_POST['orders']));
					if (sizeof($new_orders)) {
						foreach ($new_orders as $one_key => $one_val) {
							$new_orders[$one_key]++;
						}
					}

					$result = OpenDrive::i()->apiClient()->update_multiple_notelist_order($new_orders);
				}
				break;
			}
		case 'notelist-create':
			{
				$notepad_id = postValue('notepad_id');
				$name = postValue('name');

				$result = OpenDrive::i()->apiClient()->create_notes_list($notepad_id, $name);
				break;
			}
		case 'notelist-update':
			{
				$notelist_id = postValue('notelist_id');
				$name = ( postValue('name')  != '' ) ? postValue('name') : null;
				$order = ( postValue('order')  != '' ) ? postValue('order') : null;
				$color = ( postValue('color')  != '' ) ? postValue('color') : null;
				$size = ( postValue('size')  != '' ) ? postValue('size') : null;
				
				$result = OpenDrive::i()->apiClient()->update_notelist($notelist_id, $name, $order, $color, $size);
				break;
			}
		case 'notelist-archive':
			{
				$notelist_id = postValue('notelist_id');
				$result = OpenDrive::i()->apiClient()->archive_notelist($notelist_id);
				
				break;
			}
		case 'notelist-trash':
			{
				$notelist_id = postValue('notelist_id');
				$result = OpenDrive::i()->apiClient()->trash_notelist($notelist_id);
				
				break;
			}
		case 'notelist-delete':
			{
				$notelist_id = postValue('notelist_id');
				$result = OpenDrive::i()->apiClient()->delete_notelist($notelist_id);

				break;
			}
		case 'notelist-restore-trashed':
			{
				$notelist_id = postValue('notelist_id');
				$result = OpenDrive::i()->apiClient()->restore_trashed_notelist($notelist_id);
				break;
			}
		case 'note-create':
			{
				$notelist_id = postValue('notelist_id');

				$text = postValue('text', null, false);
				$text = strip_tags($text, '<br><i><b><u><em><strong><div>');

				$result = OpenDrive::i()->apiClient()->create_note($notelist_id, $text);
				break;
			}
		case 'note-delete':
			{
				$note_id = postValue('note_id');
				
				$result = OpenDrive::i()->apiClient()->delete_note($note_id);
				break;
			}
		case 'note-update':
			{
				$note_id = postValue('note_id');
				$text = postValue('text', null, false);
				$text = strip_tags($text, '<br><i><b><u><em><strong><div>');
				$status = postValue('status');
				
				$result = OpenDrive::i()->apiClient()->update_note($note_id, $text, $status);
				break;
			}
		case 'empty-notes-trash':
			{
				$result = OpenDrive::i()->apiClient()->empty_notes_trash();
				break;
			}

		case 'notes.search-items':
			$search_query = OpenDrive::postValue('query', null, true, 100);
			if($search_query !== null)
				$result = OpenDrive::i()->apiClient()->notes_search_items($search_query);
			else
				$error = true;
			break;
		break;
			
		case 'sidebar-visible':
			$state = (int)(postValue('state', 0, false, 1) != 0);
			if($state) setcookie('od_sidebar_visible', null, -1, '/');
			else setcookie('od_sidebar_visible', 0, strtotime('+1 day'), '/');
			break;
		case 'trash-empty':
			{
				$result = OpenDrive::i()->apiClient()->trash_empty();
				break;
			}
		case 'trash-file':
			{
				$file_id = postValue('file_id');
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->trash_file($file_id, $sharing_id);
				break;
			}
		case 'files.trash-folder':
			{
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				$folderIds = explode(',', $folder_id);
				foreach($folderIds as &$folder_id) {
					if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				}

				$result = OpenDrive::i()->apiClient()->trash_folder(implode(',', $folderIds), $sharing_id);
				break;
			}
		case 'trash-file-remove':
			{
				$file_id = postValue('file_id');
				$result = OpenDrive::i()->apiClient()->trash_file_remove($file_id);
				break;
			}
		case 'trash-file-restore':
			{
				$file_id = postValue('file_id');
				$result = OpenDrive::i()->apiClient()->trash_file_restore($file_id);
				break;
			}
		case 'trash-folder-remove':
			{
				$folder_id = postValue('folder_id');
				$result = OpenDrive::i()->apiClient()->trash_folder_remove($folder_id);
				break;
			}
		case 'trash-folder-restore':
			{
				$folder_id = postValue('folder_id');
				$result = OpenDrive::i()->apiClient()->trash_folder_restore($folder_id);
				break;
			}
		case 'files.get-file-info':
			{
				$file_id = postValue('file_id');
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->get_file($file_id, $sharing_id);
				break;
			}

		case 'files.get-files-info':
			{
				$file_ids = postArrayValue('file_ids');
				$folder_ids = postArrayValue('folder_ids');
				$sharing_ids = array();
				foreach ($file_ids as $index => $file_id) {
					if (!isset($folder_ids[$index])) continue;
					$sharing_id = '';
					if (strpos($folder_ids[$index], '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_ids[$index]);
					$sharing_ids[$index] = $sharing_id;
				}
				$result = OpenDrive::i()->apiClient()->get_files_info($file_ids, $sharing_ids);
				if(!OpenDrive::i()->apiClient()->error) {
					foreach($result as &$file) \od_includes\OpenDriveFiles::setFileType($file);
				} else $result = array();
				break;
			}
		case 'files.file-versions':
			{
				$file_group_id = postValue('file_group_id');
				$result = OpenDrive::i()->apiClient()->get_file_versions($file_group_id);
				if(!OpenDrive::i()->apiClient()->error){
					\od_includes\OpenDriveFiles::formatFileVersions($result);
				}
				break;
			}
		case 'remove-file-version':
			{
				$file_id = postValue('file_id');
				$result = OpenDrive::i()->apiClient()->remove_file_version($file_id);
				break;
			}
		case 'users.get-group':
			{
				$group_id = postValue('group_id');
				$result = OpenDrive::i()->apiClient()->get_group($group_id);
				break;
			}
		case 'files.get-folder-info':
			{
				$folder_id = postValue('folder_id');
				$parent_folder_id = postValue('parent_folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->get_folder($folder_id, $sharing_id);
				break;
			}
		case 'create-file':
			{
				$folder_id = postValue('folder_id');
				$file_type = postValue('file_type');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->create_file($folder_id, $file_type, $sharing_id);
				break;
			}
		case 'files.update-file':
			{
				$file_id = postValue('file_id');
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$file_price = postValue('file_price');
				$file_name = postValue('file_name');
				$file_description = postValue('file_description');
				$file_password = postValue('file_password', null, false);
				$file_dest_url = postValue('file_dest_url');
				$file_ispublic = postValue('file_ispublic');
				$file_edit_online = postValue('file_edit_online');

				$result = OpenDrive::i()->apiClient()->update_file($file_id, $file_price, $file_name, $file_description, $file_password, $file_dest_url, $file_ispublic, $file_edit_online, $sharing_id);
				break;
			}
		case 'send-by-email':
			{
				$send_item_id = postValue('send_item_id');
				$send_item_type = postValue('send_item_type');
				$send_email = postValue('send_email');
				$send_subject = postValue('send_subject');
				$send_message = postValue('send_message');
				$captcha_response = postValue('captcha_response');
				$send_expiring_enabled = postValue('send_expiring_enabled');
				switch ($send_item_type) {
					case 'file':
						$result = OpenDrive::i()->apiClient()->send_file_by_email($send_item_id, $send_email, $send_subject, $send_message, $captcha_response, $send_expiring_enabled);
						break;
					case 'folder':
						$result = OpenDrive::i()->apiClient()->send_folder_by_email($send_item_id, $send_email, $send_subject, $send_message, $captcha_response, $send_expiring_enabled);
						break;
				}

				break;
			}
		case 'create-folder':
			{
				$folder_name = postValue('folder_name');
				$folder_sub_parent = postValue('folder_sub_parent');
				$folder_is_public = postValue('folder_is_public');
				$folder_public_upl = postValue('folder_public_upl');
				$folder_public_display = postValue('folder_public_display');
				$folder_public_dnl = postValue('folder_public_dnl');
				$folder_description = postValue('folder_description');
				$folder_display_subfolders = postValue('folder_display_subfolders');

				$result = OpenDrive::i()->apiClient()->create_folder($folder_name, $folder_sub_parent, $folder_is_public, $folder_public_upl, $folder_public_display, $folder_public_dnl, $folder_description, $folder_display_subfolders);
				if(!OpenDrive::i()->apiClient()->error && postValue('load_subfolders'))
				{
					$folder_content = OpenDrive::i()->apiClient()->get_folder_content($folder_sub_parent, null, true);

					$folders = array();
					if ( isset($folder_content->Folders) ) $folders = $folder_content->Folders;

					$result->SubFolders = $folders;
				}
				break;
			}
		case 'files.update-folder':
			{
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$folder_name = postValue('folder_name');
				$folder_description = postValue('folder_description');
				$folder_access = postValue('folder_access');
				$folder_public_upl = postValue('folder_public_upl');
				$folder_public_display = postValue('folder_public_display');
				$folder_public_dnl = postValue('folder_public_dnl');
				$folder_display_subfolders = postValue('folder_display_subfolders');

				$result = OpenDrive::i()->apiClient()->update_folder($folder_id, $folder_name, $folder_description, $folder_access, $folder_public_upl, $folder_public_display, $folder_public_dnl, $folder_display_subfolders, $sharing_id);
				break;
			}
		case 'files.rename-folder':
			{
				$folder_name = postValue('folder_name');
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->rename_folder($folder_id, $folder_name, $sharing_id);
				break;
			}
		case 'files.rename-file':
			{
				$file_name = postValue('file_name');
				$file_id = postValue('file_id');
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->rename_file($file_id, $file_name, $sharing_id);
				break;
			}
		case 'files.move-file':
			{
				$src_file_id = postValue('src_file_id');
				$dest_folder_id = postValue('dest_folder_id');

				$result = OpenDrive::i()->apiClient()->copy_move_file($src_file_id, $dest_folder_id, true);
				break;
			}
		case 'files.move-folder':
			{
				$src_folder_id = postValue('src_folder_id');
				$dest_folder_id = postValue('dest_folder_id');

				$result = OpenDrive::i()->apiClient()->copy_move_folder($src_folder_id, $dest_folder_id, true);
				break;
			}
		case 'files.copy-file':
			{
				$src_file_id = postValue('src_file_id');
				$dest_folder_id = postValue('dest_folder_id');

				$result = OpenDrive::i()->apiClient()->copy_move_file($src_file_id, $dest_folder_id, false);
				break;
			}
		case 'files.copy-folder':
			{
				$src_folder_id = postValue('src_folder_id');
				$dest_folder_id = postValue('dest_folder_id');

				$result = OpenDrive::i()->apiClient()->copy_move_folder($src_folder_id, $dest_folder_id, false);
				break;
			}

		case 'files.list-trash':
			$trashInfo = OpenDrive::i()->apiClient()->get_trash_folder_content(1);
			if(!OpenDrive::i()->apiClient()->error){
				$result['ItemsCount'] = $trashInfo->FilesCount + $trashInfo->FoldersCount;
			}
		break;

		case 'folder-files-links':
			{
				$folder_id = postValue('folder_id');
				$sharing_id = null;
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$result = OpenDrive::i()->apiClient()->get_folder_content($folder_id, null, null, null, null, null, $sharing_id);

				if (!OpenDrive::i()->apiClient()->error) {
					$files_urls = array();
					$files_direct_urls = array();

					if (isset($result->Files) && $result->Files) {
						foreach ($result->Files as $one_file) {
							if ($one_file->DownloadLink !== 'n/a') $files_urls[] = $one_file->DownloadLink;
							if ($one_file->StreamingLink !== 'n/a')  $files_direct_urls[] = $one_file->StreamingLink;
						}
					}

					$result = array(
						'files_urls' => $files_urls,
						'files_direct_urls' => $files_direct_urls,
						'folder_link' => $result->DirectFolderLink
					);
				}

				break;
			}
        case 'file-expiring-links':
        {
            $file_id = postValue('file_id');
            $result = OpenDrive::i()->apiClient()->get_file_expiring_links($file_id);
            break;
        }
        case 'folder-expiring-links':
        {
            $folder_id = postValue('folder_id');
            $result = OpenDrive::i()->apiClient()->get_folder_expiring_links($folder_id);
            break;
        }
		case 'files.list-folder':
			{
				$folder_id = postValue('folder_id');
				$sharing_id = postValue('sharing_id');
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$with_breadcrumbs = postValue('with_breadcrumbs', null, false);
				$only_subfolders = postValue('only_subfolders', null, false);
				$search_query = postValue('search_query', null, false);
				if($folder_id === 'shared_users') {
					$result = OpenDrive::i()->apiClient()->list_shared_users();
				} else {
					if ($sharing_id) {
						$share_info = OpenDrive::itemDecode($sharing_id);
						if ($share_info) {
							if ($share_info[1] == '0') {
								$result = OpenDrive::i()->apiClient()->list_shared_folders($sharing_id);
							} else {
								$result = OpenDrive::i()->apiClient()->get_folder_content(
									$folder_id, $search_query, true, null, null, null, $sharing_id
								);
							}
						}
					} else {
						$result = OpenDrive::i()->apiClient()->get_folder_content(
							$folder_id, $search_query, $only_subfolders, $with_breadcrumbs
						);
					}

				}
				break;
			}

		case 'files.load-folder-content':
				$folder_id = postValue('folder_id');
				$sharing_id = postValue('sharing_id');
				if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
				$offset = postValue('offset');
				$last_request_time = postValue('last_request_time');
				$with_breadcrumbs = postValue('with_breadcrumbs', null, false);
				$only_subfolders = postValue('only_subfolders', null, false);
				$search_query = postValue('search_query', null, false);
				$public_folder = postValue('public');
			    $order_by = postValue('order_by');
				if(!$order_by) $order_by = null;
				$order_type = postValue('order_type');
				if(!$order_type) $order_type = null;
				switch($folder_id) {
					case 'trash':
						$result = OpenDrive::i()->apiClient()->get_trash_folder_content(0, $last_request_time, $offset, $order_by, $order_type);
						if (!OpenDrive::i()->apiClient()->error) {
							\od_includes\OpenDriveFiles::formatFolderContent($result, $folder_id, $search_query);
						}
						break;

					case 'shared_users':
						$result = OpenDrive::i()->apiClient()->list_shared_users();
						if (!OpenDrive::i()->apiClient()->error) {
							\od_includes\OpenDriveFiles::formatSharedUsers($result);
						}
						break;

					default:
						if ($public_folder) {
							$result = OpenDrive::i()->apiClient()->get_shared_folder_content(
								$folder_id, $with_breadcrumbs, $last_request_time, $offset, $order_by, $order_type
							);

							if (!OpenDrive::i()->apiClient()->error) {
								\od_includes\OpenDriveFiles::formatFolderContent($result, $folder_id, $search_query);
							}
						} else {
							if ($sharing_id) {
								$share_info = OpenDrive::itemDecode($sharing_id);
								if ($share_info) {
									if ($share_info[1] == '0') {
										$result = OpenDrive::i()->apiClient()->list_shared_folders($sharing_id);
										if (!OpenDrive::i()->apiClient()->error) {
											\od_includes\OpenDriveFiles::formatSharedFolders($result);
										}
									} else {
										$result = OpenDrive::i()->apiClient()->get_folder_content(
											$folder_id, $search_query, false, $with_breadcrumbs, $last_request_time, $offset, $sharing_id, $order_by, $order_type);
										if (!OpenDrive::i()->apiClient()->error) {
											\od_includes\OpenDriveFiles::formatFolderContent($result, $folder_id, $search_query);
										}
									}
								}
							} else {
								$result = OpenDrive::i()->apiClient()->get_folder_content(
									$folder_id, $search_query, $only_subfolders, $with_breadcrumbs, $last_request_time, $offset, null, $order_by, $order_type);
								if (!OpenDrive::i()->apiClient()->error) {
									\od_includes\OpenDriveFiles::formatFolderContent($result, $folder_id, $search_query);
								}
							}
						}
				}

		break;
		case 'account-user-folders-list':
			$folder_id = postValue('folder_id');
			$email = postValue('email');
			$folder_content = OpenDrive::i()->apiClient()->get_account_user_folders($email, $folder_id);
			if (!OpenDrive::i()->apiClient()->error) {
				$folders = $folder_content->Folders;
				$result = array('folders' => $folders);
			}

			break;

		case 'files.set-view-mode':
			{
				$view_mode = postValue('view_mode');
				if($view_mode === 'grid' || $view_mode === 'list') setcookie('view_mode', $view_mode, time()+31536000, '/');
				break;
			}

		case 'set-folder-access':
			{
				$access_email = postValue('access_email');
				$foldersObj = postArrayValue('foldersObj');
				$update = postValue('update');

				$result = OpenDrive::i()->apiClient()->set_folder_access($access_email, $foldersObj, $update);
				break;
			}
		case 'create-accessuser':
			{
				$access_first_name = postValue('access_first_name');
				$access_last_name = postValue('access_last_name');
				$access_password = postValue('access_password', null, false);
				$access_email = postValue('access_email');
				$access_admin_mode = postValue('access_admin_mode');
				$access_admin_mode = $access_admin_mode === null ? false : (int)postValue('access_admin_mode');
				$access_notification = (int)postValue('access_notification');
				$access_max_storage = (float)postValue('access_max_storage');
				$access_bw_max = (float)postValue('access_bw_max');
				$group_id = (int)postValue('group_id');
				$access_phone = postValue('access_phone');
				$access_password_change = postValue('access_password_change');
				$access_position = postValue('access_position');
				$access_send_password = postValue('access_send_password');

				$result = OpenDrive::i()->apiClient()->create_access_user($access_first_name, $access_last_name, $access_password, $access_email, $access_admin_mode, $access_notification, $access_max_storage, $access_bw_max, $group_id, $access_phone, $access_password_change, $access_position, $access_send_password );
				break;
			}

		case 'edit-accessuser':
			{
				$access_first_name = ( postValue('access_first_name') ) ? postValue('access_first_name') : false;
				$access_last_name = ( postValue('access_last_name') ) ? postValue('access_last_name') : false;
				$access_password = ( postValue('access_password') ) ? postValue('access_password') : false;
				$access_email = ( postValue('access_email') ) ? postValue('access_email') : false;
				$new_access_email = ( postValue('new_access_email') ) ? postValue('new_access_email') : false;
				$access_admin_mode = postValue('access_admin_mode');
				$access_admin_mode = $access_admin_mode === null ? false : (int)postValue('access_admin_mode');
				$access_notification = postValue('access_notification', false);
				$access_notification = $access_notification === false ? false : (int)postValue('access_notification');
				$access_max_storage = ( postValue('access_max_storage') ) ? (float)postValue('access_max_storage') : false;
				$access_bw_max = ( postValue('access_bw_max') ) ? (float)postValue('access_bw_max') : false;
				$access_phone = ( postValue('access_phone') ) ? (int)postValue('access_phone') : false;
				$access_password_change = postValue('access_password_change');
				$access_position = ( postValue('access_position') ) ? postValue('access_position') : false;

				$access_admin_level = postValue('access_admin_level');
				$access_admin_level = $access_admin_level === null ? false : (int)$access_admin_level;

				$result = OpenDrive::i()->apiClient()->edit_access_user($access_first_name, $access_last_name, $access_password, $access_password_change, $access_email, $new_access_email, $access_admin_mode, $access_notification, $access_max_storage, $access_bw_max, $access_phone, $access_position, $access_admin_level);
				break;
			}
		case 'delete-avatar':
			{
				$image_type = postValue('image_type', 'user');
				$result = OpenDrive::i()->apiClient()->delete_avatar($image_type);
				break;
			}
		case 'delete-usergroup':
			{
				$group_id = postValue('group_id');

				$result = OpenDrive::i()->apiClient()->delete_user_group($group_id);
				break;
			}
		case 'create-usergroup':
			{
				$group_name = postValue('group_name');
				$group_bw_max = postValue('group_bw_max');
				$group_max_storage = postValue('group_max_storage');
                $group_settings_enable = postValue('group_settings_enable');

				$result = OpenDrive::i()->apiClient()->create_user_group($group_name, $group_bw_max, $group_max_storage);
				break;
			}
		case 'edit-usergroup':
			{
				$group_id = postValue('group_id');
				$group_name = postValue('group_name');
				$group_bw_max = postValue('group_bw_max');
				$group_max_storage = postValue('group_max_storage');
$group_settings_enable = postValue('group_settings_enable');
				$result = OpenDrive::i()->apiClient()->edit_user_group($group_id, $group_name, $group_bw_max, $group_max_storage, $group_settings_enable);
				break;
			}
		case 'files.check-file-exists':
			$sharing_id = null;
			$folder_id = postValue('folder_id');
			if (strpos($folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $folder_id);
			$result = OpenDrive::i()->apiClient()->check_file_exists_in_folder($folder_id, postArrayValue('filenames'), $sharing_id);
			break;
		case 'user-set-access':
			{
				$access_email = postValue('access_email');
				$access_active = postValue('access_active');

				$result = OpenDrive::i()->apiClient()->account_user_set_access($access_email, $access_active);
				break;
			}
		case 'user-delete':
			{
				$access_email = postValue('access_email');
				$result = OpenDrive::i()->apiClient()->account_user_delete($access_email);
				break;
			}

		case 'admin.reset-secure-files-password':
			$user_id = postValue('user_id');
			$result = OpenDrive::i()->apiClient()->admin_reset_secure_files_password($user_id);
			break;

		case 'admin.get-last-user-notes':
			{
				$user_id = (int)postValue('user_id');
				$notes = OpenDrive::i()->apiClient()->get_user_notes($user_id, 5, 'desc');
				if(!OpenDrive::i()->apiClient()->error && is_array($notes)) {
					foreach ( $notes as $note_key => $one_note)
					{
						$notes[$note_key]['note_date'] = OpenDrive::formatTimeTZ($one_note['note_time'], 'M d, Y');
					}
					$result = $notes;
				}
				else $result = array();
				break;
			}

		case 'admin.blacklist-file':
			$user_id = postValue('user_id', null, false);
			$file_id = postValue('file_id', null, false);

			$result = OpenDrive::i()->apiClient()->admin_blacklist_file($user_id, $file_id);
			if (!OpenDrive::i()->apiClient()->error) {

				$result = OpenDrive::i()->apiClient()->admin_get_user_info($user_id, $file_id);
				if (!OpenDrive::i()->apiClient()->error) {
					$result = \od_includes\OpenDriveAdmin::formatUserInfo($result, false, false, false);
				}
			}
			break;

		case 'admin.block-file':
			$user_id = postValue('user_id', null, false);
			$file_id = postValue('file_id', null, false);

			$result = OpenDrive::i()->apiClient()->admin_block_file($user_id, $file_id);
			if (!OpenDrive::i()->apiClient()->error) {

				$result = OpenDrive::i()->apiClient()->admin_get_user_info($user_id, $file_id);
				if (!OpenDrive::i()->apiClient()->error) {
					$result = \od_includes\OpenDriveAdmin::formatUserInfo($result, false, false, false);
				}
			}
			break;

        case 'admin.blacklist-user':
            $result = OpenDrive::i()->apiClient()->admin_blacklist_user(
                postValue('user_id'),
                postValue('user_email'),
                postValue('user_last_login_ip'),
                postValue('user_registration_ip'),
                postValue('user_all_transactions_ip')
            );
            break;

		case 'admin.load-users-stat':
			$start_date = OpenDrive::postValue('start_date');
			$stat_type = OpenDrive::postValue('stat_type');
			$date = $start_date ? OpenDrive::i()->parseLocalTime($start_date, true) : null;
			if ($start_date) {
				$result = OpenDrive::i()->apiClient()->admin_get_users_stat(
					$date->format('Y'),
					$date->format('m'),
					$date->format('d'),
					$stat_type
				);
				if (!OpenDrive::i()->apiClient()->error) {
					foreach ($result['users'] as &$r) {
						$r['acc_type'] = \OpenDrive::i()->getAccountType($r['acc_type'], true);
						$r['suspended'] = $r['suspended'] > 0 ? '<span class="suspended">(' . __('Suspended', 'opendrive') . ')</span>' : '';
					}
				}
			} else {
				$error = true;
			}

			break;

		case 'get_user_avatar':
			{
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->get_avatar('user', 0, 0, $user_id);
				break;
			}
		case 'get-account-user':
			{
				$access_email = postValue('access_email');

				$result = OpenDrive::i()->apiClient()->get_account_user($access_email);
				if( isset($result->AccessUserID) )
				{
					$result->Avatar = OpenDrive::i()->apiClient()->get_avatar('account_user', 0, $result->AccessUserID);
				}

				break;
			}
		case 'move-account-user':
			{
				$access_email = postValue('access_email');
				$group_id = (int)postValue('dest_group_id');

				$result = OpenDrive::i()->apiClient()->move_account_user($access_email, $group_id);

				break;
			}
		case 'load-stat':
			$month = date('n');
			$year = date('Y');
			$selectedDate = explode('/', postValue('monthselector-date'));

			if ( count($selectedDate) == 2 ) list($month, $year) = $selectedDate;

			$stat = OpenDrive::i()->apiClient()->get_user_bw_stats($month, $year);

			if(!OpenDrive::i()->apiClient()->error){
				$result['up_num_dataset'] = $stat['up_num_dataset'];
				$result['dl_num_dataset'] = $stat['dl_num_dataset'];
				$result['upload_bw_dataset'] = $stat['upload_bw_dataset'];
				$result['download_bw_dataset'] = $stat['download_bw_dataset'];
				$result['montly_uploaded'] = $stat['montly_uploaded'];
				$result['montly_downloaded'] = $stat['montly_downloaded'];
				$result['dataset_keys'] = array_keys($result['up_num_dataset']);
			} else
				$error = true;
		break;

		case 'admin-monthly-load-stat':
			$month = date('n');
			$year = date('Y');
			$partner_id = postValue('item_id');
			$selectedDate = explode('/', postValue('monthselector-date'));

			if ( count($selectedDate) == 2 ) list($month, $year) = $selectedDate;

			$stat = OpenDrive::i()->apiClient()->admin_get_partner_stats($year, $month, $partner_id, 'monthly');

			if(!OpenDrive::i()->apiClient()->error){
				$result = $stat;
				$result['dataset_keys'] = array_keys($result['up_num_dataset']);
			} else
				$error = true;
		break;

		case 'check-user-subdomain-exists':
			$result = OpenDrive::i()->apiClient()->check_user_subdomain_exists(postValue('subdomain', null, false));

		break;

		case 'admin.profile-recalculate-space':
			{
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->profile_recalculate_space($user_id);

				break;
			}
		case 'profile-reset-bw':
			{
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->profile_reset_bw($user_id);

				break;
			}
		case 'profile_trash_files':
			{
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->profile_trash_files($user_id);
				break;
			}
		case 'suspend-user':
			{
				$result = OpenDrive::i()->apiClient()->admin_suspend_user(postValue('user_id'));
				break;
			}
		case 'unsuspend-user':
			{
				$user_id = postValue('user_id');

				$update_users_array = array("user_id" => $user_id, "suspended" => 0);
				$result = OpenDrive::i()->apiClient()->admin_update_user_info($update_users_array);
				break;
			}
		case 'close-user':
			{
				$user_id = postValue('user_id');
				$result = OpenDrive::i()->apiClient()->admin_close_user_account($user_id);
				break;
			}
		case 'admin.update-user-info':
			{
				$data = array();
				$data['user_id'] = postValue('user_id', null, false);
				$data['passwd'] = postValue('passwd', null, false);
				$data['verify_passwd'] = postValue('verify_passwd', null, false);
				$data['email'] = postValue('email');
				$data['first_name'] = postValue('first_name');
				$data['last_name'] = postValue('last_name');
				$data['level'] = postValue('level');
				$data['company_name'] = postValue('company_name');
				$data['phone'] = postValue('phone');
				$data['acc_type'] = postValue('acc_type');
				$data['storage_max'] = postValue('storage_max');
				$data['bw_max'] = postValue('bw_max');
				$data['file_versioning'] = postValue('file_versioning');
				$data['file_versions'] = postValue('file_versions');
				$data['account_users'] = postValue('account_users');
				$data['bw_reset_period'] = postValue('bw_reset_period');
				$data['trial'] = postValue('trial');
				$data['suspended'] = postValue('suspended');
				$data['next_billing'] = postValue('next_billing');
				$data['next_billing'] = $data['next_billing'] == 'n/a' ? 0 : (int)strtotime($data['next_billing']);
				$data['close_reason'] = postValue('close_reason');
				$data['close_reason_text'] = postValue('close_reason_text');
				$data['web_link'] = postValue('web_link');
				$data['address_1'] = postValue('address_1');
				$data['address_2'] = postValue('address_2');

				if ( $data['storage_max'] === 'UNL') unset($data['storage_max']);
				if ( $data['bw_max'] === 'UNL') unset($data['bw_max']);

				$result = OpenDrive::i()->apiClient()->admin_update_user_info($data);
				if (!OpenDrive::i()->apiClient()->error) {
					$result = \od_includes\OpenDriveAdmin::formatUserInfo($result, false, false, false);
				}
				break;
			}
		case 'add-user-note':
			{
				$user_id = (int)postValue('user_id');
				$note_text = postValue('note_text');

				$result = OpenDrive::i()->apiClient()->add_user_note($user_id, $note_text);
				break;
			}

		case 'admin.get-user':
			$user_id = postValue('user_id', null, false);
			$file_id = postValue('file_id', null, false);
			$with_cc = postValue('user_cc');
			$CCList = false;
			$last_notes = postValue('last_notes');
			$result = OpenDrive::i()->apiClient()->admin_get_user_info($user_id, $file_id);

			if(!OpenDrive::i()->apiClient()->error) {
				$notes = false;
				if ($last_notes) {
					$notes = \OpenDrive::i()->apiClient()->get_user_notes($user_id, 5, 'desc');
					if (\OpenDrive::i()->apiClient()->error) $notes = false;
				}
				if(OpenDrive::isExtensionPluginActive()) {
					$transactions = \OpenDriveExtension::i()->apiClient()->get_user_transactions($user_id);

					if (\OpenDrive::i()->apiClient()->error) $transactions = false;
					else $transactions = $transactions['Transactions'];
				} else {
					$transactions = false;
				}

				if($with_cc && OpenDrive::isExtensionPluginActive()) {
					$CCList = \OpenDriveExtension::i()->apiClient()->admin_get_user_credit_cards($user_id, true);
					if (\OpenDriveExtension::i()->apiClient()->error) $CCList = false;
				}

				$result = \od_includes\OpenDriveAdmin::formatUserInfo($result, $notes, $transactions, $CCList);
			}
			break;
        case 'settings.2FA':
            $email=postValue('email');
            $user = postValue('id');
            $country = postValue('authy-countries');
            $cellphone = postValue('authy-cellphone');
            $result = OpenDrive::i()->apiClient()->enable2fa($email, $country, $cellphone);
            if (!OpenDrive::i()->apiClient()->error) {
                $result->message = __('Two factor authentication enabled', 'opendrive');
            }


            break;
        case 'settings.2FA-disable':
            $result = OpenDrive::i()->apiClient()->disable2fa();
            if (!OpenDrive::i()->apiClient()->error) {
                $result->message = __('Two factor authentication disabled', 'opendrive');
            }


            break;
        case 'settings.2FA-auth':
            $user_token = postValue('authy_token');
            $result = OpenDrive::i()->apiClient()->authy_login($user_token);
            if (!OpenDrive::i()->apiClient()->error) {
                $result->message = __('Authorized', 'opendrive');
            }


            break;

		case 'admin.send-trial-reminder':
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->admin_send_trial_reminder($user_id);
				break;

		case 'admin.send-payment-reminder':
				$user_id = (int)postValue('user_id');
				$result = OpenDrive::i()->apiClient()->admin_send_payment_reminder($user_id);
				break;
		case 'admin.add-new-payment':
				$result = OpenDrive::i()->apiClient()->admin_add_payment(
					postValue('user_id'),
					strtotime(postValue('trans_date')),
					postValue('processor'),
					postValue('amount'),
					postValue('trans_status'),
					postValue('cc'),
					strtotime(postValue('due_date')),
					postValue('trans_id'),
					postValue('note'));
			break;
			
			
		case 'admin.load-user-logs':
			{
				$user_id = postValue('user_id');
				$user_info = OpenDrive::i()->getUserInfo();

				$activity_start_date = postValue( 'start_date', strtotime('-1 day'));
				if(is_string($activity_start_date))$activity_start_date = strtotime($activity_start_date);
				$activity_end_date = postValue('end_date', time());
				if(is_string($activity_end_date))$activity_end_date = strtotime($activity_end_date);
				$activity_log_type = (int)postValue( 'log_type', 0);
				
				$params = array('start_date' => $activity_start_date, 'end_date' => $activity_end_date);
				if ( $activity_log_type ) $params['log_type'] = $activity_log_type;

				$logs = OpenDrive::i()->apiClient()->get_admin_user_logs($user_id, $params);
				if(OpenDrive::i()->apiClient()->error) {
					$error = true;
				} else {
					$logs = $logs->Logs;
					ob_start();
					if ( sizeof($logs) > 0 )
					{
						?>
						<div class="settings col-md-12 col-sm-12">
								<div class="settings-row col-md-12 heading-row">
									<div class="settings-row-time col-md-2"><h3><?php _e('Time', 'opendrive')?></h3></div>
									<div class="settings-row-user col-md-2"><h3><?php _e('User', 'opendrive')?></h3></div>
									<div class="settings-row-logtype col-md-1"><h3><?php _e('Log Type', 'opendrive')?></h3></div>
									<div class="settings-row-ip col-md-1"><h3><?php _e('IP', 'opendrive')?></h3></div>
									<div class="settings-row-name col-md-2"><h3><?php _e('Name', 'opendrive')?></h3></div>
									<div class="settings-row-filesize col-md-1"><h3><?php _e('File Size', 'opendrive')?></h3></div>
									<div class="settings-row-details col-md-2"><h3><?php _e('Details', 'opendrive')?></h3></div>
									<div class="settings-row-app col-md-1"><h3><?php _e('App', 'opendrive')?></h3></div>
								</div>
								<?php
								foreach ($logs as $one_log)
								{
										?>
										<div class="settings-row col-md-12">
											<div class="settings-row-time col-md-2">
												<?php echo convert_to_user_date(date('M d, Y, h:ia', $one_log->Time), 'M d, Y, h:ia', $user_info->TimeZone);?>
											</div>
											<div class="settings-row-user col-md-2">
											   <?php echo esc_html($one_log->User);?>
											</div>
											<div class="settings-row-logtype col-md-1" title="<?php echo $one_log->LogType?>">
											   <?php echo esc_html($one_log->LogType)?>
											</div>
											<div class="settings-row-ip col-md-1">
												<?php echo esc_html($one_log->IP)?>
											</div>
											<div class="settings-row-name col-md-2" title="<?php esc_attr_e($one_log->FileName)?>">
												<div class="ellipsis_overflow"><?php echo esc_html($one_log->FileName);?></div>
											</div>
											<div class="settings-row-filesize col-md-1">
												<?php
												if ( $one_log->FileSize != '' )
												{
													echo size_format($one_log->FileSize, 1);
												}
												?>
											</div>
											<div class="settings-row-details col-md-2">
												<?php echo esc_html($one_log->Details);?>
											</div>
											<div class="settings-row-app col-md-1">
												<?php echo esc_html($one_log->App)?>
											</div>
										</div>
										<?php
								}
								?>
						</div>
						<?php
					} else {
					?>
						<div class="col-md-12 table-notice"><?php _e('No log records found.', 'opendrive')?></div>
					<?php
					}
					$result['Logs'] = ob_get_clean();
				}

				break;
			}
		case 'admin.load-notes':
			$user_id = (int)postValue('user_id');
			$notes = OpenDrive::i()->apiClient()->get_user_notes($user_id, 0);
			if(!OpenDrive::i()->apiClient()->error) {
					$notes = array_reverse($notes);
					foreach ($notes as &$note) {
						$note['note_time'] = OpenDrive::formatTimeTZ($note['note_time'], 'M d, Y h:i a');
					}
				$result['Notes'] = $notes;
			}
			break;

		case 'admin.load-account-history':
				$plans_history =  OpenDrive::i()->apiClient()->admin_get_plans_history(postValue('user_id'));
				$plan_history_types = OpenDrive::i()->getConfigItem('plan_history_types');
				if(!OpenDrive::i()->apiClient()->error && is_array($plans_history))
					foreach ($plans_history as &$one_plan){
						$one_plan['plan_date'] = OpenDrive::formatTimeTZ($one_plan['plan_date'], 'M d, Y H:i');
						$one_plan['plan_name'] = OpenDrive::i()->getPlanName($one_plan['level']);
						$one_plan['acc_type_name'] = OpenDrive::i()->getAccountType($one_plan['acc_type'], true);
						$one_plan['od_max_storage'] = od_size_format($one_plan['od_max_storage'] * 1048576, true);
						$one_plan['bw_max'] = od_size_format($one_plan['bw_max'] * 1048576, true);
						if(isset($plan_history_types[$one_plan['type']])) $one_plan['type'] = $plan_history_types[$one_plan['type']];
					}

					$result = $plans_history;

				break;
        case 'admin.load-user-files-stat':
            $result =  OpenDrive::i()->apiClient()->admin_get_user_files_stat(postValue('user_id'));
            break;

		case 'admin.get-account-users':
            $users = OpenDrive::i()->apiClient()->admin_get_account_users(postValue('user_id'));
            if (!OpenDrive::i()->apiClient()->error)
            {
                $result['AccountUsers'] = \od_includes\OpenDriveAdmin::formatAccountUsersList($users);
            }
            break;

		case 'load-logs':
			$page = (int)postValue('page');
			$activity_user_id = postValue('activity_user_id');
			$activity_start_date = OpenDrive::i()->parseLocalTime(postValue('activity_start_date'));
			$activity_end_date = OpenDrive::i()->parseLocalTime(postValue('activity_end_date'));
			$activity_log_type = (int)postValue('activity_log_type');
			$result = OpenDrive::i()->apiClient()->get_user_logs($activity_user_id, $activity_start_date, $activity_end_date, $activity_log_type, $page, true);
			if (!OpenDrive::i()->apiClient()->error) {
				foreach ($result['Logs'] as &$log) {
					$log['Time'] = OpenDrive::i()->formatTimeUserTZ($log['Time'], 'M d, Y, h:ia');
					$log['FileSize'] = $log['FileSize'] > 0 ? size_format($log['FileSize'], 1) : '';
				}
			}
			break;

		case 'forgot-change-password':
			$newPass = OpenDrive::postValue('password', null, false);
			$tempPass = OpenDrive::postValue('temp_password', null, false);
			$newPassConfirm = OpenDrive::postValue('confirm_password', null, false);

			if ($newPass !== $newPassConfirm ) {
				$result = array( 'error' => array('message'=> __('The passwords does not match', 'opendrive')) );
			} else $result = OpenDrive::i()->apiClient()->user_update_password($newPass, $tempPass);
		break;

		case 'files.trash_list':
			$result = OpenDrive::i()->apiClient()->get_trash_folder_content(1);
		break;

		case 'admin.load-users':
			$items_on_page = (int)postValue('items_on_page');
			$page = (int)postValue('page');
			$user_type = postValue('user_type');
			if(!$user_type) $user_type = 'all';
			$due_filter = postValue('due_filter');
			$suspended_filter = postValue('suspended');
			$search_term = postValue('search', '', false, 100);
			$order_by = postValue('order_by');
			$items_on_page_values = array(10, 25, 50, 100, 1000);

			if(!in_array($items_on_page, $items_on_page_values)) $items_on_page = 25;
			if($page < 1) $page = 1;
			if(!$suspended_filter) $suspended_filter = 'all';

			$order_by_field = false;
			$order_by_asc = false;
			if ($order_by) {
				list($order_by_field, $order_by_asc) = explode('__', $order_by);
			}

			$query_array = array('items_on_page' => $items_on_page, 'page' => $page, 'filter' => $user_type);
			if ($search_term != '') {
				$query_array['search_query'] = $search_term;
			} else {
				if ($order_by_field != '') {
					$query_array['order'] = $order_by_asc;
					$query_array['order_by'] = $order_by_field;
				}

				if ($due_filter != '' && ($user_type == 'premium' || $user_type == 'trials')) {
					$query_array['search_by'] = 'due_date';
					switch ($due_filter) {
						case 'today':
							$query_array['search_query'] = strtotime('today');
							break;
						case 'tomorrow':
							$query_array['search_query'] = strtotime('tomorrow');
							break;
						case 'all':
							$query_array['search_query'] = 0;
							break;
						case 'past':
							$query_array['search_query'] = -strtotime('today');
							break;
						default:
							$query_array['search_query'] = (int)strtotime($due_filter);
					}
					if (!$query_array['search_query']) $due_filter = 'all';
				}
				if ($user_type == 'suspended' && $suspended_filter == 'm90')
					$query_array['filter'] = 'suspended_90d';
			}

			switch ($due_filter) {
				case 'today':
					$dueFilterText = __('Due today', 'opendrive');
					break;
				case 'tomorrow':
					$dueFilterText = __('Due tomorrow', 'opendrive');
					break;
				case 'all':
					$dueFilterText = __('All due', 'opendrive');
					break;
				case 'past':
					$dueFilterText = __('Past Due', 'opendrive');
					break;
				default:
					$dueFilterText = __('Due', 'opendrive'). ' ' . $due_filter;
			}
			$suspendedFilterText = '';
			if ($suspended_filter == 'all') $suspendedFilterText = __('All', 'opendrive');
			else if ($suspended_filter == 'm90') $suspendedFilterText = __('More than 90 days', 'opendrive');

			$result = OpenDrive::i()->apiClient()->admin_get_all_users($query_array);
			if(!OpenDrive::i()->apiClient()->error) {
				$result = array(
					'UsersHtml' => \od_includes\OpenDriveAdmin::formatUsersList(
						$result, $items_on_page, $items_on_page_values, $order_by_field, $order_by_asc, $page,
						$user_type, $search_term
					),
					'Breadcrumbs' => array(
						'DueFilterText' => $dueFilterText,
						'SuspendedFilterText' => $suspendedFilterText,
						'TotalUsersCount' => isset($result['TotalUsers']) ? $result['TotalUsers'] : 0
					)
				);
			}
		break;

		//-- TASKS --

		case 'tasks.search-items':
			$search_query = OpenDrive::postValue('query', null, true, 100);
			if($search_query !== null)
				$result = OpenDrive::i()->apiClient()->tasks_search_items($search_query);
			else
				$error = true;
			break;

		//Project list
		case 'tasks.projects-list':
			$with_projects = ( postValue('with_projects') && postValue('with_projects') == 1 ) ? true : false;
			$filter = postValue('filter');
			$result = OpenDrive::i()->apiClient()->tasks_get_project_lists($with_projects, null, null, $filter);
			break;

		case 'tasks.new-project-list':
			$result = OpenDrive::i()->apiClient()->tasks_add_projects_list('New project list');
			$error = OpenDrive::i()->apiClient()->error;
		break;

		case 'tasks.update-project-list':
			$name = trim(postValue('list_name'));
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_update_projects_list($list_id, $name);
		break;

		case 'tasks.archive-project-list':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_archive_project_list($list_id);
		break;

		case 'tasks.trash-project-list':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_project_list($list_id);
		break;

		//Project
		case 'tasks.add-project':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_add_project($list_id, 'New Project');
		break;

		case 'tasks.add-project-permission':
			$project_id = postValue('project_id');
			$access_user_email = postValue('access_user_email');
			$mode = postValue('mode');
			
			$result = OpenDrive::i()->apiClient()->tasks_add_project_permission($project_id, $access_user_email, $mode);
		break;

		case 'tasks.update-project':
			$project_id = postValue('project_id');
			$start_date = postValue('start_date');
			$due_date = postValue('due_date');

			if($start_date !== null){
				$start_date = strtotime($start_date);
				if($start_date === false) $start_date = null;
				else $start_date = date('Y-m-d', $start_date);
			}

			if($due_date !== null){
				$due_date = strtotime($due_date);
				if($due_date === false) $due_date = null;
				else $due_date = date('Y-m-d', $due_date);
			}

			$data = array(
				'project_name' => postValue('name'),
				'start_date' => $start_date,
				'due_date' => $due_date,
			);

			$result = OpenDrive::i()->apiClient()->tasks_update_project($project_id, $data);

			if(!OpenDrive::i()->apiClient()->error){
				$date = new \DateTime();
				$date->setTimezone(new \DateTimeZone('UTC'));

				$date->setTimestamp(strtotime($result->StartDate));
				$result->StartDateText = $result->StartDate == '0000-00-00' ? 'Not set' : $date->format('j M Y');
				$date->setTimestamp(strtotime($result->DueDate));
				$result->DueDateText = $result->DueDate == '0000-00-00' ? 'Not set' : $date->format('j M Y');
			}
		break;

		case 'tasks.archive-project':
			$project_id = postValue('project_id');
			$result = OpenDrive::i()->apiClient()->tasks_archive_project($project_id);
		break;

		case 'tasks.trash-project':
			$project_id = postValue('project_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_project($project_id);
		break;

		//Task List
		case 'tasks.load-task-lists':
			$project_id = postValue('project_id');
			$task_list_id = postValue('task_list_id');
			$filter = postValue('filter');
			$item_type = postValue('item_type');
			switch($filter){
				case 'archive': $filter = 'archived'; break;
				case 'trash': $filter = 'trashed'; break;
				default: $filter = null;
			}
			$result = OpenDrive::i()->apiClient()->tasks_get_tasks_list($project_id, $task_list_id, true, $filter, $item_type);
			$date = new \DateTime();
			$date->setTimezone(new \DateTimeZone('UTC'));

			if(!OpenDrive::i()->apiClient()->error){
				foreach($result->TaskLists as &$taskList){
					\od_includes\OpenDriveTasks::formatTaskList($taskList);
				}

				if(isset($result->Project)){
					$date->setTimestamp(strtotime($result->Project->StartDate));
					$result->Project->StartDateText = $result->Project->StartDate == '0000-00-00' ? 'Not set' : $date->format('j M Y');
					$date->setTimestamp(strtotime($result->Project->DueDate));
					$result->Project->DueDateText = $result->Project->DueDate == '0000-00-00' ? 'Not set' : $date->format('j M Y');
				}
			}
		break;

		case 'tasks.add-task-list':
			$project_id = postValue('project_id');
			$result = OpenDrive::i()->apiClient()->tasks_add_task_list($project_id, 'New Task List');
		break;

		case 'tasks.update-task-list':
			$list_id = postValue('list_id');
			$list_name = postValue('list_name');
			$due_date = postValue('due_date');
			if($due_date !== null){
				$due_date = strtotime($due_date);
				if($due_date === false) $due_date = null;
				else $due_date = date('Y-m-d', $due_date);
			}
			$complete_all_tasks = postValue('complete_all_tasks');
			$result = OpenDrive::i()->apiClient()->tasks_update_task_list($list_id, $list_name, $due_date, $complete_all_tasks);
			if(!OpenDrive::i()->apiClient()->error){
				$date = new \DateTime();
				$date->setTimezone(new \DateTimeZone('UTC'));
				$date->setTimestamp(strtotime($result->DueDate));
				$result->DueDateText =  $date->format('j M Y');
			}
		break;

		case 'tasks.archive-task-list':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_archive_task_list($list_id);
		break;

		case 'tasks.trash-task-list':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_task_list($list_id);
		break;

		case 'tasks.restore-task-list':
			$list_id = postValue('list_id');
			$result = OpenDrive::i()->apiClient()->tasks_restore_task_list($list_id);
		break;

		//tasks
		case 'tasks.update-task':
			$task_id = postValue('task_id');
			$start_date = postValue('start_date');
			if($start_date !== null){
				$start_date = strtotime($start_date);
				if($start_date === false) $start_date = null;
				else $start_date = date('Y-m-d', $start_date);
			}
			$due_date = postValue('due_date');
			if($due_date !== null){
				$due_date = strtotime($due_date);
				if($due_date === false) $due_date = null;
				else $due_date = date('Y-m-d', $due_date);
			}
			$data = array(
				'status' => postValue('status'),
				'task_name' => postValue('task_name'),
				'progress' => postValue('progress'),
				'priority' => postValue('priority'),
				'private' => postValue('private'),
				'color' => postValue('color'),
				'tag_id' => postValue('tag_id'),
				'task_list_id' => postValue('task_list_id'),
				'task_description' => postValue('task_description', null, false),
				'access_userid_assign_to' => postValue('access_userid_assign_to'),
				'start_date' => $start_date,
				'due_date' => $due_date,
			);

			$result = OpenDrive::i()->apiClient()->tasks_update_task($task_id, $data);

			if(!OpenDrive::i()->apiClient()->error){
				$date = new \DateTime();
				$date->setTimezone(new \DateTimeZone('UTC'));

				if($result->DueDate == '0000-00-00') $result->DueDateText = '<span class="empty-date">-</span>';
				else {
					$date->setTimestamp(strtotime($result->DueDate));
					$result->DueDateText = od_days_diff($date->getTimestamp());
				}
				$date->setTimestamp(strtotime($result->StartDate));
				$result->StartDateText = od_days_diff($date->getTimestamp());
			}
		break;

		case 'tasks.archive-task':
			$task_id = postValue('task_id');
			$result = OpenDrive::i()->apiClient()->tasks_archive_task($task_id);
		break;

		case 'tasks.trash-task':
			$task_id = postValue('task_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_task($task_id);
		break;

		case 'tasks.restore-task':
			$task_id = postValue('task_id');
			$result = OpenDrive::i()->apiClient()->tasks_restore_task($task_id);
		break;

		case 'tasks.add-task':
			$task_list_id = postValue('task_list_id');
			$result = OpenDrive::i()->apiClient()->tasks_add_task($task_list_id, array('task_name' => ''));
			if(!OpenDrive::i()->apiClient()->error){
				$date = new \DateTime();
				$date->setTimezone(new \DateTimeZone('UTC'));

				if($result->DueDate == '0000-00-00') $result->DueDateText = '<span class="empty-date">-</span>';
				else {
					$date->setTimestamp(strtotime($result->DueDate));
					$result->DueDateText = od_days_diff($date->getTimestamp());
				}
				$date->setTimestamp(strtotime($result->StartDate));
				$result->StartDateText = od_days_diff($date->getTimestamp());
				if($result->Name == '') $result->Name = 'New Task';
			}
		break;

		case 'tasks.load-tasks':
			$search_query = postValue('search_query', null, false);
			$task_id = postValue('task_id', null, false);
			$task_list_id = postValue('task_list_id');
			$with_comments = postValue('with_comments');
			$result = OpenDrive::i()->apiClient()->tasks_get_tasks($search_query, $task_id, $task_list_id, $with_comments);
			if(!OpenDrive::i()->apiClient()->error){
				$date = new \DateTime();
				$date->setTimezone(new \DateTimeZone('UTC'));

				foreach($result as &$task){
					settype($task->Description, 'string');
					if($task->DueDate == '0000-00-00') $task->DueDateText = '<span class="empty-date">-</span>';
					else {
						$date->setTimestamp(strtotime($task->DueDate));
						$task->DueDateText = od_days_diff($date->getTimestamp());
					}
					$date->setTimestamp(strtotime($task->StartDate));
					$task->StartDateText = od_days_diff($date->getTimestamp());
					$task->StartTimeText = $date->format('g:i a');
					if(isset($task->Attachments)){
						foreach($task->Attachments as &$attach){
							$attach->FileType = OpenDrive::isKnownFile($attach->FileName) ? 'known-file':'unknown-file' .
							' type-'. urlencode(strtolower(pathinfo($attach->FileName, PATHINFO_EXTENSION)));
							$attach->Size = od_size_format($attach->Size);
							$attach->DownloadLink = file_download_link($attach->FileId);
						}
					}
					if(isset($task->Comments)){
						foreach($task->Comments as &$comment){
							$comment->CommentDate = od_days_diff(OpenDrive::i()->getLocalTime($comment->Created));
							$comment->CommentTime = OpenDrive::formatTimeTZ($comment->Created, 'g:i a');

							foreach($comment->Attachments as &$attach){
								$attach->FileType = OpenDrive::isKnownFile($attach->FileName) ? 'known-file':'unknown-file' .
								' type-'. urlencode(strtolower(pathinfo($attach->FileName, PATHINFO_EXTENSION)));
								$attach->Size = od_size_format($attach->Size);
								$attach->DownloadLink = file_download_link($attach->FileId);
							}

							if(isset($comment->SubComments)){
								foreach($comment->SubComments as &$subcomment){
									$subcomment->SubCommentDate = od_days_diff(OpenDrive::i()->getLocalTime($subcomment->Created));
									$subcomment->SubCommentTime = OpenDrive::formatTimeTZ($subcomment->Created, 'g:i a');
								}
							}
						}
					}
				}
				if($task_id && $result){
					$task = $result[0];
					$result = array(
						'Task' => $result[0],
					);
				}
			}
		break;

		case 'tasks.move-task':
			$result = OpenDrive::i()->apiClient()->tasks_move_task(
				postValue('task_id'),
				postValue('insert_after_taskid'),
				postValue('task_list_id'),
				postValue('project_id'),
				postValue('item_type')
				);
			if(!OpenDrive::i()->apiClient()->error){
				\od_includes\OpenDriveTasks::formatTaskList($result->OldTaskList);
				\od_includes\OpenDriveTasks::formatTaskList($result->NewTaskList);
			}
		break;

		//Comments
		case 'tasks.add-comment':
			$task_id = postValue('task_id');
			$comment_text = postValue('comment_text', null, false);
			$result = OpenDrive::i()->apiClient()->tasks_add_comment($task_id, $comment_text);
		break;

		case 'tasks.update-comment':
			$comment_id = postValue('comment_id');
			$comment_text = postValue('comment_text', null, false);
			$tag_id = postValue('tag_id', null, false);
			$result = OpenDrive::i()->apiClient()->tasks_update_comment($comment_id, $comment_text, $tag_id);
			if(!OpenDrive::i()->apiClient()->error){
				$result->CommentDate = od_days_diff(OpenDrive::i()->getLocalTime($result->Created));
				$result->CommentTime = OpenDrive::formatTimeTZ($result->Created, 'g:i a');
			}
		break;

		case 'tasks.trash-comment':
			$comment_id = postValue('comment_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_comment($comment_id);
		break;

		//Subcomments

		case 'tasks.add-subcomment':
			$comment_id = postValue('comment_id');
			$text = postValue('text', null, false);
			$result = OpenDrive::i()->apiClient()->tasks_add_subcomment( $comment_id, $text);
			if(!OpenDrive::i()->apiClient()->error){
				$result->SubCommentDate = od_days_diff(OpenDrive::i()->getLocalTime($result->Created));
				$result->SubCommentTime = OpenDrive::formatTimeTZ($result->Created, 'g:i a');
			}
		break;

		case 'tasks.update-subcomment':
			$subcomment_id = postValue('subcomment_id');
			$text = postValue('text', null, false);
			$result = OpenDrive::i()->apiClient()->tasks_update_subcomment($subcomment_id, $text);
			if(!OpenDrive::i()->apiClient()->error){
				$result->SubCommentDate = od_days_diff(OpenDrive::i()->getLocalTime($result->Created));
				$result->SubCommentTime = OpenDrive::formatTimeTZ($result->Created, 'g:i a');
			}
		break;

		case 'tasks.trash-subcomment':
			$subcomment_id = postValue('subcomment_id');
			$result = OpenDrive::i()->apiClient()->tasks_trash_subcomment($subcomment_id);
		break;

		case 'tasks.empty-trash':
			$result = OpenDrive::i()->apiClient()->tasks_empty_trash();
		break;

		case 'tasks.list-trash':
			$result = OpenDrive::i()->apiClient()->tasks_list_trash();
			if(!OpenDrive::i()->apiClient()->error){
				$itemsCount = $result->Projects + $result->ProjectLists + $result->Tasks + $result->TaskLists;
				$result->ItemsCountText = sprintf( _n( '%s item', '%s items', $itemsCount ), $itemsCount );
			}
		break;

		case 'tasks.delete-attachment':
			$result = OpenDrive::i()->apiClient()->tasks_delete_attachment(
				postValue('item_type'), postValue('item_id'), postValue('file_id')
			);
		break;

		case 'settings.update-password':
			$old_password = postValue('user_info_old_password', '', false);
			$new_password = postValue('user_info_new_password', '', false);
			$repeat_password = postValue('user_info_repeat_password', '', false);

			if ( $old_password == '' || $new_password == '' || $repeat_password == '' )
			{
				$error = true;
				$error_message = __('Please fill all password fields', 'opendrive');
			}

			if ( !$error && $new_password != $repeat_password )
			{
				$error = true;
				$error_message = __('Your password was not changed. New password and repeated new password did not match', 'opendrive');
			}

			if ( !$error )
			{
				OpenDrive::i()->apiClient()->user_update_password($new_password, $old_password);
				if ( OpenDrive::i()->apiClient()->error )
				{
					$error = true;
					$error_message = OpenDrive::i()->apiClient()->error_message;
				}
				else
				{
					$error = false;
					$result['message'] = __('Password changed', 'opendrive');
				}
			}

			break;
		case 'settings.update-profile-access_user':
			$first_name = postValue('user_access_first_name');
			$last_name = postValue('user_access_last_name');
			$phone = postValue('user_access_phone');

			$result = OpenDrive::i()->apiClient()->user_update($first_name, $last_name, null, $phone, null, null, null, null, null);

			if (!OpenDrive::i()->apiClient()->error) {
				$result->message = __('Profile updated.', 'opendrive');
			}
			break;

		case 'settings.update-profile':
			$first_name = postValue('user_info_first_name');
			$last_name = postValue('user_info_last_name');
			$company_name = postValue('user_info_company');
			$phone = postValue('user_info_phone');
			$time_zone = postValue('user_info_time_zone');
			$address_1 = postValue('user_info_address_1');
			$address_2 = postValue('user_info_address_2');
			$invoiceAddress = postValue('user_info_invoice_address');
			$file_versioning = 0;
			$file_versions = 0;
			$default_file_perm = postValue('default_file_perm');
			$user_info_file_versioning = postValue('user_info_file_versioning');
			if ($user_info_file_versioning !== null) {
				$file_versioning = 1;
			}
			$file_versions = (int)postValue('user_info_versions');
			$lang = null;
			$daily_stat = 0;
			if (postValue('user_info_daily_stat', 0)) {
				$daily_stat = 1;
			}
			$result = OpenDrive::i()->apiClient()->user_update($first_name, $last_name, $company_name, $phone, $time_zone, $file_versioning, $file_versions, $lang, $daily_stat, $invoiceAddress, $default_file_perm, $address_1, $address_2);

			if (!OpenDrive::i()->apiClient()->error) {
				$result->message = __('Profile updated.', 'opendrive');
			}
			break;

		case 'settings.affiliate':
			$enabled = (int)postValue('enabled');

			$result = OpenDrive::i()->apiClient()->user_affiliate_setting($enabled);

			if (!OpenDrive::i()->apiClient()->error) {
				$result->message = __('Profile updated.', 'opendrive');
			}
			break;

		case 'internal.refresh-token':
		break;
        case 'expiring-links.generate':
            $date = postValue('date');
            $counter = postValue('counter');
            $file_id = postValue('file_id');
            $enable = postValue('enable');
            $result = OpenDrive::i()->apiClient()->generateExpiringLink($date, $counter, $file_id, $enable);
            break;
        case 'expiring-links-folder.generate':
            $date = postValue('date');
            $counter = postValue('counter');
            $folder_id = postValue('folder_id');
            $enable = postValue('enable');
            $result = OpenDrive::i()->apiClient()->generateExpiringFolderLink($date, $counter, $folder_id, $enable);
            break;

		default:
			{
				$error = true;
				$error_message = __('Action not found', 'opendrive');
				header('Not found', true, 404);
			}
	}
	if ($error && !$result && $error_message) {
		$result['error'] = array(
			'message' => $error_message
		);
	}

	if(OpenDrive::i()->apiClient()->error) {
		$error_message = OpenDrive::i()->apiClient()->error_message;
		$error = true;
		if(OpenDrive::i()->apiClient()->error_code == 401) {
			$loginUrl = OpenDrive::redirectToLoginPage();
			if(is_array($result)) $result['redirect_url'] = $loginUrl;
			elseif(is_object($result)) $result->redirect_url = $loginUrl;
		}
	}

	if ( !$error && $csrfToken) {
		if(is_array($result)) $result['new_csrf_token'] = $csrfToken;
		elseif(is_object($result)) $result->new_csrf_token = $csrfToken;
	}
	header('Content-Type: application/json', true, 200);
	echo json_encode($result);
} else {
	header('Not found', true, 404);
}
