'use strict';

var gulp = require('gulp');
var uglify = require('gulp-uglify');
var uglifycss = require('gulp-uglifycss');
var rename = require('gulp-rename');
var concat = require('gulp-concat');
var fs = require('fs');

gulp.task('scripts', function () {
    gulp.src('./js/vendor/pdfjs/build/*.js')
        .pipe(uglify())
        .pipe(rename(function (path) {
            path.basename += '.min';
            return path;
        }))
        .pipe(gulp.dest('./js/vendor/pdfjs/build/min'));

    gulp.src(['./js/vendor/pdfjs/*.js'])
        .pipe(concat('pdf_viewer.min.js'))
        .pipe(uglify())
        .pipe(gulp.dest('./js/vendor/pdfjs/build/min'));

});

gulp.task('css', function () {
    gulp.src('./css/vendor/pdfjs/viewer.css')
        .pipe(uglifycss())
        .pipe(rename(function (path) {
            path.basename += '.min';
            return path;
        }))
        .pipe(gulp.dest('./css/vendor/pdfjs'))
});


gulp.task('copy_default_translations', function () {
    var langs = {
        'cs_CZ': 'Czech',
        'es_ES': 'Spanish',
        'fr_FR': 'French',
        'de_DE': 'Dutch',
        'hu_HU': 'Hungarian',
        'nl_NL': 'Nederlands',
        'pl_PL': 'Polish',
        'pt_PT': 'Portuguese',
        'ru_RU': 'Russian',
        'sk_SK': 'Slovak',
        'zh_CN': 'Chinese Simplified',
        'zh_TW': 'Taiwanese Mandarin'
    };

    Object.keys(langs).forEach(function (lang) {
        fs.readFile('./lang/po/opendrive-en_US.po', 'utf8', function (err, data) {
            if (err) {
                return;
            }
            var result = data.replace(/"Language: English/g, '"Language: ' + langs[lang]);

            fs.writeFile('./lang/po/opendrive-' + lang + '.po', result, 'utf8', function (err) {
                if (err) return;
            });
        });
        fs.createReadStream('./lang/l10n/en_US.viewer.properties', 'utf8').pipe(fs.createWriteStream('./lang/l10n/' + lang + '.viewer.properties', 'utf8'));
    });
});

gulp.task('default', ['scripts', 'css', 'translations']);