(function ($) {
    var usersChart = false;
    var bwChart = false;
    var usersData = false;
    var bwData = false;
    var usersChartGraph;
    var bwChartGraph;

    $(function () {
        usersChart = $('#usersChart');
        bwChart = $('#bwChart');
            $('.monthselector').monthselector({
                callback: function (cdata) {
                    load_chart_data(cdata.stat_date, cdata.wrapper);
                }
            });

            var cur_date = new Date();
            var stat_date = (cur_date.getMonth() + 1) + '/' + cur_date.getFullYear();

            function draw(wrapper) {

                var load_bw_data = true;
                var load_users_data = true;

                if (wrapper) {
                    if (wrapper.closest('.chart-head').hasClass('users-chart-head')) {
                        load_bw_data = false;
                    }

                    if (wrapper.closest('.chart-head').hasClass('bw-chart-head')) {
                        load_users_data = false;
                    }
                }

                if (usersData && bwData && usersChart.length > 0 && bwChart.length > 0) {
                    var selector = '#usersChart, #bwChart';

                    jQuery(selector).attr('width', jQuery(selector).closest('.chart').width());
                    jQuery(selector).attr('height', jQuery(selector).closest('.chart').height());

                    var lineOptions = {
                        scaleShowVerticalLines: false,
                        customTooltips: function (tooltip) {
                            var tooltipEl = jQuery('#users-chartjs-tooltip');
                            if (!tooltip) {
                                tooltipEl.css({
                                    opacity: 0
                                });
                                return;
                            }
                            tooltipEl.removeClass('above below');
                            tooltipEl.addClass(tooltip.yAlign);
                            var innerHtml = '';
                            for (var i = 0; i < tooltip.labels.length; i++) {
                                innerHtml += OpenDrive.helpers.applyTemplate({
                                    Color: tooltip.legendColors[i].fill,
                                    Label: tooltip.labels[i],
                                    Premium: i == 0
                                }, 'ChartUsersTooltip');

                            }
                            tooltipEl.html(innerHtml);

                            tooltipEl.css({
                                opacity: 1,
                                right: '0px',
                                top: '0px',
                                fontFamily: tooltip.fontFamily,
                                fontSize: tooltip.fontSize,
                                fontStyle: tooltip.fontStyle
                            });
                        }
                    };

                    lineOptions.animation = load_users_data;
                    if(usersChartGraph) usersChartGraph.destroy();
                    usersChartGraph = new Chart(document.getElementById('usersChart').getContext('2d')).Line(usersData, lineOptions);

                    lineOptions = {
                        scaleShowVerticalLines: false,
                        customTooltips: function (tooltip) {
                            var tooltipEl = jQuery('#bw-chartjs-tooltip');
                            if (!tooltip) {
                                tooltipEl.css({
                                    opacity: 0
                                });
                                return;
                            }
                            tooltipEl.removeClass('above below');
                            tooltipEl.addClass(tooltip.yAlign);
                            var innerHtml = '';
                            for (var i = 0; i < tooltip.labels.length; i++) {
                                innerHtml += OpenDrive.helpers.applyTemplate({
                                    Color: tooltip.legendColors[i].fill,
                                    Label: tooltip.labels[i],
                                    Downloads: i != 0
                                }, 'ChartDataTooltip');
                            }
                            tooltipEl.html(innerHtml);

                            tooltipEl.css({
                                opacity: 1,
                                right: '0px',
                                top: '0px',
                                fontFamily: tooltip.fontFamily,
                                fontSize: tooltip.fontSize,
                                fontStyle: tooltip.fontStyle
                            });
                        }
                    };

                    lineOptions.animation = load_bw_data;
                    if(bwChartGraph) bwChartGraph.destroy();
                    bwChartGraph = new Chart(document.getElementById('bwChart').getContext('2d')).Line(bwData, lineOptions);
                }

            }

            function load_chart_data(stat_date, wrapper) {
                var load_bw_data = true;
                var load_users_data = true;

                if (wrapper) {
                    var container = wrapper.closest('.chart-head');
                    if (container.hasClass('users-chart-head')) {
                        load_bw_data = false;
                    }

                    if (container.hasClass('bw-chart-head')) {
                        load_users_data = false;
                    }

                    container.find('.js-loading').show();
                } else {
                    $('.js-loading').show();
                }

                OpenDrive.ajax.do('admin-monthly-load-stat', {
                    item_id: $('.monthselector').data('item-id'),
                    'monthselector-date': stat_date
                }, function (data) {
                    if(wrapper) {
                        container.find('.js-loading').hide();
                    } else {
                        $('.js-loading').hide();
                    }

                    if (load_users_data) {
                        usersData = {
                            labels: data.dataset_keys,
                            datasets: [
                                {
                                    label: usersChart.data('premium-users-line'),
                                    fillColor: 'rgba(221,221,221,0.5)',
                                    strokeColor: '#aaaaaa',
                                    pointColor: '#aaaaaa',
                                    pointStrokeColor: '#aaaaaa',
                                    pointHighlightFill: '#333',
                                    pointHighlightStroke: '#ccc',
                                    data: data.users_pay_dataset
                                },
                                {
                                    label: usersChart.data('free-users-line'),
                                    fillColor: 'rgba(110,161,231,0.3)',
                                    strokeColor: '#6ea1e7',
                                    pointColor: '#6ea1e7',
                                    pointStrokeColor: '#6ea1e7',
                                    pointHighlightFill: '#6ea1e7',
                                    pointHighlightStroke: '#ccc',
                                    data: data.users_free_dataset
                                }
                            ]
                        };
                        $('.js-month_users_count').html(data.month_users_count);
                        var usersCount = 0;
                        for (var i in data.users_pay_dataset) usersCount += data.users_pay_dataset[i];
                        $('.js-month_premium_users_count').html(usersCount);
                    }

                    if (load_bw_data) {

                        $('.bw-chart-head #monthly-uploaded').html(OpenDrive.helpers.humanFileSize(data.montly_uploaded));
                        $('.bw-chart-head #monthly-downloaded').html(OpenDrive.helpers.humanFileSize(data.montly_downloaded));


                        bwData = {
                            labels: data.dataset_keys,
                            datasets: [
                                {
                                    label: bwChart.data('upload-bw-title'),
                                    fillColor: 'rgba(221,221,221,0.5)',
                                    strokeColor: '#aaaaaa',
                                    pointColor: '#aaaaaa',
                                    pointStrokeColor: '#aaaaaa',
                                    pointHighlightFill: '#333',
                                    pointHighlightStroke: '#ccc',
                                    data: data.upload_bw_dataset
                                },
                                {
                                    label: bwChart.data('dl-bw-title'),
                                    fillColor: 'rgba(110,161,231,0.3)',
                                    strokeColor: '#6ea1e7',
                                    pointColor: '#6ea1e7',
                                    pointStrokeColor: '#6ea1e7',
                                    pointHighlightFill: '#6ea1e7',
                                    pointHighlightStroke: '#ccc',
                                    data: data.download_bw_dataset
                                }
                            ]
                        };
                    }
                    if (usersChart.length && bwChart.length) {
                        if(usersChart.destroy) usersChart.destroy();
                        if(bwChart.destroy) bwChart.destroy();
                    }
                    draw(wrapper);

                });
            }

            load_chart_data(stat_date);

            $(document).on('ODResizeFinished', function () {
                if (usersChart.length) {
                    usersChartGraph.clear().resize().draw();
                }
                if (bwChart.length) {
                    bwChartGraph.clear().resize().draw();
                }
            });
    })
})(jQuery);
