(function ($) {
    $(function () {
        var InitOptions = $.parseJSON($('#js-init-data').html());
        var ItemTabs = new OpenDrive.widgets.ItemTabs('AdminUsers', InitOptions.SessionToken);
        var billingPlans = $.parseJSON($('#js-billing-plans').html());
        var filterOptions = InitOptions.FilterOptions,
            firstLoad;
        var closeAccLB = $('.js-lighbox-close-account'),
            resetSFpasswordLB = $('.js-lighbox-reset-secure-files-password'),
            blacklistUserLB = $('.js-lighbox-blacklist-user'),
            refundTransactionLB = $('.js-lighbox-refund-user-transaction'),
            reasonTextArea = $('.js-close-reason-text', closeAccLB),
            closeReasonSelect = $('.js-close-reason', closeAccLB);

        var SearchBox = new function () {
            var input = $('.js-item-search-field');

            this.reset = function () {
                input.val('');
            };

            function doSearch() {
                filterOptions.search = input.val().trim();
                filterOptions.page = 1;
                searchTab.loadTabContent();
            }

            this.setValue = function (v) {
                input.val(v);
            };

            $('.js-item-search-icon').click(function () {
                doSearch();
                return false;
            });

            input.keypress(function (e) {
                if (e.which == 13) {
                    doSearch();
                    return false;
                }
            });
        };

        function SearchTab(completeCallback) {
            var usersTabId = '<search>';
            var _this = this;

            function onClose() {
            }

            function onActivate(id, args) {
            }

            function onSave() {
                return {
                    userId: usersTabId
                }
            }

            function onWakeUp() {
            }

            function resetFilter() {
                filterOptions = {
                    items_on_page: 25,
                    page: 1,
                    user_type: '',
                    due_filter: '',
                    suspended: '',
                    search: '',
                    order_by: ''
                };
                SearchBox.reset();
            }

            if (!filterOptions) {
                resetFilter();
                firstLoad = true;
            }
            SearchBox.setValue(filterOptions.search);

            var usersTab = ItemTabs.openTab(usersTabId,
                {
                    breadCrumb: OpenDrive.helpers.applyTemplate(
                        {
                            ItemId: usersTabId,
                            TotalUsersCount: 0
                        },
                        'BreadCrumbMenu'
                    ),
                    tabContent: OpenDrive.helpers.applyTemplate({FirstRun: firstLoad}, 'UsersList'),
                    titleOpts: {
                        Unclosable: true
                    },
                    Name: 'Users'
                },
                {
                    //close: onClose,
                    save: onSave
                    //wakeup: onWakeUp,
                    //activate: onActivate
                }
            );
            usersTab.tab.addClass('scrollable');
            usersTab.tab.data('ItemTab', _this);

            //Events
            usersTab.breadcrumb.on('click', '[data-user-type]', function () {
                resetFilter();
                filterOptions.user_type = $(this).data('user-type');
                _this.loadTabContent();
                return false;
            });

            usersTab.breadcrumb.on('click', '[data-due]', function () {
                filterOptions.due_filter = $(this).data('due');
                _this.loadTabContent();
                return false;
            });

            usersTab.breadcrumb.on('click', '[data-suspended-filter]', function () {
                filterOptions.suspended = $(this).data('suspended-filter');
                _this.loadTabContent();
                return false;
            });

            usersTab.tab.on('click', '[data-items-limit]', function () {
                filterOptions.items_on_page = $(this).data('items-limit');
                _this.loadTabContent();
                return false;
            });

            usersTab.tab.on('click', '[data-order-by]', function () {
                filterOptions.order_by = $(this).data('order-by');
                _this.loadTabContent();
                return false;
            });

            usersTab.tab.on('click', '.js-page', function () {
                filterOptions.page = $(this).data('page');
                _this.loadTabContent();
                return false;
            });

            usersTab.tab.on('click', '.js-admin-user-new-payment-btn', function () {
                var user = $(this).closest('[data-userid]');
                var user_id = user.data('userid');
                new UserTab(user_id, true);
                return false;
            });

            usersTab.tab.on('click', '.js-admin-user-edit-trigger', function () {
                var user = $(this).closest('[data-userid]');
                var user_id = user.data('userid');
                var fileId = user.data('fileid');
                new UserTab(user_id, false, false, null, fileId ? {fileId: fileId} : null);
                return false;
            });

            usersTab.tab.on('click', '[data-user-action]', function () {
                var $this = $(this);

                var action = $this.data('user-action');

                if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                    var user = $this.closest('[data-userid]');
                    var user_id = user.data('userid');
                    OpenDrive.ajax.do(action, {user_id: user_id}, function () {
                        _this.loadTabContent(true);
                    })
                }
                return false;
            });


            function initializeContent() {
                $('.js-avatar', usersTab.tab).lazyload({
                    threshold: 100,
                    container: usersTab.tab,
                    effect: 'fadeIn',
                    skip_invisible: false,
                    load: function () {
                        $(this)
                            .removeClass('js-avatar')
                            .removeData('original');
                    }
                });
            }

            function updateBreadCrumbs(data) {
                data.ShowDueFilter = filterOptions.user_type == 'premium' || filterOptions.user_type == 'trials';
                data.ShowSuspendedFilter = filterOptions.user_type == 'suspended';
                data.UserType = filterOptions.user_type;

                OpenDrive.helpers.applyTemplate(data, 'BreadCrumbMenuContent', usersTab.breadcrumb);
                $('.js-due-datepicker', usersTab.breadcrumb).datepicker({
                    inline: true,
                    dateFormat: 'M d, yy',
                    minDate: '-2y',
                    maxDate: '+1y +1d',
                    onSelect: function (date) {
                        filterOptions.due_filter = date;
                        _this.loadTabContent();
                        return false;
                    }
                });
            }

            this.loadTabContent = function (noHistoryChange) {
                ItemTabs.setTabLoadedStatus(usersTabId);
                if(this.xhr) this.xhr.abort();
                $('.js-loading').show();
                this.xhr = OpenDrive.ajax.do('admin.load-users', filterOptions, function (response) {
                    updateBreadCrumbs(response.Breadcrumbs);
                    ItemTabs.setTabLoadedStatus(usersTabId, true);
                    usersTab.tab[0].innerHTML = response.UsersHtml;
                    initializeContent();
                    if (!noHistoryChange) WindowHistory.push();
                    if(completeCallback instanceof Function) {
                        completeCallback();
                        completeCallback = null;
                    }
                    $('.js-loading').hide();
                }, function () {
                    ItemTabs.setTabLoadedStatus(usersTabId, true);
                    $('.js-loading').hide();
                })
            };

            if(firstLoad) {
                ItemTabs.setTabLoadedStatus(usersTabId, true);
                if(completeCallback instanceof Function) {
                    completeCallback();
                    completeCallback = null;
                }
            }
            else _this.loadTabContent(true);
        }

        function UserTab(userId, isPaymentForm, noActivate, completeCallback, extOptions) {
            var _this = this;
            var tabId = 'user-' + userId;
            var paymentAmount;
            var reminderDropdown;

            function onClose() {
                $('.js-withdatepicker', userTab.tab).datepicker('destroy');
            }

            function onActivate(id, args) {
            }

            function onSave() {
                return {
                    userId: userId,
                    type: isPaymentForm
                }
            }

            function onWakeUp() {
            }

            function applyUserDetails(user) {
                deInitializeContent();
                user.Initials = (user.UserFirstName.substr(0, 1) + user.UserLastName.substr(0, 1)).toUpperCase();
                OpenDrive.helpers.applyTemplate(user, 'UserDetailsBreadCrumbContent', userTab.breadcrumb);
                OpenDrive.helpers.applyTemplate(
                    user,
                    'UserEditForm',
                    userTab.tab
                );
                ItemTabs.updateTabTitle(tabId, user.UserFirstName + ' ' + user.UserLastName + ' (' + user.UserID + ')');
                initializeUserEditFormContent(user);
            }

            this.loadTabContent = function (completeCallback) {
                ItemTabs.setTabLoadedStatus(tabId);

                var params = isPaymentForm ? {
                    user_cc: 1,
                    last_notes: 1,
                    user_id: userId
                } : {
                    user_id: userId
                };
                if(extOptions && extOptions.fileId) params.file_id = extOptions.fileId;
                OpenDrive.ajax.do('admin.get-user',
                    params,
                    function (user) {
                        if(isPaymentForm) {
                            deInitializeContent();
                            OpenDrive.helpers.applyTemplate(
                                user,
                                'PaymentForm',
                                userTab.tab
                            );
                            OpenDrive.helpers.applyTemplate(user, 'PaymentBreadCrumbContent', userTab.breadcrumb);
                            initializePaymentFormContent();
                            ODAdmin.addTransactionsToAutocompleteList(user.Transactions);
                            ODAdmin.resetForm();
                        } else {
                            applyUserDetails(user);
                        }
                        ItemTabs.updateTabTitle(tabId, user.UserFirstName + ' ' + user.UserLastName + ' (' + user.UserID + ')');
                        ItemTabs.setTabLoadedStatus(tabId, true);
                        if (completeCallback instanceof Function) completeCallback();
                    }, function () {
                        ItemTabs.closeTab(tabId, false, true);
                        if (completeCallback instanceof Function) completeCallback();
                    });
            };

            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            function initializeUserEditFormContent(user) {
                ODAdmin.fillUsageBar(user);
                $('#admin-user-account-type', userTab.tab).val(user.AccType);
                $('#admin-user-file-size', userTab.tab).val(user.MaxFileSize ? readableFileSizeShort(user.MaxFileSize * 1024) : 'UNL').data('size', user.MaxFileSize);
                $('#admin-user-plan', userTab.tab).val(user.Level);
                $('#admin-user-space-unit', userTab.tab).val(user.MaxStorageInfo.units);
                $('#admin-user-bw-unit', userTab.tab).val(user.BwInfo.units);
                $('.js-withdatepicker', userTab.tab).datepicker({
                    inline: true,
                    dateFormat: 'M d, yy',
                    minDate: '-2y'
                });
            }
            
            function initializePaymentFormContent() {
                paymentAmount = $('.js-new_payment_amount', userTab.tab);
                reminderDropdown = $('.js-reminder-dropdown', userTab.tab);
                $('.js-withdatepicker', userTab.tab).datepicker({
                    inline: true,
                    dateFormat: 'M d, yy',
                    minDate: '-2y'
                });

                $('.js-new_payment_trans_id', userTab.tab).on('change keyup keydown paste input cut', function () {
                    var _this = $(this);
                    if (_this.data('prevValue') !== this.value) {
                        this.value = this.value.trim();
                        _this.data('prevValue', this.value);
                    }
                });

                $('.js-new_payment_cc', userTab.tab).change(function () {
                    if (this.value == '') {
                        $('.js-new_payment_trans_id, .js-new_payment_trans_status', userTab.tab).removeAttr('disabled');
                    } else {
                        $('.js-new_payment_trans_id, .js-new_payment_trans_status', userTab.tab).attr('disabled', 'disabled').val('');
                    }
                });

                $('.js-admin-add-payment-btn', userTab.tab).click(ODAdmin.submitPayment);

                $('.js-send-reminder', userTab.tab).click(function () {
                    var _this = $(this);
                    _this.append('<span class="js-spinner-rotate spinner-rotate"></span>');
                    OpenDrive.ajax.do(_this.data('type'), {
                        user_id: userId
                    }, function () {
                        _this.find('.js-spinner-rotate').remove();
                        ODAdmin.loadPaymentFormNotes(function () {
                            ItemTabs.getTab('<search>').data('ItemTab').loadTabContent(true);
                        });
                    }, function(){
                        _this.find('.js-spinner-rotate').remove();
                    });
                    return false;
                });

                paymentAmount.inputmask().autocomplete({
                    source: ODAdmin.autocompleteTransactions
                });
            }

            function deInitializeContent() {
                userTab.tab.off('scroll');
            }

            var userTab = ItemTabs.openTab(tabId,
                {
                    breadCrumb: OpenDrive.helpers.applyTemplate(
                        {
                            ItemId: tabId
                        },
                        'PaymentFormBreadCrumb'
                    ),
                    tabContent: '',
                    titleOpts: {
                        Unclosable: false
                    },
                    Name: 'Loading user ...',
                    noActivate: noActivate
                },
                {
                    close: onClose,
                    save: onSave
                    //wakeup: onWakeUp,
                    //activate: onActivate
                }
            );
            userTab.tab.addClass('scrollable');
            userTab.tab.data('ItemTab', _this);

            //Events
            userTab.breadcrumb.on('click', '.js-open-user-details', function () {
                isPaymentForm = false;
                _this.loadTabContent();
                return false;
            });

            userTab.breadcrumb.on('click', '.js-open-payment-form', function () {
                isPaymentForm = true;
                _this.loadTabContent();
                return false;
            });

            userTab.breadcrumb.on('click', '.js-reload-user', function () {
                _this.loadTabContent();
                return false;
            });

            userTab.tab.on('click', '#recalc-user-space-btn', function () {
                var _this = $(this).addClass('rotate-fast-animation');

                OpenDrive.ajax.do('admin.profile-recalculate-space', {user_id: userId}, function (user) {
                    OpenDrive.ajax.do('admin.get-user', {user_id: userId}, function (user) {
                        _this.removeClass('rotate-fast-animation');
                        ODAdmin.fillUsageBar(user);
                    });
                });
                return false;
            });

            userTab.tab.on('click', '#remove-trashed-90-files-btn', function () {
                var _this = $(this).addClass('pulse-animation');
                OpenDrive.ajax.do('profile_trash_files', {user_id: userId}, function (user) {
                    _this.removeClass('pulse-animation');
                    if (user) $.magnificPopup.open({
                        items: {
                            type: 'inline',
                            src: '<div class="modal-popup">Files and folders are removed</div>',
                            closeBtnInside: true
                        }
                    });

                    OpenDrive.ajax.do('admin.get-user', {user_id: userId}, function (user) {
                        _this.removeClass('pulse-animation');
                        ODAdmin.fillUsageBar(user);
                    });
                }, function () {
                    _this.removeClass('pulse-animation');
                });
                return false;
            });

            userTab.tab.on('click', '#reset-user-bw-btn', function () {
                var _this = $(this).addClass('rotate-fast-animation');
                OpenDrive.ajax.do('profile-reset-bw', {user_id: userId}, function (user) {
                    _this.removeClass('rotate-fast-animation');
                    OpenDrive.ajax.do('admin.get-user', {user_id: userId}, function (user) {
                        _this.removeClass('pulse-animation');
                        ODAdmin.fillUsageBar(user);
                    });
                });
                return false;
            });

            userTab.tab.on('click', '.js-userinfo-tab', function () {
                var id = $(this).attr('id');
                var content_id = id + '-content';

                $('.js-userinfo-tab.active', userTab.tab).removeClass('active');
                $(this).addClass('active');

                $('.tabs_content .tab.active', userTab.tab).removeClass('active');
                var tab = $("#" + content_id, userTab.tab);
                tab.addClass('active');
                var dataType = tab.data('type');
                if(dataType && !tab.data('data-loaded')) ODAdmin.loadUserData(dataType, tab);
            });

            userTab.tab.on('change', '#admin-user-plan', function () {
                var close_reason_label = $('.js-close_reason_label', userTab.tab);
                var closeReasonTitle = $('.js-close-reason-title', userTab.tab);
                if (this.value == '0') {
                    var select = $('.js-close-reason');
                    var reason = $('.js-close_reason_value', userTab.tab).val();
                    select.find('option[value="' + reason + '"]').attr('selected', true);
                    if (reason == '1' || reason == '0') {
                        reasonTextArea.removeAttr('disabled');
                        closeReasonTitle.removeClass('disabled');
                    }
                    else {
                        reasonTextArea.attr('disabled', 'disabled');
                        closeReasonTitle.addClass('disabled');
                    }
                    close_reason_label.removeClass('hidden');
                    show_lightbox(closeAccLB);
                } else
                    close_reason_label.addClass('hidden');

                var planSpace = 1048576*1024,
                    planBW = 1048576*1024;

                if (billingPlans[this.value]) {
                    planSpace = billingPlans[this.value].max_storage * 1048576;
                    planBW = billingPlans[this.value].max_bandwidth * 1048576;
                    var maxVersions = billingPlans[this.value].file_versions;
                    $('#admin-user-file-versions', userTab.tab).prop('disabled', maxVersions <= 1).val(maxVersions);
                    $('input[name="admin-user-fversioning"][value="' + (maxVersions <= 1 ? 0 : 1) + '"]', userTab.tab).prop('checked', true);
                }

                if(planSpace > 0) planSpace = readableFileSizeShort(planSpace);
                else planSpace = '0 GB';

                if(planBW > 0) planBW = readableFileSizeShort(planBW);
                else planBW = '0 GB';


                planSpace = planSpace.split(' ');
                planBW = planBW.split(' ');

                $('#admin-user-space', userTab.tab).val(planSpace[0]);
                $('#admin-user-space-unit', userTab.tab).val(planSpace[1]);

                $("#admin-user-bw", userTab.tab).val(planBW[0]);
                $("#admin-user-bw-unit", userTab.tab).val(planBW[1]);
                var planId = parseInt(this.value, 10);
                if(planId <= 1) $('#admin-user-billing-date_' + userId, userTab.tab).val('n/a');
            });

            userTab.tab.on('click', 'input[name="admin-user-fversioning"]', function () {
                $('#admin-user-file-versions', userTab.tab).prop('disabled', this.value == '0');
            });

            userTab.tab.on('click', '#save-admin-user-btn', function () {
                var $this = $(this);
                if($this.hasClass('disabled')) return false;
                $this.addClass('disabled');
                $this.append('<span class="js-spinner-rotate spinner-rotate"></span>');
                var admin_user_edit = $('#admin-user-edit', userTab.tab);

                var passwd = $("#admin-user-password", admin_user_edit).val();
                var verify_passwd = $("#admin-user-repeat-password", admin_user_edit).val();
                var email = $("#admin-user-email", admin_user_edit).val();
                var first_name = $("#admin-user-first-name", admin_user_edit).val();
                var last_name = $("#admin-user-last-name", admin_user_edit).val();
                var level = $("#admin-user-plan", admin_user_edit).val();
                var company_name = $("#admin-user-company", admin_user_edit).val();
                var phone = $("#admin-user-phone", admin_user_edit).val();
                var web_link = $("#admin-user-weblink", admin_user_edit).val();
                var address_1 = $("#admin-user-address-1", admin_user_edit).val();
                var address_2 = $("#admin-user-address-2", admin_user_edit).val();
                var acc_type = $("#admin-user-account-type", admin_user_edit).val();
                var storage_max = $("#admin-user-space", admin_user_edit).val();
                var storage_max_unit = $("#admin-user-space-unit", admin_user_edit).val();
                var bw_max = $("#admin-user-bw", admin_user_edit).val();
                var bw_max_unit = $("#admin-user-bw-unit", admin_user_edit).val();
                var account_users = $("#admin-user-account-users", admin_user_edit).val();
                var bw_reset_period = $("#bw_reset_period", admin_user_edit).val();
                var close_reason = $(".js-close_reason_value", admin_user_edit).val();
                var close_reason_text = reasonTextArea.val();
                var fileVersioning = $('input[name="admin-user-fversioning"]:checked', admin_user_edit).val();
                var fileVersions = $('#admin-user-file-versions', admin_user_edit).val();
                var trial = 0;
                if ( $("#admin-user-trial-yes", admin_user_edit).is(':checked') ) trial = 1;
                var suspended = 0;
                if ( $("#admin-user-suspended-yes", admin_user_edit).is(':checked') ) suspended = 1;
                var next_billing = $("#admin-user-billing-date_" + userId, admin_user_edit).val();

                if ( storage_max_unit == 'GB' ) storage_max = storage_max * 1024;
                else if ( storage_max_unit == 'TB' ) storage_max = storage_max * 1024 * 1024;

                if ( bw_max_unit == 'GB' ) bw_max = bw_max * 1024;
                else if ( bw_max_unit == 'TB' ) bw_max = bw_max * 1024 * 1024;

                var post_data = {
                    user_id: userId,
                    passwd: passwd,
                    verify_passwd: verify_passwd,
                    email: email,
                    first_name: first_name,
                    last_name: last_name,
                    level: level,
                    company_name: company_name,
                    phone: phone,
                    acc_type: acc_type,
                    storage_max: storage_max,
                    bw_max: bw_max,
                    account_users: account_users,
                    bw_reset_period: bw_reset_period,
                    file_versioning: fileVersioning,
                    file_versions: fileVersions,
                    trial: trial,
                    suspended: suspended,
                    next_billing: next_billing,
                    close_reason: close_reason,
                    close_reason_text: close_reason_text,
                    web_link: web_link,
                    address_1: address_1,
                    address_2: address_2
                };
                OpenDrive.ajax.do('admin.update-user-info', post_data, function( user ) {
                    $this.removeClass('disabled');
                    $this.find('.js-spinner-rotate').remove();
                    isPaymentForm = false;
                    applyUserDetails(user);
                    ItemTabs.getTab('<search>').data('ItemTab').loadTabContent(false);
                }, function () {
                    $this.find('.js-spinner-rotate').remove();
                    $this.removeClass('disabled')
                });
                return false;
            });

            userTab.tab.on('click', '.js-reset-billing-date', function () {
                $('#admin-user-billing-date_' + userId, userTab.tab).val('n/a');
                return false;
            });

            userTab.tab.on('click', '#admin-show-logs-btn', function(){
                ODAdmin.loadLogs();
                return false;
            });

            userTab.tab.on('click', '#admin-add-note-btn', function () {
                $(this).hide();
                $('#add-new-note', userTab.tab).show();
                return false;
            });

            userTab.tab.on('click', '#admin-cancel-note-btn', function(){
                $("#admin-add-note-btn", userTab.tab).show();
                $("#add-new-note", userTab.tab).hide();
                return false;
            });

            userTab.tab.on('click', '.js-blacklist-file', function () {
                OpenDrive.ajax.do('admin.blacklist-file', {
                    user_id: userId,
                    file_id: extOptions.fileId
                }, function (user) {
                    OpenDrive.helpers.applyTemplate(user, 'FileInfoTab', $('#tab-fileinfo-content', userTab.tab), true);
                    $('#tab-fileinfo-content', userTab.tab).addClass('active');
                });
                return false;
            });

            userTab.tab.on('click', '.js-block-file', function () {
                OpenDrive.ajax.do('admin.block-file', {
                    user_id: userId,
                    file_id: extOptions.fileId
                }, function (user) {
                    OpenDrive.helpers.applyTemplate(user, 'FileInfoTab', $('#tab-fileinfo-content', userTab.tab), true);
                    $('#tab-fileinfo-content', userTab.tab).addClass('active');
                });
                return false;
            });

            userTab.tab.on('click', '#admin-save-note-btn', function () {
                var add_note_cont = $("#add-new-note", userTab.tab);
                var note_inp = $("#new_note_text", add_note_cont);
                var note_text = note_inp.val().trim();

                if (note_text != '') {
                    OpenDrive.ajax.do("add-user-note", {user_id: userId, note_text: note_text}, function () {
                        $("#admin-add-note-btn", userTab.tab).show();
                        $("#add-new-note", userTab.tab).hide();
                        ODAdmin.loadUserEditFormNotes();
                        note_inp.val('');
                    });
                } else {
                    note_inp.focus();
                }

                return false;
            });

            userTab.tab.on('click', '#reset-secure-folders-password', function () {
                $('#secure-folders-admin-reset-confirmed', resetSFpasswordLB).prop('checked', false);
                $('#secure-folders-user-reset-confirmed', resetSFpasswordLB).prop('checked', false);
                $('.js-reset-password', resetSFpasswordLB).attr('disabled', 'disabled');
                resetSFpasswordLB.data('user-id', userId);
                show_lightbox(resetSFpasswordLB);
                return false;
            });

            function updateRefundButton() {
                var refundAmount = parseFloat($('.js-refund-amount', refundTransactionLB).inputmask('unmaskedvalue'));
                var transAmount = parseFloat(refundTransactionLB.data('trans-amount'));

                var amountValid = (!isNaN(refundAmount) && refundAmount > 0 && refundAmount <= transAmount);
                var refundTypeValid = $('.js-refund-type', refundTransactionLB).val() != '';
                var refundConfirmed = $('#refund-user-transaction-confirmed', refundTransactionLB).is(':checked');

                if (amountValid && refundConfirmed && refundTypeValid) {
                    $('.js-refund-user-transaction', refundTransactionLB).removeAttr('disabled');
                } else {
                    $('.js-refund-user-transaction', refundTransactionLB).attr('disabled', 'disabled');
                }
            }

            $('#refund-user-transaction-confirmed, .js-refund-type', refundTransactionLB).change(updateRefundButton);
 
            userTab.tab.on('click', '.admin-refund-transaction-btn', function () {
                var trans_id = $(this).data('trans-id');
                var trans_amount = $(this).data('trans-amount');
                var trans_amount_original = $(this).data('trans-amount-original');
                if(trans_amount_original !== null) {
                    var trans_amount_float = parseFloat(trans_amount);
                    var trans_amount_original_float = parseFloat(trans_amount_original);

                    if(trans_amount_original_float > trans_amount_float)
                        trans_amount = trans_amount_original;
                }

                var paymentAmount = $('.js-refund-amount', refundTransactionLB);

                $('#refund-user-transaction-confirmed', refundTransactionLB).prop('checked', false);
                paymentAmount.val(trans_amount);
                paymentAmount.inputmask({
                    oncomplete: function () {
                        updateRefundButton();
                    }
                }).autocomplete({
                    source: ODAdmin.autocompleteTransactions
                });

                $('.js-refund-type', refundTransactionLB).val('');
                $('.js-refund-user-transaction', refundTransactionLB).attr('disabled', 'disabled');

                refundTransactionLB.data('trans-id', trans_id);
                refundTransactionLB.data('trans-amount', trans_amount);
                show_lightbox(refundTransactionLB);

                return false;
            });

            refundTransactionLB.on('click', '.js-refund-user-transaction', function(){
                $('.js-refund-user-transaction', refundTransactionLB).attr('disabled', 'disabled');

                if(OpenDrive.extAjax) {

                    var trans_id = refundTransactionLB.data('trans-id');
                    var refund_amount = $('.js-refund-amount').inputmask('unmaskedvalue');
                    var refund_type = $('.js-refund-type').val();
                    OpenDrive.extAjax.do('admin.refund-transaction', {
                        user_id: userId,
                        transaction_id: trans_id,
                        refund_amount: refund_amount,
                        refund_type: refund_type
                    }, function (response) {
                        ODAdmin.loadTransactions();
                        $('.lightbox').hide();

                        $.magnificPopup.open({
                            items: {
                                type: 'inline',
                                src: '<div class="modal-popup">Transaction <b>' + trans_id + '</b> has been updated.</div>',
                                closeBtnInside: true
                            }
                        });

                    }, function() {
                        $('.js-refund-user-transaction', refundTransactionLB).removeAttr('disabled');
                    });
                    
                }

                return false;
            });

            userTab.tab.on('click', '#blacklist-user', function () {
                $('input[type=checkbox]', blacklistUserLB).prop('checked', false);
                resetSFpasswordLB.data('user-id', userId);
                show_lightbox(blacklistUserLB);
                return false;
            });

            var ODAdmin = new function () {
                var lastTransactionAmounts;

                this.autocompleteTransactions = function (request, response) {
                    var term = request.term.replace(/[^-0-9.,]/g, '');
                    term = term.replace(/\.0+$/, '');
                    if (lastTransactionAmounts && lastTransactionAmounts.length) response($.ui.autocomplete.filter(lastTransactionAmounts, term));
                };

                this.resetForm = function () {
                    $('.js-new_payment_amount', userTab.tab).val(0);
                    var inpTransDate = $('#new_payment_trans_date_' + userId, userTab.tab);
                    inpTransDate.val(inpTransDate.data('original-value'));
                };

                this.addTransactionsToAutocompleteList = function (transactions) {
                    lastTransactionAmounts = [];
                    var amount;
                    for (var i = 0; i < transactions.length; i++) {
                        amount = transactions[i].trans_amount.toString().replace(/,/g, '');
                        if (transactions[i].trans_status == 1 && lastTransactionAmounts.indexOf(amount) == -1) lastTransactionAmounts.push(amount);
                    }
                };

                function disableButtons() {
                    $('.js-admin-add-payment-btn', userTab.tab).addClass('disabled');
                }

                function enableButtons() {
                    $('.js-admin-add-payment-btn', userTab.tab).removeClass('disabled');
                }

                this.submitPayment = function () {
                    if ($(this).hasClass('disabled')) {
                        return false;
                    }
                    var new_payment_trans_date = $('#payment_trans_date_' + userId, userTab.tab).val(),
                        new_payment_amount = parseFloat($('.js-new_payment_amount', userTab.tab).val().replace(/[^-0-9.]/g, '')),
                        new_payment_processor = $('#new_payment_processor', userTab.tab).val(),
                        new_payment_trans_status = $('#new_payment_trans_status', userTab.tab).val(),
                        new_payment_trans_id = $('.js-new_payment_trans_id', userTab.tab).val().trim(),
                        new_payment_cc = $('.js-new_payment_cc', userTab.tab).val(),
                        new_payment_note = $('#new_payment_note', userTab.tab).val(),
                        new_payment_due_date = $('#payment_due_date', userTab.tab).val(),

                        data = {
                            trans_date: new_payment_trans_date,
                            amount: new_payment_amount,
                            processor: new_payment_processor,
                            trans_status: new_payment_trans_status,
                            trans_id: new_payment_trans_id,
                            cc: new_payment_cc,
                            note: new_payment_note,
                            due_date: new_payment_due_date,
                            user_id: userId
                        };

                    if (isNaN(new_payment_amount)) {
                        $('.js-new_payment_amount', userTab.tab).focus();
                        return false;
                    }

                    disableButtons();
                    OpenDrive.ajax.do('admin.add-new-payment', data, function () {
                        _this.loadTabContent(function () {
                            ItemTabs.getTab('<search>').data('ItemTab').loadTabContent(true);
                        });

                        enableButtons();
                    },
                        enableButtons);
                    return false;
                };

                this.loadPaymentFormNotes = function (completeCallback) {
                    reminderDropdown.removeClass('open');
                    OpenDrive.ajax.do('admin.get-last-user-notes', {user_id: userId}, function (notes) {
                        var noteslist = $('.js-notes-list', userTab.tab);
                        OpenDrive.helpers.applyTemplate({Notes: notes}, 'PaymentFormUserNotes', noteslist);
                        if (completeCallback instanceof Function) completeCallback();
                    });
                };

                this.fillUsageBar = function (user) {
                    user.space_width = user.MaxStorage ? Math.ceil(( user.StorageUsed * 100 ) / (user.MaxStorage * 1024 * 1024)) : 100;
                    user.downloads_width = user.BwMax ? Math.ceil(( user.BwUsed * 100 ) / (user.BwMax * 1024 * 1024)) : 100;
                    user.space_width = Math.min(100, user.space_width);
                    user.downloads_width = Math.min(100, user.downloads_width);
                    OpenDrive.helpers.applyTemplate(user, 'UserEditFormSpaceInfo', $('.js-user-info', userTab.tab));
                };

                userTab.tab.on('scroll', function () {
                    paymentAmount.autocomplete('close');
                });

                function loadAccountUsers() {
                    OpenDrive.ajax.do('admin.get-account-users', {user_id: userId}, function (account_users_response) {
                        $('#tab-users-content', userTab.tab).html(account_users_response.AccountUsers);
                    });
                }

                this.loadTransactions = function () {
                    if(OpenDrive.extAjax) {
                        OpenDrive.extAjax.do('admin.load-transactions', {user_id: userId}, function (transactions) {
                            OpenDrive.helpers.applyTemplate(transactions,
                                'UserEditFormTransactions',
                                $('.js-transactions-list', userTab.tab)
                            );
                        });
                    }
                }

                this.loadUserEditFormNotes = function () {
                    OpenDrive.ajax.do('admin.load-notes', {user_id: userId}, function (notes) {
                        OpenDrive.helpers.applyTemplate(notes,
                            'UserEditFormNotes',
                            $('#account-users-notes', userTab.tab)
                        )
                    });
                };

                this.loadLogs = function() {
                    var start_date = $('#activity_start_date_' + userId, userTab.tab).val();
                    var end_date = $('#activity_end_date_' + userId, userTab.tab).val();
                    var log_type = $("#activity_log_type", userTab.tab).val();
                    OpenDrive.ajax.do('admin.load-user-logs',
                        {
                            user_id: userId, start_date: start_date, end_date: end_date, log_type: log_type
                        },
                        function (logs_response) {
                            $('#account-users-logs', userTab.tab).html(logs_response.Logs);
                        }
                    );
                };

                function loadUserPlansHistory() {
                    OpenDrive.ajax.do('admin.load-account-history', {user_id: userId}, function (response) {
                        OpenDrive.helpers.applyTemplate(
                            {history: response},
                            'UserEditFormPlansHistory', $('.js-plans-history-list', userTab.tab)
                        );
                    });
                }

                function loadFilesStat() {
                    OpenDrive.ajax.do('admin.load-user-files-stat', {user_id: userId}, function (response) {
                        OpenDrive.helpers.applyTemplate(
                            {List: response},
                            'StatsFileList',
                            $('.js-list', userTab.tab)
                        );
                    });
                }

                this.loadUserData = function(type, tab) {
                    switch(type) {
                        case 'account-users':
                            loadAccountUsers();
                            break;

                        case 'user-logs':
                            ODAdmin.loadLogs();
                            break;
                        case 'transactions':
                            ODAdmin.loadTransactions();
                            break;
                        case 'notes':
                            ODAdmin.loadUserEditFormNotes();
                            break;
                        case 'account-history':
                            loadUserPlansHistory();
                            break;
                        case 'files-stat':
                            loadFilesStat();
                            break;
                        default:
                            $(document).trigger('od-admin-load-content.od', {
                                userId: userId,
                                type: type,
                                tab: userTab,
                                container: tab
                            });
                    }
                    tab.data('data-loaded', true);
                }

            };

            _this.loadTabContent(completeCallback);
        }

        var WindowHistory = new function () {
            this.push = function () {
                window.history.pushState(filterOptions, null, '/admin/users?' + $.param(filterOptions) );
            };

            window.addEventListener('popstate', function (e) {
                if (e && e.state) {
                    filterOptions = e.state;
                    searchTab.loadTabContent(true);
                }
            });

            return this;
        };

        var data = $.parseJSON($('#js-initial-data').html());


        function restoreCallback() {
            ItemTabs.sessionTabs.restore(function (opts) {
                if (opts && opts.data) {
                    if (ItemTabs.getTab(opts.id).length) {
                        setTimeout(restoreCallback, 0);
                    } else {
                        if (opts.data.userId) new UserTab(opts.data.userId, opts.data.type, true, restoreCallback);
                    }
                }
            })
        }
        var searchTab = new SearchTab(restoreCallback);

        $('.js-logout').click(function () {
            ItemTabs.sessionTabs.clear();
        });

        //to refactor

        $(".lightbox-header .lightbox-close-btn").click(function(){
            var lb = $(this).closest('.lightbox');
            lb.hide();
            var callback = lb.data('close_callback');
            if(callback instanceof Function) callback.apply(this, arguments);
            return false;
        });

        $(".lightbox").escape(function(){
            $(".lightbox").hide();
            var callback = $(this).data('close_callback');
            if(callback instanceof Function) callback.apply(this, arguments);
        });


        $('.js-save_close_reason', closeAccLB).click(function () {
            var tab = ItemTabs.getActiveTab();
            $('.js-close_reason_value', $("#admin-user-edit", tab)).val(closeReasonSelect.val());
            closeAccLB.hide();
            var close_reason_label = $('.js-close_reason_label', tab);
            close_reason_label.html('(' + closeReasonSelect[0].options[parseInt(closeReasonSelect.val()) - 1].innerHTML + ')');
            return false;
        });

        closeReasonSelect.change(function () {
            var tab = ItemTabs.getActiveTab();
            var closeReasonTitle = $('.js-close-reason-title', tab);
            if (this.value == '1') {
                reasonTextArea.removeAttr('disabled');
                closeReasonTitle.removeClass('disabled');
            }
            else {
                reasonTextArea.attr('disabled', 'disabled');
                closeReasonTitle.addClass('disabled');
            }
        });


        resetSFpasswordLB.on('click', '#secure-folders-admin-reset-confirmed, #secure-folders-user-reset-confirmed', function () {
            var checked = $('#secure-folders-admin-reset-confirmed', resetSFpasswordLB).prop('checked');
            checked = checked && $('#secure-folders-user-reset-confirmed', resetSFpasswordLB).prop('checked');
            if(checked) $('.js-reset-password', resetSFpasswordLB).removeAttr('disabled');
            else $('.js-reset-password', resetSFpasswordLB).attr('disabled', 'disabled');
        });

        resetSFpasswordLB.on('click', '.js-reset-password', function () {
            $('.js-reset-password', resetSFpasswordLB).attr('disabled', 'disabled');
            OpenDrive.ajax.do('admin.reset-secure-files-password', {user_id: resetSFpasswordLB.data('user-id')}, function () {
                $('.lightbox').hide();
                $.magnificPopup.open({
                    items: {
                        type: 'inline',
                        src: '<div class="modal-popup">Password is reseted.</div>',
                        closeBtnInside: true
                    }
                });
            }, function () {
                $('.lightbox').hide();
            });

            return false;
        });

        blacklistUserLB.on('click', '.js-blacklist-user', function () {
            var inputs = $('input:checked', blacklistUserLB);
            var data = {
                user_id: resetSFpasswordLB.data('user-id')
            };

            if (inputs.length == 0) {
                $('.lightbox').hide();
                return;
            }

            inputs.each(function () {
                data[this.name] = 1;
            });

            OpenDrive.ajax.do('admin.blacklist-user', data, function () {
                $('.lightbox').hide();
                $.magnificPopup.open({
                    items: {
                        type: 'inline',
                        src: '<div class="modal-popup">User data has been added to the blacklist</div>',
                        closeBtnInside: true
                    }
                });
            }, function () {
                $('.lightbox').hide();
            });

            return false;
        });

        function show_lightbox(wrapper)
        {
            wrapper.show();
        }
        $(".lightbox .js-cancel-btn").click(function(){
            $(".lightbox").hide();
            var callback = $(this).data('callback');
            if(callback instanceof Function) callback.apply(this, arguments);
            return false;
        });
    });
})(jQuery);
