(function ($) {
    $(function () {
        var rootMenu = $('.js-root-menu');

        $(".select-all-input").focus(function () {
            var $this = $(this);
            $this.select();

            // Work around Chrome's little problem
            $this.mouseup(function () {
                // Prevent further mouseup intervention
                $this.unbind("mouseup");
                return false;
            });
        });

        function closeDropdownMenus() {
            var menus = $('.dropdown-menu').parent();
            menus.removeClass('open');
            menus.each(function () {
                $('[aria-expanded="true"]', this).attr('aria-expanded', 'false')
            });
            $('.dropdown-menu.js-dynamic').remove();
        }

        $(document).on('click', function (e) {
            if (e.button != 2) closeDropdownMenus();
        });

        function isElementOutViewport(el) {
            if (el instanceof jQuery) {
                el = el[0];
            }
            if (!el) return false;
            var rect = el.getBoundingClientRect();


            if (rect.top >= 0 && rect.left >= 0) {
                if (rect.bottom > (window.innerHeight || document.documentElement.clientHeight) && rect.right > (window.innerWidth || document.documentElement.clientWidth)) {
                    return 'wh';
                }
                if (rect.bottom > (window.innerHeight || document.documentElement.clientHeight)) {
                    return 'h';
                }
                else if (rect.right > (window.innerWidth || document.documentElement.clientWidth)) {
                    return 'w';
                }
            }
            return false;
        }

        var InitOptions = $.parseJSON($('#js-init-data').html());

        var ItemTabs = new OpenDrive.widgets.ItemTabs('file', InitOptions.SessionToken);

        if (InitOptions.SelectedFolder != 'trash' && InitOptions.SelectedFolder != 'search') rootMenu.data('current-folder-id', InitOptions.SelectedFolder);

        function TabFileUploader($tab, uplFolderId, sessionId, endPoint) {
            var _this = this;
            var apiUploadArgs = {
                session_id: sessionId
            };

            this.setFolderId = function (folderId) {
                var sharingID = '';
                var folderInfo = folderId.toString().split('-');
                if (folderInfo.length == 2) {
                    folderId = folderInfo[0];
                    sharingID = folderInfo[1];
                }
                apiUploadArgs.folder_id = folderId;
                apiUploadArgs.sharing_id = sharingID;
            };

            _this.setFolderId(uplFolderId);

            $tab.on('click', '.js-context-replace', function () {
                var file_name_to_replace = $(this).closest(".item").find('.file-name').data('filename'),
                    replaceFileLightbox = $('#confirm-file-replace');
                var data = {
                    'filenames[]': file_name_to_replace,
                    folder_id: $tab.data('ItemTab').getFolderId()
                };
                setSingleFileUpload();
                closeDropdownMenus();

                OpenDrive.ajax.do('files.check-file-exists', data, function (response) {
                    if (response.result) {
                        //replaceFileLightbox.data('file_name_to_replace', file_name_to_replace);
                        replaceFileLightbox.find('.js-filename').html(file_name_to_replace);
                        replaceFileLightbox.data('is_replace', true);
                        extendedUploadArgs = {
                            advanced_upload: 1,
                            file_same_name: 2,
                            file_name_to_replace: file_name_to_replace
                        };
                        OpenDrive.widgets.LightBoxes.ReplaceFile.show();
                    }
                });
                return false;
            });

            $tab.on('click', '.js-context-upload-version', function (e) {
                var file_name_to_replace = $(this).closest('.item').find('.file-name').data('filename');
                setSingleFileUpload();
                extendedUploadArgs = {
                    advanced_upload: 1,
                    file_same_name: 2,
                    file_name_to_replace: file_name_to_replace
                };
                _this.fileInput.click();
                return false;
            });

            function addFile(res) {
                var container = $('.js-all-folders-files', $tab);
                var uploading_file = OpenDrive.helpers.applyTemplate(res, container.hasClass('files-grid') ? 'UploadingFileGridItem' : 'UploadingFileRowItem');
                container.prepend(uploading_file).addClass('is-uploading');
            }

            function removeFileFromHtml(id) {
                $('#file-' + id, $tab).remove();
            }

            function onUploadProgress(res, progress) {
                var uploader = $("#file-" + res.id, $tab);
                $(".progress-bar", uploader).css("width", (progress * 100) + '%');
            }

            var extendedUploadArgs = null;
            var replaceFileLightbox = $('#confirm-file-replace');

            this.acceptDnDFiles = function () {
                r.assignDrop($tab[0]);
            };

            this.isUploading = function () {
                return r.isUploading();
            }

            var r = new Resumable({
                target: endPoint,
                chunkSize: 20 * 1048576,
                query: function () {
                    return resumableQueryCallback.apply(this, arguments);
                },
                simultaneousUploads: 1,
                permanentErrors: [400, 401, 402, 403, 404, 409, 413, 415, 500, 503, 507],
                maxChunkRetries: 10,
                testChunks: false,
                maxFilesErrorCallback: function (files, errorCount) {
                    var maxFiles = r.getOpt('maxFiles');
                    OpenDrive.popups.showError('Please upload ' + maxFiles + ' file' + (maxFiles === 1 ? '' : 's') + ' at a time.');
                },
                minFileSizeErrorCallback: function (file, errorCount) {
                    OpenDrive.popups.showError(file.fileName || file.name + ' is too small, please upload files larger than ' + OpenDrive.helpers.humanFileSize(r.getOpt('minFileSize')) + '.');
                },
                maxFileSizeErrorCallback: function (file, errorCount) {
                    OpenDrive.popups.showError(file.fileName || file.name + ' is too large, please upload files less than ' + OpenDrive.helpers.humanFileSize(r.getOpt('maxFileSize')) + '.');
                }
            });

            if (!r.support) return false;

            var fileQueue = {};

            r.on('fileAdded', function (file) {
                var id = file.uniqueIdentifier;
                var name = file.fileName;
                var extenstion = file.fileName.split('.').pop();
                var size = file.size;

                var res = {"id": id, "name": name, "type": extenstion, "size": size};
                for (var fileId in fileQueue) {
                    if (fileQueue.hasOwnProperty(fileId)) {
                        if (fileQueue[fileId].name == name) {
                            r.removeFile(file);
                            OpenDrive.popups.showNotification(OpenDrive._('File_was_already_in_uploading_queue', {name: name}));
                            return;
                        }
                    }
                }

                var extendedUpload = extendedUploadArgs != null;

                fileQueue[id] = {
                    opts: extendedUploadArgs ? extendedUploadArgs : {
                        advanced_upload: 0, //0 to use source file name, 1 to use custom filename
                        file_same_name: '', //0 - normal upload, 2 - replace existing file (using file_name_to_replace in both cases)
                        file_name_to_replace: '' //filename for adv upload,
                    },
                    checked: extendedUpload ? 'yes' : 'no',
                    name: name
                };

                extendedUploadArgs = null;
                addFile(res);

                $('#file-' + id, $tab).on('click', '.upload-play-pause', function () {
                    $(this).closest('.item').toggleClass('paused');
                    if ($(this).closest('.item').hasClass('paused')) {
                        r.pause();
                    }
                    else {
                        r.upload();
                    }
                    return false;
                });
                if (Object.keys(fileQueue).length >= this.files.length) {
                    var fileNames = [];
                    var fileNamesId = {};
                    for (fileId in fileQueue) {
                        if (fileQueue.hasOwnProperty(fileId)) {
                            if (fileQueue[fileId].checked == 'no') {
                                fileNames.push(fileQueue[fileId].name);
                                fileQueue[fileId].checked = 'pending';
                                fileNamesId[fileQueue[fileId].name] = fileId;
                            }
                        }
                    }
                    if (fileNames.length && !extendedUpload) {
                        var data = {
                            'filenames[]': fileNames,
                            folder_id: $tab.data('ItemTab').getFolderId()
                        };

                        OpenDrive.ajax.do('files.check-file-exists', data, function (response) {
                            if (response && response.result && response.result.length) {
                                for (var fileId in fileQueue) {
                                    if (fileQueue.hasOwnProperty(fileId)) {
                                        if (fileQueue[fileId].checked == 'pending') {
                                            if (fileNames.indexOf(fileQueue[fileId].name) >= 0)fileQueue[fileId].checked = 'yes';
                                        }
                                    }
                                }
                                replaceFileLightbox.data('file_name_to_replace', fileNames);
                                replaceFileLightbox.find('.js-filename').html(response.result.join(', '));
                                OpenDrive.widgets.LightBoxes.ReplaceFile.show();
                            } else
                                r.upload();
                        }, function () {
                            for (var i = 0; i < fileNamesId.length; i++) {
                                fileQueue[fileNamesId[i]].checked = 'no';
                                //r.removeFile();
                            }
                        });
                    } else {
                        r.upload();
                    }
                }
            });
            r.on('fileSuccess', function (file) {
                //			r.opts.chunkSize = 1 * 1024 * 1024; // reset chunk size for every file
                var id = file.uniqueIdentifier;
                var name = file.fileName;
                var size = file.size;
                var res = {"id": id, "name": name, "size": size};
                onUploadProgress(res, 1);
                delete fileQueue[id];
                r.removeFile(file);
                delete apiUploadArgs.upload_id;
            });
            r.on('pause', function (file) {
            });
            r.on('complete', function () {
                delete apiUploadArgs.upload_id;
                if ($.isEmptyObject(fileQueue)) $tab.data('ItemTab').loadTabContent(true);
            });
            r.on('fileRetry', function (file) {
            });
            r.on('fileProgress', function (file, data) {
                var size = file.size;
                var progress = file.progress();
                var id = file.uniqueIdentifier;
                if (data) {
                    try {
                        data = JSON.parse(data);
                        if (data && data.upload_id) {
                            apiUploadArgs.upload_id = data.upload_id;
                        }
                    } catch (e) {
                    }
                }

                if (progress > 0) {
                    var name = file.fileName;
                    var res = {"id": id, "name": name, "size": size};
                    onUploadProgress(res, progress);
                }
            });
            r.on('fileError', function (file, message) {
                var errorMessage = '';
                try {
                    message = $.parseJSON(message);
                    if (message && message.error && message.error.message) {
                        errorMessage = message.error.message.toString();
                    }
                } catch (e) {
                }
                if (!errorMessage) errorMessage = OpenDrive._('Unable_to_upload_the_file');
                r.removeFile(file);
                delete fileQueue[file.uniqueIdentifier];
                delete apiUploadArgs.upload_id;
                $('#file-' + file.uniqueIdentifier, $tab).remove();
                if(message && message.error && message.error.code == 415)
                    OpenDrive.popups.showNotification(errorMessage);
                else
                    OpenDrive.popups.showError(errorMessage);
                if ($.isEmptyObject(fileQueue)) {
                    $('.js-all-folders-files', $tab).removeClass('is-uploading');
                }
            });

            function resumableQueryCallback(file, chunk) {
                var params = $.extend({}, apiUploadArgs);
                if (fileQueue[file.uniqueIdentifier]) $.extend(params, fileQueue[file.uniqueIdentifier].opts);
                return params;
            }

            $('#confirm-file-replace #confirm-replace-btn').click(function () {
                var replaceFileLightbox = $(this).closest('#confirm-file-replace');
                replaceFileLightbox.hide();
                var fileNames = replaceFileLightbox.data('file_name_to_replace');
                if (fileNames instanceof Array && fileNames.length) {
                    for (var fileId in fileQueue) {
                        if (fileQueue.hasOwnProperty(fileId)) {
                            if (fileQueue[fileId].checked == 'yes') {
                                if (fileNames.indexOf(fileQueue[fileId].name) >= 0) {
                                    fileQueue[fileId].opts = {
                                        advanced_upload: 1, //0 to use source file name, 1 to use custom filename
                                        file_same_name: 2, //0 - normal upload, 2 - replace existing file (using file_name_to_replace in both cases)
                                        file_name_to_replace: fileQueue[fileId].name //filename for adv upload,
                                    }
                                }
                            }
                        }
                    }
                }
                replaceFileLightbox.data('file_name_to_replace', null);

                if (replaceFileLightbox.data('is_replace')) {
                    replaceFileLightbox.data('is_replace', false);
                    _this.fileInput.click();
                }
                else r.upload();
                return false;
            });

            replaceFileLightbox.find('.js-cancel-btn').data('callback', function () {
                var fileNames = replaceFileLightbox.data('file_name_to_replace');
                if (fileNames instanceof Array && fileNames.length) {
                    for (var fileId in fileQueue) {
                        if (fileQueue.hasOwnProperty(fileId)) {
                            for (var i = 0, f; (f = r.files[i++]);) {
                                if (f.uniqueIdentifier == fileId) {
                                    f.cancel();
                                    delete fileQueue[fileId];
                                    removeFileFromHtml(fileId);
                                }
                            }
                        }
                    }
                }
                replaceFileLightbox.data('file_name_to_replace', null);
                replaceFileLightbox.data('is_replace', false);
                extendedUploadArgs = null;
            });

            this.resetUploadForm = function () {
                _this.fileInput.attr('multiple', true);
                extendedUploadArgs = null;
                replaceFileLightbox.data('is_replace', false);
            };

            function setSingleFileUpload() {
                _this.fileInput.attr('multiple', false);
            }

            this.initialize = function () {
                this.fileInput = $('<input type="file" class="hidden" multiple name="upl' + parseInt(Math.random() * 1e9) + '"/>');
                $(document.body).append(this.fileInput);
                _this.fileInput.on('drop', _this.resetUploadForm);
                r.assignBrowse(_this.fileInput);
            };

            this.initialize();

            return this;
        }

        function FolderTab(folderId, itemName, completeCallback, noHistoryChange) {
            var _this = this;
            var folderData;
            var $tab;
            var $breadcrumb;
            var itemsOffset = 0;
            var partialLoaded;
            var lastRequestTime = 0;
            var orderType = 'asc', orderBy = 'name';
            var itemsXhr;
            var downloadAllItems;
            var searchQuery = '';
            var tabId = 'folder-' + folderId;
            var searchTermTemp = null;      // we use searchTermTemp to allow user to apply filters of folders find by search

            this.getFolderId = function () {
                return folderId;
            };

            function initializeContent() {
                var thumbs = $('.js-file-thumb', $tab);
                thumbs.lazyload({
                    threshold: 100,
                    container: $tab,
                    skip_invisible: false,
                    load: function () {
                        $(this)
                            .removeClass('js-file-thumb')
                            .removeData('original')
                            .css('background-size', 'contain');
                    },
                    error: function (naturalWidth, naturalHeight) {
                        if (!naturalWidth && !naturalHeight) {
                            $(this).closest('.js-content-item').addClass('type-unknown');
                        }
                    }
                });
                setTimeout(function () {
                    $('.js-all-folders-files .recently-uploaded', $tab).removeClass('recently-uploaded');
                }, 20000);
                truncateNames();

                $('.js-all-folders-files > .folder-item.droppable', $tab)
                    .removeClass('droppable')
                    .droppable({
                        activeClass: 'can-drop',
                        hoverClass: 'drop-active',
                        greedy: true,
                        scope: 'draggablefiles',
                        tolerance: 'pointer',
                        drop: DnDHandler
                    });

                var isTouch;
                if (('ontouchstart' in window) || window.DocumentTouch && document instanceof DocumentTouch) {
                    isTouch = true;
                }
                if (!isTouch) {
                    $('.js-all-folders-files > .js-content-item.draggable', $tab)
                        .removeClass('draggable')
                        .draggable({
                            cursorAt: {left: 10, top: 10},
                            delay: 500,
                            scope: 'draggablefiles',
                            revert: 'invalid',
                            containment: 'window',
                            helper: 'clone',
                            appendTo: 'body',
                            cursor: 'move',
                            distance: 10,
                            scroll: false,
                            zIndex: 99999
                        });
                }
            }

            function DnDHandler(event, ui) {
                var drop = $(this);
                var drag = ui.draggable;
                var dest_folder_id = drop.hasClass('root-dir') ? 0 : drop.attr('id').replace('folder-', '');

                if (drag.hasClass('file-item')) {
                    // move file
                    var src_file_id = drag.attr('id').replace('file-', '');

                    drag.hide();

                    OpenDrive.ajax.do('files.move-file', {
                            src_file_id: src_file_id, dest_folder_id: dest_folder_id
                        },
                        function () {
                            drag.remove()
                        },
                        function () {
                            drag.show();
                        });
                }
                else {
                    // move folder
                    var src_folder_id = drag.attr('id').replace('folder-', '');

                    drag.hide();

                    OpenDrive.ajax.do('files.move-folder',
                        {
                            src_folder_id: src_folder_id, dest_folder_id: dest_folder_id
                        },
                        function () {
                            drag.remove()
                        },
                        function () {
                            drag.show();
                        });
                }
            }

            _this.setTabFolderId = function (selectedFolderId, noHistoryChange, data) {
                tabId = 'folder-' + selectedFolderId;
                if (!data) data = {};
                orderType = 'asc';
                orderBy = 'name';
                rootMenu.data('current-folder-id', selectedFolderId);
                $breadcrumb.removeData('itemid').attr('data-itemid', tabId);
                $tab.removeData('itemid').attr('data-itemid', tabId);
                ItemTabs.getTabHeader('folder-' + folderId).removeData('itemid').attr('data-itemid', tabId);
                folderId = selectedFolderId;
                _this.fileUploader.setFolderId(selectedFolderId);
                _this.loadTabContent(true, noHistoryChange, null, data);
                ItemTabs.activateTab('folder-' + selectedFolderId, {noHistoryChange: true, sharingID: data.sharing_id});
            };

            function initBreadcrumbEvents() {
                if ($breadcrumb.data('_eventsInitialized')) return;
                else $breadcrumb.data('_eventsInitialized', true);

                $breadcrumb.on('click', '.js-selectall', function () {
                    var $this = $(this);
                    $this.toggleClass('selected');

                    if ($this.hasClass('selected')) {
                        downloadAllItems = true;
                        $('.js-content-item', $tab).addClass('selected');
                    }
                    else {
                        downloadAllItems = false;
                        $('.js-content-item', $tab).removeClass('selected');
                    }

                    dashboard_menu_active();
                    return false;
                });

                $breadcrumb.on('click', '.js-create-new-file', function () {
                    var file_type = $(this).attr('id').replace("new-file-", '');
                    var access_folder_id = 0;

                    OpenDrive.ajax.do('create-file', {
                        file_type: file_type,
                        access_folder_id: access_folder_id,
                        folder_id: folderId
                    }, function (response) {
                        _this.loadTabContent(true, true, function () {
                            if (response.FileId) {
                                var item = $tab.find('.js-content-item#file-' + response.FileId);
                                if (item.length) {
                                    var delta = item.offset().top - $tab.offset().top;
                                    $tab.animate({
                                        scrollTop: delta
                                    }, 300)
                                }
                            }
                        });
                    });

                    return false;
                });

                $breadcrumb.on('click', '.js-menu-upload-btn', function () {
                    if (!$(this).hasClass('permanent-disabled')) {
                        _this.fileUploader.resetUploadForm();
                        _this.fileUploader.fileInput.click();
                    }
                    return false;
                });

                $breadcrumb.on('click', "#trash-restore-btn", function () {

                    var selected_elements = $(".item.selected");
                    if (!$(this).hasClass('disabled') && !$(this).hasClass('permanent-disabled') && selected_elements.length > 0) {
                        $.each(selected_elements, function (index, one_element) {
                            one_element = $(one_element);
                            var element_id = one_element.attr('id');
                            var post_data = false;
                            var action;
                            if (one_element.hasClass('folder-item')) {
                                var folder_id = element_id.replace('folder-', '');
                                post_data = {folder_id: folder_id};
                                action = 'trash-folder-restore';
                            }
                            else if (one_element.hasClass('file-item')) {
                                var file_id = element_id.replace('file-', '');
                                post_data = {file_id: file_id};
                                action = 'trash-file-restore';
                            }

                            if (post_data) {
                                OpenDrive.ajax.do(action, post_data, function () {
                                    one_element.remove();
                                    Trash.refresh();
                                });
                            }
                        });
                    }

                    return false;
                });

                $breadcrumb.on('click', "#menu-trash-btn", function () {
                    var btn = $(this);
                    if (!btn.hasClass('disabled') && !btn.hasClass('permanent-disabled')) {
                        var selected_elements = $('.item.selected', $tab);
                        if (selected_elements.length == 0) {
                            OpenDrive.popups.showNotification(OpenDrive._('No_items_selected'));
                            return false;
                        }

                        if (selected_elements.length > 0 && confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                            var files = [], folders = [];
                            $.each(selected_elements, function (index, one_element) {
                                one_element = $(one_element);
                                var element_id = one_element.attr('id');
                                if (one_element.hasClass('folder-item')) {
                                    folders.push(element_id.replace('folder-', ''));
                                }
                                else if (one_element.hasClass('file-item')) {
                                    files.push(element_id.replace('file-', ''));
                                }


                            });

                            if (folders.length || files.length) {
                                $('.js-all-folders-files', $tab).append('<div class="js-loading"><div class="files-blocker"></div><i class="fa fa-refresh fa-2x fa-spin spin-loading"></i></div>');
                            }

                            if (folders.length) {
                                btn.addClass('disabled');
                                OpenDrive.ajax.do('files.trash-folder', {folder_id: folders.join()}, function () {
                                    if (files.length) {
                                        OpenDrive.ajax.do('trash-file', {
                                            file_id: files.join(),
                                            folder_id: folderId
                                        }, function () {
                                            _this.loadTabContent(true, true);
                                            btn.removeClass('disabled');
                                        });
                                    } else {
                                        _this.loadTabContent(true, true);
                                        btn.removeClass('disabled');
                                    }
                                }, function () {
                                    _this.loadTabContent(true, true);
                                    btn.removeClass('disabled');
                                });
                            } else {
                                btn.addClass('disabled');
                                if (files.length) {
                                    OpenDrive.ajax.do('trash-file', {
                                        file_id: files.join(),
                                        folder_id: folderId
                                    }, function () {
                                        _this.loadTabContent(true, true);
                                        btn.removeClass('disabled');
                                    }, function () {
                                        _this.loadTabContent(true, true);
                                        btn.removeClass('disabled');
                                    });
                                }
                            }
                        }
                    }
                    return false;
                });

                $breadcrumb.on('click', "#trash-delete-btn", function () {
                    if (!$(this).hasClass('disabled') && !$(this).hasClass('permanent-disabled')) {
                        if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                            var selected_elements = $(".item.selected");
                            if (selected_elements.length > 0) {
                                $.each(selected_elements, function (index, one_element) {
                                    one_element = $(one_element);
                                    var element_id = one_element.attr('id');
                                    var post_data = false;
                                    var action;
                                    if (one_element.hasClass('folder-item')) {
                                        var folder_id = element_id.replace('folder-', '');
                                        post_data = {folder_id: folder_id};
                                        action = 'trash-folder-remove';
                                    }
                                    else if (one_element.hasClass('file-item')) {
                                        var file_id = element_id.replace('file-', '');
                                        post_data = {action: 'trash-file-remove', file_id: file_id};
                                        action = 'trash-file-remove';
                                    }

                                    if (post_data) {
                                        OpenDrive.ajax.do(action, post_data, function () {
                                            one_element.remove();
                                            Trash.refresh();
                                        });
                                    }
                                });
                            } else {
                                OpenDrive.popups.showNotification(OpenDrive._('No items selected.'));
                            }
                        }
                    }
                    return false;
                });


                $breadcrumb.on('click', '#menu-download-btn', function () {
                    var $selected_items = $('.item.selected', $tab),
                        api_url = InitOptions.ZipEndPoint,
                        session_id = InitOptions.SessionId,
                        item_arr,
                        files = [],
                        folders = [];

                    if (downloadAllItems) {
                        folders.push(folderId);
                    } else {
                        $.each($selected_items, function () {
                            item_arr = $(this).attr('id').split('-');
                            if (item_arr[0] == 'folder') {
                                folders.push(item_arr[1])
                            }
                            if (item_arr[0] == 'file') {
                                files.push(item_arr[1])
                            }
                        });
                    }

                    if (files.length || folders.length) {
                        if (confirm(OpenDrive._('Do_you_want_to_download_selected_items'))) {

                            var form = $('#zip_download_form');
                            if (!form.length) {
                                form = $('<form><input type="hidden" id="session_id" name="session_id"/><input type="hidden" name="files" id="files"/><input type="hidden" name="folders" id="folders"/></form>');
                                document.body.appendChild(form[0]);
                                form[0].action = api_url;
                                form[0].target = '_self';
                                form[0].method = 'post';
                            }
                            form[0].elements['session_id'].value = session_id;
                            form[0].elements['files'].value = files.join();
                            form[0].elements['folders'].value = folders.join();
                            form[0].submit();
                        }
                    } else {
                        OpenDrive.popups.showNotification(OpenDrive._('No_items_selected'));
                    }
                });


                $breadcrumb.on('click', "#submenu-new-folder-btn", function () {
                    return false;
                });
            }

            function dashboard_menu_active() {
                if (folderId == 'trash') {
                    if ($(".item.selected", $tab).length == 0) {
                        $("#trash-delete-btn", $breadcrumb).addClass('disabled').attr('aria-disabled', 'true');
                        $("#trash-restore-btn", $breadcrumb).addClass('disabled').attr('aria-disabled', 'true');
                    }
                    else {
                        $("#trash-delete-btn", $breadcrumb).removeClass('disabled').attr('aria-disabled', 'false');
                        $("#trash-restore-btn", $breadcrumb).removeClass('disabled').attr('aria-disabled', 'false');
                    }
                }
                else {
                    if (folderId == 0) {
                        $("#menu-request-btn", $breadcrumb).addClass('disabled').attr('aria-disabled', 'true');
                    }
                    if ($(".item.selected", $tab).length == 0) {
                        $("#menu-download-btn", $breadcrumb).addClass('disabled').attr('aria-disabled', 'true');
                        $("#menu-trash-btn", $breadcrumb).addClass('disabled').attr('aria-disabled', 'true');
                    }
                    else {
                        $("#menu-download-btn", $breadcrumb).removeClass('disabled').attr('aria-disabled', 'false');
                        $("#menu-trash-btn", $breadcrumb).removeClass('disabled').attr('aria-disabled', 'false');
                    }
                }
            }

            function openItemContextMenu($item) {
                closeDropdownMenus();

                var menu = $('.dropdown-menu', $item);
                if (!menu.length) {
                    var menuHtml, data;

                    menuHtml = $item.hasClass('file-item')
                        ? OpenDrive.helpers.applyTemplate(
                        {
                            ParentFolderId: folderId,
                            InitOptions: InitOptions,
                            FolderReadOnly: folderData.FolderReadOnly,
                            EditLink: $item.data('editlink'),
                            GroupID: $item.data('file_group_id'),
                            FileId: $item.attr('id').replace('file-', '')
                        }, 'FilePopupMenu')
                        : OpenDrive.helpers.applyTemplate(
                        {
                            ParentFolderId: folderId,
                            FolderReadOnly: folderData.FolderReadOnly,
                            EditLink: $item.data('editlink'),
                            InitOptions: InitOptions,
                            FolderId: $item.attr('id').replace('folder-', '')
                        }, 'FolderPopupMenu');
                    $item.find($item.hasClass('list-item') ? '.hover-btns' : '.js-item-menu-btn').after(menuHtml);
                    menu = $('.dropdown-menu', $item);
                }
                menu.removeClass('bottom-aligned-menu left-aligned-menu left-bottom-aligned-menu');
                menu.parent().addClass('open');

                var menuPosition = isElementOutViewport(menu);
                if (menuPosition == 'h' || menuPosition == 'wh') {
                    menu.addClass('bottom-aligned-menu');
                }
                else if (menuPosition == 'w') {
                    menu.addClass('left-aligned-menu');
                }

                $item.addClass('active');
            }

            function showLoader(state) {
                var loader = $('.js-partial-content', $tab);
                if (state) loader.show();
                else loader.hide();
            }

            function initTabEvents() {
                truncateNames();

                if ($tab.data('_eventsInitialized')) return;
                else $tab.data('_eventsInitialized', true);

                $tab.on('click', '.js-item-checkbox', function () {
                    $(this).closest('.js-content-item').toggleClass('selected');
                    downloadAllItems = false;
                    dashboard_menu_active();
                    return false;
                });

                $tab.on('contextmenu', '.js-content-item', function () {
                    openItemContextMenu($(this));
                    return false;
                });

                $tab.on('click', '.js-content-item .js-item-menu-btn', function () {
                    openItemContextMenu($(this).closest('.js-content-item', $tab));
                    this.setAttribute('aria-expanded', 'true');
                    return false;
                });


                $(window).resize(function () {
                    if ($tab.is(':visible')) truncateNames();
                });

                $tab.on('click', '.js-sort-table', function () {
                    var sort_link = $(this);
                    var order = 'asc';
                    if (sort_link.hasClass('order-asc')) {
                        order = 'desc';
                    }

                    $('.js-sort-table', $tab)
                        .removeClass('order-asc')
                        .removeClass('order-desc');

                    if (order == 'asc') {
                        sort_link.addClass('order-asc');
                    }
                    else {
                        sort_link.addClass('order-desc');
                    }
                    orderType = order;
                    orderBy = sort_link.data('sort-by');
                    if (orderBy) {
                        _this.loadTabContent(true, true, null, {searchTerm: searchTermTemp});
                    }

                    return false;
                });

                $tab.on('click', '.js-content-item .file-name, .js-content-item .folder-name', function () {
                    var name_label = $(this);

                    var all_folders_files = $(this).closest('.js-all-folders-files');
                    if (all_folders_files.length > 0 && all_folders_files.data('rename-enabled')) {
                        if (name_label.hasClass('editing')) return true;

                        var name = name_label.data('filename');
                        var item = name_label.closest('.js-content-item');

                        var rename_input = $('<input type="text" class="rename-item">');
                        rename_input.val(name);
                        name_label.html(rename_input).addClass('editing');
                        $(".rename-item", name_label).focus();
                        rename_input.on('click', function (e) {
                            e.stopPropagation();
                        })
                    }

                    return false;
                });

                $tab.on('click', '.js-content-item.folder-item', function () {
                    if (folderId != 'trash') {
                        var selectedFolderId = this.id.replace('folder-', '');
                        var sharingId = this.getAttribute('data-sharing-id');
                        _this.setTabFolderId(selectedFolderId, false, {sharing_id: sharingId});
                        rootMenu.trigger('load-subfolders.od', {
                            folderId: folderId ? selectedFolderId : folderId,
                            complete: function () {
                            }
                        });
                    }

                    return false;
                });

                $tab.on('click', '.js-context-move-link', function () {
                    OpenDrive.widgets.LightBoxes.MoveItem.show($(this).closest('.js-content-item'));
                    closeDropdownMenus();
                    return false;
                });

                $tab.on('click', '.js-context-copy-link', function () {
                    OpenDrive.widgets.LightBoxes.CopyItem.show($(this).closest('.js-content-item'));
                    closeDropdownMenus();
                    return false;
                });

                $tab.on('click', '.js-context-send-by-email', function () {
                    var this_item = $(this).closest('.js-content-item');

                    $('.item.active', $tab).removeClass('active');
                    this_item.addClass('active');

                    closeDropdownMenus();
                    OpenDrive.widgets.LightBoxes.SendByEmail.show(this_item);
                    return false;
                });

                $tab.on('click', '.js-context-edit-link', function () {
                    var this_item = $(this).closest('.js-content-item');
                    if (this_item.length) {
                        var filename = this_item.find('.js-file-name').data('filename')
                        var file_id = this_item.attr('id').replace('file-', '');
                        new DocumentFileTab(file_id, folderId, filename);
                    }
                    return false;
                });

                $tab.on('click', '.js-context-links-link', function () {
                    var this_item = $(this).closest('.js-content-item');
                    $(".item.active", $tab).removeClass('active');
                    this_item.addClass('active');
                    var privateItem = this_item.data('access') == 0;
                    closeDropdownMenus();
                    OpenDrive.widgets.LightBoxes.ContextLink.show(this_item, privateItem);

                    return false;
                });

                $tab.on('click', '.js-context-expiring-links-link', function () {
                    var this_item = $(this).closest('.js-content-item');
                    $(".item.active", $tab).removeClass('active');
                    this_item.addClass('active');
                    var privateItem = this_item.data('access') == 0;
                    closeDropdownMenus();
                    OpenDrive.widgets.LightBoxes.ContextExpiringLink.show(this_item, privateItem);

                    return false;
                });

                $tab.on('click', '.js-contex-file-versions', function () {

                    var this_item = $(this).closest('.item');

                    $('.item.active', $tab).removeClass('active');
                    this_item.addClass('active');

                    if (this_item.hasClass('file-item')) {
                        closeDropdownMenus();
                        OpenDrive.widgets.LightBoxes.FileVersions.show(this_item);
                    }

                    return false;
                });

                $tab.on('click', '.js-context-remove-file', function () {
                    if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                        var one_element = $(this).closest(".item");
                        var file_id = one_element.attr("id").replace('file-', '');

                        OpenDrive.ajax.do('trash-file-remove', {file_id: file_id}, function () {
                            one_element.fadeOutRemove();
                            Trash.refresh();
                        });
                    }
                    return false;
                });

                $tab.on('click', '.js-context-restore-file', function () {
                    var one_element = $(this).closest(".item");
                    var file_id = one_element.attr("id").replace('file-', '');

                    OpenDrive.ajax.do('trash-file-restore', {file_id: file_id}, function () {
                        one_element.fadeOutRemove();
                        Trash.refresh();
                    });

                    return false;
                });

                $tab.on('click', '.js-context-remove-folder', function () {
                    if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                        var one_element = $(this).closest(".item");
                        var folder_id = one_element.attr("id").replace('folder-', '');


                        OpenDrive.ajax.do('trash-folder-remove', {folder_id: folder_id}, function () {
                            one_element.remove();
                            Trash.refresh();
                        });
                    }
                    return false;
                });

                $tab.on('click', ".js-context-restore-folder", function () {
                    var one_element = $(this).closest(".item");
                    var folder_id = one_element.attr("id").replace('folder-', '');

                    OpenDrive.ajax.do('trash-folder-restore', {folder_id: folder_id}, function () {
                        one_element.remove();
                        Trash.refresh();
                    });

                    return false;
                });


                $tab.on('click', '.js-context-trash-link', function () {

                    var this_item = $(this).closest('.item');
                    closeDropdownMenus();

                    if (this_item.hasClass('file-item')) {
                        var file_id = this_item.attr('id').replace('file-', '');
                        if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                            OpenDrive.ajax.do('trash-file', {file_id: file_id, folder_id: folderId}, function () {
                                this_item.remove();
                                Trash.refresh();
                            });
                        }

                    }
                    else {
                        var folder_id = this_item.attr('id').replace('folder-', '');
                        if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                            OpenDrive.ajax.do('files.trash-folder', {folder_id: folder_id}, function () {
                                this_item.remove();
                                $(document).trigger('item-trashed.od', {folderId: folder_id});
                            });
                        }
                    }

                    return false;
                });

                $tab.on('click', '.js-file', function (e) {
                    if ($(e.srcElement).hasClass('js-context-download'))return;
                    var file = $(this).closest('.js-content-item');
                    if (InitOptions.Public) {
                        var url = file.data('directlink');
                        if (url) {
                            var a = document.querySelector('.js-new-file-link');
                            if (!a) {
                                a = document.createElement('a');
                                a.className = 'js-new-file-link';
                                a.target = '_blank';
                                a.style.display = 'none';
                                document.body.appendChild(a);
                            }
                            a.href = url;
                            a.click();
                        }
                        return false;
                    }
                    var fileId = file[0].id.replace('file-', '');
                    var name = file.find('.js-file-name').data('filename');

                    if (file.hasClass('type-img')) new ImageFileTab(fileId, folderId, name);
                    else if (file.hasClass('type-document')) new DocumentFileTab(fileId, folderId, name);
                    else if (file.hasClass('type-pdf')) new PDFFileTab(fileId, folderId, name);
                    else new PreviewFileTab(fileId, folderId, name);
                    return false;
                });

                $tab.on('click', '.js-context-properties-link', function () {
                    var this_item = $(this);
                    var item = this_item.closest('.js-content-item');
                    $('.item.active', $tab).removeClass('active');
                    this_item.addClass('active');
                    if (item.hasClass('file-item')) {
                        var itemFileId = item.attr('id').replace('file-', '');
                        OpenDrive.widgets.LightBoxes.FileContextProperties.show(itemFileId, folderId);
                    }
                    else if (item.hasClass('folder-item')) {
                        var itemFolderId = item.attr('id').replace('folder-', '');
                        OpenDrive.widgets.LightBoxes.FolderContextProperties.show(itemFolderId, folderId);
                    }
                    return false;
                });

                $tab.on('focusout keypress', '.js-content-item input.rename-item', function (event) {
                    if (!event.keyCode || event.keyCode == 13) {
                        try {
                            var name_input = $(this);
                            var name_label = name_input.closest('label');
                            var new_name = name_input.val();
                            var item = name_input.closest('.js-content-item');
                            var is_folder = false;
                            if (item.hasClass('folder-item')) {
                                is_folder = true;
                            }

                            name_input.remove();
                            name_label.text(new_name).attr('title', new_name).removeClass('editing');

                            if (is_folder) {
                                var folder_id = item.attr('id').replace('folder-', '');

                                OpenDrive.ajax.do('files.rename-folder',
                                    {folder_id: folder_id, folder_name: new_name},
                                    function (response) {
                                        $tab.data('ItemTab').cache.renameItem({folderId: folder_id, name: new_name});
                                        try {
                                            name_label
                                                .text(response.Name)
                                                .data('filename', response.Name)
                                                .attr('title', response.Name)
                                                .ellipsisMiddle({reinitialize: true});
                                            rootMenu.find('#folder-' + folder_id + ' > a .js-folder-name').eq(0).text(response.Name);
                                        } catch (e) {
                                        }
                                    }, function () {
                                        name_label.text(name_label.data('filename')).ellipsisMiddle({reinitialize: true});
                                    });
                            }
                            else {
                                var file_id = item.attr('id').replace('file-', '');

                                OpenDrive.ajax.do('files.rename-file', {
                                    file_id: file_id,
                                    folder_id: folderId,
                                    file_name: new_name
                                }, function (response) {
                                    item.data('streaminglink', response.StreamingLink);
                                    item.data('downloadlink', response.DownloadLink);
                                    $tab.data('ItemTab').cache.renameItem({fileId: file_id, name: new_name});
                                    try {
                                        name_label
                                            .text(response.Name)
                                            .data('filename', response.Name)
                                            .attr('title', response.Name)
                                            .ellipsisMiddle({reinitialize: true});
                                    } catch (e) {
                                    }
                                }, function () {
                                    name_label.text(name_label.data('filename')).ellipsisMiddle({reinitialize: true});
                                });
                            }
                        } catch (e) {

                        }
                        return false;
                    }
                });

                $tab.on('scroll', function (e) {
                    var threshold = 330;
                    if (this.scrollHeight - this.clientHeight - this.scrollTop <= threshold) {
                        _this.loadTabContent(false, true, null, {partialLoading: true});
                    }
                });

                $(document).on('item-trashed.od', function (e, data) {
                    if (data && data.folderId) {
                        $('#folder-' + data.folderId, $tab).remove();
                        if (folderId == data.folderId) {
                            _this.setTabFolderId(0, false);
                        } else if (folderData && folderData.Breadcrumbs instanceof Array) {
                            for (var i = 0, bc; (bc = folderData.Breadcrumbs[i++]);) {
                                if (bc.FolderID && data.folderId == bc.FolderID) {
                                    _this.setTabFolderId(0, false);
                                    break;
                                }
                            }
                        }
                        $('#folder-' + data.folderId, rootMenu).fadeOutRemove();
                        _this.cache.deleteItem(data);
                    }
                });
            }

            function truncateNames() {
                var innerHeight = window.innerHeight;
                $('.js-truncate', $tab).each(function () {
                    var rect = this.getBoundingClientRect();
                    if (rect.bottom > innerHeight || rect.top < 0 || rect.left < 0) return;
                    OpenDrive.helpers.ellipsisMiddle(this);
                })
            }

            function onClose() {
            }

            function onActivate(id, args) {
                if (!args) args = {};
                if (!args.noHistoryChange) WindowHistory.pushFolder(folderId);
                truncateNames();
            }

            function onSave() {
                return {
                    folderId: folderId
                }
            }

            function onWakeUp() {

            }

            this.render = function (itemsAppended, partialData) {
                if (itemsAppended) {
                    partialData.InitOptions = InitOptions
                    $tab.find('.js-all-folders-files').append(OpenDrive.helpers.applyTemplate(partialData, 'FolderContentList'));
                } else {
                    folderData.InitOptions = InitOptions;
                    OpenDrive.helpers.applyTemplate(folderData, 'FolderContent', $tab);
                }

                initializeContent();

                if (!itemsAppended) {
                    //_this.fileUploader.initialize();
                    _this.fileUploader.acceptDnDFiles();
                }
            };

            this.setViewMode = function (mode) {
                InitOptions.ViewMode = mode;
            };

            this.loadTabContent = function (reload, noHistoryChange, completeCallback, data) {
                if (!data) data = {};
                var partialLoading = data.partialLoading;
                if (partialLoading && _this.fileUploader.isUploading()) return;
                if (partialLoaded && partialLoading) return;
                if (!partialLoading) ItemTabs.setTabLoadedStatus(tabId);
                else showLoader(true);
                if (reload) {
                    downloadAllItems = false;
                    itemsOffset = 0;
                    lastRequestTime = 0;
                    searchQuery = '';
                }

                var folderParams = {
                    folder_id: folderId,
                    with_breadcrumbs: 1,
                    last_request_time: lastRequestTime,
                    public: InitOptions.Public,
                    offset: itemsOffset,
                    order_by: orderBy,
                    order_type: orderType
                };


                if ('searchTerm' in data) {
                    searchTermTemp = folderParams.search_query = data.searchTerm;
                    searchQuery = folderParams.search_query;
                }
                else
                    searchTermTemp = null;

                if (searchQuery != '')folderParams.search_query = searchQuery;
                if (data.sharing_id) folderParams.sharing_id = data.sharing_id;

                $tab.addClass('scrollable folder');
                $tab.data('ItemTab', _this);

                if (itemsXhr) {
                    if (itemsXhr.__folderId !== folderId) itemsXhr.abort();
                    else return;
                }

                itemsXhr = OpenDrive.ajax.do(
                    'files.load-folder-content',
                    folderParams,
                    function (response) {
                        itemsXhr = null;
                        if (response) {
                            var breadcrumbs = {
                                UploadAllowed: folderId != 'trash' && folderId != 'search' && InitOptions.UploadEnabled,
                                Breadcrumbs: (response.Breadcrumbs && response.Breadcrumbs.length > 2) ? response.Breadcrumbs.slice(2) : response.Breadcrumbs,
                                BreadcrumbsTruncated: response.Breadcrumbs && response.Breadcrumbs.length > 2,
                                UserAccessMode: response.UserAccessMode,
                                DownloadAllowed: folderId != 'trash' && InitOptions.DownloadEnabled,
                                CanCreateItems: folderId != 'trash' && folderId != 'search' && response.UserAccessMode !== 0 && !InitOptions.Public,
                                SiteConfig: InitOptions,
                                FolderId: folderId,
                                SharedUserName: response.SharedUserName,
                                ItemId: tabId
                            };
                            if (!noHistoryChange) WindowHistory.pushFolder(folderId);
                            if ('PublicUpload' in response) breadcrumbs.UploadAllowed = breadcrumbs.UploadAllowed && response.PublicUpload;
                            if (!partialLoading) {
                                if (reload) {
                                    var breadcrumbVisible = $breadcrumb.css('display');
                                    OpenDrive.helpers.applyTemplate(
                                        breadcrumbs,
                                        'BreadCrumbItem',
                                        $breadcrumb, true
                                    );
                                    $breadcrumb = ItemTabs.getBreadCrumb(tabId);
                                    $breadcrumb.css('display', breadcrumbVisible);
                                    ItemTabs.updateTabTitle(tabId, response.Name);
                                }
                                ItemTabs.setTabLoadedStatus(tabId, true);
                                folderData = response;
                                partialLoaded = false;
                            } else {
                                if (folderData.Files) Array.prototype.push.apply(folderData.Files, response.Files);
                                if (folderData.Folders) Array.prototype.push.apply(folderData.Folders, response.Folders);
                                showLoader(false);
                                if (folderData.Files && folderData.Folders) {
                                    if (!response.Files.length && !response.Folders.length) partialLoaded = true;
                                }
                            }

                            folderData.OrderType = orderType;
                            folderData.OrderBy = orderBy;

                            var DirUpdateTime = parseInt(response.DirUpdateTime);
                            if (DirUpdateTime != lastRequestTime && lastRequestTime && folderId != 0) {
                                partialLoading = false;
                                partialLoaded = false;
                                if (response.Files && response.Folders) {
                                    itemsOffset = response.Files.length + response.Folders.length;
                                }
                            } else {
                                if (response.Files && response.Folders) {
                                    itemsOffset += response.Files.length + response.Folders.length;
                                }
                            }

                            lastRequestTime = DirUpdateTime;

                            response.FolderId = folderId;

                            _this.render(partialLoading, response);
                            if (!partialLoading) {
                                initTabEvents();
                                initBreadcrumbEvents();
                                dashboard_menu_active();
                                if (folderId == 'search' || folderId == 'trash' || folderId == 'shared_users') {
                                    $('.js-item-search-field').attr('disabled', true).attr('placeholder', OpenDrive._('Search'));
                                } else {
                                    $('.js-item-search-field').attr('disabled', false).attr('placeholder', OpenDrive._('Search_in') + ' ' + response.RealName);
                                }
                                ItemTabs.sessionTabs.save();
                                $(document).trigger('folder-loaded.od', response);

                                if (completeCallback instanceof Function) completeCallback();
                                completeCallback = null;
                            }
                        }
                    }, function () {
                        itemsXhr = null;
                        showLoader(false);
                    });
                itemsXhr.__folderId = folderId;
            };

            this.cache = {
                deleteItem: function (data) {
                    if (data && folderData) {
                        if (data.folderId) {
                            for (var i = 0, f; (f = folderData.Folders[i++]);) {
                                if (f.FolderID === data.folderId) {
                                    folderData.Folders.splice(i - 1, 1);
                                    break;
                                }
                            }
                        } else if (data.fileId) {
                            for (var i = 0, f; (f = folderData.Files[i++]);) {
                                if (f.FileId === data.fileId) {
                                    folderData.Files.splice(i - 1, 1);
                                    break;
                                }
                            }
                        }
                        --itemsOffset;
                    }
                },
                renameItem: function (data) {
                    if (data && folderData) {
                        if (data.folderId) {
                            for (var i = 0, f; (f = folderData.Folders[i++]);) {
                                if (f.FolderID === data.folderId) {
                                    f.Name = data.name;
                                    break;
                                }
                            }
                        } else if (data.fileId) {
                            for (var i = 0, f; (f = folderData.Files[i++]);) {
                                if (f.FileId === data.fileId) {
                                    f.Name = data.name;
                                    break;
                                }
                            }
                        }
                    }
                }
            };

            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            var tabInfo = ItemTabs.openTab(tabId,
                {
                    breadCrumb: OpenDrive.helpers.applyTemplate(
                        {
                            SiteConfig: InitOptions,
                            ItemId: tabId,
                            FolderId: folderId
                        },
                        'BreadCrumbItem'
                    ),
                    tabContent: null,
                    titleOpts: {
                        Unclosable: true,
                        Hidden: InitOptions.Public
                    },
                    Name: itemName
                },
                {
                    close: onClose,
                    save: onSave,
                    wakeup: onWakeUp,
                    activate: onActivate
                }
            );

            $tab = tabInfo.tab;
            $breadcrumb = tabInfo.breadcrumb;

            $(document).on('reload-folder.od', function () {
                _this.loadTabContent(true, true);
            });

            $(document).on('load-folder.od', function (e, data) {
                if (data && data.folderId != null) {
                    delete data.noHistoryChange;
                    _this.setTabFolderId(data.folderId, data.noHistoryChange, data);
                }
                return false;
            });
            _this.loadTabContent(true, noHistoryChange, completeCallback);
            if (!_this.fileUploader)_this.fileUploader = new TabFileUploader($tab, folderId, InitOptions.SessionId, InitOptions.EndPoint);
        }

        function PDFFileTab(fileId, folderId, name, completeCallback, noHistoryChange, noActivate) {
            var tabId = 'file-' + fileId;
            var _this = this;
            var $tab;
            var $breadcrumb;

            function onSave() {
                return {
                    fileId: fileId,
                    folderId: folderId,
                }
            }

            function onActivate(id, args) {
                if (!args || !args.noHistoryChange) WindowHistory.pushFile(fileId);
            }

            function loadTabContent() {
                if (!noHistoryChange) WindowHistory.pushFile(fileId);
                var tabInfo = ItemTabs.openTab(tabId,
                    {
                        breadCrumb: OpenDrive.helpers.applyTemplate(
                            {
                                ItemId: tabId,
                                FileId: fileId,
                                SiteConfig: InitOptions,
                                FolderId: folderId,
                                Name: name
                            },
                            'BreadCrumbPDFFileItem'
                        ),
                        tabContent: OpenDrive.helpers.applyTemplate({Type: 'pdf', FileId: fileId, FolderId: folderId}, 'ContentFrameTab'),
                        Name: name,
                        noActivate: noActivate
                    },
                    {
                        //close: onClose,
                        save: onSave,
                        //wakeup: onWakeUp,
                        activate: onActivate
                    }
                );

                if (tabInfo.exists) {
                    return;
                }

                $tab = tabInfo.tab;
                $breadcrumb = tabInfo.breadcrumb;
                $tab.data('ItemTab', _this);
                $tab.addClass('no-scroll');
                initEvents();
                if (completeCallback instanceof Function) completeCallback();
            }

            function initEvents() {
                $breadcrumb.on('click', '.js-file-action', function () {
                    var action = $(this).data('action');
                    $tab.find('iframe')[0].contentWindow.postMessage({file_action: action}, '*');
                    return false;
                });
            }


            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            loadTabContent();
        }

        function PreviewFileTab(fileId, folderId, name, completeCallback, noHistoryChange, noActivate) {
            var tabId = 'file-' + fileId;
            var _this = this;
            var $tab;
            var $breadcrumb;

            function onSave() {
                return {
                    fileId: fileId,
                    folderId: folderId
                }
            }

            function onActivate(id, args) {
                if (!args || !args.noHistoryChange) WindowHistory.pushFile(fileId);
            }

            function loadTabContent() {
                if (!noHistoryChange) WindowHistory.pushFile(fileId);
                var tabInfo = ItemTabs.openTab(tabId,
                    {
                        breadCrumb: OpenDrive.helpers.applyTemplate(
                            {
                                ItemId: tabId,
                                FileId: fileId,
                                SiteConfig: InitOptions,
                                FolderId: folderId,
                                Name: name
                            },
                            'BreadCrumbFileItem'
                        ),
                        tabContent: OpenDrive.helpers.applyTemplate({
                            Type: 'preview',
                            FileId: fileId,
                            FolderId: folderId
                        }, 'ContentFrameTab'),
                        Name: name,
                        noActivate: noActivate
                    },
                    {
                        //close: onClose,
                        save: onSave,
                        //wakeup: onWakeUp,
                        activate: onActivate
                    }
                );

                $tab = tabInfo.tab;
                $breadcrumb = tabInfo.breadcrumb;
                $tab.data('ItemTab', _this);
                $tab.addClass('no-scroll');
                initEvents();
                if (completeCallback instanceof Function) completeCallback();
            }

            function initEvents() {
                $breadcrumb.on('click', '.js-file-action', function () {
                    var action = $(this).data('action');
                    $tab.find('iframe')[0].contentWindow.postMessage({file_action: action}, '*');
                    return false;
                });
            }

            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            loadTabContent();
        }

        function ImageFileTab(fileId, folderId, name, completeCallback, noHistoryChange, noActivate) {
            var tabId = 'file-' + fileId;
            var _this = this;
            var $tab;
            var $breadcrumb;

            function onSave() {
                return {
                    fileId: fileId,
                    folderId: folderId
                }
            }

            function onActivate(id, args) {
                if (!args || !args.noHistoryChange) WindowHistory.pushFile(fileId);
            }

            function loadTabContent() {
                if (!noHistoryChange) WindowHistory.pushFile(fileId);
                var tabInfo = ItemTabs.openTab(tabId,
                    {
                        breadCrumb: OpenDrive.helpers.applyTemplate(
                            {
                                ItemId: tabId,
                                FileId: fileId,
                                SiteConfig: InitOptions,
                                FolderId: folderId,
                                Name: name
                            },
                            'BreadCrumbImageItem'
                        ),
                        tabContent: OpenDrive.helpers.applyTemplate({
                            Type: 'preview',
                            FileId: fileId,
                            FolderId: folderId
                        }, 'ContentFrameTab'),
                        Name: name,
                        noActivate: noActivate
                    },
                    {
                        //close: onClose,
                        save: onSave,
                        //wakeup: onWakeUp,
                        activate: onActivate
                    }
                );

                $tab = tabInfo.tab;
                $breadcrumb = tabInfo.breadcrumb;
                $tab.data('ItemTab', _this);
                $tab.addClass('no-scroll');
                initEvents();
                if (completeCallback instanceof Function) completeCallback();
            }

            function initEvents() {
                $breadcrumb.on('click', '.js-file-action', function () {
                    var action = $(this).data('action');
                    $tab.find('iframe')[0].contentWindow.postMessage({file_action: action}, '*');
                    return false;
                });
            }

            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            loadTabContent();
        }

        function DocumentFileTab(fileId, folderId, name, completeCallback, noHistoryChange, noActivate) {
            var tabId = 'file-' + fileId;
            var _this = this;
            var $tab;
            var $breadcrumb;

            function onSave() {
                return {
                    fileId: fileId,
                    folderId: folderId
                }
            }

            function onActivate(id, args) {
                if (!args || !args.noHistoryChange) WindowHistory.pushFile(fileId);
            }

            function initEvents() {
                $breadcrumb.on('click', '.js-file-action', function () {
                    var action = $(this).data('action');
                    $tab.find('iframe')[0].contentWindow.postMessage({file_action: action}, '*');
                    return false;
                });
            }

            function loadTabContent() {
                if (!noHistoryChange) WindowHistory.pushFile(fileId);
                var tabInfo = ItemTabs.openTab(tabId,
                    {
                        breadCrumb: OpenDrive.helpers.applyTemplate(
                            {
                                ItemId: tabId,
                                FileId: fileId,
                                SiteConfig: InitOptions,
                                FolderId: folderId,
                                Name: name
                            },
                            'BreadCrumbFileItem'
                        ),
                        tabContent: OpenDrive.helpers.applyTemplate({
                            Type: 'document',
                            FileId: fileId,
                            FolderId: folderId
                        }, 'ContentFrameTab'),
                        Name: name,
                        noActivate: noActivate
                    },
                    {
                        //close: onClose,
                        save: onSave,
                        //wakeup: onWakeUp,
                        activate: onActivate
                    }
                );

                if (tabInfo.exists) {
                    return;
                }

                $tab = tabInfo.tab;
                $tab.find('iframe').load(function () {
                    ItemTabs.setTabLoadedStatus(tabId, true);
                    $tab.find('.js-image-preloading').remove();
                });
                $breadcrumb = tabInfo.breadcrumb;
                $tab.data('ItemTab', _this);
                $tab.addClass('no-scroll');

                initEvents();
                if (completeCallback instanceof Function) completeCallback();
            }


            var existingTab = ItemTabs.getTab(tabId);
            if (existingTab.length) {
                ItemTabs.activateTab(tabId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            loadTabContent();
        }

        var Trash = new function () {
            var trash = this;
            this.refresh = function () {
                var counter = $('.js-trash-items-counter');
                if (counter.length) {
                    setTimeout(function () {
                        OpenDrive.ajax.do('files.list-trash', {}, function (data) {
                            counter.text(data.ItemsCount > 1000 ? '>1k' : data.ItemsCount);
                        });
                    }, 0);
                }
            };

            $('.js-trash-clear-btn').on('click', function () {
                var _this = $(this);
                if (!_this.hasClass('disabled') && confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                    _this.addClass('disabled').attr('aria-disabled', 'true');
                    OpenDrive.ajax.do('trash-empty', {},
                        function () {
                            _this.removeClass('disabled');
                            trash.refresh();
                            var trashTab = ItemTabs.getTab('folder-trash');
                            if (trashTab.length) trashTab.data('ItemTab').loadTabContent(true, true);
                        },
                        function () {
                            _this.removeClass('disabled').attr('aria-disabled', 'false');
                        });
                }
                return false;
            });

            $(document).on('item-trashed.od', function () {
                trash.refresh();
                return false;
            })
        };

        var WindowHistory = new function () {
            var lastFileId;
            var lastFolderId;
            this.pushFile = function (fileId) {
                if (fileId === lastFileId) return;
                lastFileId = fileId;
                lastFolderId = undefined;
                window.history.pushState({fileId: fileId}, null, '/file/' + fileId);
            };

            this.pushFolder = function (folderId) {
                if (folderId === lastFolderId) return;
                lastFolderId = folderId;
                lastFileId = undefined;
                var prefix = InitOptions.Public ? '/fl/' : '/files/';
                window.history.pushState({folderId: folderId}, null, folderId ? (prefix + folderId) : prefix);
            };

            window.addEventListener('popstate', function (e) {
                if (e) {
                    var state = e.state;
                    if (state && (state.fileId !== undefined || state.folderId !== undefined)) {
                        if (state.fileId) {
                            ItemTabs.activateTab('file-' + state.fileId, {noHistoryChange: true})
                        } else {
                            var data = {};
                            if (folderTab.getFolderId() != state.folderId) folderTab.setTabFolderId(state.folderId, true, data);
                            else ItemTabs.activateTab('folder-' + state.folderId, {noHistoryChange: true});
                        }
                    }
                }
            });

            return this;
        };

        var folderTab;
        Trash.refresh();

        (function () {
            var sessionTabsData = ItemTabs.sessionTabs.getSessionData();
            var startupFolderId = InitOptions.SelectedFolder;
            var filesIds = [], folderIds = [];
            var data;
            if (!startupFolderId && startupFolderId != 'trash' && startupFolderId != 'search') {
                for (var i = 0; i < sessionTabsData.length; i++) {
                    data = sessionTabsData[i].data;
                    if (!data) continue;
                    if (data.folderId != null) {
                        startupFolderId = data.folderId;
                        break;
                    }
                }
            }

            for (var i = 0; i < sessionTabsData.length; i++) {
                data = sessionTabsData[i].data;
                if (!data) continue;
                if (data.fileId != null) {
                    filesIds.push(data.fileId);
                    folderIds.push(data.folderId);
                }
            }

            var filesInfo = {};
            folderTab = new FolderTab(startupFolderId, InitOptions.SelectedFolderName, function () {
                if (filesIds.length) {
                    OpenDrive.ajax.do('files.get-files-info', {file_ids: filesIds, folder_ids: folderIds}, function (response) {
                        filesInfo = response;
                        restoreCallback();
                    });
                }
            });

            function restoreCallback() {

                ItemTabs.sessionTabs.restore(function (opts) {
                    var keys = Object.keys(filesInfo);
                    if (keys.length) {
                        var file = filesInfo[keys[0]];
                        delete filesInfo[keys[0]];
                        var sharingID = file.SharingID ? '0-' + file.SharingID : '';
                        switch (file.FileTypeClass) {
                            case 'type-img':
                                new ImageFileTab(file.FileId, sharingID, file.Name, restoreCallback, true, true);
                                break;

                            case 'type-document':
                                new DocumentFileTab(file.FileId, sharingID, file.Name, restoreCallback, true, true);
                                break;

                            case 'type-pdf':
                                new PDFFileTab(file.FileId, sharingID, file.Name, restoreCallback, true, true);
                                break;

                            default:
                                new PreviewFileTab(file.FileId, sharingID, file.Name, restoreCallback, true, true);
                        }
                    }
                })
            }
        })();


        $('.js-logout').click(function () {
            ItemTabs.sessionTabs.clear();
        });

        var BreadCrumbs = new function () {
            var container = $('.js-breadcrumbs-container');

            container.on('click', '.js-change-view-mode', function () {
                var _this = $(this);
                //if (!_this.hasClass('active')) {
                var activeTab = ItemTabs.getActiveTab();
                if (!activeTab) activeTab = ItemTabs.getFirstTab();
                if (activeTab && activeTab.length) {
                    container.find('.js-change-view-mode').removeClass('active');
                    var folderTab = activeTab.data('ItemTab');
                    var mode = _this.data('mode');
                    folderTab.setViewMode(mode);
                    OpenDrive.ajax.do('files.set-view-mode', {
                        view_mode: mode
                    });
                    _this.addClass('active');
                    folderTab.render();
                }
                //}
                return false;
            });
        };

        var SearchBox = new function () {
            var input = $('.js-item-search-field');

            function doSearch() {
                var searchTerm = input.val().trim();
                if (searchTerm != '') {
                    $(document).trigger('load-folder.od', {
                        folderId: folderTab.getFolderId(),
                        noHistoryChange: false,
                        searchTerm: searchTerm
                    });
                }
            }

            $('.js-item-search-icon').click(function () {
                doSearch();
                return false;
            });

            input.keypress(function (e) {

                if (e.which == 13) {
                    doSearch();
                    return false;
                }
            });
        };

        window.addEventListener('message', function (event) {
            if (event.data && event.data.iframe_dom_ready && event.data.item_id && event.data.item_type) {
                ItemTabs.setTabLoadedStatus(event.data.item_type + '-' + event.data.item_id, true);
                ItemTabs.getTab(event.data.item_type + '-' + event.data.item_id).find('.js-image-preloading').remove();
            }
        }, false);

    });
})(jQuery);
