(function ($) {
    $(function () {

        function show_lightbox(wrapper) {
            wrapper.show();
            var container = $('.lightbox-container', wrapper),
                header = $('.lightbox-header', container),
                buttons = $('.lightbox-buttons', container),
                scrollBody = $('.lightbox-scrollable-content', container);

            function recalcHeight() {
                if (scrollBody.length) {
                    var bodyHeight = container.height() - buttons.outerHeight(true) - header.outerHeight(true) - (scrollBody.outerHeight(true) - scrollBody.outerHeight());
                    if (bodyHeight < scrollBody.innerHeight()) {
                        scrollBody.css('height', bodyHeight + 'px');
                        var api = scrollBody.data('jsp');
                        if (api) api.reinitialise();
                        else scrollBody.jScrollPane();
                    }
                }
            }

            if (!wrapper.data('on_resize')) {
                wrapper.data('on_resize', true);
                $(window).on('resize', recalcHeight)
            }

            container.css({'top': '50%', 'margin-top': -1 * Math.ceil(container.outerHeight() / 2) + 'px'});
            recalcHeight();
        }

        function loadLightboxFolderTree(folderId, lightbox) {

            OpenDrive.ajax.do('files.list-folder', {folder_id: folderId}, function (response) {
                var folders = {SubFolders: response.Folders};
                folders.Drivename = $('body').data('drivename');
                OpenDrive.helpers.applyTemplate(folders, 'LightboxFolderTree', $(".move-copy-folders-list"));
                show_lightbox(lightbox);
            });
        }

        OpenDrive.widgets.LightBoxes = {
            MoveItem: {
                show: function ($item) {
                    var move_folder_id = 0;
                    var move_file_id = 0;

                    var move_lightbox = $("#file-folder-move");
                    var header = $('.lightbox-header h2', move_lightbox);

                    if ($item.hasClass('folder-item')) {
                        var folder_name = $(".folder-name", $item).html();
                        header.find('.js-item-name').text(folder_name);
                        header.find('.js-item-file').hide();
                        header.find('.js-item-folder').show();
                        move_folder_id = $item.attr('id').replace('folder-', '');
                    } else if ($item.hasClass('file-item')) {
                        var file_name = $(".file-name", $item).html();
                        header.find('.js-item-name').text(file_name);
                        header.find('.js-item-folder').hide();
                        header.find('.js-item-file').show();
                        move_file_id = $item.attr('id').replace('file-', '');
                    }

                    $(".item.active", $item.closest('.js-tab-content')).removeClass('active');
                    $item.addClass('active');


                    $("#move-folder-id", move_lightbox).val(move_folder_id);
                    $("#move-file-id", move_lightbox).val(move_file_id);

                    // get list of root folders
                    loadLightboxFolderTree(0, move_lightbox);
                }
            },
            CopyItem: {
                show: function ($item) {
                    var copy_folder_id = 0;
                    var copy_file_id = 0;

                    var copy_lightbox = $("#file-folder-copy");
                    var header = $('.lightbox-header h2', copy_lightbox);

                    if ($item.hasClass('folder-item')) {
                        var folder_name = $(".folder-name", $item).html();
                        header.find('.js-item-name').text(folder_name);
                        header.find('.js-item-file').hide();
                        header.find('.js-item-folder').show();
                        copy_folder_id = $item.attr('id').replace('folder-', '');
                    } else if ($item.hasClass('file-item')) {
                        var file_name = $(".file-name", $item).html();
                        header.find('.js-item-name').text(file_name);
                        header.find('.js-item-file').show();
                        header.find('.js-item-folder').hide();
                        copy_file_id = $item.attr('id').replace('file-', '');
                    }

                    $(".item.active", $item.closest('.js-tab-content')).removeClass('active');
                    $item.addClass('active');


                    $("#copy-folder-id", copy_lightbox).val(copy_folder_id);
                    $("#copy-file-id", copy_lightbox).val(copy_file_id);

                    // get list of root folders

                    loadLightboxFolderTree(0, copy_lightbox);
                }
            },
            SendByEmail: {
                show: function (this_item) {
                    var send_lightbox = $("#send-file");
                    var type = 'file';
                    var subject = $("#send-subject", send_lightbox);
                    $("#send-expiring-url", send_lightbox).val("");
                    if (this_item.hasClass('file-item')) {
                        var file_id = this_item.attr('id').replace('file-', '');
                        var file_name = $(".file-name", this_item).data('filename');

                        $("#send-item-id", send_lightbox).val(file_id);
                        $("#send-url", send_lightbox).val(this_item.data('directlink'));

                        OpenDrive.ajax.do('file-expiring-links', {file_id: file_id}, function (response) {
                            if(response.DownloadLink !== undefined)
                                $("#send-expiring-url", send_lightbox).val(response.DownloadLink.replace(/\/d\//, '/f/'));
                        });

                        subject.val(subject.data('file') + ' ' + file_name);
                        $('.js-file', send_lightbox).show();
                        $('.js-folder', send_lightbox).hide();
                    } else {
                        type = 'folder';
                        var folder_id = this_item.attr('id').replace('folder-', '');
                        var folder_name = $(".folder-name", this_item).html();
                        $("#send-url", send_lightbox).val(this_item.data('directlink'));

                        OpenDrive.ajax.do('folder-expiring-links', {folder_id: folder_id}, function (response) {
                            if(response.Link !== undefined)
                                $("#send-expiring-url", send_lightbox).val(response.Link);
                        });

                        $("#send-item-id", send_lightbox).val(folder_id);
                        subject.val(subject.data('folder') + ' ' + folder_name);
                        $('.js-folder', send_lightbox).show();
                        $('.js-file', send_lightbox).hide();
                    }
                    $("#send-item-type", send_lightbox).val(type);

                    if(send_lightbox.data('g-recaptcha-loaded') === undefined) {
                        $.getScript("https://www.google.com/recaptcha/api.js?hl=en&onload=onloadCallback&render=explicit");
                        send_lightbox.data('g-recaptcha-loaded', true);
                    }

                    show_lightbox(send_lightbox);
                }
            },
            ContextLink: {
                show: function (this_item, privateItem) {
                    if (this_item.hasClass('file-item')) {
                        var prop_lightbox = $("#file-links");
                        var file_id = this_item.attr('id').replace('file-', '');
                        prop_lightbox.data('file-id', file_id);
                        prop_lightbox.data('file-type', 'file');

                        var fileName = $('.js-file-name', this_item).data('filename');
                        $('.js-lightbox-title', prop_lightbox).html(fileName);

                        $(".file-embed iframe", prop_lightbox).attr('src', '');
                        $(".file-embed", prop_lightbox).hide();


                        $("#links-file-url", prop_lightbox).val(this_item.data('directlink'));
                        if (this_item.data('streaminglink') == 'n/a') {
                            $("#links-file-streaming", prop_lightbox).hide();
                            prop_lightbox.find('.js-hotlinking-s-disabled').show();
                        } else {
                            $("#links-file-streaming", prop_lightbox).val(this_item.data('streaminglink')).show();
                            prop_lightbox.find('.js-hotlinking-s-disabled').hide();
                        }

                        if (this_item.data('downloadlink') == 'n/a') {
                            $("#links-file-download", prop_lightbox).hide();
                            prop_lightbox.find('.js-hotlinking-dl-disabled').show();
                        } else {
                            $("#links-file-download", prop_lightbox).val(this_item.data('downloadlink')).show();
                            $("#links-file-download", prop_lightbox);
                            prop_lightbox.find('.js-hotlinking-dl-disabled').hide();
                        }
                        if (this_item.data('streaminglink') == 'n/a' && this_item.data('downloadlink') == 'n/a') {
                            $('.js-hide-stream-dl-links', prop_lightbox).hide();
                        } else {
                            $('.js-hide-stream-dl-links', prop_lightbox).show();
                        }
                        //
                        $("#links-file-thumbnail", prop_lightbox).val(this_item.data('thumblink'));
                        if (this_item.data('editlink')) {
                            $('#links-edit-file-url', prop_lightbox).val(this_item.data('editlink'));
                            $('.js-editlinkbox', prop_lightbox).removeClass('hidden');
                        } else {
                            $('#links-edit-file-url', prop_lightbox).val('');
                            $('.js-editlinkbox', prop_lightbox).addClass('hidden');
                        }

                        if (this_item.hasClass('type-video')) {
                            prop_lightbox.data('item-type', 'video');
                            $(".file-embed #links-file-embed", prop_lightbox).val(getMediaUrl(file_id, 'video'));
                            $(".file-embed iframe", prop_lightbox).addClass('video-preview').attr('src', '/player/' + file_id);
                            $(".file-embed", prop_lightbox).show();
                            $('.js-video-options', prop_lightbox).show();
                        } else if (this_item.hasClass('type-audio')) {
                            prop_lightbox.data('item-type', 'audio');
                            $(".file-embed #links-file-embed", prop_lightbox).val(getMediaUrl(file_id, 'audio'));
                            $(".file-embed iframe", prop_lightbox).addClass('audio-preview').attr('src', '/player/' + file_id);
                            $(".file-embed", prop_lightbox).show();
                            $('.js-video-options', prop_lightbox).hide();
                        } else {
                            prop_lightbox.data('item-type', 'simplefile');
                            $(".file-embed #links-file-embed", prop_lightbox).val('');
                            $(".file-embed .video-preview", prop_lightbox).attr('src', '');
                            $(".file-embed", prop_lightbox).hide();
                        }

                        if (privateItem) $('.js-not-shareable-item', prop_lightbox).removeClass('hidden');
                        else $('.js-not-shareable-item', prop_lightbox).addClass('hidden');

                        show_lightbox(prop_lightbox);
                        $('.js-lightbox-title', prop_lightbox)
                            .html(fileName)
                            .ellipsisMiddle({reinitialize: true});
                    } else {
                        var folder_id = this_item.attr('id').replace('folder-', '');
                        var folder_name = $('.js-folder-name', this_item).data('filename');
                        if (!folder_name) folder_name = $(".folder-name", this_item).html();
                        showFolderLinksDialog(folder_id, folder_name, privateItem);
                    }
                }
            },
            ContextExpiringLink: {
                show: function (this_item, privateItem) {
                    if (this_item.hasClass('file-item')) {
                        var prop_lightbox = $("#file-expiring-links");
                        var file_id = this_item.attr('id').replace('file-', '');
                        $("#file-id", prop_lightbox).val(file_id);
                        prop_lightbox.data('file-type', 'file');

                        var fileName = $('.js-file-name', this_item).data('filename');
                        $('.js-lightbox-title', prop_lightbox).html(fileName);

                        $("#download-expiring-file-links", prop_lightbox).val("");
                        $("#stream-expiring-file-links", prop_lightbox).val("");

                        if (privateItem) $('.js-not-shareable-item', prop_lightbox).removeClass('hidden');
                        else $('.js-not-shareable-item', prop_lightbox).addClass('hidden');

                        show_lightbox(prop_lightbox);
                        $('.js-lightbox-title', prop_lightbox)
                            .html(fileName)
                            .ellipsisMiddle({reinitialize: true});

                        showFileExpiringLinksDialog(file_id, fileName, privateItem);
                    } else {
                        var folder_id = this_item.attr('id').replace('folder-', '');
                        $("#folder-id", prop_lightbox).val(folder_id);
                        var folder_name = $('.js-folder-name', this_item).data('filename');
                        if (!folder_name) folder_name = $(".folder-name", this_item).html();
                        showFolderExpiringLinksDialog(folder_id, folder_name, privateItem);
                    }
                }
            },
            FileVersions: {
                show: function (this_item) {
                    var vers_lightbox = $("#file-versions");
                    var file_group_id = this_item.data('file_group_id');

                    OpenDrive.ajax.do('files.file-versions', {file_group_id: file_group_id}, function (response) {
                        OpenDrive.helpers.applyTemplate({Versions: response}, 'FileVersionsTable', $('table', vers_lightbox), true);
                        show_lightbox(vers_lightbox);
                    });
                }
            },
            ReplaceFile: {
                show: function () {
                    show_lightbox($('#confirm-file-replace'));
                }
            },
            FileContextProperties: {
                show: function (fileId, parentFolderId) {
                    showFilePropertiesLightbox(fileId, parentFolderId);
                }
            },
            FolderContextProperties: {
                show: function (folderId, parentFolderId) {
                    showFolderPropertiesLighbox(folderId, parentFolderId);
                }
            }
        };

        function showFolderPropertiesLighbox(folder_id, parentFolderId) {
            var prop_lightbox = $("#folder-properties");
            prop_lightbox.data('folder-id', parentFolderId);
            OpenDrive.ajax.do('files.get-folder-info', {
                folder_id: folder_id,
                parent_folder_id: parentFolderId
            }, function (response) {
                //closeDropdownMenus();

                $("#prop-folder-id", prop_lightbox).val(folder_id);
                $("#prop-folder-name", prop_lightbox).val(response.Name);

                $('input[name="prop-folder-access"][value="' + response.Access + '"]').prop('checked', true);


                if (response.PublicUpload == true) {
                    $("#new-folder-upload-enabled", prop_lightbox).click();
                } else {
                    $("#new-folder-upload-disabled", prop_lightbox).click();
                }

                $('#prop-folder-public-content', prop_lightbox).attr('checked', response.PublicContent);
                $('#prop-folder-public-subfolders', prop_lightbox).attr('checked', response.DisplaySubfolders);
                $('#prop-folder-public-download', prop_lightbox).attr('checked', response.PublicDownload);

                $("#prop-folder-description", prop_lightbox).val(response.Description);

                show_lightbox(prop_lightbox);
                $('.js-lightbox-title', prop_lightbox)
                    .html(response.Name)
                    .ellipsisMiddle({reinitialize: true});

            });
        }

        function showFolderLinksDialog(folder_id, folder_name, privateItem) {
            var prop_lightbox = $("#folder-links");
            prop_lightbox.data('folder-id', folder_id);

            $('.js-lightbox-title', prop_lightbox).html(folder_name);

            OpenDrive.ajax.do('folder-files-links', {folder_id: folder_id}, function (response) {
                $("#links-folder-url", prop_lightbox).val(response.folder_link);
                $("#links-folder-files", prop_lightbox).val(response.files_urls.join("\n"));
                $("#links-folder-direct", prop_lightbox).val(response.files_direct_urls.join("\n"));

                if (privateItem) $('.js-not-shareable-item', prop_lightbox).removeClass('hidden');
                else $('.js-not-shareable-item', prop_lightbox).addClass('hidden');
                show_lightbox(prop_lightbox);
                $('.js-lightbox-title', prop_lightbox)
                    .html(folder_name)
                    .ellipsisMiddle({reinitialize: true});
            });
        }

        function showFolderExpiringLinksDialog(folder_id, folder_name, privateItem) {
            var folder_lightbox = $("#folder-expiring-links");
            folder_lightbox.data('folder-id', folder_id);

            $('.js-lightbox-title', folder_lightbox).html(folder_name);
            OpenDrive.ajax.do('folder-expiring-links', {folder_id: folder_id}, function (response) {
                $("#url-expiring-folder-links", folder_lightbox).val(response.Link);
                $("#expiring-link-counter", folder_lightbox).val(response.CounterMax);
                $("#expiring-links-used", folder_lightbox).val(response.Counter);
                $("#expiring-link-date", folder_lightbox).val(response.ExpiringDate);
                if (response.CounterEnable === "1")
                    $("#expiring-link-counter-enable", folder_lightbox).prop('checked', true);
                else
                    $("#expiring-link-counter-enable", folder_lightbox).prop('checked', false);
                show_lightbox(folder_lightbox);
                $('.js-lightbox-title', folder_lightbox)
                    .html(folder_name)
                    .ellipsisMiddle({reinitialize: true});

            });
        }

        function showFileExpiringLinksDialog(file_id, file_name, privateItem) {
            var file_lightbox = $("#file-expiring-links");
            file_lightbox.data('file-id', file_id);

            $('.js-lightbox-title', file_lightbox).html(file_name);
            OpenDrive.ajax.do('file-expiring-links', {file_id: file_id}, function (response) {
                $("#download-expiring-file-links", file_lightbox).val(response.DownloadLink);
                $("#stream-expiring-file-links", file_lightbox).val(response.StreamingLink);
                $("#expiring-link-counter", file_lightbox).val(response.CounterMax);
                $("#expiring-links-used", file_lightbox).val(response.Counter);
                $("#expiring-link-date", file_lightbox).val(response.ExpiringDate);
                if (response.CounterEnable === "1")
                    $("#expiring-link-counter-enable", file_lightbox).prop('checked', true);
                else
                    $("#expiring-link-counter-enable", file_lightbox).prop('checked', false);


                show_lightbox(file_lightbox);
                $('.js-lightbox-title', file_lightbox)
                    .html(folder_name)
                    .ellipsisMiddle({reinitialize: true});
            });
        }

        $(".lightbox").escape(function () {
            $(this).hide();
            var callback = $(this).find('.js-cancel-btn').data('callback');
            if (callback instanceof Function) callback.apply(this, arguments);
        });

        $(".lightbox .js-cancel-btn").click(function () {
            $(".lightbox").hide();
            var callback = $(this).data('callback');
            if (callback instanceof Function) callback.apply(this, arguments);
            return false;
        });

        $("#file-folder-move").on("click", "#move-file-folder-btn", function () {
            var this_button = $(this);
            var move_lightbox = $("#file-folder-move");

            var move_file_id = $("#move-file-id", move_lightbox).val();
            var move_folder_id = $("#move-folder-id", move_lightbox).val();

            var dest_folder_id = $(".one-folder.selected", move_lightbox).attr('id');

            if ($(".one-folder.selected", move_lightbox).length > 0 && dest_folder_id != '' && this_button.is(":not(:disabled)")) {
                this_button.prop('disabled', true);
                var action, data;
                if (move_file_id != '' && move_folder_id == '0') {
                    // move file
                    action = 'files.move-file';
                    data = {src_file_id: move_file_id, dest_folder_id: dest_folder_id};
                } else if (move_folder_id != '' && move_file_id == '0') {
                    // move folder
                    action = 'files.move-folder';
                    data = {src_folder_id: move_folder_id, dest_folder_id: dest_folder_id};
                }

                OpenDrive.ajax.do(action,
                    data,
                    function () {
                        this_button.prop('disabled', false);
                        move_lightbox.hide();
                        $(document).trigger('reload-folder.od');
                    }, function () {
                        this_button.prop('disabled', false);
                    });
            } else {
                OpenDrive.popups.showNotification(OpenDrive._('Select_destination_folder'));
            }

            return false;
        });

        $("#file-folder-copy").on("click", "#copy-file-folder-btn", function () {
            var copy_lightbox = $("#file-folder-copy");

            var copy_file_id = $("#copy-file-id", copy_lightbox).val();
            var copy_folder_id = $("#copy-folder-id", copy_lightbox).val();

            var dest_folder_id = $(".one-folder.selected", copy_lightbox).attr('id');

            if ($(".one-folder.selected", copy_lightbox).length > 0 && dest_folder_id != '') {
                var action, data;
                if (copy_file_id != '' && copy_folder_id == '0') {
                    // copy file
                    action = 'files.copy-file';
                    data = {src_file_id: copy_file_id, dest_folder_id: dest_folder_id};
                } else if (copy_folder_id != '' && copy_file_id == '0') {
                    // copy folder
                    action = 'files.copy-folder';
                    data = {src_folder_id: copy_folder_id, dest_folder_id: dest_folder_id};
                }

                OpenDrive.ajax.do(
                    action,
                    data,
                    function () {
                        copy_lightbox.hide();
                    });
            } else {
                OpenDrive.popups.showNotification(OpenDrive._('Select_destination_folder'));
            }

            return false;
        });

        $(".lightbox .move-copy-folders-list").on("click", ".checkbox, .folder-title", function () {
            $(".move-copy-folders-list .selected").removeClass('selected');
            $(this).closest(".one-folder").addClass('selected');

            return false;
        });

        $(".lightbox .move-copy-folders-list").on("click", ".expand", function () {

            var this_folder = $(this).closest(".one-folder");
            var folder_id = this_folder.attr("id");

            if (this_folder.hasClass('no-subfolders') || this_folder.hasClass('expanded')) return false;

            this_folder.addClass("expanded");

            // get list of root folders

            OpenDrive.ajax.do('files.list-folder', {folder_id: folder_id, only_subfolders: true}, function (response) {
                var folders = response.Folders;
                var foldersList = this_folder.closest('.lightbox-scrollable-content');
                foldersList.height(foldersList.parent().height());
                if (folders && folders.length > 0) {
                    this_folder.append(OpenDrive.helpers.applyTemplate(response, 'LightboxSubFolderTree'));
                } else {
                    this_folder.addClass('no-subfolders');
                }

                var api = foldersList.data('jsp');
                if (api) api.reinitialise();
                else foldersList.jScrollPane();
            });

            return false;
        });


        $("#send-file #send-btn").click(function () {
            var this_lightbox = $(this).closest(".lightbox");

            var send_item_id = $("#send-item-id", this_lightbox).val();
            var send_item_type = $("#send-item-type", this_lightbox).val();
            var send_email = $("#send-email", this_lightbox).val();
            var send_subject = $("#send-subject", this_lightbox).val();
            var send_message = $("#send-message", this_lightbox).val();
            var captcha_response = $("#g-recaptcha-response", this_lightbox).val();
            var send_expiring_enabled =$("#expiring-link-enable", this_lightbox).prop("checked");
            var send_expiring_url =$("#send-expiring-url", this_lightbox).val();

            if (!captcha_response){
                captcha_response = "Invalid site key";
            }
            if (send_expiring_url === "") {
                send_expiring_enabled = false;
            }
            OpenDrive.ajax.do('send-by-email',
                {
                    send_item_id: send_item_id,
                    send_item_type: send_item_type,
                    send_email: send_email,
                    send_subject: send_subject,
                    send_message: send_message,
                    captcha_response: captcha_response,
                    send_expiring_enabled: send_expiring_enabled,
                },
                function (response) {
                    OpenDrive.popups.showNotification(OpenDrive._('Emailed_to') + ' ' + response);
                    $("#send-email", this_lightbox).val('');
                    $("#send-message", this_lightbox).val('');
                    $("#send-subject", this_lightbox).val('');
                    this_lightbox.hide();
                    grecaptcha.reset();
                },
                function (response) {
                    grecaptcha.reset();
                }
            );

            return false;
        });


        function getMediaUrl(file_id, type, opts) {
            if (opts instanceof Array) opts = opts.join('&');
            var domain_url = location.protocol + '//' + location.host;

            return type == 'video'
                ? '<iframe src="' + domain_url + '/player/' + file_id + (opts ? '?' + opts : '') + '" height="320" width="480" style="border:0" scrolling="no" frameborder="0" allowtransparency="true" allowfullscreen></iframe>'
                : '<iframe src="' + domain_url + '/player/' + file_id + (opts ? '?' + opts : '') + '" height="25" width="297" style="border:0" scrolling="no" frameborder="0" allowtransparency="true"></iframe>';
        }


        $('#file-links .js-enable-autoplay').click(function () {
            var lb = $(this).closest('.lightbox');
            var file_id = lb.data('file-id');
            var opts;
            var item_type = lb.data('item-type');
            if (!file_id || item_type != 'video') return;
            if (this.checked) opts = ['autoplay'];
            $('#links-file-embed', lb).val(getMediaUrl(file_id, 'video', opts));
        });

        $("#file-versions").on("click", ".delete-file-version", function () {
            if (confirm(OpenDrive._('Do_you_really_want_to_perform_this_action'))) {
                var this_row = $(this).closest('tr');
                var file_id = $(this).attr('file-id');

                OpenDrive.ajax.do('remove-file-version', {file_id: file_id}, function () {
                    this_row.remove();
                });
            }
            return false;
        });

        $('.js-open-file-settings, .js-open-folder-settings').click(function () {
            var lb = $(this).closest('.lightbox');
            lb.hide();
            var fileId = lb.data('file-id');
            var folderId = lb.data('folder-id');
            if (fileId) {
                OpenDrive.widgets.LightBoxes.FileContextProperties.show(fileId);
            } else if (folderId) {
                OpenDrive.widgets.LightBoxes.FolderContextProperties.show(folderId);
                return false;
            }

            return false;
        });

        function showFilePropertiesLightbox(file_id, parentFolderId) {
            var prop_lightbox = $("#file-properties");
            prop_lightbox.data('folder-id', parentFolderId);
            OpenDrive.ajax.do('files.get-file-info', {
                file_id: file_id,
                folder_id: parentFolderId
            }, function (response) {
                $("#prop-file-id", prop_lightbox).val(response.FileId);
                $("#prop-file-name", prop_lightbox).val(response.Name);
                $("#prop-file-size", prop_lightbox).html(OpenDrive.helpers.humanFileSize(response.Size) + ' (' + response.Size + ' bytes)');
                if (response.AccessDisabled) {
                    $('.js-file-sharing-prohibited', prop_lightbox).removeClass('hidden');
                    $('.js-set-file-access', prop_lightbox).addClass('hidden');
                } else {
                    $('.js-file-sharing-prohibited', prop_lightbox).addClass('hidden');
                    $('.js-set-file-access', prop_lightbox).removeClass('hidden');
                }

                if (response.Access == 0) {
                    $("#prop-access-private", prop_lightbox).click();
                } else if (response.Access == 1) {
                    $("#prop-access-public", prop_lightbox).click();
                } else if (response.Access == 2) {
                    $("#prop-access-hidden", prop_lightbox).click();
                }

                if (response.EditOnline == 1) {
                    $("#prop-file-edit-online", prop_lightbox).attr('checked', true);
                } else {
                    $("#prop-file-edit-online", prop_lightbox).attr('checked', false);
                }

                if (response.Price == 0) {
                    $("#prop-file-free", prop_lightbox).click();
                    $("#prop-file-price", prop_lightbox).val('0.00');
                } else {
                    $("#prop-file-paid", prop_lightbox).click();
                    $("#prop-file-price", prop_lightbox).val(response.Price);
                }

                var pwdInput = $("#prop-file-password", prop_lightbox);
                $('.js-pass_warning').addClass('hidden');
                pwdInput.data('pwdsend', false);
                if (response.Password != '') {
                    pwdInput.val('');
                    pwdInput.data('password', true);
                    pwdInput.attr('placeholder', '******');
                } else {
                    pwdInput.data('password', false);
                    pwdInput.attr('placeholder', '');
                }
                if (!pwdInput.data('change_attached')) {
                    pwdInput.data('change_attached', true);
                    pwdInput.on('change keyup keydown paste input cut', function () {
                        pwdInput.attr('placeholder', '');
                        pwdInput.data('pwdsend', true);
                        $('.js-pass_warning').removeClass('hidden');
                    });
                }

                if (response.DestURL != '') {
                    $("#prop-file-url", prop_lightbox).val(response.DestURL);
                }

                if (response.Description != '') {
                    $("#prop-file-description", prop_lightbox).val(response.Description);
                }

                show_lightbox(prop_lightbox);
                $('.js-lightbox-title', prop_lightbox)
                    .html(response.Name)
                    .ellipsisMiddle({reinitialize: true});
            });
        };


        $(".lightbox #prop-save-btn").click(function () {
            var file_lightbox = $("#file-properties");


            var file_id = $("#prop-file-id", file_lightbox).val();
            var folder_id = file_lightbox.data('folder-id');
            var file_price = 0;
            if ($("#prop-file-paid", file_lightbox).is(':checked')) {
                file_price = $("#prop-file-price", file_lightbox).val();
            }
            var file_name = $("#prop-file-name", file_lightbox).val();
            var file_description = $("#prop-file-description", file_lightbox).val();
            var file_password = $("#prop-file-password", file_lightbox);
            var file_dest_url = $("#prop-file-url", file_lightbox).val();
            var file_ispublic = $("input[name='prop_access']:checked", file_lightbox).val();
            var file_edit_online = 0;
            if ($("#prop-file-edit-online", file_lightbox).is(':checked')) {
                file_edit_online = 1;
            }

            var data = {
                file_id: file_id,
                folder_id: folder_id,
                file_price: file_price,
                file_name: file_name,
                file_description: file_description,
                file_dest_url: file_dest_url,
                file_ispublic: file_ispublic,
                file_edit_online: file_edit_online
            };
            if (file_password.data('pwdsend')) data.file_password = file_password.val();

            OpenDrive.ajax.do('files.update-file', data, function () {
                $(document).trigger('reload-folder.od');
                file_lightbox.hide()
            });

            return false;
        });

        $("#file-expiring-links #generate-btn").click(function () {

            var file_lightbox = $("#file-expiring-links");
            var date = $("#expiring-link-date", file_lightbox).val();
            var counter = 0;
            var enable = 0;
            if ($("#expiring-link-counter-enable", file_lightbox).is(':checked')) {
                enable = 1;
                counter = $("#expiring-link-counter", file_lightbox).val();
                if (counter < 1)
                    counter = 1;
            }

            var file_id = file_lightbox.data('file-id');
            var data = {
                date: date,
                counter: counter,
                file_id: file_id,
                enable: enable
            };


            OpenDrive.ajax.do('expiring-links.generate', data, function (response) {
                $("#download-expiring-file-links", file_lightbox).val(response.DownloadLink);
                $("#stream-expiring-file-links", file_lightbox).val(response.StreamingLink);
                $("#expiring-links-used", file_lightbox).val(0);
                $("#expiring-link-counter", file_lightbox).val(counter);
            });

        });

        $("#folder-expiring-links #generate-btn").click(function () {
                var folder_lightbox = $("#folder-expiring-links");
                var date = $("#expiring-link-date", folder_lightbox).val();
                var counter = 0;
                var enable = 0;
                if ($("#expiring-link-counter-enable", folder_lightbox).is(':checked')) {
                    enable = 1;
                    counter = $("#expiring-link-counter", folder_lightbox).val();
                    if (counter < 1)
                        counter = 1;
                }

                var folder_id = folder_lightbox.data('folder-id');
                var data = {
                    date: date,
                    counter: counter,
                    folder_id: folder_id,
                    enable: enable
                };


                OpenDrive.ajax.do('expiring-links-folder.generate', data, function (response) {
                    $("#url-expiring-folder-links", folder_lightbox).val(response.Link);
                    $("#expiring-links-used", folder_lightbox).val(0);
                    $("#expiring-link-counter", folder_lightbox).val(counter);
                });
            }
        );

        $(".lightbox #create-folder-btn").click(function () {
            var folder_lightbox = $("#create-new-folder");

            var folder_name = $("#new-folder-name").val();
            var folder_sub_parent = $('.js-root-menu').data('current-folder-id');
            var folder_is_public = $("input[name='new-folder-access']:checked").val();
            var folder_public_upl = $("input[name='new-folder-upload']:checked").val();
            var folder_public_display = 0;
            var folder_display_subfolders = 0;
            if ($("#new-folder-public-content").is(':checked')) {
                folder_public_display = 1;
            }
            if ($('#new-folder-public-subfolders').is(':checked')) {
                folder_display_subfolders = 1;
            }
            var folder_public_dnl = 0;
            if ($("#new-folder-public-download").is(':checked')) {
                folder_public_dnl = 1;
            }
            var folder_description = $("#new-folder-description").val();

            var data = {
                folder_name: folder_name,
                folder_sub_parent: folder_sub_parent,
                folder_is_public: folder_is_public,
                folder_public_upl: folder_public_upl,
                folder_public_display: folder_public_display,
                folder_public_dnl: folder_public_dnl,
                folder_display_subfolders: folder_display_subfolders,
                folder_description: folder_description
            };

            OpenDrive.ajax.do('create-folder', data, function () {
                folder_lightbox.hide();
                $(document).trigger('reload-folder.od');
            });

            return false;
        });

        $(".lightbox #prop-save-folder-btn").click(function () {
            var folder_lightbox = $("#folder-properties");
            var folder_id = $("#prop-folder-id", folder_lightbox).val();

            var folder_name = $("#prop-folder-name", folder_lightbox).val();
            var folder_description = $("#prop-folder-description", folder_lightbox).val();
            var folder_access = $("input[name='prop-folder-access']:checked", folder_lightbox).val();
            var folder_public_upl = $("input[name='prop-folder-upload']:checked", folder_lightbox).val();

            var folder_public_display = 0;
            var folder_display_subfolders = 0;
            if ($("#prop-folder-public-content", folder_lightbox).is(':checked')) {
                folder_public_display = 1;
            }

            if ($('#prop-folder-public-subfolders', folder_lightbox).is(':checked')) {
                folder_display_subfolders = 1;
            }
            var folder_public_dnl = 0;
            if ($("#prop-folder-public-download", folder_lightbox).is(':checked')) {
                folder_public_dnl = 1;
            }

            var parent_folder_id = folder_lightbox.data('folder-id');

            var data = {
                folder_id: folder_id,
                parent_folder_id: parent_folder_id,
                folder_name: folder_name,
                folder_description: folder_description,
                folder_access: folder_access,
                folder_public_upl: folder_public_upl,
                folder_public_display: folder_public_display,
                folder_public_dnl: folder_public_dnl,
                folder_display_subfolders: folder_display_subfolders
            };
            OpenDrive.ajax.do('files.update-folder', data, function (response) {
                if (response.Name) $('.js-root-menu').find('#folder-' + folder_id + ' > a .js-folder-name').eq(0).text(response.Name);
                $(document).trigger('reload-folder.od');
                folder_lightbox.hide();
            });

            return false;

        });

        //root menu
        //$(".create-dir-btn, .create-new-folder, .contex-folder-create-link").click(function(){
        //    $(".root.open").removeClass("open");
        //    show_lightbox($("#create-new-folder"));
        //    return false;
        //});
        $('.js-open-shared-folders').click(function () {
            return false;
        });

        $(document).keyup(function (e) {

            if (e.keyCode == 27) {
                $(".lightbox").hide();
            }   // esc
        });

        $(".lightbox-header .lightbox-close-btn").click(function () {
            var lb = $(this).closest('.lightbox');
            lb.hide();
            var callback = lb.find('.js-cancel-btn').data('callback');
            if (callback instanceof Function) callback.apply(this, arguments);
            return false;
        });

        $("a.question").hover(function () {
            var tip_head = $(this).attr('tip_head');
            var tip_body = $(this).attr('tip_body');
            if (tip_head != undefined && tip_body != undefined && tip_head != '' && tip_body != '') {
                $(".tip .text .head").html(tip_head);
                $(".tip .text .body").html(tip_body);
                //var offset = $(this).offset();

                var position = $(this).position();

                $(".tip").css('left', position.left + 50);
                $(".tip").css('top', position.top - $('.tip').height());

                $(".tip").show();
            }
        });

        $("a.question").mouseleave(function () {
            $(".tip").hide();
        });
    });




})(jQuery);
