(function ($) {
    $(function () {

        var RootMenu = new OpenDrive.widgets.RootMenu();
        var leftSidebar = $('.js-left-sidebar');
        leftSidebar.resizable({
            handles: 'e,w',
            start: function (event, ui) {
                var maxWidth = Math.floor(ui.originalElement.parent().width() * .45);
                ui.originalElement.css('max-width', maxWidth + 'px');
            }
        });

        leftSidebar.on('click', '.js-trash-btn', function () {
            $(document).trigger('load-folder.od', {folderId: 'trash'});
            return false;
        });

        function closeDropdownMenus() {
            var menus = $('.dropdown-menu').parent();
            menus.removeClass('open');
            menus.each(function () {
                $('[aria-expanded="true"]', this).attr('aria-expanded', 'false')
            });
            $('.dropdown-menu.js-dynamic').remove();
        }

        var rootMenu = $('.js-root-menu');
        rootMenu.on('load-subfolders.od', function (e, data) {
            if (data && data.folderId) {
                var dir = rootMenu.find('#folder-' + data.folderId);
                if (dir.length) loadSubfolders(dir, data.complete, true);
            }
            return false;
        });

        var rootMenuItems = $('.js-root-menu-items', rootMenu);
        //  sidebar context menu
        rootMenuItems.on('contextmenu', '.folder-item', function () {
            closeDropdownMenus();
            $('> .js-item-menu-btn', this).click();
            return false;
        });

        // sidebar root menu item contex menu
        $('.js-first-menu-item', rootMenu).on('contextmenu', function () {
            closeDropdownMenus();
            $('.js-item-menu-btn', $(this)).click();
            return false;
        });

        rootMenuItems.on('contextmenu', '.js-folder-link', function () {
            closeDropdownMenus();
            $(this).parent().find('.js-open-folder-menu').trigger('click');
            return false;
        });

        rootMenuItems.on('click', '.js-folder-link, .js-root-folder', function () {
            closeDropdownMenus();
            var folder = $(this).closest('.folder-item');
            if (folder.length) {
                var folderId = folder[0].id.replace('folder-', '');
                var _this = $(this);

                $(document).trigger('load-folder.od', {folderId: folderId});
                rootMenuItems.find('> .item.active, .folder-item.active').removeClass('active');
                if(_this.hasClass('js-root-folder')) {
                    folder.addClass('active');
                } else if( _this.hasClass('js-folder-link') ) {
                    var rootFolder = _this.closest('.js-root-item');
                    rootFolder.find('.folder-item.active').removeClass('active');
                    _this.parents('.folder-item').addClass('active');
                }
                setTimeout(function () {
                    loadSubfolders(folder, null, true)
                }, 0);
                return false;
            }
        });

        function setTreeActiveFolder(folderId) {
            rootMenuItems.find('> .item.active, .folder-item.active').removeClass('active');
            var folder = rootMenuItems.find('#folder-' + folderId);
            folder.parents('.folder-item, .js-root-item').addClass('active');
            folder.addClass('active');
        }

        rootMenuItems.on('click', '.js-item-menu-btn', function(){

            closeDropdownMenus();

            $(".bottom-aligned-menu").removeClass('bottom-aligned-menu');
            $(".left-aligned-menu").removeClass('left-aligned-menu');
            //$(".left-bottom-aligned-menu").removeClass('left-bottom-aligned-menu');

            var menu_el = $("> .dropdown-menu", $(this).closest('.item'));

            menu_el.parent().addClass('open');

            var menu_out = isElementOutViewport(menu_el);
            if ( menu_out == 'h' ||  menu_out == 'wh')
            {
                menu_el.addClass('bottom-aligned-menu');
            }
            else if ( menu_out == 'w' )
            {
                menu_el.addClass('left-aligned-menu');
            }
            else if ( menu_out == 'wh' )
            {
                //menu_el.addClass('left-bottom-aligned-menu');
            }

            $(this).toggleClass('active');
            return false;
        });


        function isElementOutViewport (el) {

            //special bonus for those using jQuery
            if (typeof jQuery === "function" && el instanceof jQuery) {
                el = el[0];
            }

            var rect = el.getBoundingClientRect();


            if ( rect.top >= 0 && rect.left >= 0  )
            {
                if ( rect.bottom > (window.innerHeight || document.documentElement.clientHeight) && rect.right > (window.innerWidth || document.documentElement.clientWidth) )
                {
                    return 'wh';
                }
                if ( rect.bottom > (window.innerHeight || document.documentElement.clientHeight) )
                {
                    return 'h';
                }
                else if ( rect.right > (window.innerWidth || document.documentElement.clientWidth) )
                {
                    return 'w';
                }
            }

            return false;

        }


        function initSidebarDnD(){
            $('.droppable', rootMenuItems).droppable({
                activeClass: "can-drop", hoverClass: "drop-active", greedy: true, scope: 'draggablefiles', tolerance: 'pointer',
                drop: SidebarDnDHandler
            }).removeClass('droppable');
        }
        initSidebarDnD();


        function SidebarDnDHandler( event, ui ){
            var drop = $(this).closest('.folder-item');
            var drag = ui.draggable;

            var dest_folder_id = drop.attr('id').replace('folder-', '');


            if ( drag.hasClass('file-item') )
            {
                // move file
                var src_file_id = drag.attr('id').replace('file-', '');

                drag.hide();

                OpenDrive.ajax.do('files.move-file',
                    {src_file_id: src_file_id, dest_folder_id: dest_folder_id},
                    function () {
                        drag.remove();
                    },
                    function () {
                        drag.show();
                    }
                );
            }
            else
            {
                // move folder
                var src_folder_id = drag.attr('id').replace('folder-', '');

                drag.hide();

                OpenDrive.ajax.do('files.move-folder',
                    {src_folder_id: src_folder_id, dest_folder_id: dest_folder_id},
                    function () {
                        drag.remove();
                    },
                    function () {
                        drag.show();
                    }
                );
            }
        }

        $('.js-root-dir.droppable', leftSidebar).droppable({
            activeClass: "can-drop", hoverClass: "drop-active", greedy: true, scope: 'draggablefiles', tolerance: 'pointer',
            drop: DnDHandler
        }).removeClass('droppable');

        $('.js-root-dir', leftSidebar).click(function(){
            $(document).trigger('load-folder.od', {folderId: 0});
            return false;
        });

        function DnDHandler( event, ui ){
            var drop = $(this);
            var drag = ui.draggable;

            if ( drop.hasClass('root-dir') )
            {
                var dest_folder_id = 0;
            }
            else
            {
                var dest_folder_id = drop.attr('id').replace('folder-', '');
            }


            if ( drag.hasClass('file-item') )
            {
                // move file
                var src_file_id = drag.attr('id').replace('file-', '');

                drag.hide();

                OpenDrive.ajax.do('files.move-file', {src_file_id: src_file_id, dest_folder_id: dest_folder_id},
                    function () {
                        drag.remove();
                    },
                    function () {
                        drag.show();
                    });
            }
            else
            {
                // move folder
                var src_folder_id = drag.attr('id').replace('folder-', '');

                drag.hide();


                OpenDrive.ajax.do('files.move-folder', {src_folder_id: src_folder_id, dest_folder_id: dest_folder_id},
                    function () {
                        drag.remove();
                    },
                    function () {
                        drag.show();
                    });
            }
        }

        // drop on trash
        $(".trash.droppable").droppable({activeClass: "can-drop", hoverClass: "drop-active", greedy: true, scope: 'draggablefiles', tolerance: 'touch',
            drop: function( event, ui ) {
                var drag = ui.draggable;
                if ( drag.hasClass('file-item') )
                {
                    if (confirm('Do you really wish to trash this file?'))
                    {
                        // move file
                        var src_file_id = drag.attr('id').replace('file-', '');
                        drag.hide();
                        OpenDrive.ajax.do('trash-file', {file_id: src_file_id}, function(){
                            $(document).trigger('item-trashed.od', {fileId: file_id});
                        });
                    }
                }
                else
                {
                    if (confirm('Do you really wish to trash this folder?'))
                    {
                        // move folder
                        var src_folder_id = drag.attr('id').replace('folder-', '');
                        drag.hide();
                        trash_folder(src_folder_id);
                    }
                }
            }
        });

        function trash_folder(folder_id, onTrash) {
            OpenDrive.ajax.do('files.trash-folder', {folder_id: folder_id}, onTrash);
        }

        rootMenuItems.on('click', '.js-context-trash-link', function(){
            var this_item = $(this).closest('.folder-item');
            var folder_id = this_item.attr('id').replace('folder-', '');
            if ( confirm(OpenDrive._('Do_you_really_want_to_perform_this_action')) )
            {
                trash_folder(folder_id, function () {
                    this_item.remove();
                    $(document).trigger('item-trashed.od', {folderId: folder_id})
                });
            }

            return false;
        });

        function loadSubfolders(dir, completeCallback, expandChildFolders) {
            function getSubDir() {
                return dir.find('> .js-child-dir');
            }

            var subdir = getSubDir();
            if (!dir.hasClass('expanded-folder') && !subdir.data('folders-loaded')) {
                var folderId = dir.attr('id').replace('folder-', '');
                OpenDrive.helpers.applyTemplate({IsLoading: true}, 'RootMenuSubdirItem', subdir, true);
                OpenDrive.ajax.do('files.list-folder', {
                    folder_id: folderId,
                    only_subfolders: true
                }, function (response) {
                    subdir = getSubDir();
                    var data = {
                        SubFolders: response.Folders,
                        SharedUsers: response.SharedUsers,
                        SharingID: response.SharingID,
                        SharedFolders: response.SharedFolders,
                        UserAccessMode: response.UserAccessMode
                    };
                    OpenDrive.helpers.applyTemplate(data, 'RootMenuSubdirItem', subdir, true);
                    subdir.data('folders-loaded', 1);
                    initSidebarDnD();
                    dir.addClass('expanded-folder');
                    if(completeCallback instanceof Function) completeCallback();
                });
            } else {
                if(completeCallback instanceof Function) completeCallback();
            }
            if (subdir.length && !subdir.is(':visible') && expandChildFolders) {
                subdir.slideDown();
                dir.addClass('expanded-folder');
            }
            RootMenu.resize();
        }

        rootMenu
            .on('click', '.js-expand-folder', function () {
                var dir = $(this).parent();
                loadSubfolders(dir);
                dir.toggleClass('expanded-folder');
                dir.find('> .js-child-dir').slideToggle();
                return false;
            })
            .on('click', '.js-open-folder-menu', function (e) {
                var folder = $(this.parentNode);

                $('.js-folder-menu', rootMenuItems).remove();
                var readOnlyAccess = parseInt(folder.data('useraccessmode')) === 0;
                var isSharedUser = folder.data('shared-user') != undefined;
                folder.append(
                    OpenDrive.helpers.applyTemplate({
                        FolderID: folder.attr('id').replace('folder-', ''),
                        ReadOnly: readOnlyAccess
                    }, 'RootFoldersPopupMenu')
                );

                var menu = folder.find('> .js-folder-menu');

                menu.removeClass('bottom-aligned-menu');
                folder.addClass('open');
                this.setAttribute('aria-expanded', 'true');
                if (rootMenuItems.offset().top + rootMenuItems.height() <= menu.offset().top + menu.outerHeight()) menu.addClass('bottom-aligned-menu');
                else menu.removeClass('bottom-aligned-menu');
                e.stopPropagation();
            })
            .on('click', '.js-create-subfolder, .js-context-folder-create-link', function () {
                if ($(this).hasClass('disabled')) {
                    OpenDrive.popups.showNotification(OpenDrive._('This_folder_is_read-only'), 4000);
                    return false;
                }
                $('.js-first-menu-item.open').removeClass('open');
                var folderId = rootMenu.data('current-folder-id');
                var parentFolder = $('#folder-' + folderId, '.js-root-menu-items');
                if (folderId == '0') {
                    var newFolder = $(OpenDrive.helpers.applyTemplate(null, 'RootDirItem'));
                    rootMenuItems.append(newFolder);
                    RootMenu.resize();
                    OpenDrive.widgets.EditableItem(
                        newFolder.find('.js-folder-name'), function (text) {
                            if (!text) {
                                newFolder.remove();
                                return;
                            }

                            var data = {
                                folder_name: text,
                                folder_sub_parent: folderId,
                                folder_public_upl: 1,
                                folder_public_display: 1,
                                folder_public_dnl: 1
                            };
                            OpenDrive.ajax.do('create-folder', data, function (response) {
                                    if (response && response.FolderID) {
                                        OpenDrive.helpers.applyTemplate(response, 'RootDirItem', newFolder, true);
                                        $(document).trigger('reload-folder.od');
                                        initSidebarDnD();
                                    }
                                },
                                function () {
                                    newFolder.remove();
                                });

                        }, {maxChars: 16},
                        function () {
                            newFolder.remove();
                        });
                } else if (parentFolder.length) {
                    var childDirs = $('> .js-child-dir', parentFolder);
                    $('.js-child-dir', '.js-root-menu-items').show();
                    childDirs.append(OpenDrive.helpers.applyTemplate(null, 'NewSubFolder'));
                    var subFolder = childDirs.find('.js-new-folder').last();

                    OpenDrive.widgets.EditableItem(subFolder, function (text) {
                            var parentItem = this.closest('li');
                            if (!text) {
                                parentItem.remove();
                                return;
                            }
                            var parentDir = this.closest('.js-child-dir');

                            var data = {
                                load_subfolders: 1,
                                folder_name: text,
                                folder_sub_parent: folderId,
                                folder_public_upl: 1,
                                folder_public_display: 1,
                                folder_public_dnl: 1
                            };
                            OpenDrive.ajax.do('create-folder', data, function (response) {
                                if (response && response.FolderID) {
                                    OpenDrive.helpers.applyTemplate(response, 'RootMenuSubdirItem', parentDir, true);
                                    $(document).trigger('reload-folder.od');
                                    initSidebarDnD();
                                }
                            }, function () {
                                parentItem.remove();
                            });

                        }, {maxChars: 16},
                        function () {
                            this.closest('li').remove();
                        });

                    var pos = subFolder.offset();
                    var subFolderRight = pos.left + subFolder.outerWidth(true);
                    var sidebarWidth = leftSidebar.width();
                    var sidebarRight = sidebarWidth + leftSidebar.offset().left;
                    if (sidebarRight < subFolderRight) leftSidebar.width(sidebarWidth + subFolderRight - sidebarRight + 8); //scrollbar width
                }
                return false;
            });

        //Child dirs
        rootMenuItems.on('click', '.js-context-move-link', function(){
            var this_item = $(this).closest('[id^="folder-"]');
            var move_lightbox = $('#file-folder-move');
            var header = $('.lightbox-header h2', move_lightbox);

            var folder_name = this_item.find('.js-folder-name').html();
            header.find('.js-item-name').text(folder_name);
            header.find('.js-item-file').hide();
            header.find('.js-item-folder').show();
            var move_folder_id = this_item.attr('id').replace('folder-', '');

            $('#move-folder-id', move_lightbox).val(move_folder_id);
            $('#move-file-id', move_lightbox).val(0);

            // get list of root folders
            loadLightboxFolderTree(0, move_lightbox);

            $('.dropdown-menu').closest('.open').removeClass('open');
        });

        function loadLightboxFolderTree(folderId, lightbox){
            OpenDrive.ajax.do('files.list-folder', {folder_id: folderId}, function (response) {
                var folders = {SubFolders: response.Folders};
                folders.Drivename = $('body').data('drivename');
                OpenDrive.helpers.applyTemplate(folders, 'LightboxFolderTree', $(".move-copy-folders-list"));
                show_lightbox(lightbox);
            });
        }

        rootMenuItems.on('click', '.js-context-copy-link', function(){
            var this_item = $(this).closest('[id^="folder-"]');
            var copy_folder_id = 0;
            var copy_file_id = 0;

            var copy_lightbox = $("#file-folder-copy");
            var header = $('.lightbox-header h2', copy_lightbox);

            var folder_name = this_item.find('.js-folder-name').html();
            header.find('.js-item-name').text(folder_name);
            header.find('.js-item-file').hide();
            header.find('.js-item-folder').show();
            copy_folder_id = this_item.attr('id').replace('folder-', '');

            $("#copy-folder-id", copy_lightbox).val(copy_folder_id);
            $("#copy-file-id", copy_lightbox).val(copy_file_id);

            // get list of root folders

            loadLightboxFolderTree(0, copy_lightbox);

            closeDropdownMenus();

            return false;
        });

        rootMenuItems.on('click', '.js-context-properties-link', function(){
            var this_item = $(this).closest('[id^="folder-"]');
            var itemFolderId = this_item.attr('id').replace('folder-', '');
            OpenDrive.widgets.LightBoxes.FolderContextProperties.show(itemFolderId/*, folderId*/);
            //showFolderPropertiesLighbox(folder_id);
        });

        rootMenuItems.on('click', '.js-context-links-link', function(){
            var this_item = $(this).closest('[id^="folder-"]');
            var folder_id = this_item.attr('id').replace('folder-', '');
            var folder_name = this_item.find('.js-folder-name').html();
            showFolderLinksDialog(folder_id, folder_name, this_item.data('access') == 0);
        });
        rootMenuItems.on('click', '.js-context-expiring-links-link', function(){
            var this_item = $(this).closest('[id^="folder-"]');
            var folder_id = this_item.attr('id').replace('folder-', '');
            var folder_name = this_item.find('.js-folder-name').html();
            showExpiringFolderLinksDialog(folder_id, folder_name, this_item.data('access') == 0);
        });

        rootMenuItems.on('click', '.js-context-send-by-email', function () {
            var this_item = $(this).closest('[id^="folder-"]'),
                type = 'folder';

            var send_lightbox = $("#send-file");

            var folder_id = this_item.attr('id').replace('folder-', '');
            var folder_name = this_item.find('.js-folder-name').html();
            $("#send-url", send_lightbox).val(this_item.data('directlink'));
            $("#send-item-id", send_lightbox).val(folder_id);
            var subject = $("#send-subject", send_lightbox);
            subject.val(subject.data('folder') + ' ' + folder_name);
            $('.js-folder', send_lightbox).show();
            $('.js-file', send_lightbox).hide();

            $("#send-item-type", send_lightbox).val(type);

            closeDropdownMenus();

            if(send_lightbox.data('g-recaptcha-loaded') === undefined) {
                $.getScript("https://www.google.com/recaptcha/api.js?hl=en&onload=onloadCallback&render=explicit");
                send_lightbox.data('g-recaptcha-loaded', true);
            }

            show_lightbox(send_lightbox);

        });


        function showFolderLinksDialog(folder_id, folder_name, privateItem) {
            var prop_lightbox = $("#folder-links");
            prop_lightbox.data('folder-id', folder_id);

            $('.js-lightbox-title', prop_lightbox).html(folder_name);

            OpenDrive.ajax.do('folder-files-links', {folder_id: folder_id}, function (response) {
                {
                    $("#links-folder-url", prop_lightbox).val(response.folder_link);
                    $("#links-folder-files", prop_lightbox).val(response.files_urls.join("\n"));
                    $("#links-folder-direct", prop_lightbox).val(response.files_direct_urls.join("\n"));

                    closeDropdownMenus();
                    if (privateItem) $('.js-not-shareable-item', prop_lightbox).removeClass('hidden');
                    else $('.js-not-shareable-item', prop_lightbox).addClass('hidden');
                    show_lightbox(prop_lightbox);
                    $('.js-lightbox-title', prop_lightbox)
                        .html(folder_name)
                        .ellipsisMiddle({reinitialize: true});
                }
            });
        }
        function showExpiringFolderLinksDialog(folder_id, folder_name, privateItem) {
            var prop_lightbox = $("#folder-expiring-links");
            prop_lightbox.data('folder-id', folder_id);
            console.log(folder_id);

            $('.js-lightbox-title', prop_lightbox).html(folder_name);

            OpenDrive.ajax.do('folder-expiring-links', {folder_id: folder_id}, function (response) {
                {
                    $("#url-expiring-folder-links", prop_lightbox).val(response.Link);
                    $("#expiring-link-counter", prop_lightbox).val(response.CounterMax);
                    $("#expiring-link-date", prop_lightbox).val(response.ExpiringDate);
                    $("#expiring-links-used", prop_lightbox).val(response.Counter);
                    if(response.CounterEnable === "1")
                        $("#expiring-link-counter-enable", prop_lightbox).prop('checked', true);
                    else
                        $("#expiring-link-counter-enable", prop_lightbox).prop('checked', false);
                    closeDropdownMenus();
                    show_lightbox(prop_lightbox);
                    $('.js-lightbox-title', prop_lightbox)
                        .html(folder_name)
                        .ellipsisMiddle({reinitialize: true});
                }
            });
        }

        function show_lightbox(wrapper)
        {
            wrapper.show();
            var container = $('.lightbox-container', wrapper),
                header = $('.lightbox-header', container),
                buttons = $('.lightbox-buttons', container),
                scrollBody = $('.lightbox-scrollable-content', container);

            function recalcHeight(){
                if ( scrollBody.length  ) {
                    var bodyHeight = container.height() - buttons.outerHeight(true) - header.outerHeight(true) - (scrollBody.outerHeight(true) - scrollBody.outerHeight());
                    if(bodyHeight < scrollBody.innerHeight()) {
                        scrollBody.css('height', bodyHeight + 'px');
                        var api = scrollBody.data('jsp');
                        if(api) api.reinitialise();
                        else scrollBody.jScrollPane();
                    }
                }
            }
            if(!wrapper.data('on_resize')){
                wrapper.data('on_resize', true);
                $(window).on('resize', recalcHeight)
            }

            container.css({'top': '50%', 'margin-top' : -1 * Math.ceil(container.outerHeight() / 2) +'px'});
            recalcHeight();
        }

        $(document).on('folder-loaded.od', function (e, folderData) {
            if (folderData) {
                var folderId = folderData.FolderId;
                var userAccessMode = folderData.UserAccessMode;
                if (folderId != null) {
                    setTreeActiveFolder(folderId);
                    RootMenu.scrollToElement('#folder-' + folderId);
                    RootMenu.showPrimaryMenu(folderId !== 'trash');
                    if (userAccessMode !== undefined) $('.js-create-subfolder', rootMenu)[userAccessMode == 0 ? 'addClass' : 'removeClass']('disabled');
                }
            }
        })
    });
})(jQuery);
