(function ($) {
    OpenDrive.widgets.TaskWidgets = {
        /**
         *
         * @param item  jQuery instance
         * @constructor
         */
        DatePicker: function (item) {
            var target = item.find('.js-date');
            var offset = item.offset();
            var offsetY = parseInt(item.data('dt-y-pad'));
            if (isNaN(offsetY)) offsetY = 0;
            var defaultDate = null;
            var date = target.data('date');
            if (date) {
                var dateValues = date.split('-');
                if (dateValues.length == 3 && parseInt(dateValues[0]) > 0) {
                    defaultDate = new Date();
                    defaultDate.setHours(0, 0, 0, 0);
                    defaultDate.setFullYear(dateValues[0], parseInt(dateValues[1]) - 1, dateValues[2]);
                }
            }
            target.datepicker('dialog', defaultDate, function (date) {
                    saveDate(date, target);
                },
                {
                    defaultDate: defaultDate,
                    beforeShow: function (input) {
                        $(input).hide();
                    },
                    dateFormat: 'd M yy',
                    minDate: '-1y'
                },
                [offset.left, offset.top + item.height() + offsetY]);

            function saveDate(date, widget) {
                var action = widget.data('action'),
                    itemId = widget.data('item-id'),
                    itemType = widget.data('item-type'),
                    param = widget.data('param'),
                    field = widget.data('response-value'),
                    fieldText = widget.data('response-value-text'),
                    data = {};

                data[itemType] = itemId;
                data[param] = date;
                OpenDrive.ajax.do(action, data, function (response) {
                    if (response) {
                        if (response[field]) widget.attr('data-date', response[field]);
                        if (response[fieldText]) widget.html(response[fieldText]);
                        item.trigger('datepicker-updated.od', response);
                    }
                })
            }
        },
        SelectPicker: {
            draw: function (context) {
                $('.js-select', context ? context : document.body).selectpicker({iconBase: ''});
            },

            /**
             *
             * @param select Select HTML node
             */
            colorizeSelectedValue: function (select) {
                if (select.selectedIndex >= 0) {
                    var color = $(select.options[select.selectedIndex]).data('color');
                    var btn = $(select).closest('.bootstrap-select').find('button');
                    btn.css('color', color == null ? 'inherit' : '#' + color);
                }
            }
        },
        ConfirmAction: function (message) {
            if (!message) message = OpenDrive._('Do_you_really_want_to_perform_this_action');
            return confirm(message);
        },
        SaveAnimation: {
            show: function ($item) {
                $item.after('<i class="fa fa-spin saving-icon fa-refresh js-save-animation" aria-hidden="true"></i>');
                $item.hide();
            },
            remove: function ($item) {
                $item.parent().find('> .js-save-animation').remove();
            }
        },
        SlideToggle: function (parent, doneCallback) {
            var target = $(parent.attr('data-target'));
            target.removeClass('hidden');
            target.slideToggle(400, function () {
                if (doneCallback) doneCallback();
                target.trigger('slidetoggled.od');
            });
        },
        AvatarReplacer: function () {
            this.find('.js-avatar')
                .one('load', function () {
                    $(this).removeClass('invisible');
                    return false;
                })
                .removeClass('js-avatar');
        },
        AnchorConverter: function () {
            this.find('.js-comment .js-description a:not([target="_blank"]), .js-subcomment .js-subcomment-input a:not([target="_blank"])').attr('target', '_blank');
        }
    };
})(jQuery);
