(function ($) {
    OpenDrive.ready(function () {
        var ITEM_TASKLIST = '.js-tasklist',
            ITEM_TASKSLIST_TASKS = '.js-tasklist-tasks',
            ITEM_TASK = '.js-task',
            ITEM_PROJECTLIST_NAME = '.js-project-list-name',
            ITEM_PROJECT = '.js-project',
            ITEM_COMMENT = '.js-comment',
            ITEM_SUBCOMMENT = '.js-subcomment',
            ITEM_ATTACHMENT = '.js-attachment',
            ITEM_COMMENT_ATTACHMENT = '.js-comment-attachments',
            ITEM_PROJECTNAME_CONTAINER = '.js-project-name-container',
            ITEM_PROJECTLIST = '.js-project-list-item';

        $(document).on('click', '[data-toggle=slidetoggle]', function (e, params) {
            var $this = $(this);
            OpenDrive.widgets.TaskWidgets.SlideToggle($this, params && params.doneCallback);
            var parentItemClass = $this.data('parent-item');
            if (parentItemClass) {
                var parentItem = $this.closest(parentItemClass);
                if (parentItem.length) {
                    parentItem.toggleClass('expanded-item');
                    if (parentItemClass == ITEM_PROJECTLIST) {
                        ProjectsListContainer.saveTree();
                    }
                }
            }
            return false;
        });

        $(document).on('click', '.js-open-datepicker', function () {
            var _this = $(this);
            if (!this.hasAttribute('disabled')) new OpenDrive.widgets.TaskWidgets.DatePicker(_this);
            return false;
        });

        $(document).on('click', '.js-new-project-list', function () {
            ProjectsListContainer.appendNewProjectList();
            return false;
        });

        var RootMenu = new OpenDrive.widgets.RootMenu();

        var CurrentUser = $.parseJSON($('#js-current-user-data').html());
        if (CurrentUser && CurrentUser.FirstName !== undefined && CurrentUser.LastName !== undefined) CurrentUser.Initials = (CurrentUser.FirstName.substr(0, 1) + CurrentUser.LastName.substr(0, 1)).toUpperCase();

        var Scrollbars = new function () {
            var _this = this;

            this.updateContentScrollbar = function () {
                //var scrollablePageContent = $('.js-scroll-content');
                //scrollablePageContent.perfectScrollbar({theme: 'od'});
                //scrollablePageContent.perfectScrollbar('update');
            };

            this.update = function () {
                _this.updateContentScrollbar();
                RootMenu.resize();
            };

            $(window).resize(function () {
                _this.updateContentScrollbar();
            });
            _this.update();
        };

        var ItemTabs = new OpenDrive.widgets.ItemTabs('task', CurrentUser.SessionToken);

        var WindowHistory = new function () {
            var lastTaskId,
                lastProjectId;
            this.pushProject = function (projectId) {
                if (projectId === lastProjectId) return;
                lastProjectId = projectId;
                lastTaskId = undefined;
                var url = projectId ? '/tasks/project/' + encodeURIComponent(projectId) : '/tasks';
                window.history.pushState({projectId: projectId}, null, url);
            };

            this.pushTask = function (taskId) {
                if (taskId === lastTaskId) return;
                lastTaskId = taskId;
                lastProjectId = undefined;
                window.history.pushState({taskId: taskId}, null, '/tasks/' + encodeURIComponent(taskId));
            };

            this.pushArchiveTrash = function () {
                lastTaskId = undefined;
                lastProjectId = undefined;
                window.history.pushState(null, null, '/tasks/' + encodeURIComponent(Project.getArchiveTrashItemFilter()));
            };

            window.addEventListener('popstate', function (e) {
                if (e) {
                    var state = e.state;
                    if (state && state.taskId) {
                        ItemTabs.activateTab(state.taskId /*|| state.projectId*/, {noHistoryChange: true});
                    } else {
                        ItemTabs.activateTab('<overview>', {
                            noHistoryChange: true,
                            projectId: state ? state.projectId : undefined
                        });
                    }
                }
            });

            return this;
        };

        var ProjectsListContainer = new function () {
            var _rootMenu;
            var _rootMenuItems;

            function rootMenu() {
                if (!_rootMenu) _rootMenu = $('.js-root-menu');
                return _rootMenu;
            }

            function rootMenuItems() {
                if (!_rootMenuItems) _rootMenuItems = $('.js-root-menu-items', rootMenu());
                return _rootMenuItems;
            }

            rootMenu().on('shown.bs.dropdown', function (e) {
                var target = $(e.target);
                var menuItems = rootMenuItems();
                var menu = target.find('> .dropdown-menu');

                menu.removeClass('dropdown-bottom-aligned');
                if (menuItems.offset().top + menuItems.height() <= menu.offset().top + menu.outerHeight()) menu.addClass('dropdown-bottom-aligned');
                else menu.removeClass('dropdown-bottom-aligned');
                return false;
            });

            rootMenu().on('click', '.js-rename-project-list', function (e) {
                var item = $(this).closest(ITEM_PROJECTLIST);
                item.removeClass('open');
                editProjectListName(item);
                e.preventDefault();
                return false;
            });

            rootMenu().on('click', '.js-archive-project-list', function (e) {
                e.preventDefault();
                if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                    var item = $(this).closest(ITEM_PROJECTLIST);
                    var listId = item.data('projectlistid');
                    OpenDrive.ajax.do('tasks.archive-project-list', {
                        list_id: listId
                    }, function (data) {
                        if (data && data.result) {
                            item.remove();
                            RootMenu.resize();
                            window.location = '/tasks';
                        }
                    });
                }
                return false;
            });

            rootMenu().on('click', '.js-trash-project-list', function (e) {
                e.preventDefault();
                if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                    var item = $(this).closest(ITEM_PROJECTLIST);
                    var listId = item.data('projectlistid');
                    OpenDrive.ajax.do('tasks.trash-project-list', {
                        list_id: listId
                    }, function (data) {
                        if (data && data.result) {
                            item.remove();
                            RootMenu.resize();
                            window.location = '/tasks';
                        }
                    });
                }
                return false;
            });

            rootMenu().on('click', '.js-add-project', function (e) {
                e.preventDefault();
                addProject($(this).closest(ITEM_PROJECTLIST))
            });

            rootMenu().on('click', ITEM_PROJECT, function () {
                var project = $(this);
                if (project.data('trashed') || project.data('archived')) return false;
                var projectId = project.data('projectid');
                Project.loadOverview(projectId);
                ItemTabs.activateTab('<overview>');
                return false;
            });

            rootMenu().on('click', '.js-rename-project', function (e) {
                e.preventDefault();
                var project = $(this).closest(ITEM_PROJECTNAME_CONTAINER).find(ITEM_PROJECT);
                editProjectName(project);
            });

            rootMenu().on('click', '.js-trash-project', function () {
                if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                    var project = $(this).closest(ITEM_PROJECTNAME_CONTAINER).find(ITEM_PROJECT);
                    Project.trashProject(project.data('projectid'));
                }
                return false;
            });

            rootMenu().on('click', '.js-archive-project', function () {
                if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                    var project = $(this).closest(ITEM_PROJECTNAME_CONTAINER).find(ITEM_PROJECT);
                    var projectId = project.data('projectid');
                    Project.archiveProject(projectId);
                }
                return false;
            });

            rootMenu().on('click', ITEM_PROJECTLIST_NAME, function () {
                var projectList = $(this).closest(ITEM_PROJECTLIST);
                if (projectList.hasClass('without-projects')) {
                    ProjectsListContainer.setProjectListsInactive();
                    projectList.addClass('active');
                    ProjectsListContainer.showMsgNoProjects();
                    return false;
                }
            });

            this.appendNewProjectList = function () {
                OpenDrive.ajax.do('tasks.new-project-list', null, function (data) {
                    if (data) {
                        rootMenuItems().append(OpenDrive.helpers.applyTemplate(
                            data,
                            'NewProjectList'
                        ));
                        RootMenu.resize();
                        var projectList = findProjectList(data.ProjectListId);
                        editProjectListName(projectList, true);
                        ProjectsListContainer.scrollToProjectList(data.ProjectListId);
                    }
                });
            };

            this.scrollToProjectList = function (listId) {
                var projectList = findProjectList(listId);
                RootMenu.scrollToElement(projectList);
            };

            function findProjectList(ProjectListId) {
                return $('.js-project-list-item[data-projectlistid="' + ProjectListId + '"]', rootMenuItems()).first();
            }

            function findProject(ProjectId) {
                return $(ITEM_PROJECT + '[data-projectid="' + ProjectId + '"]', rootMenuItems()).first();
            }

            function addProject(projectList) {
                var listId = projectList.data('projectlistid');
                OpenDrive.ajax.do('tasks.add-project', {
                    list_id: listId
                }, function (data) {
                    if (data && data.ProjectId) {
                        projectList.find('.js-project-list-collapse').append(
                            OpenDrive.helpers.applyTemplate(
                                data,
                                'NewProject'
                            )
                        );
                        projectList.removeClass('without-projects').addClass('expanded-item');
                        var list = projectList.find(ITEM_PROJECTLIST_NAME);
                        if (!projectList.find('.js-project-list-collapse').is(':visible')) OpenDrive.widgets.TaskWidgets.SlideToggle(list);
                        editProjectName(projectList.find('[data-projectid="' + data.ProjectId + '"]'), true);
                        ProjectsListContainer.initAcceptingDroppedTasks();
                    }
                });
            }

            function editProjectListName(item, isNewItem) {
                new OpenDrive.widgets.EditableItem(
                    item.find(ITEM_PROJECTLIST_NAME),
                    saveProjectListName,
                    isNewItem ? {initialValue: ''} : null
                );
            }

            function editProjectName(item, isNewItem) {
                if (isNewItem) item.data('is-new-project', true);
                new OpenDrive.widgets.EditableItem(
                    item,
                    saveProjectName,
                    isNewItem ? {initialValue: ''} : null
                );
            }

            function saveProjectListName(text) {
                var name = this;
                var projectList = name.closest(ITEM_PROJECTLIST);
                var listId = projectList.data('projectlistid');
                OpenDrive.ajax.do('tasks.update-project-list',
                    {
                        list_id: listId,
                        list_name: text
                    }, function (data) {
                        if (data) {
                            name.html(data.Name).attr('title', data.Name);
                            ProjectsListContainer.hasProjects();
                        }
                    });
            }

            function saveProjectName(text) {
                var project = this;
                var projectId = project.data('projectid');
                OpenDrive.ajax.do('tasks.update-project',
                    {
                        project_id: projectId,
                        name: text
                    }, function () {
                        if (project.data('is-new-project', true)) {
                            project.removeData('is-new-project');
                            ProjectsListContainer.makeProjectActive(projectId);
                            Project.loadOverview(projectId);
                        }
                    }
                );
            }

            /**
             *
             * @param listId
             * @param doneCallback
             * @param noSetActive
             * @returns {boolean} true - list set to expanded state, false - already expanded
             */
            this.expandProjectList = function (listId, doneCallback, noSetActive) {
                var projectListRootItem = findProjectList(listId);
                var projectList = projectListRootItem.find('.js-project-list-collapse-' + listId).first();
                if (projectList.length) {
                    var visible = projectList.is(':visible');
                    if (!visible && !projectList.data('has-expand-animation')) {
                        projectList.data('has-expand-animation', true);
                        if (!noSetActive) projectListRootItem.addClass('active');
                        projectListRootItem
                            .find('> [data-toggle="slidetoggle"]')
                            .first()
                            .trigger('click', {
                                doneCallback: function () {
                                    projectList.removeData('has-expand-animation');
                                    if (doneCallback) doneCallback();
                                }
                            });
                    } else if (doneCallback) {
                        doneCallback();
                    }
                    return visible;
                }
            };

            this.collapseProjectList = function (listId, doneCallback) {
                var projectListRootItem = findProjectList(listId);
                var projectList = projectListRootItem.find('.js-project-list-collapse-' + listId).first();
                if (projectList.length) {
                    if (projectList.is(':visible') && !projectList.data('has-collapse-animation')) {
                        projectList.data('has-collapse-animation', true);
                        projectListRootItem
                            .addClass('active')
                            .find('> [data-toggle="slidetoggle"]')
                            .first()
                            .trigger('click', {
                                doneCallback: function () {
                                    projectList.removeData('has-collapse-animation');
                                    if (doneCallback) doneCallback();
                                }
                            });
                    } else if (doneCallback) {
                        doneCallback();
                    }
                }
            };

            this.setProjectListsInactive = function () {
                rootMenuItems().find(ITEM_PROJECT + '.active, .js-project-list-item.active').removeClass('active');
            };

            this.makeProjectActive = function (projectId) {
                this.setProjectListsInactive();
                var projectItem = findProject(projectId);
                projectItem.addClass('active');
                var projectList = projectItem.closest(ITEM_PROJECTLIST);
                projectList.addClass('active');
                ProjectsListContainer.expandProjectList(projectList.data('projectlistid'), function () {
                    RootMenu.scrollToElement(projectItem);
                    ProjectsListContainer.saveTree();
                });
            };

            this.hasProjectLists = function () {
                if ($.isEmptyObject(CurrentUser)) return;
                var length = rootMenuItems().find(ITEM_PROJECTLIST).length;
                if (!length && !CurrentUser.AccessUserId) {
                    var msg;
                    switch (Project.getArchiveTrashItemFilter()) {
                        case 'trash':
                            msg = OpenDrive._('No_trashed_project_lists');
                            break;
                        case 'archive':
                            msg = OpenDrive._('No_archived_project_lists');
                            break;
                        default:
                            msg = OpenDrive._('Create_your_first_Project_List');
                    }
                    Project.writeAlert(msg);
                }
                return length;
            };

            this.hasProjects = function () {
                if ($.isEmptyObject(CurrentUser)) return;
                if (this.hasProjectLists()) {
                    var length = rootMenuItems().find(ITEM_PROJECT).length;
                    if (!length) {
                        var msg;
                        switch (Project.getArchiveTrashItemFilter()) {
                            case 'trash':
                                msg = OpenDrive._('No_trashed_projects');
                                break;
                            case 'archive':
                                msg = OpenDrive._('No_archived_projects');
                                break;
                            default:
                                msg = OpenDrive._('Project_list_has_no_projects_yet');
                        }
                        Project.writeAlert(msg);
                    }
                    else Project.removeAlerts();
                    Project.enableNewTaskList(length, Project.currentProject());
                    return length;
                }
            };

            this.showMsgNoProjects = function () {
                if ($.isEmptyObject(CurrentUser) || Project.getArchiveTrashItemFilter()) return;
                Project.writeAlert(OpenDrive._('This_project_list_has_no_projects_yet'));
            };

            this.addProjectToActiveList = function () {
                addProject(rootMenu().find('.js-project-list-item.active'));
            };

            this.addFirstNewProject = function () {
                var firstPl = rootMenuItems().find(ITEM_PROJECTLIST).first();
                firstPl.find('.js-add-project').trigger('click')
            };

            this.collapseAllProjectLists = function () {
                var openedPl = rootMenuItems().find('.js-project-list-item.expanded-item').removeClass('expanded-item');
                openedPl.each(function () {
                    $('.js-project-list-collapse', this).hide();
                });
                this.saveTree();
            };

            function loadTree() {
                var data;
                try {
                    data = JSON.parse(sessionStorage.getItem('od-tasks-pl-tree'));
                } catch (e) {
                }
                if (!(data instanceof Object)) data = {};
                var pls = rootMenuItems().find(ITEM_PROJECTLIST);
                pls.each(function () {
                    var $this = $(this);
                    var plId = $this.data('projectlistid');
                    if (!data[plId]) {
                        $this.addClass('expanded-item');
                        $('.js-project-list-collapse', this).show();
                    }

                });
            }

            this.clearTree = function () {
                try {
                    sessionStorage.removeItem('od-tasks-pl-tree');
                } catch (e) {
                }
            };

            this.saveTree = function () {
                var tree = {};
                rootMenuItems().find(ITEM_PROJECTLIST).each(function () {
                    var $this = $(this);
                    if (!$this.hasClass('expanded-item')) tree[$this.data('projectlistid')] = true;
                });

                try {
                    sessionStorage.setItem('od-tasks-pl-tree', JSON.stringify(tree));
                } catch (e) {
                }
            };

            this.initAcceptingDroppedTasks = function () {
                $(ITEM_PROJECT, _rootMenuItems).droppable({
                    activeClass: false,
                    hoverClass: 'drop-active',
                    greedy: true,
                    scope: 'draggabletasks',
                    tolerance: 'pointer',
                    drop: TasksDnDHandler
                });

                var timeoutId;

                $(ITEM_PROJECTLIST, _rootMenuItems).droppable({
                    activeClass: false,
                    hoverClass: false,
                    greedy: true,
                    scope: 'draggabletasks',
                    tolerance: 'pointer',
                    out: function (event, ui) {
                        //var _this = $(this);
                        //if (timeoutId) clearTimeout(timeoutId);
                        //timeoutId = setTimeout(function () {
                        //    if(!_this.find('.js-project.drop-active').length) {
                        //        if(_this.data('expanded-state')) ProjectsListContainer.collapseProjectList(_this.data('projectlistid'));
                        //        _this.removeData('expanded-state');
                        //    }
                        //}, 500);
                    },
                    over: function (event, ui) {
                        var _this = $(this);
                        if (timeoutId) clearTimeout(timeoutId);
                        timeoutId = 0;
                        ProjectsListContainer.expandProjectList(_this.data('projectlistid'), null, true);
                        return false;
                    }
                });

                function TasksDnDHandler(event, ui) {
                    var drop = $(this),
                        drag = ui.draggable,
                        projectId = drop.data('projectid');
                    drag.data('drop-target-project', projectId)
                }
            };

            loadTree();
            this.initAcceptingDroppedTasks();

            return this;
        };

        var Project = new function () {
            var content = $('.js-tab-content');
            var colorTags = $.parseJSON($('#js-tags-data').html());
            var ProjectVars = $.parseJSON($('#js-project-vars').html());
            var ArchiveTrashItemFilter = ProjectVars.ArchiveTrashItemFilter;

            this.getArchiveTrashItemFilter = function () {
                return ArchiveTrashItemFilter;
            };

            this.getColorTags = function () {
                return colorTags;
            };

            this.writeProjectDates = function (data) {
                if (data) {
                    OpenDrive.helpers.applyTemplate(
                        data,
                        'ProjectDates',
                        $('.js-project-buttons')
                    );
                } else {
                    $('.js-project-buttons').empty();
                }
            };

            this.attachImageFromClipboard = function () {

            };

            this.hasTaskLists = function () {
                if ($.isEmptyObject(CurrentUser)) return;
                if (ProjectsListContainer.hasProjectLists() && ProjectsListContainer.hasProjects()) {
                    var overviewTab = ItemTabs.getTab('<overview>');
                    if (!overviewTab.length) return;
                    var taskLists = overviewTab.data('TaskTab').findTaskList(null);
                    if (taskLists.length) Project.removeAlerts();
                    else {
                        if (overviewTab.data('TaskTab').getOverviewMode()) Project.writeAlert('Please select the project list and project.');
                        else {
                            var msg;
                            switch (Project.getArchiveTrashItemFilter()) {
                                case 'trash':
                                    msg = OpenDrive._('No_trashed_tasks');
                                    break;
                                case 'archive':
                                    msg = OpenDrive._('No_archived_tasks');
                                    break;
                                default:
                                    msg = OpenDrive._('Create_your_first_Task_List');
                            }
                            Project.writeAlert(msg);
                        }
                    }
                }
            };


            this.loadTaskTab = function (taskId, completeCallback) {
                new TaskTab(taskId, completeCallback);
            };

            this.loadOverview = function (projectId, completeCallback) {
                new OverviewTab(projectId, completeCallback);
            };

            this.trashProject = function (projectId) {
                OpenDrive.ajax.do(
                    'tasks.trash-project',
                    {
                        project_id: projectId
                    }, function (response) {
                        if (response && response.result) {
                            location.reload();
                        }
                    })
            };

            this.archiveProject = function (projectId) {
                OpenDrive.ajax.do(
                    'tasks.archive-project',
                    {
                        project_id: projectId
                    }, function (response) {
                        if (response && response.result) {
                            location.reload();
                        }
                    })
            };

            this.currentProject = function () {
                var overviewTab = ItemTabs.getTab('<overview>');
                if (!overviewTab.length) return;
                return overviewTab.data('TaskTab').getProjectId();
            };

            this.setCurrentProject = function (projectId) {
                content.removeData('projectid');
                content.attr('data-projectid', projectId);
            };

            this.enableNewTaskList = function (enable, show) {
                if(Project.getArchiveTrashItemFilter()) show = false;
                $('.js-new-task-list-btn')
                    [enable ? 'removeClass' : 'addClass']('disabled')
                    [show ? 'removeClass' : 'addClass']('hidden');
            };

            this.removeAlerts = function () {
                var overviewTab = ItemTabs.getTab('<overview>');
                if (!overviewTab.length) return;
                overviewTab.data('TaskTab').removeAlerts();
            };

            this.writeAlert = function (msg) {
                var overviewTab = ItemTabs.getTab('<overview>');
                if (!overviewTab.length) return;
                overviewTab.data('TaskTab').addAlert(msg);
            };

            /**
             * Move task to task list or project
             * @param taskId
             * @param insertAfterTaskId
             * @param taskListId
             * @param projectId
             */
            this.moveTask = function (taskId, insertAfterTaskId, taskListId, projectId) {
                var opts = {
                    task_id: taskId
                };
                if (taskListId) opts.task_list_id = taskListId;
                else if (projectId) opts.project_id = projectId;
                else return;
                if (insertAfterTaskId) opts.insert_after_taskid = insertAfterTaskId;

                var overviewTab = ItemTabs.getTab('<overview>');
                var isOverview = overviewTab.data('TaskTab').getOverviewMode();
                if (isOverview && !Project.getArchiveTrashItemFilter()) opts.item_type = 'uncompleted_task';

                OpenDrive.ajax.do('tasks.move-task', opts, function (data) {
                    if (!overviewTab.length) return;
                    overviewTab.data('TaskTab').updateTaskList(data);
                }, function () {
                    if (overviewTab.length) {
                        overviewTab.data('TaskTab').initDnDTasks();
                        overviewTab.data('TaskTab').makeTasksSortable();
                    }
                    ProjectsListContainer.initAcceptingDroppedTasks();
                });
            };

            $(document).on('click', '.js-new-task-list-btn', function () {
                var _this = $(this);
                if (!_this.hasClass('disabled')) {
                    var currentProjectId = Project.currentProject();
                    if (!currentProjectId) return false;
                    OpenDrive.ajax.do('tasks.add-task-list', {
                        project_id: currentProjectId
                    }, function (data) {
                        if (data && data.TaskListId) {
                            var overviewTab = ItemTabs.getTab('<overview>');
                            if (!overviewTab.length) return;
                            overviewTab.data('TaskTab').appendNewTaskList(data);
                        }
                    });
                }
                return false;
            });

            return this;
        };

        function TabFileUploader(options, $tab) {
            this.fileInput = $('<input type="file" class="hidden" multiple/>');
            this.target = null;
            $tab.append(this.fileInput);

            var _this = this;
            this.queryVars = {
                session_id: $('#api_session_id').val()
            };
            var opts = options;

            this.uploadArgs = {};

            this.addFile = function (file) {
                _this.resumable.addFile(file);
            };

            function resumableQueryCallback() {
                return _this.uploadArgs;
            }

            this.resumable = new Resumable({
                target: $('#upload_url').val(),
                query: function () {
                    return resumableQueryCallback.apply(this, arguments);
                },
                chunkSize: 1048576,
                testChunks: false,
                simultaneousUploads: 1,
                permanentErrors: [400, 401, 402, 403, 404, 409, 413, 415, 500, 503, 507],
                maxChunkRetries: 10
            });

            if (!this.resumable.support) console.log('Upload is not supported');

            this.resumable.assignBrowse(this.fileInput);

            this.resumable.on('fileAdded', function (file) {

                var data = {
                    File: file,
                    Size: readableFileSize(file.size)
                };
                if(file.file._isBlob) {
                    var reader = new FileReader();
                        reader.onload = function(e){
                        data.EmbedImageUrl = e.target.result;
                        _this.target.append(OpenDrive.helpers.applyTemplate(
                            data,
                            'UploadingFile'
                        ));
                    };
                    reader.readAsDataURL(file.file);
                } else {
                    _this.target.append(OpenDrive.helpers.applyTemplate(
                        data,
                        'UploadingFile'
                    ));
                }
            });

            this.resumable.on('fileSuccess', function (file) {
                delete _this.uploadArgs.upload_id;
            });
            this.resumable.on('pause', function (file) {
            });

            this.resumable.on('complete', function () {
                delete _this.uploadArgs.upload_id;
                if (opts.completeCallback) opts.completeCallback();
            });

            this.resumable.on('fileRetry', function (file) {
            });

            this.resumable.on('fileProgress', function (file, data) {
                if(data) {
                    try {
                        data = JSON.parse(data);
                        if (data && data.upload_id) {
                            _this.uploadArgs.upload_id = data.upload_id;
                        }
                    } catch (e) {
                    }
                }
                var progress = file.progress();
                var id = file.uniqueIdentifier;

                if (progress > 0) {
                    _this.target.find('.js-uploading-file[data-fileid="' + id + '"] .js-progress').removeClass('hidden').html(Math.ceil(progress * 100));
                }
            });

            this.resumable.on('fileError', function (file, message) {
                delete _this.uploadArgs.upload_id;
            });
            return this;
        };

        (function () {
            this.openDialog = function () {
                this.fileInput.click();
            };

            this.setUploadArgs = function (args) {
                this.uploadArgs = $.extend(args, this.queryVars);
            };

            this.setTargetContainer = function (node) {
                this.target = node;
            };

            this.startUpload = function () {
                this.resumable.upload();
            };

            this.removeFile = function (fileId) {
                var file = this.resumable.getFromUniqueIdentifier(fileId);
                if (file) this.resumable.removeFile(file);
            };

            this.clearQueue = function () {
                this.resumable.files = [];
                this.setUploadArgs({});
            };
        }).call(TabFileUploader.prototype);


        var Editors = new function () {
            this.removeAll = function () {
                for (var i in CKEDITOR.instances) {
                    var editor = CKEDITOR.instances[i];
                    editor.destroy();
                }
            };

            this.attach = function ($node, opts, onChangeCallback) {
                if ($node.length) {
                    $node = $node.first();
                    $node.prop('contenteditable', true);
                    if ($node.data('editor-id')) return;
                    var editor = CKEDITOR.inline($node[0], opts);
                    editor.on('instanceReady', function (ev) {
                        var editor = ev.editor;
                        editor.setReadOnly(false);
                    });
                    $node
                        .data('editor-id', editor.name)
                        .addClass('js-ckeditor');
                    if (onChangeCallback) editor.on('change', onChangeCallback);

                    $node[0].addEventListener('paste', function (e) {
                        if (!e.clipboardData || !e.clipboardData.items || !e.clipboardData.items.length) return;
                        var item = e.clipboardData.items[0];
                        if (item.kind == 'file' && /^image\/(gif|jpeg|pjpeg|png)$/.test(item.type)) {
                            var blob = item.getAsFile();
                            var ext = RegExp.$1;
                            var $tab = ItemTabs.getActiveTab();
                            if ($tab.length) $tab.data('TaskTab').attachImageFromClipboard(blob, ext);
                        } else {
                            return;
                        }
                        e.stopPropagation();
                        e.stopImmediatePropagation();
                        e.preventDefault();
                    });

                    editor.on('paste', function (e) {
                        var data = e.data,
                            html = (data.html || ( data.type && data.type == 'html' && data.dataValue));
                        if (!html)
                            return;
                        html = html.replace(/<img src="(data:image\/(gif|jpeg|(?:p)?jpeg|png);base64,.*?)"[^>]*>/, '');
                        var dataUrl = RegExp.$1;
                        var ext = RegExp.$2;
                        if (dataUrl) {
                            var img = new Image();
                            img.src = dataUrl;
                            img.onload = function () {
                                var canvas = document.createElement('canvas');
                                canvas.width = img.width;
                                canvas.height = img.height;
                                var ctx = canvas.getContext('2d');
                                ctx.drawImage(img, 0, 0, canvas.width, canvas.height);

                                function getBlob(blob) {
                                    var $tab = ItemTabs.getActiveTab();
                                    if ($tab.length) $tab.data('TaskTab').attachImageFromClipboard(blob, ext);
                                }

                                if (canvas.toBlob) canvas.toBlob(getBlob);
                                else if (canvas.msToBlob) getBlob(canvas.msToBlob());
                            }
                        }
                        if (e.data.html)
                            e.data.html = html;
                        else
                            e.data.dataValue = html;

                    });
                }
            };

            this.getEditor = function ($node) {
                var editorId = $node.first().data('editor-id');
                if (editorId && CKEDITOR.instances[editorId]) return CKEDITOR.instances[editorId];
                else throw 'Editor not found';
            };

            this.getData = function ($node) {
                var editor = this.getEditor($node);
                if (editor) {
                    var string = editor.getData();
                    string = string
                        .replace(/(?:&nbsp;|&#160;)/gi, ' ')
                        .replace(/\t/, ' ')
                        .replace(/(?:\s){2,}/, ' ')
                        .replace(/<p>\s*?<\/p>/gi, '');
                    return string;
                }
                else throw 'Editor not found';
            };

            this.remove = function ($node) {
                if ($node.length) {
                    $node = $node.first();
                    $node.prop('contenteditable', false);
                    var editorId = $node.data('editor-id');
                    if (editorId) {
                        var editor = CKEDITOR.instances[editorId];
                        if (editor) {
                            editor.destroy();
                        }
                        $node
                            .removeData('editor-id')
                            .removeClass('js-ckeditor');
                    }
                }
            };
            return this;
        };

        /**
         *
         * @param {String} projectId
         * @param {Function} completeCallback
         * @param {Boolean} noActivate
         * @constructor
         */
        function OverviewTab(projectId, completeCallback, noActivate) {
            var $tab;
            var isOverview = !projectId;
            var tabId = '<overview>';
            var _this = this;

            function getHeader(tasklists) {
                var tasksCount = 0;
                for(var i = tasklists.length - 1; i >= 0 ; i--) tasksCount += tasklists[i].Tasks.length;
                return OpenDrive.helpers.applyTemplate({
                    Overview: isOverview,
                    TasksCount: tasksCount,
                    orderAsc: DueDateOrder.orderAsc
                }, 'TaskListHeader');
            }

            function appendTaskLists(data) {
                $tab.append(OpenDrive.helpers.applyTemplate(
                    {
                        TaskLists: data,
                        ColorTags: Project.getColorTags(),
                        Overview: isOverview
                    },
                    'TasksList'
                ));
                OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
            }

            function updateBreadCrumbs(opts, replace) {
                var breadCrumb = ItemTabs.getBreadCrumb(tabId);
                var baseOpts = {};

                if (replace) baseOpts = $.extend(opts, baseOpts);
                else baseOpts = opts;

                opts.Overview = isOverview;
                OpenDrive.helpers.applyTemplate(
                    baseOpts,
                    'BreadCrumbs',
                    breadCrumb
                );
            }

            this.initDnDTasks = function () {
                $(ITEM_TASK, $tab).draggable(
                    {
                        delay: 200,
                        revertDuration: 200,
                        scope: 'draggabletasks',
                        revert: 'invalid',
                        containment: 'window',
                        helper: 'clone',
                        appendTo: 'body',
                        cursor: 'move',
                        distance: 10,
                        scroll: false,
                        refreshPositions: true,
                        connectToSortable: ITEM_TASKLIST,
                        handle: '.js-move-task',
                        zIndex: 99999
                    });
            };

            this.makeTasksSortable = function () {
                $('.js-task.ui-draggable.ui-draggable-dragging', document).remove();
                $(ITEM_TASKLIST, $tab).each(function () {
                    $(this).sortable({
                        axis: 'y',
                        containment: this,
                        delay: 200,
                        zIndex: 99999,
                        distance: 10,
                        placeholder: 'ui-state-highlight',
                        forcePlaceholderSize: true,
                        handle: '.js-move-task',
                        items: ITEM_TASK,
                        receive: function (event, ui) {
                            var taskId = ui.item.data('taskid');
                            if ($(ITEM_TASK + '[data-taskid="' + taskId + '"]', this).length) ui.item.hide();
                        },
                        update: function (event, ui) {
                            var taskListId = $(this).data('tasklistid'),
                                taskId = ui.item.data('taskid'),
                                insertAfterTask = ui.item.prev(ITEM_TASK),
                                projectId = ui.item.data('drop-target-project');

                            if (projectId) {
                                ui.item.removeData('drop-target-project');
                                Project.moveTask(taskId,
                                    null,
                                    null,
                                    projectId);
                            } else {
                                Project.moveTask(taskId,
                                    insertAfterTask.length ? insertAfterTask.data('taskid') : null,
                                    taskListId,
                                    null);
                            }
                        }
                    })
                })
            };

            this.updateTask = function (data) {
                if (!data || !data.TaskId) return;
                TaskHelper.updateTaskRow(data);
            };

            function sortTaskLists(data, ascending) {
                data.TaskLists = data.TaskLists.sort(function (a, b) {
                    return a.DueDateTime == b.DueDateTime ? 0 :
                        (a.DueDateTime > b.DueDateTime
                            ? (ascending ? 1 : -1)
                            : (ascending ? -1 : 1))
                });
                data.TaskLists.forEach(function (value, index) {
                    data.TaskLists[index].Tasks = value.Tasks.sort(function (a, b) {
                        return a.DueDateTime == b.DueDateTime ? 0 :
                            (a.DueDateTime > b.DueDateTime
                                ? (ascending ? 1 : -1)
                                : (ascending ? -1 : 1))
                    });
                })
            }

            var projectData = null;

            function loadTabContent(noHistoryChange) {
                ItemTabs.setTabLoadedStatus(tabId);

                var params = {
                    filter: Project.getArchiveTrashItemFilter()
                };
                if (isOverview && !Project.getArchiveTrashItemFilter()) params.item_type = 'uncompleted_task';
                if (projectId) params.project_id = projectId;

                OpenDrive.ajax.do('tasks.load-task-lists',
                    params,
                    function (data) {
                        data.Overview = isOverview;
                        projectData = data.Project;
                        if (data) {
                            if (data.Project) {
                                Project.setCurrentProject(projectId);
                                Project.enableNewTaskList(true, projectId);
                                Project.writeProjectDates(data.Project);
                            } else {
                                Project.setCurrentProject(null);
                                Project.enableNewTaskList(false, false);
                                Project.writeProjectDates();
                            }

                            if (!noHistoryChange) {
                                if (Project.getArchiveTrashItemFilter()) WindowHistory.pushArchiveTrash();
                                else WindowHistory.pushProject(projectId);
                            }
                            if(!Project.getArchiveTrashItemFilter() || data.TaskLists.length) ItemTabs.updateTab(tabId, getHeader(data.TaskLists));
                            if (isOverview) sortTaskLists(data, DueDateOrder.orderAsc);

                            if (data.ProjectList && data.Project) updateBreadCrumbs({
                                ProjectId: data.Project.ProjectId,
                                Project: data.Project.Name,
                                ProjectListId: data.ProjectList.ProjectListId,
                                ProjectList: data.ProjectList.Name
                            });
                            else {
                                updateBreadCrumbs({});
                            }
                            if (data.TaskLists) appendTaskLists(data.TaskLists, projectId);
                            ItemTabs.setTabLoadedStatus(tabId, true);
                            if (!noActivate) ProjectsListContainer.makeProjectActive(projectId);
                            Project.hasTaskLists();
                            _this.initDnDTasks();
                            _this.makeTasksSortable();
                            Scrollbars.updateContentScrollbar();
                        }
                        if (completeCallback instanceof Function) completeCallback();
                    });
            }

            this.appendNewTaskList = function (data) {
                Project.removeAlerts();
                data.Overview = isOverview;
                $tab.append(OpenDrive.helpers.applyTemplate(
                    data,
                    'SingleTaskList'
                ));
                editTaskListName(_this.findTaskList(data.TaskListId), true);
            };

            this.findTaskList = function (taskListId) {
                return $tab.find('.js-tasklist' + (taskListId === null ? '' : '[data-tasklistid="' + taskListId + '"]'));
            };

            this.getOverviewMode = function () {
                return isOverview;
            };

            this.updateTaskList = function (data) {
                var oldTaskList = _this.findTaskList(data.OldTaskList.TaskListId),
                    newTaskList = _this.findTaskList(data.NewTaskList.TaskListId);

                if (oldTaskList.length) {
                    oldTaskList.sortable('destroy');
                    data.OldTaskList.ColorTags = Project.getColorTags();
                    data.OldTaskList.Overview = isOverview;
                    OpenDrive.helpers.applyTemplate(
                        data.OldTaskList,
                        'SingleTaskList',
                        oldTaskList,
                        true
                    );
                }

                if (newTaskList.length && data.OldTaskList.TaskListId != data.NewTaskList.TaskListId) {
                    newTaskList.sortable('destroy');
                    data.NewTaskList.ColorTags = Project.getColorTags();
                    data.NewTaskList.Overview = isOverview;
                    OpenDrive.helpers.applyTemplate(
                        data.NewTaskList,
                        'SingleTaskList',
                        newTaskList,
                        true
                    );
                }
                OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                _this.initDnDTasks();
                _this.makeTasksSortable();
            };

            this.addAlert = function (msg) {
                var alerts = $tab.find('.js-alerts');
                if (!alerts.length) $tab.html('<div class="alert alert-info js-alerts"></div>');
                $tab.find('.js-alerts').html(msg);
            };

            this.removeAlerts = function () {
                $tab.find('.js-alerts').remove();
            };

            function findTask(taskId) {
                return $tab.find(ITEM_TASK + '[data-taskid="' + taskId + '"]')
            }

            function editTaskListName(taskList, isNewItem) {
                var listName = $('.js-tasklist-name', taskList);
                var opts = {maxChars: 64};
                if (isNewItem) opts.initialValue = '';
                new OpenDrive.widgets.EditableItem(listName, function (listNameText) {
                        var listId = taskList.data('tasklistid');
                        OpenDrive.ajax.do('tasks.update-task-list', {
                            list_id: listId,
                            list_name: listNameText
                        }, function (data) {
                            if (data && data.Name) listName.html(data.Name);
                        });
                    },
                    opts
                )
            }

            function restoreTaskList($taskList) {
                var listId = $taskList.data('tasklistid');
                OpenDrive.ajax.do('tasks.restore-task-list', {
                    list_id: listId
                }, function (data) {
                    if (data.result) {
                        $taskList.fadeOutRemove();
                    }
                });
            }

            function completeTaskList(taskListId, status) {
                OpenDrive.ajax.do('tasks.update-task-list', {
                    list_id: taskListId,
                    complete_all_tasks: status
                }, function () {
                    if (isOverview) {
                        _this.findTaskList(taskListId).fadeOutRemove();
                    } else {
                        loadTaskList(taskListId)
                    }
                });
            }

            function loadTaskList(taskListId) {
                OpenDrive.ajax.do('tasks.load-task-lists', {
                    project_id: projectId,
                    task_list_id: taskListId,
                    filter: Project.getArchiveTrashItemFilter()
                }, function (data) {
                    if (data && data.TaskLists) {
                        OpenDrive.helpers.applyTemplate(
                            {
                                TaskLists: data.TaskLists,
                                ColorTags: Project.getColorTags(),
                                Overview: isOverview
                            },
                            'TasksList',
                            _this.findTaskList(taskListId),
                            true
                        );
                        OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                        _this.initDnDTasks();
                    }
                });
            }

            var TaskHelper = new function () {
                var _th = this;
                /**
                 * Task Data
                 * @param taskId
                 * @param data
                 */
                this.update = function (taskId, data) {
                    data = data || {};
                    data.task_id = taskId;
                    OpenDrive.ajax.do('tasks.update-task', data, function (response) {
                        if (response && response.TaskId && !data.color) {
                            _th.updateTaskRow(response);
                        }
                    });
                };

                this.trash = function (taskId) {
                    OpenDrive.ajax.do('tasks.trash-task', {task_id: taskId}, function (response) {
                        if (response && response.result) {
                            var task = $tab.find('.js-task[data-taskid="' + taskId + '"]');
                            task.remove();
                            Trash.refresh();
                        }
                    });
                };

                this.archive = function (taskId) {
                    OpenDrive.ajax.do('tasks.archive-task', {task_id: taskId}, function (response) {
                        if (response && response.result) {
                            var task = $tab.find('.js-task[data-taskid="' + taskId + '"]');
                            task.remove();
                        }
                    });
                };

                this.saveProgress = function (taskId, progress) {
                    var data = {progress: progress, task_id: taskId};
                    OpenDrive.ajax.do('tasks.update-task', data, function (response) {
                        if (response && response.TaskId) {
                            _th.updateTaskRow(response);
                        }
                    });
                };

                this.savePrivacy = function (taskId, privacy) {
                    this.update(taskId, {private: privacy});
                };

                this.editTaskName = function (taskId, isNewItem) {
                    var task = findTask(taskId);
                    var taskName = task.find('.js-task-name');
                    var opts = {maxChars: 64};
                    if (isNewItem) opts.initialValue = '';
                    new OpenDrive.widgets.EditableItem(taskName, function (taskNameText) {
                            if (taskNameText != '')TaskHelper.update(taskId, {task_name: taskNameText});
                        },
                        opts);
                };

                this.openTaskShareDialog = function ($task) {
                    Lightboxes.showShareLink($task.find('.js-task-name').text(), $task.data('link'));
                };

                this.restore = function ($task) {
                    OpenDrive.ajax.do('tasks.restore-task', {task_id: $task.data('taskid')}, function (response) {
                        if (response.result) $task.fadeOutRemove();
                    });
                };

                this.updateTaskRow = function (data) {
                    var task = findTask(data.TaskId);
                    if (!task.length) return;
                    data.ColorTags = Project.getColorTags();
                    OpenDrive.helpers.applyTemplate(data, 'Task', task, true);
                    task = findTask(data.TaskId);
                    task.hide();
                    OpenDrive.widgets.TaskWidgets.SelectPicker.draw();
                    task.show();
                };

                this.addNewTask = function (taskList, taskListId) {
                    OpenDrive.ajax.do('tasks.add-task', {task_list_id: taskListId}, function (response) {
                        if (response && response.TaskId) {
                            var newTaskHtml = OpenDrive.helpers.applyTemplate(response, 'Task');
                            taskList.append(newTaskHtml);
                            OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                            _this.initDnDTasks();
                            _this.makeTasksSortable();
                            TaskHelper.editTaskName(response.TaskId, true);
                        }
                    });
                };

                this.savePriority = function (taskId, priority) {
                    var data = {priority: priority, task_id: taskId};
                    OpenDrive.ajax.do('tasks.update-task', data, function (response) {
                        if (response && response.TaskId) {
                            _th.updateTaskRow(response);
                        }
                    });
                };

                this.saveColor = function (taskId, color) {
                    var task = findTask(taskId);
                    task.data('bgcolor', color).css('backgroundColor', '#' + color);
                    this.update(taskId, {color: task.data('bgcolor')});
                };

                this.saveTag = function (taskId, tagId) {
                    this.update(taskId, {tag_id: tagId});
                };

                this.assignTo = function (taskId, userId) {
                    this.update(taskId, {access_userid_assign_to: userId});
                };

                return this;
            };

            function onActivate(id, args) {
                Project.enableNewTaskList(true, projectId);
                Project.writeProjectDates(projectData);
                Scrollbars.updateContentScrollbar();
                if (!args || !args.noHistoryChange) {
                    if (Project.getArchiveTrashItemFilter()) WindowHistory.pushArchiveTrash();
                    else WindowHistory.pushProject(projectId);
                }
                if (args && 'projectId' in args && args.projectId !== projectId) _this.loadProjectTaskLists(args.projectId, args && args.noHistoryChange);
            }

            this.getProjectId = function () {
                return projectId;
            };

            this.loadProjectTaskLists = function (_projectId, noHistoryChange) {
                projectId = _projectId;
                isOverview = !_projectId;
                loadTabContent(noHistoryChange);
            };

            function onSave() {
                return {
                    projectId: projectId
                }
            }

            function onWakeUp() {

            }

            var tabInfo = ItemTabs.openTab(tabId,
                {
                    breadCrumb: OpenDrive.helpers.applyTemplate(
                        {
                            ItemId: tabId,
                            Overview: isOverview
                        },
                        'BreadCrumbItem'
                    ),
                    tabContent: '',
                    Name: OpenDrive._('Overview'),
                    titleOpts: {
                        Unclosable: true
                    },
                    isFirst: true,
                    noActivate: noActivate
                },
                {
                    //close: closeCallback
                    activate: onActivate,
                    save: onSave,
                    wakeup: onWakeUp
                }
            );
            if (tabInfo.exists) {
                var _projectId = tabInfo.tab.data('TaskTab').getProjectId();
                if (projectId !== _projectId) tabInfo.tab.data('TaskTab').loadProjectTaskLists(projectId);
                if (completeCallback instanceof Function) completeCallback();
                return;
            }
            $tab = tabInfo.tab;
            $tab.addClass('task-lists scrollable');
            $tab.data('TaskTab', _this);

            loadTabContent();

            var DueDateOrder = new function () {
                var _this = this;
                $tab.on('click', '.js-due-date-caret', function () {
                    setSortOrdering(this);
                    return false;
                });

                function setSortOrdering(item) {
                    item = $(item);
                    var order = item.hasClass('dropup');
                    if (order) item.removeClass('dropup');
                    else item.addClass('dropup');

                    _this.orderAsc = !_this.orderAsc;
                    loadTabContent();
                }

                this.orderAsc = true;
                return this;
            };

            (function (content) {
                content.on('click', '.js-archive-tasklist', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var taskList = $(this).closest(ITEM_TASKLIST);
                        var taskListId = taskList.data('tasklistid');
                        OpenDrive.ajax.do('tasks.archive-task-list', {list_id: taskListId}, function (response) {
                            if (response && response.result) {
                                taskList.remove();
                            }
                        });
                    }
                    return false;
                });

                content.on('click', '.js-trash-tasklist', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var taskList = $(this).closest(ITEM_TASKLIST);
                        var taskListId = taskList.data('tasklistid');
                        OpenDrive.ajax.do('tasks.trash-task-list', {list_id: taskListId}, function (response) {
                            if (response && response.result) {
                                taskList.remove();
                                Trash.refresh();
                            }
                        });
                    }
                    return false;
                });

                content.on('click', '.js-edit-tasklist-name', function () {
                    var taskList = $(this).closest(ITEM_TASKLIST);
                    editTaskListName(taskList);
                    return false;
                });

                content.on('click', '.js-restore-tasklist', function () {
                    var taskList = $(this).closest(ITEM_TASKLIST);
                    restoreTaskList(taskList);
                    return false;
                });

                content.on('click', '.js-task-complete-checkbox', function (e) {
                    var task = $(this).closest(ITEM_TASK);
                    TaskHelper.update(task.data('taskid'), {status: this.checked ? 'completed' : 'active'});
                    e.stopPropagation();
                });

                content.on('click', '.js-trash-task', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.trash(task.data('taskid'));
                    }
                    return false;
                });

                content.on('click', '.js-archive-task', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.archive(task.data('taskid'));
                    }
                    return false;
                });

                content.on('click', '.js-restore-task', function () {
                    TaskHelper.restore($(this).closest(ITEM_TASK));
                    return false;
                });

                content.on('click', '.js-get-share-link', function () {
                    var task = $(this).closest(ITEM_TASK);
                    TaskHelper.openTaskShareDialog(task);
                    return false;
                });

                content.on('click', '.js-edit-task-name', function () {
                    var task = $(this).closest(ITEM_TASK);
                    TaskHelper.editTaskName(task.data('taskid'));
                    return false;
                });

                content.on('click', '.js-add-new-task', function () {
                    var taskList = $(this).closest(ITEM_TASKLIST);
                    TaskHelper.addNewTask(taskList, taskList.data('tasklistid'));
                    return false;
                });

                content.on('click', '.js-slidetoggle-tasklist', function () {
                    var taskList = $(this).closest(ITEM_TASKLIST);
                    var tasksContainer = taskList.find(ITEM_TASKSLIST_TASKS);
                    tasksContainer.slideToggle(400, function () {
                        if (tasksContainer.is(':visible')) {
                            taskList.removeClass('collapsed-list');
                        } else {
                            taskList.addClass('collapsed-list');
                        }
                    });

                    return false;
                });

                content.on('change', '.js-select-progress', function (e) {
                    if (this.value !== undefined) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.saveProgress(task.data('taskid'), this.value);
                    }
                    e.stopPropagation();
                });

                content.on('change', '.js-select-priority', function (e) {
                    if (this.value !== undefined) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.savePriority(task.data('taskid'), this.value);
                    }
                    e.stopPropagation();
                });
                content.on('change', '.js-set-task-tag', function (e) {
                    if (this.value !== undefined) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.saveTag(task.data('taskid'), this.value);
                        OpenDrive.widgets.TaskWidgets.SelectPicker.colorizeSelectedValue(this);
                    }
                    e.stopPropagation();
                });

                content.on('change', '.js-assign-user-task', function (e) {
                    if (this.value !== undefined) {
                        var task = $(this).closest(ITEM_TASK);
                        TaskHelper.assignTo(task.data('taskid'), this.value);
                    }
                    e.stopPropagation();
                });

                content.on('change loaded.bs.select', '.js-assign-user-task', function (e) {
                    if (this.value !== undefined) {
                        var $this = $(this);
                        var container = $this.closest('.bootstrap-select');
                        container.attr('selected-index', this.selectedIndex);
                    }
                });

                content.on('loaded.bs.select', '.js-set-task-tag', function (e) {
                    var _this = $(this);
                    if (e.type == 'loaded') {
                        var opt = _this.find('option:selected');
                        if (opt.length) {
                            var btn = $(this).closest('.bootstrap-select.js-set-task-tag').find('button');
                            btn.css('color', '#' + opt.data('color'));
                        }
                    }
                });

                content.on('rendered.bs.select loaded.bs.select', '.js-select-priority', function (e) {
                    var _this = $(this);
                    var widget = _this.closest('.bootstrap-select.js-select');
                    if (!widget.length) return;
                    var label = widget.find('.btn.btn-select > .filter-option');
                    var icon = label.find('i');
                    label.empty().append(icon);
                    var select = widget.find('select');
                    var priority = $(select[0].options[select[0].selectedIndex]).text();
                    if (select.length && select[0].selectedIndex >= 0) widget.find('button')
                        .attr('title', 'Priority: ' + priority).attr('aria-label', 'Priority: ' + priority);
                });

                content.on('shown.bs.select', function (e) {
                    var select = $(e.target).parent();
                    var menu = select.find('> .dropdown-menu');
                    var btn = select.find('> button');
                    menu.css('margin-left', -(menu.outerWidth() / 2 - btn.outerWidth() / 2) + 'px');
                });

                content.on('click', '.js-set-task-privacy', function () {
                    var task = $(this).closest(ITEM_TASK);
                    TaskHelper.savePrivacy(task.data('taskid'), $(this).hasClass('private-task') ? 0 : 1);
                    return false;
                });

                content.on('click', '.js-set-task-color', function () {
                    var task = $(this).closest(ITEM_TASK);
                    var colors = ['ffffff', 'f2dede', 'fcf8e3', 'dff0d8', 'd9edf7'];
                    var prevColor = task.data('bgcolor');
                    var index = colors.indexOf(prevColor);
                    if (index == -1) index = 0;
                    else index = (index + 1) % colors.length;
                    task.css('background-color', '#' + colors[index]);
                    TaskHelper.saveColor(task.data('taskid'), colors[index]);
                    return false;
                });

                content.on('click', '.js-tasklist-complete-checkbox', function () {
                    var msg = this.checked
                        ? OpenDrive._('Do_you_really_want_to_mark_all_tasks_as_completed')
                        : OpenDrive._('Do_you_really_want_to_mark_all_tasks_as_uncompleted');
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction(msg)) {
                        var taskList = $(this).closest(ITEM_TASKLIST);
                        completeTaskList(taskList.data('tasklistid'), this.checked);
                    }
                    return false;
                });

                content.on('click', '.js-task-name', function () {
                    var task = $(this).closest(ITEM_TASK);
                    Project.loadTaskTab(task.data('taskid'));
                    return false;
                });

                content.on('click', '.js-add-project', function () {
                    ProjectsListContainer.addFirstNewProject();
                    return false;
                });

                content.on('click', '.js-add-project-to-active-list', function (e) {
                    ProjectsListContainer.addProjectToActiveList();
                    return false;
                });
            })($tab);
        }

        /**
         *
         * @param {String} taskId
         * @param {Function} completeCallback
         * @param {Boolean} noUpdateHistory
         * @param {Boolean} noActivate
         * @constructor
         */
        function TaskTab(taskId, completeCallback, noUpdateHistory, noActivate) {
            var _this = this;
            var $tab;

            function editTaskDescription() {
                var $input = $tab.find('.js-description-input');

                if ($input.length) {
                    Editors.attach($input, {startupFocus: false});
                }
            }

            function editNewComment() {
                var commentNode = $tab.find('.js-comment-input');
                if (commentNode.length) {
                    commentNode.addClass('is-editing');
                    Editors.attach(commentNode, {startupFocus: false}, function () {
                        var btn = $tab.find('.js-cancel-newcomment-edit');
                        if (this.getData() == '') btn.hide();
                        else btn.show();
                    });
                }
            }

            function saveTaskDescriptionAndUploadFiles() {
                var btn = $(this);
                if (btn.hasClass('disabled')) return false;
                var description = btn.closest('.js-task-description');
                var input = $('.js-description-input', description);

                var descriptionText = Editors.getData(input);
                if (descriptionText == '') {
                    input.focus();
                    return false;
                }

                btn.addClass('disabled');
                OpenDrive.widgets.TaskWidgets.SaveAnimation.show(btn);
                Editors.remove(input);

                OpenDrive.ajax.do(
                    'tasks.update-task',
                    {
                        task_id: taskId,
                        task_description: descriptionText
                    }, function (response) {
                        if (response) {
                            if (response.TaskId) {
                                _this.fileUploader.setUploadArgs({task_id: response.TaskId});
                                _this.fileUploader.startUpload();
                            }
                        }
                    },
                    function () {
                        OpenDrive.widgets.TaskWidgets.SaveAnimation.remove(btn);
                    }
                );
                return false;
            }

            function saveTaskCommentAndUploadFiles(container, commentText) {
                var _this = this;
                OpenDrive.ajax.do(
                    'tasks.add-comment',
                    {
                        task_id: taskId,
                        comment_text: commentText
                    }, function (response) {
                        if (response) {
                            if (response.CommentId) {
                                _this.fileUploader.setUploadArgs({task_comment_id: response.CommentId});
                                _this.fileUploader.startUpload();
                            }
                        }
                    },
                    function () {
                        OpenDrive.widgets.TaskWidgets.SaveAnimation.remove(container);
                    }
                );
            }

            function initializeContent() {
                _this.fileUploader = new TabFileUploader({completeCallback: uploadFileCallback}, $tab);
                OpenDrive.widgets.TaskWidgets.AnchorConverter.call($tab);
                OpenDrive.widgets.TaskWidgets.AvatarReplacer.call($tab);
                OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                editTaskDescription();
                editNewComment();
                Scrollbars.updateContentScrollbar();
            }

            function onClose() {
                this.find('.js-ckeditor').each(function () {
                    Editors.remove($(this));
                });
            }

            function onActivate(id, args) {
                Project.enableNewTaskList(true, null);
                Project.writeProjectDates();
                Scrollbars.updateContentScrollbar();
                if (!args || !args.noHistoryChange) WindowHistory.pushTask(taskId);
            }

            function onSave() {
                return {
                    taskId: taskId
                }
            }

            function onWakeUp() {

            }

            function loadTabContent() {
                var tabInfo = ItemTabs.openTab(taskId,
                    {
                        breadCrumb: OpenDrive.helpers.applyTemplate(
                            {ItemId: taskId},
                            'BreadCrumbItem'
                        ),
                        tabContent: '',
                        Name: OpenDrive._('Loading_Task'),
                        noActivate: noActivate
                    },
                    {
                        close: onClose,
                        save: onSave,
                        wakeup: onWakeUp,
                        activate: onActivate
                    }
                );
                if (tabInfo.exists) {
                    return;
                }
                $tab = tabInfo.tab;
                $tab.data('TaskTab', _this);

                $tab.addClass('scrollable');

                OpenDrive.ajax.do(
                    'tasks.load-tasks',
                    {
                        task_id: taskId,
                        with_comments: true
                    },
                    function (response) {
                        if (response && response.Task) {
                            var task = response.Task;
                            task.ColorTags = Project.getColorTags;
                            task.CurrentUser = CurrentUser;
                            task.DescriptionEditable =
                                task.AccessMode == 1 &&
                                task.Description === '' && CurrentUser &&
                                CurrentUser.UserId == task.OwnerUserId &&
                                CurrentUser.AccessUserId == task.OwnerAccessUserId;
                            task.CanAddComment = task.AccessMode == 1 && CurrentUser && CurrentUser.UserId &&
                                (
                                    task.Description !== '' || !(task.Description === '' && task.OwnerUserId == CurrentUser.UserId &&
                                    task.OwnerAccessUserId == CurrentUser.AccessUserId)
                                );
                            ItemTabs.updateTabTitle(taskId, '[' + task.Number + '] ' + task.Name);

                            OpenDrive.helpers.applyTemplate(
                                {
                                    ItemId: taskId,
                                    Overview: false,
                                    TaskId: task.TaskId,
                                    Task: task.Name,
                                    ProjectListId: task.ProjectListId,
                                    ProjectList: task.ProjectListName,
                                    ProjectId: task.ProjectId,
                                    Project: task.ProjectName
                                },
                                'BreadCrumbItem',
                                tabInfo.breadcrumb,
                                true
                            );
                            tabInfo.breadcrumb = ItemTabs.getBreadCrumb(taskId);
                            if(noActivate) tabInfo.breadcrumb.hide();
                            OpenDrive.helpers.applyTemplate(task, 'TaskWindow', $tab);

                            if (!noActivate) ProjectsListContainer.makeProjectActive(task.ProjectId);
                            Project.enableNewTaskList(false);

                            initializeContent();
                            initTWEvents($tab);
                            ItemTabs.setTabLoadedStatus(taskId, true);
                            if (completeCallback instanceof Function) completeCallback();
                        }
                    }, function () {
                        ItemTabs.closeTab(taskId, false, true);
                        if (completeCallback instanceof Function) completeCallback();
                    });
            }

            var existingTab = ItemTabs.getTab(taskId);
            if (existingTab.length) {
                ItemTabs.activateTab(taskId);
                if (completeCallback instanceof Function) completeCallback();
                completeCallback = null;
                return;
            }

            function uploadFileCallback() {
                OpenDrive.ajax.do(
                    'tasks.load-tasks',
                    {
                        task_id: taskId,
                        with_comments: true
                    },
                    function (response) {
                        if (response && response.Task) {
                            var task = response.Task;
                            task.ColorTags = Project.getColorTags();
                            task.CurrentUser = CurrentUser;
                            task.DescriptionEditable =
                                task.AccessMode == 1 &&
                                task.Description === '' && CurrentUser &&
                                CurrentUser.UserId == task.OwnerUserId &&
                                CurrentUser.AccessUserId == task.OwnerAccessUserId;
                            task.CanAddComment = task.AccessMode == 1 && CurrentUser && CurrentUser.UserId &&
                                (
                                    task.Description !== '' || !(task.Description === '' && task.OwnerUserId == CurrentUser.UserId &&
                                    task.OwnerAccessUserId == CurrentUser.AccessUserId)
                                );

                            var taskHTML = OpenDrive.helpers.applyTemplate(
                                task,
                                'TaskWindow'
                            );
                            ItemTabs.updateTab(taskId, taskHTML);
                            initializeContent();
                        }
                    });

                initializeContent();
            }

            function initTWEvents(content) {
                content.on('change', '.js-task-window-set-tag', function () {
                    if (this.value !== undefined) {
                        saveTag(taskId, this.value);
                        OpenDrive.widgets.TaskWidgets.SelectPicker.colorizeSelectedValue(this);
                    }
                    return false;
                });

                content.on('loaded.bs.select', '.js-task-window-set-tag', function (e) {
                    if (e.type == 'loaded') {
                        OpenDrive.widgets.TaskWidgets.SelectPicker.colorizeSelectedValue(this);
                    }
                    e.stopPropagation();
                });

                content.on('click', '.js-task-window-complete-checkbox', function (e) {
                    update(taskId, {status: this.checked ? 'completed' : 'active'});
                    e.stopPropagation();
                });

                content.on('change', '.js-task-window-select-progress', function (e) {
                    if (this.value !== undefined) {
                        saveProgress(taskId, this.value);
                    }
                    e.stopPropagation();
                });

                content.on('change', '.js-assign-user-task-window', function (e) {
                    if (this.value !== undefined) {
                        update(taskId, {access_userid_assign_to: this.value})
                    }
                    e.stopPropagation();
                });

                content.on('click', '.js-attach-file-task', function () {
                    _this.fileUploader.setUploadArgs({task_id: taskId});
                    _this.fileUploader.setTargetContainer(
                        $(this).closest(ITEM_COMMENT).find(ITEM_COMMENT_ATTACHMENT)
                    );
                    _this.fileUploader.openDialog();
                    return false;
                });

                content.on('click', '.js-attach-file-comment', function () {
                    _this.fileUploader.setTargetContainer(
                        $(this).closest(ITEM_COMMENT).find(ITEM_COMMENT_ATTACHMENT)
                    );
                    _this.fileUploader.openDialog();
                    return false;
                });

                content.on('click', '.js-save-task-description', saveTaskDescriptionAndUploadFiles);

                content.on('click', '.js-save-comment', function () {
                    var comment = $(this).closest(ITEM_COMMENT);
                    var input = comment.find('.js-comment-input');
                    var btn = $(this);
                    if (btn.hasClass('disabled')) return false;
                    var commentText = Editors.getData(input);
                    if (commentText != '') {
                        btn.addClass('disabled');
                        btn.parent().find('>.js-cancel-newcomment-edit').hide();
                        OpenDrive.widgets.TaskWidgets.SaveAnimation.show(btn);
                        Editors.remove(input);
                        saveTaskCommentAndUploadFiles.call(_this, btn, commentText);
                    } else input.focus();
                    return false;
                });

                content.on('click', '.js-remove-uploading-file', function () {
                    var fileItem = $(this).closest('.js-uploading-file');
                    _this.fileUploader.removeFile(fileItem.data('fileid'));
                    fileItem.remove();
                    return false;
                });

                content.on('click', '.js-edit-comment', function () {
                    var comment = $(this).closest(ITEM_COMMENT);
                    editComment(comment);
                    return false;
                });

                content.on('click', '.js-edit-subcomment', function () {
                    var $subcomment = $(this).closest(ITEM_SUBCOMMENT);
                    editSubComment($subcomment);
                    return false;
                });

                content.on('click', '.js-save-editing-comment', function () {
                    var comment = $(this).closest(ITEM_COMMENT);
                    var input = comment.find('.js-description');
                    var _this = $(this);
                    if (_this.hasClass('disabled')) return false;
                    var commentText = Editors.getData(input);
                    if (commentText != '') {
                        _this.addClass('disabled');
                        Editors.remove(input);
                        saveComment(comment, commentText);
                    } else input.focus();
                    return false;
                });

                content.on('click', '.js-save-editing-subcomment', function () {
                    var $subcomment = $(this).closest(ITEM_SUBCOMMENT);
                    var input = $subcomment.find('.js-subcomment-input');
                    var commentText = Editors.getData(input);
                    Editors.remove(input);
                    saveSubComment($subcomment, commentText);
                    return false;
                });

                content.on('click', '.js-save-editable-task-description', function () {
                    var _this = $(this);
                    if (_this.hasClass('disabled')) return false;
                    var taskDescription = _this.closest('.js-task-description');
                    var input = taskDescription.find('.js-description');
                    var description = Editors.getData(input);
                    if (description == '') {
                        input.focus()
                    } else {
                        _this.addClass('disabled');
                        saveTaskDescription(taskDescription, description, function () {
                            _this.removeClass('disabled');
                        });
                    }
                    return false;
                });

                content.on('click', '.js-trash-comment', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        trashComment($(this).closest(ITEM_COMMENT));
                    }
                    return false;
                });

                content.on('click', '.js-trash-subcomment', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        trashSubComment($(this).closest(ITEM_SUBCOMMENT));
                    }
                    return false;
                });

                content.on('click', '.js-write-subcomment', function () {
                    editNewSubComment($(this).closest(ITEM_COMMENT));
                    return false;
                });

                content.on('change loaded.bs.select', '.js-task-window-set-comment-tag', function (e) {
                    var $this = $(this);
                    var container = $this.closest('.bootstrap-select');
                    container.attr('selected-index', this.selectedIndex);
                    if (e.type == 'change' && this.tagName.toLowerCase() == 'select') {
                        saveCommentTag($this.closest(ITEM_COMMENT), this.value);
                    }
                    OpenDrive.widgets.TaskWidgets.SelectPicker.colorizeSelectedValue(this);
                });

                content.on('click', '.js-cancel-comment-edit', function () {
                    var comment = $(this).closest(ITEM_COMMENT);
                    Editors.remove(comment.find('.js-description'));
                    comment.removeClass('is-editing');
                    return false;
                });

                content.on('click', '.js-cancel-newcomment-edit', function () {
                    var commentNode = $tab.find('.js-comment-input');
                    var editor = Editors.getEditor(commentNode);
                    editor.setData('');
                    return false;
                });

                content.on('click', '.js-cancel-subcomment-edit', function () {
                    cancelSubcommentEdit($(this).closest(ITEM_SUBCOMMENT));
                    return false;
                });

                content.on('click', '.js-save-subcomment', function () {
                    var $comment = $(this).closest(ITEM_COMMENT);
                    var $subComment = $(this).closest(ITEM_SUBCOMMENT);
                    addSubcomment($comment, $subComment);
                    return false;
                });

                //image preview popup
                content.on('click', ITEM_ATTACHMENT, function () {
                    var file = $('.js-file', this);
                    var _this = this;
                    var href = this.href;
                    if (file.is('.type-jpeg, .type-jpg, .type-gif, .type-png, .type-bmp')) {
                        $.magnificPopup.open({
                            items: {
                                type: 'image',
                                src: href
                            },
                            image: {
                                markup: OpenDrive.helpers.applyTemplate({Url: href}, 'ImagePopup'),
                                titleSrc: function () {
                                    return _this.title;
                                },
                                cursor: ''
                            },
                            closeOnContentClick: true,
                            mainClass: 'mfp-img-mobile'
                        });
                        return false;
                    }
                });

                content.on('click', '.js-delete-task-attachment', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var container = $(this).parent();
                        var fileId = container.find(ITEM_ATTACHMENT).data('fileid');
                        if (fileId) {
                            OpenDrive.ajax.do('tasks.delete-attachment', {
                                item_type: 'task',
                                item_id: taskId,
                                file_id: fileId
                            }, function () {
                                container.fadeOutRemove();
                            });
                        }
                    }
                    return false;
                });

                content.on('click', '.js-delete-comment-attachment', function () {
                    if (OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                        var container = $(this).parent();
                        var commentId = container.closest(ITEM_COMMENT).data('commentid');
                        var fileId = container.find(ITEM_ATTACHMENT).data('fileid');
                        if (fileId && commentId) {
                            OpenDrive.ajax.do('tasks.delete-attachment', {
                                item_type: 'comment',
                                item_id: commentId,
                                file_id: fileId
                            }, function () {
                                container.fadeOutRemove();
                            });
                        }
                    }
                    return false;
                });

                content.on('datepicker-updated.od', function (e, data) {
                    updateTaskInOverview(data);
                    return false;
                });

                content.on('click', 'a', function () {
                    var regexp = new RegExp('^' + location.protocol + '//' + location.hostname + '/tasks/(\\w+)');
                    var taskId = regexp.exec(this.href);
                    if (taskId && taskId.length == 2) {
                        new TaskTab(taskId[1]);
                        return false;
                    }
                });
            }

            function addSubcomment($comment, $subComment) {
                var $input = $subComment.find('.js-subcomment-input');
                var text = Editors.getData($input);
                if (text == '') {
                    $input.focus();
                    return;
                }
                cancelSubcommentEdit($subComment);

                OpenDrive.ajax.do('tasks.add-subcomment', {
                    comment_id: $comment.data('commentid'),
                    text: text
                }, function (response) {
                    if (response.SubCommentId) {
                        response.CurrentUser = CurrentUser;
                        $comment.find('.js-subcomments').append(
                            OpenDrive.helpers.applyTemplate(
                                response,
                                'SubComment'
                            )
                        );
                        OpenDrive.widgets.TaskWidgets.AvatarReplacer.call($tab);
                    }
                });
            }

            function cancelSubcommentEdit($subComment) {
                var $input = $('.js-subcomment-input', $subComment);
                $subComment.removeClass('is-editing');
                Editors.remove($input);
                if ($subComment.hasClass('js-newsubcomment')) {
                    $subComment.remove();
                }
            }

            function trashComment(commentNode) {
                var commentId = commentNode.data('commentid');
                OpenDrive.ajax.do('tasks.trash-comment', {comment_id: commentId}, function (response) {
                    if (response && response.result) {
                        commentNode.remove();
                    }
                });
            }

            function trashSubComment($subcomment) {
                var subcommentId = $subcomment.data('subcommentid');
                OpenDrive.ajax.do('tasks.trash-subcomment', {subcomment_id: subcommentId}, function (response) {
                    if (response && response.result) {
                        $subcomment.remove();
                    }
                });
            }

            function saveTag(taskId, tagId) {
                update(taskId, {tag_id: tagId});
            }

            function saveCommentTag(commentNode, tagId) {
                updateComment(commentNode, {tag_id: tagId});
            }

            function saveProgress(taskId, progress) {
                var data = {progress: progress, task_id: taskId};
                OpenDrive.ajax.do('tasks.update-task', data, function (response) {
                    if (response && response.TaskId) {
                        updateTaskWindowHeader(response);
                    }
                });
            }

            function update(taskId, data) {
                data = data || {};
                data.task_id = taskId;
                OpenDrive.ajax.do('tasks.update-task', data, function (response) {
                    if (response && response.TaskId) {
                        updateTaskWindowHeader(response);
                    }
                });
            }

            function updateTaskWindowHeader(data) {
                data.CurrentUser = CurrentUser;
                OpenDrive.helpers.applyTemplate(
                    data,
                    'TaskWindowHeader',
                    $tab.find('.js-task-window-header'), true
                );
                OpenDrive.widgets.TaskWidgets.SelectPicker.draw();
                updateTaskInOverview(data);
            }

            function updateTaskInOverview(data) {
                var overviewTab = ItemTabs.getTab('<overview>');
                if (overviewTab.length) overviewTab.data('TaskTab').updateTask(data);
            }

            function editComment(commentNode) {

                var node = commentNode.find('.js-description');
                if (node.length) {
                    commentNode.addClass('is-editing');
                    Editors.attach(node);
                }
            }

            function editSubComment($subcomment) {

                var node = $subcomment.find('.js-subcomment-input');
                if (node.length) {
                    $subcomment.addClass('is-editing');
                    Editors.attach(node);
                }
            }

            function editNewSubComment($comment) {
                var $subcomments = $('.js-subcomments', $comment);
                if ($subcomments.find('.js-newsubcomment').length) {
                    $subcomments.find('.js-subcomment-input').focus();
                } else {
                    $subcomments.append(OpenDrive.helpers.applyTemplate({
                        CurrentUser: CurrentUser
                    }, 'NewSubComment'));

                    OpenDrive.widgets.TaskWidgets.AvatarReplacer.call($tab);

                    var $newSubcomment = $subcomments.find('.js-newsubcomment').addClass('is-editing');
                    var $input = $newSubcomment.find('.js-subcomment-input');
                    Editors.attach($input);
                }
            }

            function saveComment(commentNode, commentText) {
                commentNode.removeClass('is-editing');
                updateComment(commentNode, {
                    comment_text: commentText
                })
            }

            function saveSubComment($subcomment, commentText) {
                $subcomment.removeClass('is-editing');
                updateSubComment($subcomment, {
                    text: commentText
                })
            }

            function updateComment(commentNode, commentData) {
                commentData.comment_id = commentNode.data('commentid');
                OpenDrive.ajax.do(
                    'tasks.update-comment',
                    commentData,
                    function (data) {
                        if (data && data.CommentId) {
                            data.ColorTags = Project.getColorTags();
                            data.CurrentUser = CurrentUser;
                            OpenDrive.helpers.applyTemplate(
                                data,
                                'TaskComment',
                                commentNode,
                                true
                            );

                            OpenDrive.widgets.TaskWidgets.AnchorConverter.call($tab);
                            OpenDrive.widgets.TaskWidgets.AvatarReplacer.call($tab);
                            OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                        }
                    });
            }

            function updateSubComment($subcomment, commentData) {
                commentData.subcomment_id = $subcomment.data('subcommentid');
                OpenDrive.ajax.do(
                    'tasks.update-subcomment',
                    commentData,
                    function (data) {
                        if (data && data.SubCommentId) {
                            data.CurrentUser = CurrentUser;
                            OpenDrive.helpers.applyTemplate(
                                data,
                                'SubComment',
                                $subcomment,
                                true
                            );
                            OpenDrive.widgets.TaskWidgets.AnchorConverter.call($tab);
                            OpenDrive.widgets.TaskWidgets.AvatarReplacer.call($tab);
                            OpenDrive.widgets.TaskWidgets.SelectPicker.draw($tab);
                        }
                    });
            }

            function saveTaskDescription(descrNode, text, comlpeteCallback) {
                descrNode.removeClass('is-editing');
                var contentNode = descrNode.find('.js-description');
                Editors.remove(contentNode);

                OpenDrive.ajax.do(
                    'tasks.update-task',
                    {
                        task_id: taskId,
                        task_description: text
                    },
                    function (response) {
                        if (response && response.Description) {
                            contentNode.html(response.Description);
                            if (comlpeteCallback instanceof Function) comlpeteCallback();
                        }
                    });
            }

            this.attachImageFromClipboard = function (blob, ext) {
                if (!CKEDITOR.currentInstance) return false;
                if (ext == 'pjpeg') ext = 'jpeg';
                if (ext == 'jpeg') ext = 'jpg';
                var editorNode = CKEDITOR.currentInstance.element.$;
                try {
                    var file = new File([blob], 'attachment.' + ext);
                } catch (e) {
                    file = blob;
                    file.fileName = 'attachment.' + ext;
                }
                var isSubcomment = $(editorNode).closest(ITEM_SUBCOMMENT);
                if (isSubcomment.length) return;
                var target = $(editorNode).closest(ITEM_COMMENT).find(ITEM_COMMENT_ATTACHMENT);
                if (target.length) {
                    _this.fileUploader.setTargetContainer(target);
                    file._isBlob = true;
                    _this.fileUploader.addFile(file);
                }
            };

            loadTabContent();
        }
        OpenDrive.widgets.TaskWidgets.TaskTab = TaskTab;


        var Trash = new function () {
            this.refresh = function () {
                if ($.isEmptyObject(CurrentUser) || CurrentUser.AccessUserId) return;
                setTimeout(function () {
                    OpenDrive.ajax.do('tasks.list-trash', {}, function (data) {
                        $('.js-trash-items-count').html(data.ItemsCountText);
                    });
                }, 0);
            };

            $('.js-trash-clear-btn').on('click', function () {
                var _this = $(this);
                if (!_this.hasClass('disabled') && OpenDrive.widgets.TaskWidgets.ConfirmAction()) {
                    _this.addClass('disabled');
                    OpenDrive.ajax.do('tasks.empty-trash', {},
                        function () {
                            _this.removeClass('disabled');
                            Trash.refresh();
                        },
                        function () {
                            _this.removeClass('disabled');
                        });
                }
                return false;
            });
        };

        (function () {
            var data = $.parseJSON($('#js-initial-data').html());

            if (!data.ProjectId && !data.ProjectListId && !data.TaskId) {
                Project.loadOverview(null, restoreCallback);
            }

            if (data.TaskId) {
                Project.removeAlerts();
                var existingTabItem = ItemTabs.sessionTabs.find(data.TaskId);
                if (existingTabItem) {
                    existingTabItem.active = true;
                    restoreCallback();
                }
                else Project.loadTaskTab(data.TaskId, restoreCallback);

            } else if (data.ProjectId) {
                ProjectsListContainer.makeProjectActive(data.ProjectId);
                Project.loadOverview(data.ProjectId, restoreCallback);
            }

            if (data.ProjectListId) {
                ProjectsListContainer.expandProjectList(data.ProjectListId, function () {
                    ProjectsListContainer.saveTree();
                });
                ProjectsListContainer.scrollToProjectList(data.ProjectListId);
            }

            Trash.refresh();

            function restoreCallback() {
                ItemTabs.sessionTabs.restore(function (opts) {
                    if (opts && opts.data) {
                        if (opts.data.taskId) new TaskTab(opts.data.taskId, restoreCallback, true, !opts.active);
                        else {
                            if (opts.data.projectId && ItemTabs.getTab(opts.id).length) {
                                setTimeout(restoreCallback, 0);
                            } else {
                                new OverviewTab(opts.data.projectId, restoreCallback, true);
                            }
                        }
                    }
                })
            }

            $('.js-logout').click(function () {
                ItemTabs.sessionTabs.clear();
                ProjectsListContainer.clearTree();
            })
        })();

        var Lightboxes = new function () {
            $('.js-select-all-input').focus(function () {
                var $this = $(this);
                $this.select();

                // Work around Chrome's little problem
                $this.mouseup(function () {
                    // Prevent further mouseup intervention
                    $this.unbind("mouseup");
                    return false;
                });
            });

            $('.lightbox .js-cancel-btn').click(function () {
                $('.lightbox').hide();
                var callback = $(this).data('callback');
                if (callback instanceof Function) callback.apply(this, arguments);
                return false;
            });

            $('.lightbox-header .lightbox-close-btn').click(function () {
                var lb = $(this).closest('.lightbox');
                lb.hide();
                var callback = lb.find('.js-cancel-btn').data('callback');
                if (callback instanceof Function) callback.apply(this, arguments);
                return false;
            });


            this.showShareLink = function (title, link) {
                var lightbox = $('#task-link-dialog');
                $('#task-url', lightbox).val(link);
                show_lightbox(lightbox);
                $('.js-lightbox-title', lightbox)
                    .html(title)
                    .ellipsisMiddle({reinitialize: true});
            };

            function show_lightbox(wrapper) {
                wrapper.show();
                var body = wrapper.find('.lightbox-body');
                var content = body.find('.js-content');

                function updateHeight() {
                    var height = wrapper.find('.lightbox-container').outerHeight() - wrapper.find('.lightbox-header').outerHeight()
                        - wrapper.find('.lightbox-buttons').outerHeight();
                    body.css('height', height + 'px');
                    content.perfectScrollbar('update');
                }

                if (!wrapper.data('onresize')) {
                    wrapper.data('onresize', true);
                    $(window).resize(function () {
                        updateHeight();
                    });
                    content.perfectScrollbar({theme: 'od'});
                    updateHeight();

                    wrapper.on('slidetoggled.od', function (e) {
                        updateHeight();
                        return false;
                    })
                }
            }

            $('.lightbox').escape(function (e) {
                var lb = $(e.target).closest('.lightbox');
                if (lb.length) {
                    lb.hide();
                    var callback = lb.find('.js-cancel-btn').data('callback');
                    if (callback instanceof Function) callback.apply(lb[0], arguments);
                }
            });
        };

    });

})(jQuery);

window.onerror = function (message, source, lineno, colno, error) {
    console.log(message, source, lineno, colno, error)
};
