<?php
namespace od_includes;
if ( !defined( 'ABSPATH' ) ) exit;

class ODPluginSettings
{

    protected $settings_option;
    protected $render_settings;
    protected $od_user_settings;
    protected $google_analytics_id;
    protected static $apiColorNames = array(
        'od_scheme_background',
        'od_scheme_menu',
        'od_scheme_slider',
        'od_scheme_container',

        'od_font_color',
        'od_font_selected',
        'od_font_hover',
        'od_font_link',
        'od_font_trash',

        'od_progress_loading',
        'od_progress_available',
        'od_progress_font',

        'od_button_color',
        'od_button_hover',
        'od_button_font'
    );

    function __construct()
    {
        $this->settings_option = 'od_plugin_settings';
    }

    function init_settings()
    {

        $settings_array = $this->_get_render_settings();
        $od_user_settings = $this->get_settings();
        if(!$od_user_settings){
            $od_user_settings = array();
        }

        foreach ($settings_array as $tab => $tab_content) {

            $tab_settings = $tab_content['settings'];
            foreach ($tab_settings as $input) {

                if($input['type'] == 'group' || $input['type'] == 'colorpicker_group'){
                    foreach($input['inputs'] as $group_input){
                        if(in_array($group_input['name'], self::$apiColorNames)) continue;
                        if(!isset($od_user_settings[$group_input['name']])){
                            $od_user_settings[$group_input['name']] = $group_input['default'];
                        }
                    }
                    continue;
                }

                if(!isset($od_user_settings[$input['name']])){
                    $od_user_settings[$input['name']] = $input['default'];
                }
            }
        }
        if($this->google_analytics_id) $od_user_settings['od_google_analytics_id'] = $this->google_analytics_id;
        $this->add_settings($od_user_settings);

	    return $od_user_settings;

    }

    protected function delete_settings(){
        delete_option($this->settings_option);
        \OpenDrive::deleteCachedPartnerSettings();
    }

    function reset_settings(){
        $settings = $this->get_settings();
        if(isset($settings['od_google_analytics_id'])) $this->google_analytics_id = $settings['od_google_analytics_id'];
        \OpenDrive::i()->apiClient()->updateApiPartnerSettings(array('branding_colors' => null));
        $this->delete_settings();
        $this->init_settings();
    }

    protected function add_settings($settings)
    {

        if(!add_option($this->settings_option,serialize($settings))){
            $this->update_settings($settings);
        }
    }

    function update_settings($settings)
    {

        $api_partner_settings = array('domain' => 'od_domain', 'drive_name' => 'od_drive', 'email' => 'od_email', 'help_link' => 'od_help_link', 'port'=>'od_smtp_port', 'mail'=>'od_smtp_email', 'pas'=>'od_smtp_pas', 'enable'=>'od_smtp_enable', 'server'=>'od_smtp_server', 'authentication'=>'od_smtp_authentication');
        $settings_to_send = array();
        $colors = array();

        foreach ($api_partner_settings as $k => $v) {
            if (!empty($v)) {
                $settings_to_send[$k] = $settings[$v];
            }
            if (in_array($k, self::$apiColorNames)) $colors[$k] = $v;
        }

        foreach (self::$apiColorNames as $v) {
            if (!empty($settings[$v])) {
                $colors[$v] = $settings[$v];
                if (substr($colors[$v], 0, 1) == '#') $colors[$v] = substr($colors[$v], 1);
            }
        }

        if ($colors) $settings_to_send['branding_colors'] = $colors;

	    $result = \OpenDrive::i()->apiClient()->updateApiPartnerSettings($settings_to_send);
        if(!\OpenDrive::i()->apiClient()->error && is_object($result)) {
            $new_settings = array_diff_key($settings, array_flip(self::$apiColorNames));
            update_option($this->settings_option, serialize($new_settings));
            \OpenDrive::deleteCachedPartnerSettings();
            return true;
        }
	    return false;
    }

    function save_option($name, $value){
        $od_user_settings = $this->get_settings();
        if(isset($od_user_settings[$name])){
            $od_user_settings[$name] = $value;
            $this->update_settings($od_user_settings);
            return true;
        }else{
            return false;
        }
    }

    function get_settings()
    {
        $od_user_settings = get_option($this->settings_option);
	    $result = @unserialize($od_user_settings);
        $result = is_array($result) ? $result : array();
        $partner_settings = \OpenDrive::i()->partnerSettings();
        if (isset($partner_settings['Colors'])) {
            foreach ($partner_settings['Colors'] as $color => &$v){
                if(substr($v, 0, 1) != '#') $v = '#' . $v;
            }

            $result = array_merge($result, $partner_settings['Colors']);
        }
        return $result;
    }

    function sync_settings(){
        if(\OpenDrive::i()->apiClient()->get_od_session_id()){
            $settings = $this->get_settings();
            $partner_info = \OpenDrive::i()->apiClient()->getApiPartnerSettings(get_option('od_username'));

            if(!empty($partner_info) && !empty($settings)){
                $settings['od_domain'] = !empty($partner_info['Domain']) ? $partner_info['Domain'] : '';
                $settings['od_drive'] = !empty($partner_info['DriveName']) ? $partner_info['DriveName'] : '';
                $settings['od_email'] = !empty($partner_info['SupportEmail']) ? $partner_info['SupportEmail'] : '';
                $settings['od_help_link'] = !empty($partner_info['SupportUrl']) ? $partner_info['SupportUrl'] : '';


                $settings['od_smtp_port'] = !empty($partner_info['_Port']) ? $partner_info['_Port'] : '';
                $settings['od_smtp_email'] = !empty($partner_info['_Mail']) ? $partner_info['_Mail'] : '';
                $settings['od_smtp_pas'] = !empty($partner_info['_Pass']) ? $partner_info['_Pass'] : '';
                $settings['od_smtp_enable'] = !empty($partner_info['_Enable']) ? $partner_info['_Enable'] : '';
                $settings['od_smtp_server'] = !empty($partner_info['_Server']) ? $partner_info['_Server'] : '';
                $settings['od_smtp_authentication'] = !empty($partner_info['_Authentication']) ? $partner_info['_Authentication'] : '';

            }

            $this->update_settings($settings);
        }
    }

    private function _get_render_settings()
    {
        if($this->render_settings){
            return $this->render_settings;
        }else{
            $this->render_settings = require_once dirname(__FILE__) . '/settings.php';
            foreach ($this->render_settings as $tab_id => &$tab_items) {
                $tab_items['settings'] = apply_filters('od_extension_admin_tab', $tab_items['settings'], $tab_id);
            }
            return $this->render_settings;
        }
    }

    function render_tab_nav(){
        $render_settings = $this->_get_render_settings();
        foreach ($render_settings as $tab => $tab_content) {
            echo '<li><a href="#">'. esc_html($tab_content['name']).'</a></li>';
        }
    }

    function render()
    {
        $render_settings = $this->_get_render_settings();

        $this->od_user_settings = $this->get_settings();

        foreach ($render_settings as $tab => $tab_content) {
            echo "<div class='simpleTabsContent'>";
            echo "<table class='form-table'>";
            $tab_settings = $tab_content['settings'];
            if (!empty($tab_settings)) {
                foreach ($tab_settings as $input) {


                    switch (trim($input['type'])) {
                        case 'text':
                            $input['value'] = $this->od_user_settings[$input['name']];
                            $this->render_text_input($input);
                            break;
                        case 'checkbox':
                            $input['value'] = $this->od_user_settings[$input['name']];
                            $this->render_checkbox($input);
                            break;
                        case 'group':
                            $this->render_control_group($input);
                            break;
                        case 'colorpicker_group':
                            $this->render_colorpicker_group($input);
                            break;
                        case 'file_upload':
                            $input['value'] = $this->od_user_settings[$input['name']];
                            $this->render_upload($input);
                            break;
                    }
                }
            }
            echo "</table>";
            echo "</div>";
        }

    }

    function render_text_input($input)
    {
        $value = $input['value'];
        ?>
            <tr class="od-admin-color-wrap">
                <th scope="row">
                    <?php esc_html_e($input['title']) ?><br>
                    <i style="font-weight: normal;"><?php esc_html_e($input['description']) ?></i>
                </th>
                <td>
                    <input type="text" id="<?php esc_attr_e($input['id']); ?>" name="<?php esc_attr_e($input['name']); ?>" class="<?php esc_attr_e($input['class']); ?>" placeholder="<?php esc_attr_e($input['placeholder']); ?>" value="<?php esc_attr_e($value); ?>" size="40">
                </td>
            </tr>
        <?php
    }

    function render_checkbox($input)
    {
        $value = $input['value'];
        $value = $value == true || $value == 1;
        $checked = $value?'checked="checked"':'';

        ?>
        <tr class="od-admin-color-wrap">
            <th scope="row">
                <?php esc_html_e($input['title']) ?><br>
                <i style="font-weight: normal;"><?php esc_html_e($input['description']) ?></i>
            </th>
            <td>
                <fieldset>
                    <input type="checkbox" id="<?php esc_attr_e($input['id']); ?>" name="<?php esc_attr_e($input['name']); ?>" class="<?php esc_attr_e($input['class']); ?>" value="<?php esc_attr_e($value); ?>" <?php echo $checked; ?>>
                </fieldset>
            </td>
        </tr>
        <?php
    }

    function render_upload($input)
    {
        $value = $input['value'];
        ?>
        <tr class="od-admin-color-wrap">
            <th scope="row">
                <?php esc_html_e($input['title']) ?><br>
                <i style="font-weight: normal;"><?php esc_html_e($input['description']) ?></i>
            </th>
            <td>
                <div class="file_picker <?php esc_attr_e( $input['class']); ?>">
                    <input type="text" disabled="disabled" class="file_location" name="<?php esc_attr_e( $input['name']); ?>" value="<?php esc_attr_e( $value); ?>" placeholder="<?php esc_attr_e($input['placeholder']); ?>">
                    <div id="<?php esc_attr_e($input['id']); ?>" class="fileUpload btn btn-default">
                        <span>Upload</span>

                    </div>
                    <br class="clearfix">
                    <div id="<?php esc_attr_e($input['id']); ?>_remove" class="btn btn-default remove_btn">
                        <span>Remove</span>
                    </div>

                    <?php
                    if(!empty($input['preview'])) {
                        ?>
                        <br class="clearfix">
                        <div class="img_wrap">
                            <div id="bg_img" class="bg_pattern">
                                <table width="180" height="60" cellspacing="0" cellpadding="0" border="0"
                                       style="vertical-align:center;" id="od_logo_table">
                                    <tbody>
                                    <tr>
                                        <td valign="center" align="center" id="od_logo_table_img">
                                            <?php if ($value) { ?>
                                                <img class="od_img_preview" src="<?php esc_attr_e($value); ?>">
                                            <?php } ?>
                                        </td>
                                    </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>

                        <br class="clearfix">
                        <p class="helper">Upload logo image</p>
                        <?php
                    }
                    ?>

                </div>
            </td>
        </tr>

        <?php
    }

    function render_control_group($group)
    {
        if(isset($group['hidden']) && $group['hidden'] == true){
            $hidden = 'style="display:none;"';
        }else{
            $hidden = '';
        }
        ?>
        <tr class="od-admin-color-wrap" <?php echo $hidden; ?>>
            <th scope="row">
                <?php esc_html_e( $group['title']) ?><br>
                <i style="font-weight: normal;"><?php esc_html_e($group['description']) ?></i>
            </th>
            <td>
                <fieldset>
                    <?php
                    foreach($group['inputs'] as $input){
                        $value = $this->od_user_settings[$input['name']];
                        $i_description = !empty($input['i'])?'<i>'.esc_html($input['i']).'</i>':'';
                        switch ($input['type']){
                            case 'text':
                            ?>
                                <input type="text" id="<?php esc_attr_e($input['id']); ?>" name="<?php esc_attr_e($input['name']); ?>" class="<?php esc_attr_e($input['class']); ?>" placeholder="<?php esc_attr_e($input['placeholder']); ?>" value="<?php esc_attr_e($value); ?>"><?php echo $i_description; ?>
                            <?php
                                break;
                            case 'checkbox':
                                $checked = ($value == true || $value == 1)?'checked="checked"':'';
                                $value = $value == true || $value == 1;
                            ?>
                                <input type="checkbox" id="<?php esc_attr_e($input['id']); ?>" name="<?php esc_attr_e( $input['name']); ?>" class="<?php esc_attr_e($input['class']); ?>" value="<?php esc_attr_e($value); ?>" <?php echo $checked; ?>><?php echo $i_description; ?>
                            <?php
                                break;
                        }
                        echo '<br/>';
                    }
                    ?>
                </fieldset>
            </td>
        </tr>
        <?php
    }

    function render_colorpicker_group($group)
    {
        ?>
        <tr class="od-admin-color-wrap">
            <th scope="row">
                <?php esc_html_e( $group['title'] )?><br>
                <i style="font-weight: normal;"><?php esc_html_e( $group['description'] )?></i>
            </th>
            <td>
                <fieldset class="color_picker_group">
                    <?php
                    foreach($group['inputs'] as $input){
                        $value = $this->od_user_settings[$input['name']];
                        $i_description = !empty($input['i'])?'<i>'.$input['i'].'</i>':''; ?>
                        <label for="<?php esc_attr_e( $input['id']); ?>" ><?php esc_html_e( $input['i']); ?></label><input type="text" id="<?php esc_attr_e( $input['id']); ?>" name="<?php esc_attr_e($input['name']); ?>" class="<?php esc_attr_e( $input['class']); ?>" value="<?php esc_attr_e($value); ?>">
                        <?php
                        echo '<br/>';
                    }
                    ?>
                </fieldset>
            </td>
        </tr>
    <?php
    }

}