<?php

namespace od_includes;
if (!defined('ABSPATH')) exit;

class OpenDriveAdmin
{
    static function formatUsersList($result, $items_on_page, $items_on_page_values, $order_by_field,
                                        $order_by_asc, $page, $user_type, $search_term)
    {
        $error_message = '';
        if (!\OpenDrive::i()->apiClient()->error) {
            $users = $result['Users'];
            $total_users = $result['TotalUsers'];
            if (!$total_users) $error_message = __('No user found', 'opendrive');
        } else {
            $error_message = \OpenDrive::i()->apiClient()->error_message;
            $users = array();
            $total_users = 0;
        }

        $trans_processors = \OpenDrive::i()->getConfigItem('trans_processor_array');

        ob_start();
        ?>
        <div class="admin-container">
        <?php if($total_users):?>
        <div class="display-rows clearfix">
            <ul class="dropdown">
                <li><?php esc_html_e($items_on_page) ?><span class="caret"></span>
                    <ul>
                        <?php foreach ($items_on_page_values as $items_on_page_value): ?>
                            <li><a data-items-limit="<?php echo $items_on_page_value ?>" href="#"><?php echo $items_on_page_value ?></a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </li>
            </ul>
            <b>Show: </b>
        </div>
        <?php endif;?>
        <div class="users">

        <?php if($total_users):?>
        <div class="user-row heading-row clearfix">
            <div class="user-row-name col-md-3">
                User
            </div>
            <div class="user-row-type-position col-md-2">
                <?php
                $class = '';
                $order_id = 'Level__asc';
                if ($order_by_field == 'Level') {

                    if ($order_by_asc == 'asc') {
                        $class = 'active-asc';
                        $order_id = 'Level__desc';
                    } elseif ($order_by_asc == 'desc') {
                        $class = 'active-desc';
                    }
                }
                ?>
                Account type &amp; <a href="#" data-order-by="<?php echo $order_id ?>" class="order-by <?php echo $class ?>">plan</a>
            </div>
            <div class="user-row-since col-md-1 no-wrap no-padding">
                <?php
                $class = '';
                $order_id = 'Time__asc';
                if ($order_by_field == 'Time') {

                    if ($order_by_asc == 'asc') {
                        $class = 'active-asc';
                        $order_id = 'Time__desc';
                    } elseif ($order_by_asc == 'desc') {
                        $class = 'active-desc';
                    }
                }
                ?>
                <a href="#" data-order-by="<?php echo $order_id ?>" class="order-by <?php echo $class ?>">Since</a>
            </div>
            <div class="user-row-billing col-md-2 no-wrap no-padding">
                <?php
                $class = '';
                $order_id = 'payment_due__asc';
                if ($order_by_field == 'payment_due') {

                    if ($order_by_asc == 'asc') {
                        $class = 'active-asc';
                        $order_id = 'payment_due__desc';
                    } elseif ($order_by_asc == 'desc') {
                        $class = 'active-desc';
                    }
                }
                ?>
                <a href="#" data-order-by="<?php echo $order_id ?>" class="order-by <?php echo $class ?>"><?php _e('Billing date', 'opendrive')?></a>
            </div>
        <?php if($user_type === 'premium'):?>
            <div class="user-row-gateway col-md-1 no-wrap no-padding">
                <?php _e('Payment GW', 'opendrive')?>
            </div>
        <?php endif; ?>
            <div class="user-row-space col-md-2 no-padding">
                    <?php
                    $class = '';
                    $order_id = 'StorageUsed__asc';
                    if ($order_by_field == 'StorageUsed') {

                        if ($order_by_asc == 'asc') {
                            $class = 'active-asc';
                            $order_id = 'StorageUsed__desc';
                        } elseif ($order_by_asc == 'desc') {
                            $class = 'active-desc';
                        }
                    }
                    ?>
                    <a href="#" data-order-by="<?php echo $order_id ?>" class="order-by <?php echo $class ?>"><?php _e('Space', 'opendrive')?></a>
                    /
                    <?php
                    $class = '';
                    $order_id = 'BwUsed__asc';
                    if ($order_by_field == 'BwUsed') {

                        if ($order_by_asc == 'asc') {
                            $class = 'active-asc';
                            $order_id = 'BwUsed__desc';
                        } elseif ($order_by_asc == 'desc') {
                            $class = 'active-desc';
                        }
                    }
                    ?>
                    <a href="#" data-order-by="<?php echo $order_id ?>" class="order-by <?php echo $class ?>"><?php _e('Bandwidth', 'opendrive')?></a>
            </div>
            <div class="user-row-actions col-md-1">
                &nbsp;
            </div>
        </div>
        <?php
        endif;

        if ($error_message != '') { ?>
            <br>
            <div class="alert alert-danger">
                <?php esc_html_e($error_message) ?>
            </div>
            <?php
        }


        foreach ($users as $one_user) {
            $space_used = $one_user['StorageUsed'];
            $space_max = $one_user['MaxStorage'] * 1024 * 1024;
            $downloads_used = $one_user['BwUsed'];
            $downloads_max = $one_user['BwMax'] * 1024 * 1024;

            $space_width = $space_max ? ceil(($space_used * 100) / $space_max) : 100;
            if ($space_width > 100) $space_width = 100;
            $downloads_width = $downloads_max ? ceil(($downloads_used * 100) / $downloads_max) : 100;
            if ($downloads_width > 100) $downloads_width = 100;
            ?>
            <div class="user-row clearfix" data-userid="<?php echo esc_attr($one_user['UserId']); ?>"
                 <?php if (isset($one_user['FileIdTab'])): ?>data-fileid="<?php esc_attr_e($one_user['FileIdTab']) ?>"<?php endif; ?>
                >
                <div class="user-row-name col-md-3 inline-block-m-cont">
                    <?php if ($one_user['NotesCount']): ?>
                        <div class="today-notes-count"
                             title="<?php echo $one_user['NotesCount'] ?> new notes today"><?php echo $one_user['NotesCount'] ?></div>
                    <?php endif; ?>
                    <div class="user-row-avatar js-admin-user-edit-trigger">
                        <?php if($one_user['Avatar']): ?>
                            <div class="user-list-avatar-wrapper">
                                <div class="avatar-container">
                                    <img src="<?php esc_attr_e($one_user['Avatar']); ?>"/>
                                </div>
                            </div>

                        <?php else: ?>
                            <div class="user-list-avatar-wrapper">
                                <div class="avatar-container" style="background-color: #<?php echo $one_user['AvatarColor']?>">
                                    <?php esc_html_e(strtoupper(mb_substr($one_user['UserFirstName'],0, 1,'utf-8').mb_substr($one_user['UserLastName'],0, 1,'utf-8')))?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="inline-block-m user-name">
                        <h3 class="ellipsis_overflow js-admin-user-edit-trigger" title="<?php esc_attr_e($one_user['UserFirstName'] . ' ' . $one_user['UserLastName']) ?>"><?php echo esc_html($one_user['UserFirstName']) . ' ' . esc_html($one_user['UserLastName']) ?></h3>
                        <a class="user-row-email ellipsis_overflow" title="<?php esc_attr_e($one_user['UserEmail']) ?>"
                           href="mailto:<?php esc_attr_e($one_user['UserEmail']) ?>"><?php esc_html_e($one_user['UserEmail']) ?></a>
                    </div>
                </div>
                <div class="user-row-type-position col-md-2 inline-block-m-cont">
                    <div class="inline-block-m">
                        <div class="ellipsis_overflow"
                             title="<?php esc_attr_e(\OpenDrive::i()->getAccountType($one_user['AccType']))?><?php if ($one_user['Suspended']): ?> (Suspended)<?php endif?><?php if ($one_user['Trial']):?> (Trial)<?php endif?>">
                        <?php echo esc_html(\OpenDrive::i()->getAccountType($one_user['AccType'])); ?>
                        <?php if ($one_user['Suspended']): ?>
                            <span class="suspended">(<?php _e('Suspended', 'opendrive')?>)</span>
                        <?php endif?>
                        <?php if ($one_user['Trial']):?>
                            <span class="trial">(Trial)</span>
                        <?php endif?>
                        </div>
                        <div class="ellipsis_overflow" title="<?php esc_attr_e(\OpenDrive::i()->getPlanName($one_user['Level']))?>">
                        <strong><?php echo esc_html(\OpenDrive::i()->getPlanName($one_user['Level'])) ?></strong>
                        </div>
                    </div>
                </div>
                <div class="user-row-since col-md-1 no-wrap no-padding inline-block-m-cont">
                    <div class="inline-block-m">
                        <div class="ellipsis_overflow" title="<?php echo date('M j, Y', $one_user['UserSince']) ?>"><?php echo date('M j, Y', $one_user['UserSince']) ?></div>
                        <div class="ellipsis_overflow" title="<?php if ($one_user['LastLoginTime'] != 0) echo __('Logged', 'opendrive') , ': ' . od_days_diff(date('Y-m-d', $one_user['LastLoginTime']), false, false, true);?>">
                            <?php if ($one_user['LastLoginTime'] != 0) {
                                echo __('Logged', 'opendrive') . ': ' . od_days_diff(date('Y-m-d', $one_user['LastLoginTime']));
                            }
                            ?>
                        </div>
                    </div>
                </div>
                <div class="user-row-billing col-md-2 no-wrap no-padding inline-block-m-cont">
                    <div class="inline-block-m">
                    <?php if ($one_user['DueDate'] != '0000-00-00'): ?>
                        <div class="ellipsis_overflow" title="<?php echo date('M j, Y', strtotime($one_user['DueDate'])); ?> <?php if ($one_user['DueDate'] != '') echo '(' . od_days_diff($one_user['DueDate'], 'suspended', false, true) . ')';?>">
                            <?php echo date('M j, Y', strtotime($one_user['DueDate'])); ?>
                            <?php if ($one_user['DueDate'] != '') echo '(' . od_days_diff($one_user['DueDate'], 'suspended') . ')';?>
                        </div>
                    <?php endif;

                    if (!empty($one_user['Suspended'])) {
                        ?>
                        <div class="suspended ellipsis_overflow" title="<?php echo sprintf( __('Suspended %s days', 'opendrive'), -od_days_diff($one_user['Suspended'], true, true, true))?>">
                            <?php echo sprintf(__('Suspended %s days', 'opendrive'), -od_days_diff($one_user['Suspended'], true, true)) ?>
                        </div>
                        <?php
                    }
                    ?>
                    </div>
                </div>
            <?php if($user_type === 'premium'):?>
                <div class="user-row-gateway col-md-1 no-wrap no-padding inline-block-m-cont">
                    <div class="inline-block-m">
                    <?php if (isset($one_user['PaymentGW']) && $one_user['PaymentGW'] > 0): ?>
                        <div class="ellipsis_overflow">
                    <?php   if(isset($trans_processors[$one_user['PaymentGW']])): ?>
                        <?php echo $trans_processors[$one_user['PaymentGW']]; ?>
                    <?php   else: ?>
                        <?php echo $one_user['PaymentGW']; ?>
                    <?php   endif; ?>
                        </div>
                    <?php endif; ?>
                    </div>
                </div>
            <?php endif; ?>
                <div class="user-row-space col-md-2 no-padding">
                    <div class="space-bar clearfix">
                        <div class="col-md-1 no-padding"><i class="fa fa-hdd-o"
                                                            title="Space"></i></div>
                        <div class="od-profile-bar col-md-11 no-padding pull-right">
                            <div class="od-profile-bar-info"
                                 title="<?php echo od_size_format($space_used, true) . ' ' . __('of', 'opendrive') . ' ' . od_size_format($space_max, true) ?>"><?php echo od_size_format($space_max, true) ?></div>
                            <div class="od-profile-bar-container"
                                 title="<?php echo od_size_format($space_used, true) . ' ' . __('of', 'opendrive') . ' ' . od_size_format($space_max, true) ?>">
                                <label><?php echo od_size_format($space_used, true) ?></label>
                                                        <span class="od-profile-bar-fill"
                                                              style="width:<?php echo $space_width ?>%"></span>
                            </div>
                        </div>
                    </div>
                    <div class="downloads-bar clearfix">
                        <div class="col-md-1 no-padding"><i class="fa fa-download"
                                                            title="Downloads"></i></div>
                        <div class="od-profile-bar col-md-11 no-padding pull-right">
                            <div class="od-profile-bar-info"
                                 title="<?php echo od_size_format($downloads_used, true) . ' ' . __('of', 'opendrive') . ' ' . od_size_format($downloads_max, true) ?>"><?php echo od_size_format($downloads_max, true) ?></div>
                            <div class="od-profile-bar-container"
                                 title="<?php echo od_size_format($downloads_used, true) . ' ' . __('of', 'opendrive') . ' ' . od_size_format($downloads_max, true) ?>">
                                <label><?php echo od_size_format($downloads_used, true); ?></label>
                                                        <span class="od-profile-bar-fill"
                                                              style="width:<?php echo $downloads_width ?>%"></span>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="user-row-actions col-md-1 no-padding inline-block-m-cont text-right">
                    <?php
                    if (\OpenDrive::isExtensionPluginActive()) {
                        ?><i class="fa fa-credit-card js-admin-user-new-payment-btn"
                             title="<?php _e('New Payment', 'opendrive') ?>"></i><?php
                    }
                    ?>
                    <i class="fa fa-pencil-square-o js-admin-user-edit-trigger" title="<?php _e('Edit User', 'opendrive') ?>"></i>
                    <?php
                    if (!empty($one_user['Suspended'])) {
                        ?><i class="fa fa-play"
                             title="<?php _e('Unsuspend User', 'opendrive') ?>"
                             data-user-action="unsuspend-user"
                            ></i>

                        <?php
                    } else {
                        ?>
                        <?php
                    }
                    ?>
                </div>
            </div>

            <?php
        }
        ?>
        <div class="clearfix"></div>

        <?php
        echo self::createPagination($total_users, $items_on_page, $page);

        return ob_get_clean();
    }

    static function createPagination($total_items, $items_per_page, $page)
    {
        ob_start();
        $total_pages = ceil($total_items / $items_per_page);
        if ($total_items >= $items_per_page) {
            $prev_page = $page - 1;
            if ($prev_page <= 0) $prev_page = 1;

            $next_page = $page + 1;
            if ($next_page >= $total_pages) $next_page = $total_pages;

            ?>
            <div class="paging">
                <a class="js-page" data-page="1" href="#" title="<?php _e('First Page', 'opendrive') ?>"><i class="fa fa-angle-double-left"></i></a>
                <a class="js-page" data-page="<?php echo $prev_page ?>" href="#" title="<?php _e('Previous Page', 'opendrive') ?>"><i
                        class="fa fa-angle-left"></i></a>
                <?php
                if ($total_pages > 5) {
                    $start_i = $page - 3;
                    if ($start_i < 1) $start_i = 1;
                    $end_i = $start_i + 5;
                    if ($end_i > $total_pages) {
                        $end_i = $total_pages;
                        $start_i = $total_pages - 5;
                    }
                } else {
                    $start_i = 1;
                    $end_i = $total_pages;
                }

                if ($start_i != 1) {
                    ?><a href="#">...</a><?php
                }
                for ($i = $start_i; $i <= $end_i; $i++) {
                    ?><a class="<?php if ($i == $page) echo 'active' ?> js-page" data-page="<?php echo $i ?>"
                         href="#"
                         title="<?php _e('Page', 'opendrive') ?> <?php echo $i ?>"><?php echo $i ?></a><?php
                }
                if ($end_i != $total_pages) {
                    ?><a href="#">...</a><?php
                }
                ?>
                <a class="js-page" data-page="<?php echo $next_page ?>"
                   href="#"
                   title="Next Page"><i class="fa fa-angle-right"></i></a>
                <a class="js-page" data-page="<?php echo $total_pages ?>"
                   href="#"
                   title="Last Page"><i class="fa fa-angle-double-right"></i></a>
            </div>
            </div>
            </div>
            <?php
        }
        return trim(ob_get_clean());
    }

    static function formatUserInfo($apiResult, $notes, $transactions, $CCList)
    {
        $result = $apiResult;
        $result->SinceText = ($result->UserSince > 0) ? \OpenDrive::formatTimeTZ($result->UserSince, 'M d, Y') : __('n/a', 'opendrive');
        $result->LastLoginText = ($result->LastLoginTime > 0) ? \OpenDrive::formatTimeTZ($result->LastLoginTime, 'M d, Y h:i a') : __('n/a', 'opendrive');

        $nextBillDate = new \DateTime();
        $nextBillDate->setTimezone(new \DateTimeZone('UTC'));
        $nextBillDate->setTimestamp(strtotime($result->DueDate));
        $result->DueDateText = ($result->DueDate > 0) ? $nextBillDate->format('M j, Y') : __('n/a', 'opendrive');

        $nextBillDate->setTimestamp($result->NextDueDate);
        $result->NextDueDate = ($result->NextDueDate > 0) ? $nextBillDate->format('M j, Y') : __('n/a', 'opendrive');
        if ($result->Suspended > 0) {
            $result->SuspendedText = sprintf(__('Suspended %s days', 'opendrive'), abs(od_days_diff($result->Suspended, false, true)));
        }
        $result->AccountTypeText = \OpenDrive::i()->getAccountType($result->AccType);
        $result->PlanText = \OpenDrive::i()->getPlanName($result->Level);

        $result->MaxStorageText = od_size_format($result->MaxStorage * 1024 * 1024, true);
        $result->StorageUsedText = od_size_format($result->StorageUsed, true, 1);
        $result->MaxStorageInfo = prettyUsedSize($result->MaxStorage * 1024 * 1024, 0, true, 4);

        $result->BwMaxText = od_size_format($result->BwMax * 1024 * 1024, true);
        $result->BwUsedText = od_size_format($result->BwUsed, true, 1);
        $result->BwInfo = prettyUsedSize($result->BwMax * 1024 * 1024, 0, true, 4);
        $reasons = \OpenDrive::i()->getConfigItem('closed_reasons');
        $result->CloseReasonTextStatus = array_key_exists($result->ClosedReason, $reasons) ? $reasons[$result->ClosedReason] : __('Unknown reason', 'opendrive') . ' ' . $result->ClosedReason;
        if ($CCList !== false) {
            $ccTypes = \OpenDrive::i()->getConfigItem('cc_types_array');
            foreach ($CCList as &$cc) {
                $cc->card_type = isset($ccTypes[$cc->card_type]) ? $ccTypes[$cc->card_type] : __('n/a', 'opendrive');
            }
            $result->UserCC = $CCList;
        }

        if ($result->LastBandwidthReset > 0) {
            $result->LastBwResetText = od_days_diff(\OpenDrive::formatTimeTZ($result->LastBandwidthReset, 'Y-m-d'), false, false);
        } else {
            $result->LastBwResetText = __('n/a', 'opendrive');;
        }

        $result->NewTransactionDate = \OpenDrive::formatTimeTZ(time(), 'M d, Y');

        $prepared_transactions = array();
        if(is_array($transactions)) {
            foreach ($transactions as $trans_key => $one_transaction) {
                $one_transaction['trans_date'] = \OpenDrive::formatTimeTZ($one_transaction['trans_timestamp'], 'M d, Y H:i');
                if ($one_transaction['trans_processor'] > 0) {
                    $one_transaction['trans_processor_name'] = \OpenDrive::i()->getTransProcessor($one_transaction['trans_processor']);
                } else {
                    $one_transaction['trans_processor_name'] = '';
                }
                $one_transaction['trans_status_name'] = \OpenDrive::i()->getTransStatus($one_transaction['trans_status']);
                $one_transaction['trans_amount'] = number_format($one_transaction['trans_amount'], 2);
                $prepared_transactions[$trans_key] = $one_transaction;
            }
        }

        $result->Transactions = $prepared_transactions;
        if($notes !== false) {
            foreach ($notes as $note_key => $one_note) {
                $notes[$note_key]['note_date'] = \OpenDrive::formatTimeTZ($one_note['note_time'], 'M d, Y');
            }
            $result->Notes = $notes;
        }

        if (isset($result->FileInfo)) {
            $result->FileInfo->DateDeletedText = $result->FileInfo->DateDeleted > 1 ? \OpenDrive::formatTimeTZ($result->FileInfo->DateDeleted) : '';
            $result->FileInfo->DateUploadedText = \OpenDrive::formatTimeTZ($result->FileInfo->DateUploaded);
            $result->FileInfo->DateModifiedText = \OpenDrive::formatTimeTZ($result->FileInfo->DateModified);
            $result->FileInfo->SizeDBText = od_size_format($result->FileInfo->SizeDB);
            $result->FileInfo->SrcSizeText = od_size_format($result->FileInfo->SrcSize);
            $result->FileInfo->BakSizeText = od_size_format($result->FileInfo->BakSize);
            $publicity = array(0 => __('Private', 'opendrive'), 2 => __('Hidden', 'opendrive'), 1 => __('Public', 'opendrive'));
            $result->FileInfo->Public = $publicity[$result->FileInfo->Public];
        }
        return $result;
    }

    static function formatAccountUsersList($users){
        ob_start();
        ?>
        <div class="users col-md-12 col-sm-12">
            <div class="user-row col-md-12 heading-row">
                <div class="user-row-name col-md-3">
                    <?php _e('Account User', 'opendrive') ?>
                </div>
                <div class="user-row-position col-md-3">
                    <?php _e('Permissions', 'opendrive') ?>
                </div>
                <div class="user-row-group col-md-2">
                    <?php _e('Group', 'opendrive') ?>
                </div>
                <div class="user-row-space col-md-3 no-padding">
                    <?php _e('Usage', 'opendrive') ?>
                </div>
                <div class="col-md-1">
                    <?php _e('Since', 'opendrive') ?>
                </div>
            </div>
            <?php
            if ( sizeof($users) )
            {
                foreach ($users as $one_user)
                {
                    $space_used = $one_user['StorageUsed'];
                    $space_max = max($one_user['StorageMax'] * 1024 * 1024, 1);
                    $downloads_used = $one_user['BWUsed'];
                    $downloads_max = max($one_user['BWMax'] * 1024 * 1024, 1);

                    $space_width = 0;
                    $downloads_width = 0;
                    if ( $space_used > 0 ) $space_width = min(100, ceil(( $space_used * 100 ) / $space_max));
                    if ( $downloads_used > 0 ) $downloads_width = min(100, ceil(( $downloads_used * 100 ) / $downloads_max));
                    $class_blocked = $one_user['AccessActive'] == 2 ? 'blocked' : '';
                    ?>
                    <div class="user-row clearfix <?php echo $class_blocked?>" title="<?php if ($one_user['AccessActive'] == 2) _e('User Blocked', 'opendrive');?>">
                        <div class="user-row-name col-md-3 inline-block-m-cont">
                            <?php if($class_blocked):?>
                                <i class="fa fa-lock"></i>
                            <?php endif?>
                            <div class="user-row-avatar">
                                <?php if($one_user['Avatar']): ?>
                                    <div class="user-list-avatar-wrapper">
                                        <div class="avatar-container">
                                            <img src="<?php esc_attr_e($one_user['Avatar']); ?>"/>
                                        </div>
                                    </div>

                                <?php else: ?>
                                    <div class="user-list-avatar-wrapper">
                                        <div class="avatar-container" style="background-color: #<?php echo $one_user['AvatarColor']?>">
                                            <?php esc_html_e(strtoupper(mb_substr($one_user['FirstName'],0, 1,'utf-8').mb_substr($one_user['LastName'],0, 1,'utf-8')))?>
                                        </div>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <div class="inline-block-m user-name">
                                <h3 class="ellipsis_overflow" title="<?php esc_attr_e($one_user['FirstName'] . ' ' . $one_user['LastName']); ?>">
                                    <?php echo esc_html($one_user['FirstName']) . ' ' . esc_html($one_user['LastName']) ?>
                                </h3>
                                <a class="user-row-email ellipsis_overflow"
                                   title="<?php esc_attr_e($one_user['Email']) ?>" href="mailto:<?php esc_attr_e($one_user['Email']) ?>">
                                    <?php esc_html_e($one_user['Email']) ?>
                                </a>
                            </div>
                        </div>

                        <div class="user-row-type-position col-md-3 inline-block-m-cont">
                            <div class="inline-block-m">
                                <b><?php echo od_get_user_permission_name($one_user['AdminMode'], true); ?></b>
                                <?php
                                $text = '';
                                if ( isset($one_user['UserFolders']['edit']) ) $text = intval($one_user['UserFolders']['edit']).' ' . __('Folders edit', 'opendrive');
                                if ( isset($one_user['UserFolders']['edit']) && isset($one_user['UserFolders']['view']) ) $text .= ' | ';
                                if ( isset($one_user['UserFolders']['view']) ) $text .= intval($one_user['UserFolders']['view']).' ' . __('Folders view', 'opendrive');
                                ?>
                                <div class="ellipsis_overflow" title="<?php esc_attr_e($text)?>"><?php esc_html_e($text)?></div>
                            </div>
                        </div>

                        <div class="user-row-group col-md-2 inline-block-m-cont">
                            <div class="inline-block-m">
                                <div class="ellipsis_overflow" title="<?php esc_attr_e($one_user['GroupName'])?>"><b><?php esc_html_e($one_user['GroupName'])?></b></div>
                                <div class="ellipsis_overflow" title="Space: <?php echo prettyUsedSize($one_user['GroupMaxStorage'] * 1024 * 1024)?> | <?php _e('Bandwidth', 'opendrive')?>: <?php echo prettyUsedSize($one_user['GroupMaxBw'] * 1024 * 1024)?>">
                                Space: <?php echo prettyUsedSize($one_user['GroupMaxStorage'] * 1024 * 1024)?> | <?php _e('Bandwidth', 'opendrive')?>: <?php echo prettyUsedSize($one_user['GroupMaxBw'] * 1024 * 1024)?>
                                </div>
                            </div>
                        </div>

                        <div class="user-row-space col-md-3 no-padding">
                            <div class="space-bar clearfix">
                                <div class="col-md-1 no-padding"><i class="fa fa-hdd-o"
                                                                    title="Space"></i></div>
                                <div class="od-profile-bar col-md-11 no-padding pull-right">
                                    <div class="od-profile-bar-info"
                                         title="<?php echo od_size_format($space_used, true) . ' ' . __('of', 'opendrive') .' ' . od_size_format($space_max, true) ?>"><?php echo od_size_format($space_max, true) ?></div>
                                    <div class="od-profile-bar-container"
                                         title="<?php echo od_size_format($space_used, true) . ' ' . __('of', 'opendrive') .' ' . od_size_format($space_max, true) ?>">
                                        <label><?php echo od_size_format($space_used, true) ?></label>
                                                        <span class="od-profile-bar-fill"
                                                              style="width:<?php echo $space_width ?>%"></span>
                                    </div>
                                </div>
                            </div>
                            <div class="downloads-bar clearfix">
                                <div class="col-md-1 no-padding"><i class="fa fa-download"
                                                                    title="Downloads"></i></div>
                                <div class="od-profile-bar col-md-11 no-padding pull-right">
                                    <div class="od-profile-bar-info"
                                         title="<?php echo od_size_format($downloads_used, true) . ' ' . __('of', 'opendrive') .' ' . od_size_format($downloads_max, true) ?>"><?php echo od_size_format($downloads_max, true) ?></div>
                                    <div class="od-profile-bar-container"
                                         title="<?php echo od_size_format($downloads_used, true) . ' ' . __('of', 'opendrive') .' ' . od_size_format($downloads_max, true) ?>">
                                        <label><?php echo od_size_format($downloads_used, true); ?></label>
                                                        <span class="od-profile-bar-fill"
                                                              style="width:<?php echo $downloads_width ?>%"></span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="user-row-since col-md-1 no-wrap inline-block-m-cont">
                            <div class="inline-block-m">
                                <div class="ellipsis_overflow"><?php echo date('M d, Y', strtotime($one_user['AccessSince']))?></div>
                            </div>
                        </div>
                    </div>

                    <?php
                }
            }
            else
            {
                ?>
                <div class="col-md-12 table-notice"><?php _e('No account users found.')?></div>
                <?php
            }
            ?>
            <div class="clearfix"></div>
        </div>

        <?php
        return ob_get_clean();
    }
}