<?php
namespace od_includes;
if ( !defined( 'ABSPATH' ) ) exit;

class OpenDriveApi extends \od_includes\OpenDriveApiCore
{

	protected $isAuthorization;
	function auth($username, $password, $plugin_version, $captcha_response = '')
	{
		$partner_id = get_option('od_username');
		if(defined('OD_PARTNER')) $partner_id = OD_PARTNER;
		$data = array('username' => $username, 'passwd' => $password, 'version' => $plugin_version, 'partner_id' => $partner_id);
		if(!empty($captcha_response))
			$data['captcha_response'] = $captcha_response;
		$url = 'session/login.json';

		$this->isAuthorization = true;
		$result = $this->post_request($url, $data);
		$this->isAuthorization = false;

		if (!empty($result->SessionID)) {
			$this->set_od_session_id($result->SessionID);

		}

		return $result;
	}

    function partner_auth($partner_name, $password)
	{

		$data = array('partner_name' => $partner_name, 'passwd' => $password);
		$url = 'session/partnerlogin.json';

		$result = $this->post_request($url, $data);
		return $result;
	}

	function logout()
	{
		if ($this->od_session_id) {
			$data = array();
			$url = 'session/logout.json';
			$result = $this->post_request($url, $data);

			return true;
		}

		return false;
	}

	function user_info($apply_bw = 0, $branding = 0)
	{
		if ($this->od_session_id) {
            return $this->get_request('users/info.json/' . $this->od_session_id . '?' . http_build_query(array('apply_bw' => $apply_bw, 'branding' => $branding)));
		}

		return false;
	}

	function user_update($first_name, $last_name, $company_name, $phone, $time_zone, $file_versioning, $file_versions, $lang, $daily_stat, $invoiceAddress, $default_file_permission = null, $address_1 = "", $address_2 = "")
	{
		$data = array(
			"session_id" => $this->od_session_id,
			"first_name" => $first_name,
			"last_name" => $last_name,
			"company_name" => $company_name,
			"phone" => $phone,
			"time_zone" => $time_zone,
			"file_versioning" => $file_versioning,
			"file_versions" => $file_versions,
			"lang" => $lang,
            "daily_stat" => $daily_stat,
            "invoice_address" => $invoiceAddress,
			"default_file_permission" => $default_file_permission,
			"address_1" => $address_1,
			"address_2" => $address_2
		);

		return $this->put_request('users/info.json', $data);
	}

    function user_affiliate_setting($enabled)
    {
        if ($this->od_session_id && in_array($enabled, [0, 1])) {
            $data = array(
                'session_id' => $this->od_session_id,
                'enabled'    => $enabled
            );
            return $this->post_request('users/affiliatesetting.json', $data);
        }

        return false;
    }

	function user_update_email($email)
	{
		if ($this->od_session_id && $email != '') {
			$data = array(
			"session_id" 	=> $this->od_session_id,
			"email" 		=> $email);

			$updated_user = $this->put_request('users/email.json', $data);

			return $updated_user;
		}
	}

	function user_verify_email($ver_code)
	{
		if ($this->od_session_id && $ver_code != '') {
			$data = array(
			"session_id" 	=> $this->od_session_id,
			"ver_code" 		=> $ver_code);

			$updated_user = $this->post_request('users/verifyemail.json', $data);

			return $updated_user;
		}
	}
	function user_verify_email_signup($email, $ver_code)
	{
		if ($email != '' && $ver_code != '') {
			$data = array(
				"email" 	=> $email,
				"ver_code"  => $ver_code
			);

			$updated_user = $this->post_request('users/verifyemailsignup.json', $data);

			return $updated_user;
		}
	}

	function user_update_password($newpassword, $oldpassword)
	{
		if ($this->od_session_id) {
			$data = array(
			"session_id" 	=> $this->od_session_id,
			"newpassword" 	=> $newpassword,
			"oldpassword" 	=> $oldpassword);

			$updated_user = $this->put_request('users/password.json', $data);
			return $updated_user;
		}
	}


	function password_restore($username, $code = null)
	{
		if ($username != '' || $code != '') {
			$data = array();
			if ($username != '') $data['username'] = $username;
			if ($code != '') $data['code'] = $code;
			return $this->post_request('users/forgotpassword.json', $data, false, false);
		}
		return false;
	}

    function password_restore_confirm_code($user_id, $user_id_access, $reset_code)
    {
        if ($user_id != '' && $reset_code != '') {
            $data = array();
            if ($user_id != '') $data['user_id'] = $user_id;
            if ($reset_code != '') $data['reset_code'] = $reset_code;
            if ($user_id_access != '') $data['user_id_access'] = $user_id_access;
            return $this->post_request('users/confirmPasswordReset.json', $data, false, false);
        }
        return false;
    }

	function user_create($username, $password, $verify_password, $email, $first_name, $last_name, $reg_ip, $company_name, $phone, $lang, $partner_id)
	{
		$data = array("username" => $username, "passwd" => $password, "verify_passwd" => $verify_password, "email" => $email, "first_name" => $first_name, "last_name" => $last_name, "reg_ip" => $reg_ip, "company_name" => $company_name, "phone" => $phone, "lang" => $lang, 'created_by_id' => $partner_id,'trial_data' => array());
		$created_user = $this->post_request('users.json', $data);
		return $created_user;
	}

	function add_user_note($userId, $noteText)
	{
		if( $this->od_session_id )
		{
			$result = $this->post_request( 'admin/usernote.json', array(
			'session_id' => $this->od_session_id,
			'user_id'    => $userId,
			'note'    => $noteText
			) );

			return $result;
		}
	}

	function get_user_notes($userId, $limit = 100, $sort_mode = 'asc', $offset = 0)
	{
		return $this->get_request('admin/usernotes.json/' . $this->buildPathUrl($this->od_session_id, $userId) . '?' .
			http_build_query(array('limit' => $limit, 'sort_mode' => $sort_mode, 'offset' => $offset)), true);
	}

	function get_invoice_admin($transactionId)
	{
		if ($this->od_session_id) {
			$result = $this->get_request(implode('/', array('admin/invoice.json', $this->od_session_id, $transactionId)), true);

			return $result;
		}
	}

	function put_user_note($note_id, $text)
	{
		if( $this->od_session_id )
		{
			return $this->put_request( 'admin/usernotes.json/' . $this->od_session_id, array(
			'note_id' => $note_id,
			'text'    => $text
			) );
		}
	}

	function folder_breadcrumb($folder_id, $sharing_id = null, $with_subfolders = false)
	{
		$data = array('sharing_id' => $sharing_id, 'with_subfolders' => (int)$with_subfolders);
		$this->removeNulls($data);
		return $this->get_request('folder/breadcrumb.json/' . $this->od_session_id . '/' . $folder_id . '/?' . http_build_query($data));
	}


	function download_file($file_id, $inlineMode = false, $preview = false, $sharing_id = '')
	{
		$download_url = $this->api_url . 'download/file.json/' . $file_id;
		$queryVars = array();
        if($this->od_session_id) $queryVars['session_id'] = $this->od_session_id;
        if($sharing_id) $queryVars['sharing_id'] = $sharing_id;
		$queryVars['inline']  =  $inlineMode;
		if($preview) $queryVars['preview'] = 1;
		if (defined('OD_DEBUG_API')) $queryVars['XDEBUG_SESSION_START'] = 'PHPSTORM';

		return $download_url . '?' . http_build_query( $queryVars );
	}

    function check_file_download($file_id, $sharing_id, $inline = false)
    {
        $queryVars = array('test' => 1, 'inline' => $inline);
		if($sharing_id) $queryVars['sharing_id'] = $sharing_id;
        if ($this->od_session_id) $queryVars['session_id'] = $this->od_session_id;
        return $this->get_request('download/file.json/' . $file_id . '?' . http_build_query($queryVars));
    }

	function open_file_in_zoho_editor($file_id, $zoho_api_key)
	{
		$postVars = array('zoho_api_key' => $zoho_api_key);
		if ($this->od_session_id) $postVars['session_id'] = $this->od_session_id;
		return $this->post_request('file/openzohoeditor.json/' . rawurlencode($file_id), $postVars);
	}

	function get_file($file_id, $sharing_id = '')
	{
		$queryVars = http_build_query(array(
			'session_id' => $this->od_session_id,
			'sharing_id' => $sharing_id
		));
		$info = $this->get_request( 'file/info.json/' . $file_id . '?' . $queryVars );
		if (!$this->error && $info->DateTrashed) {
			$this->error = true;
			$this->error_message = __('File is deleted', 'opendrive');
			$info = (object)array(
				'error' => array(
					'message' => __('File is deleted', 'opendrive')
				)
			);
		}
		return $info;
	}

	function get_file_versions($file_group_id = 0)
	{
		return $this->get_request('file/fileversions.json/' .$this->od_session_id . '/' . $file_group_id);
	}

	function get_files_info(array $file_ids, array $sharing_ids)
	{
		return $this->get_request('file/infomultiple.json/' . $this->od_session_id . '?' .
			http_build_query(array('file_id' => $file_ids, 'sharing_id' => $sharing_ids)));
	}

	function remove_file_version($file_id)
	{
		return $this->delete_request('file/removefileversion.json/' . $this->od_session_id . '/' .$file_id);
	}

	function get_group($group_id = 0)
	{
		return $this->get_request('usergroups.json/' . $this->od_session_id . '/' . $group_id);
	}

	function get_folder($folder_id, $sharing_id = '')
	{
		$url = 'folder/info.json/' . $this->buildPathUrl($this->od_session_id, $folder_id);
		if ($sharing_id) $url .= '/?' . http_build_query(array('sharing_id' => $sharing_id));
		return $this->get_request($url);
	}

	function get_shared_folder_info($folder_id)
	{
		return $this->get_request('folder/sharedinfo.json/' . $this->buildPathUrl($folder_id));
	}

	function get_thumb($file_id = 0)
	{
		return $this->get_request('file/thumb.json/' . $file_id . '?session_id='.$this->od_session_id );
	}

	function get_user_branding($user_id = '')
	{
		if(!$this->od_session_id && !$user_id) return false;
		$data = array();
		if ($this->od_session_id) $data['session_id'] = $this->od_session_id;
		if ($user_id) $data['user_id'] = $user_id;
		return $this->get_request('branding.json?' . http_build_query($data));
	}

	function save_user_branding($host_mapping, $drive_name, $menu_color, $font_color, $login_page_html, $white_labeled, $subdomain)
	{
		if ($white_labeled !== null) $white_labeled = (int)$white_labeled;

		$data = array(
			"session_id" => $this->od_session_id,
			"host_mapping" => $host_mapping,
			"drive_name" => $drive_name,
			"menu_color" => $menu_color,
			"font_color" => $font_color,
			"login_page_html" => $login_page_html,
			"white_labeled" => $white_labeled,
			'subdomain' => $subdomain
		);

		return $this->put_request('branding.json', $data);
	}

    /**
     * @param string $a_type (user,account_user,group,logo,favicon)
     * @param int $group_id
     * @param int $access_user_id
     * @param string $user_id
     * @return array|mixed|string
     */
    function get_avatar($a_type = 'user', $group_id = 0, $access_user_id = 0, $user_id = '')
    {
        $params = array('type' => $a_type);
        if ($this->od_session_id) $params['session_id'] = $this->od_session_id;
        if (!empty($user_id)) $params['user_id'] = $user_id;

        if ($group_id > 0 && $a_type == 'group') $params['group_id'] = $group_id;

        if ($a_type == 'account_user' && $access_user_id > 0) $params['access_user_id'] = $access_user_id;

        $content = $this->get_request('branding/files.json?' . http_build_query($params));
        if (!is_string($content)) $content = '';
        return $content;
    }
    
	function upload_avatar_url()
	{
		$request_url = $this->api_url.'branding/upload.json';
        if(defined('OD_DEBUG_API')) $request_url .= '/?XDEBUG_SESSION_START=PHPSTORM';
		return $request_url;
	}

	function delete_avatar($a_type = 'user')
	{
		return $this->delete_request('branding/userimage.json?session_id=' . $this->od_session_id . '&image_type=' .$a_type);
	}


	function get_folder_content($folder, $searchterm = null, $only_folders = null, $with_breadcrumbs = null,
								$last_request_time = null, $offset = null, $sharing_id = null,
								$order_by = null, $order_type = null)
	{

		$url = 'folder/list.json/' . $this->od_session_id . '/' . $folder;
		$params = array(
			'search_query' => $searchterm,
			'only_subfolders' => $only_folders,
			'with_breadcrumbs' => $with_breadcrumbs,
			'last_request_time' => $last_request_time,
			'offset' => $offset,
			'sharing_id' => $sharing_id,
			'order_by' => $order_by,
			'order_type' => $order_type,
		);

		$this->removeNulls($params);
		if($params) $url .= '?' . http_build_query($params);
		return $this->get_request($url);

	}

	function get_account_user_folders($access_email, $folder)
	{
		$url = 'accountusers/folderslist.json/' . $this->buildPathUrl($this->od_session_id, $folder) . '?' .
			http_build_query(array('access_email' => $access_email));
		return $this->get_request($url);
	}

	function get_shared_folder_content($folder, $with_breadcrumbs = null, $last_request_time = null, $offset = null, $order_by = null, $order_type = null)
	{
		$params = array(
			'with_breadcrumbs' => (int)$with_breadcrumbs,
			'last_request_time' => $last_request_time,
			'offset' => $offset,
			'order_by' => $order_by,
			'order_type' => $order_type
		);
		$this->removeNulls($params);
		$url = 'folder/shared.json/' . $this->buildPathUrl($folder) . '?' . http_build_query($params);
		return $this->get_request($url);
	}

	function get_trash_folder_content($count_only = 0, $last_request_time = null, $offset = null, $order_by = null, $order_type = null)
	{
		if ($this->od_session_id) {
			$params = array(
				'count_only' => (int)$count_only,
				'last_request_time' => $last_request_time,
				'offset' => $offset,
				'order_by' => $order_by,
				'order_type' => $order_type
			);
			$this->removeNulls($params);
            return $content = $this->get_request('folder/trashlist.json/' . $this->od_session_id . '?' . http_build_query($params));
		}
	}

	function get_admin_user_logs($user_id,$params){
		if ($this->od_session_id) {
			$url = 'admin/userlogs.json/'.$this->od_session_id.'/'.$user_id;
			if(!empty($params)){
				$query_string = http_build_query($params);
				$url .= '?'.$query_string;
			}
			
			$content = $this->get_request($url);
			return $content;
		}
	}

    function get_user_logs($access_user_id = 0, $start_date = 0, $end_date = 0, $log_type = null, $page = 0, $toArray = null){
    	
		if ($this->od_session_id) {
            $params = array(
                'access_user_id' => $access_user_id,
                'start_date' => $start_date,
                'end_date' => $end_date,
                'log_type' => $log_type,
                'page' => $page
            );
			$url = 'users/userlogs.json/'.$this->od_session_id;
            $query_string = http_build_query($params);
            $url .= '?'.$query_string;
            
			$content = $this->get_request($url, $toArray); 
			return $content;
		}
	}


	function admin_get_account_users($user_id){
		if ($this->od_session_id) {
			$url = 'admin/accountusers.json/'.$this->od_session_id.'/'.rawurlencode($user_id);
			$content = $this->get_request($url, true);
			return $content;
		}
	}

	function admin_reset_secure_files_password($user_id)
	{
		return $this->put_request(
			'admin/resetsecurefilespassword.json',
			array('session_id' => $this->od_session_id, 'user_id' => $user_id)
		);
	}

	function get_admin_user_groups($user_id)
	{
		if( $this->od_session_id )
		{
			$url     = 'admin/usergroups.json/' . $this->od_session_id . '/' . rawurlencode($user_id);
			$content = $this->get_request( $url, true );

			return $content;
		}
	}

	function get_user_groups()
	{
		return $this->get_request('usergroups/all.json?session_id=' . $this->od_session_id);
	}

	function set_folder_access($access_email, $foldersObj, $update = 0)
	{
		$data = array(
			"session_id" => $this->od_session_id,
			"access_email" => $access_email,
			"foldersObj" => $foldersObj,
			"update" => $update
		);

		return $this->post_request('accountusers/setfolderaccess.json', $data);
	}

	function create_access_user($access_first_name, $access_last_name, $access_password, $access_email, $access_admin_mode, $access_notification, $access_max_storage, $access_bw_max, $group_id, $access_phone, $access_password_change, $access_position, $access_send_password)
	{

		$data = array(
			"session_id" => $this->od_session_id,
			"access_first_name" => $access_first_name,
			"access_last_name" => $access_last_name,
			"access_password" => $access_password,
			"access_email" => $access_email,
			"access_admin_mode" => $access_admin_mode,
			"access_notification" => $access_notification,
			"access_max_storage" => $access_max_storage,
			"access_bw_max" => $access_bw_max,
			"group_id" => $group_id,
			'access_phone' => $access_phone,
			'access_password_change' => $access_password_change,
			'access_position' => $access_position,
			'access_send_password' => $access_send_password
		);
		return $this->post_request('accountusers.json', $data);
	}

	function edit_access_user($access_first_name, $access_last_name, $access_password, $access_password_change, $access_email, $new_access_email, $access_admin_mode, $access_notification, $access_max_storage, $access_bw_max, $access_phone, $access_position, $access_admin_level)
	{
		if ($this->od_session_id) {
			$data = array(
			"session_id" => $this->od_session_id,
			"access_email" => $access_email,
			);

			if ( $new_access_email !== false ) $data['new_access_email'] = $new_access_email;
			if ( $access_max_storage !== false ) $data['access_max_storage'] = $access_max_storage;
			if ( $access_bw_max !== false ) $data['access_bw_max'] = $access_bw_max;
			if ( $access_position !== false ) $data['access_position'] = $access_position;
			if ( $access_phone !== false ) $data['access_phone'] = $access_phone;
			if ( $access_notification !== false ) $data['access_notification'] = $access_notification;
			if ( $access_admin_mode !== false ) $data['access_admin_mode'] = $access_admin_mode;
			if ( $access_password_change !== null ) $data['access_password_change'] = (int)$access_password_change;
			if ( $access_password !== false ) $data['access_password'] = $access_password;
			if ( $access_last_name !== false ) $data['access_last_name'] = $access_last_name;
			if ( $access_first_name !== false ) $data['access_first_name'] = $access_first_name;
			if ( $access_admin_level !== false ) $data['access_admin_level'] = $access_admin_level;


			$updated_user = $this->put_request('accountusers.json', $data);

			return $updated_user;
		}
	}

	function delete_user_group($group_id)
	{
		return $this->delete_request('usergroups.json/' . $this->od_session_id . '/' .$group_id);
	}

	function create_user_group($group_name, $group_bw_max, $group_max_storage)
	{
		if ($this->od_session_id) {
			$data = array(
			"session_id" => $this->od_session_id,
			"group_name" => $group_name,
			"group_bw_max" => $group_bw_max,
			"group_max_storage" => $group_max_storage);

			$created_group = $this->post_request('usergroups.json', $data);

			return $created_group;
		}
	}

	function edit_user_group($group_id, $group_name, $group_bw_max, $group_max_storage, $group_settings_enable)
	{
		$data = array(
			"session_id" => $this->od_session_id,
			"group_id" => $group_id,
			"group_name" => $group_name,
			"group_bw_max" => $group_bw_max,
			"group_max_storage" => $group_max_storage,
            "group_settings_enable" => $group_settings_enable
        );

		return $this->put_request('usergroups.json', $data);
	}


	function move_account_user($access_email, $group_id)
	{
		if ($this->od_session_id && $access_email != '') {
			$data = array(
			"session_id" => $this->od_session_id,
			"access_email" => $access_email,
			"group_id" => $group_id);
			

			$updated_user = $this->post_request('accountusers/move.json', $data);

			return $updated_user;
		}
	}

	function account_user_set_access($access_email, $access_active)
	{
		if ($this->od_session_id && $access_email != '') {
			$data = array(
			"session_id" => $this->od_session_id,
			"access_email" => $access_email,
			"access_active" => $access_active);

			$updated_user = $this->post_request('accountusers/setaccess.json', $data);

			return $updated_user;
		}
	}

	function account_user_delete($access_email)
	{
		if( $this->od_session_id && $access_email != '' )
		{
			$result = $this->delete_request( 'accountusers.json' . '/' .$this->od_session_id . '/' . rawurlencode($access_email) );
			return $result;
		}
	}

	function get_account_user($access_email)
	{
		return $this->get_request('accountusers/info.json/' . $this->od_session_id . '/' . rawurlencode($access_email));
	}

	function get_users_in_group($group_id, $searchQuery = '')
	{
		$url = 'accountusers/usersingroup.json/' . $this->od_session_id . '/' . $group_id;
		if ($searchQuery) {
			$url .= '?' . http_build_query(array('search_query' => $searchQuery));
		}
		return $this->get_request($url);
	}

	function get_search_account_users($searchQuery = '')
	{
		$url = 'accountusers/searchusers.json/' . $this->od_session_id . '/?' . http_build_query(array('search_query' => $searchQuery));
		return $this->get_request($url);
	}

	function admin_get_all_users(array $params)
	{
		$params['session_id'] = $this->od_session_id;
		return $this->get_request('admin/allusers.json?' . http_build_query($params), 1);
	}

	function admin_get_user_info($user_id, $file_id = null)
	{
		$params = array();
		if ($file_id) $params['file_id'] = $file_id;
		return $this->get_request('admin/user.json/' . $this->buildPathUrl($this->od_session_id, $user_id) . '/?' . http_build_query($params));
	}

	function admin_update_user_info($update_array)
	{
		$update_array['session_id'] = $this->od_session_id;
		return $this->put_request('admin/user.json', $update_array);
	}

	function admin_close_user_account($user_id)
	{
		if ($this->od_session_id) {
			$res = $this->delete_request('admin/user.json/' . $this->od_session_id . '/' . rawurlencode($user_id));
			return $res;
		}
	}

	function admin_suspend_user($user_id)
	{
		if ($this->od_session_id) {
			$res = $this->delete_request('admin/suspenduser.json/' . $this->od_session_id . '/' . rawurlencode($user_id));
			return $res;
		}
	}

	function admin_block_file($user_id, $file_id)
	{
		return $this->put_request('admin/blockfile.json/' . $this->buildPathUrl($this->od_session_id, $user_id, $file_id));
	}

	function admin_blacklist_file($user_id, $file_id)
	{
		return $this->put_request('admin/blacklistfile.json/' . $this->buildPathUrl($this->od_session_id, $user_id, $file_id));
	}

	function admin_get_users_stat($year, $month, $day, $stat_type)
	{
		return $this->get_request('stats/toplist.json/' . $this->buildPathUrl($this->od_session_id, $year, $month, $day, $stat_type), 1);
	}

	function get_all_stats($month, $year)
	{
		if ($this->od_session_id) {
			$user_stats = $this->get_request('stats/allstats.json/' . $this->od_session_id . '/' . $month . '/' . $year, 1);
			return $user_stats;
		}
	}

	function get_user_bw_stats($month, $year)
	{
		if ($this->od_session_id) {
			$user_stats = $this->get_request('stats/bandwidth.json/' . $this->od_session_id . '/' . $month . '/' . $year, 1);
			return $user_stats;
		}
	}

	function admin_create_user($data)
	{
		$created_user = $this->post_request('admin/user.json', $data, '', 1);
		return $created_user;
	}

	function admin_add_user($username, $passwd, $verify_passwd, $emai, $first_name = '', $last_name = '', $reg_ip = '', $company_name = '', $phone = '', $lang = '', $od_account_type, $od_space, $od_bw, $od_account_users)
	{
		$data = array(
		"username" => $username,
		"passwd" => $passwd,
		"verify_passwd" => $verify_passwd,
		"email" => $emai,
		"first_name" => $first_name,
		"last_name" => $last_name,
		"reg_ip" => $reg_ip,
		"company_name" => $company_name,
		"phone" => $phone,
		"lang" => $lang);

		$created_user = $this->post_request('admin/user.json', $data);
		return $created_user;
	}

    function admin_blacklist_user($user_id, $user_email, $user_last_login_ip,
                                  $user_registration_ip, $user_all_transactions_ip)
    {
        $data = array(
            'session_id'               => $this->od_session_id,
            'user_id'                  => $user_id,
            'user_email'               => $user_email,
            'user_registration_ip'     => $user_registration_ip,
            'user_last_login_ip'       => $user_last_login_ip,
            'user_all_transactions_ip' => $user_all_transactions_ip
        );

        return $this->post_request('admin/blockuser.json', $data);
    }
	function create_folder($folder_name, $folder_sub_parent, $folder_is_public, $folder_public_upl, $folder_public_display, $folder_public_dnl, $folder_description, $folder_display_subfolders)
	{

		$data = array(
			'session_id' => $this->od_session_id,
			'folder_name' => $folder_name,
			'folder_sub_parent' => $folder_sub_parent,
			'folder_is_public' => $folder_is_public,
			'folder_public_upl' => $folder_public_upl,
			'folder_public_display' => $folder_public_display,
			'folder_public_dnl' => $folder_public_dnl,
			'folder_description' => $folder_description,
			'folder_display_subfolders' => $folder_display_subfolders
		);
		$this->removeNulls($data);

		return $this->post_request('folder.json', $data);
	}

	function update_folder($folder_id, $folder_name, $folder_description, $folder_access, $folder_public_upl, $folder_public_display, $folder_public_dnl, $folder_display_subfolders, $sharing_id)
	{
		$data = array(
			'session_id' => $this->od_session_id,
			'folder_display_subfolders' => $folder_display_subfolders,
			'folder_id' => $folder_id,
			'folder_name' => $folder_name,
			'folder_description' => $folder_description,
			'folder_access' => $folder_access,
			'folder_public_upl' => $folder_public_upl,
			'folder_public_display' => $folder_public_display,
			'folder_public_dnl' => $folder_public_dnl,
			'sharing_id' => $sharing_id
		);

		return $this->put_request('folder/foldersettings.json', $data, true);
	}

	function create_file($folder_id, $file_type, $sharing_id)
	{
		$data = array(
			'session_id' => $this->od_session_id,
			'folder_id' => $folder_id,
			'file_type' => $file_type,
			'access_folder_id' => '0',
			'sharing_id' => $sharing_id,
		);
		return $this->post_request('file.json', $data);
	}

	function update_file($file_id, $file_price, $file_name, $file_description, $file_password, $file_dest_url, $file_ispublic, $file_edit_online, $sharing_id)
	{
		$data = array(
			'session_id' => $this->od_session_id,
			'file_id' => $file_id,
			'file_price' => $file_price,
			'file_name' => $file_name,
			'file_description' => $file_description,
			'file_password' => $file_password,
			'file_dest_url' => $file_dest_url,
			'file_ispublic' => $file_ispublic,
			'file_edit_online' => $file_edit_online,
			'sharing_id' => $sharing_id,
		);
		return $this->put_request('file/filesettings.json', $data, true);
	}

	function resumable_upload_url()
	{
		$url = 'upload/resumable.json';
		$full_api_url = $this->api_url . $url;
		if(defined('OD_DEBUG_API')) $full_api_url .= '/?XDEBUG_SESSION_START=PHPSTORM';
		return $full_api_url;
	}

	function zipDownloadUrl()
	{
		$endpoint = $this->api_url . 'download/all.json';
		if(defined('OD_DEBUG_API')) $endpoint .= '?XDEBUG_SESSION_START=PHPSTORM';
		return $endpoint;
	}

	function session_exists($session_id)
	{
		return $this->post_request('session/exists.json', array('session_id' => $session_id));
	}
	function trash_empty()
	{
		if ($this->od_session_id) {
			$this->delete_request('folder/trash.json/'.$this->od_session_id);
		}
		return array('result' => 'OK');
	}

	function rename_folder($folder_id, $folder_name, $sharing_id)
	{
		$data = array(
			'folder_id' => $folder_id,
			'folder_name' => $folder_name,
			'session_id' => $this->od_session_id,
			'sharing_id' => $sharing_id
		);
		return $this->post_request('folder/rename.json', $data);
	}

	function rename_file($file_id, $file_name, $sharing_id)
	{
		$data = array(
			'file_id' => $file_id,
			'new_file_name' => $file_name,
			'session_id' => $this->od_session_id,
			'sharing_id' => $sharing_id,
		);

		return $this->post_request('file/rename.json', $data);
	}

	function copy_move_file($src_file_id, $dst_folder_id, $move = false)
	{
		$move = ($move) ? 'true' : 'false';

		$data = array(
			"session_id" => $this->od_session_id,
			"src_file_id" => $src_file_id,
			"dst_folder_id" => $dst_folder_id,
			"move" => $move,
			"overwrite_if_exists" => 'true',
			"src_access_folder_id" => '',
			"dst_access_folder_id" => '');

		return $this->post_request('file/move_copy.json', $data);
	}

	function copy_move_folder($src_folder_id, $dst_folder_id, $move = false)
	{
		$move = ($move) ? 'true' : 'false';

		$data = array(
			"session_id" => $this->od_session_id,
			"folder_id" => $src_folder_id,
			"dst_folder_id" => $dst_folder_id,
			"move" => $move);

		return $this->post_request('folder/move_copy.json', $data);
	}


	function trash_folder_restore($folder_id)
	{

		$data = array(
			"folder_id" => $folder_id,
			"session_id" => $this->od_session_id
		);

		return $this->post_request('folder/restore.json', $data);
	}

	function trash_file($file_id, $sharing_id)
	{
		$data = array(
			"session_id" => $this->od_session_id,
			"file_id" => $file_id,
			"sharing_id" => $sharing_id,
		);
		return $this->post_request('file/trash.json', $data);
	}

	function trash_folder($folder_id, $sharing_id)
	{
		$data = array(
			'session_id' => $this->od_session_id,
			'folder_id' => $folder_id,
			'sharing_id' => $sharing_id
		);

		return $this->post_request('folder/trash.json', $data);
	}

	function trash_file_restore($file_id)
	{
		$data = array(
			"file_id" => $file_id,
			"session_id" => $this->od_session_id);

		return $this->post_request('file/restore.json', $data);
	}

	function trash_folder_remove($folder_id)
	{
		$data = array(
			"folder_id" => $folder_id,
			"session_id" => $this->od_session_id);

		return $this->post_request('folder/remove.json', $data);
	}

	function send_file_by_email($file_id, $emails, $message_subject, $message_body, $captcha_response, $send_expiring_enabled)
	{
		$data = array(
			'file_id'          => $file_id,
			'recipient_emails' => $emails,
			'message_subject'  => $message_subject,
			'message_body'     => $message_body,
			'captcha_response' => $captcha_response,
            'send_expiring_enabled' => $send_expiring_enabled
		);

		return $this->post_request('file/sendbyemail.json', $data);
	}

	function send_folder_by_email($folder_id, $emails, $message_subject, $message_body, $captcha_response, $send_expiring_enabled)
	{
		$data = array(
			'folder_id'        => $folder_id,
			'recipient_emails' => $emails,
			'message_subject'  => $message_subject,
			'message_body'     => $message_body,
			'captcha_response' => $captcha_response,
            'send_expiring_enabled' => $send_expiring_enabled
		);

		return $this->post_request('folder/sendbyemail.json', $data);
	}

	function trash_file_remove($file_id)
	{
		return $this->delete_request('file.json/' . $this->od_session_id . '/' . $file_id, true);
	}

	function profile_recalculate_space($user_id)
	{
		$data = array(
			'session_id' => $this->od_session_id,
			'user_id' => $user_id
		);
		return $this->post_request('maintenance/recalculatespace.json', $data);
	}

	function profile_trash_files($user_id)
	{
		$data = array(
			"session_id" => $this->od_session_id,
			"user_id" => (int)$user_id
		);
		return $this->post_request('maintenance/removetrashedfiles.json', $data);
	}

	function profile_reset_bw($user_id){
		if ($this->od_session_id) {
			$data = array(
			"session_id" => $this->od_session_id,
			"user_id" => (int)$user_id
			);
			$api_request = 'maintenance/resetbw.json';
			return $this->post_request($api_request, $data);
		}
	}

	function updateApiPartnerSettings($settings)
	{
		if ($this->od_session_id) {
			if (!empty($settings)) {
				$data = array(
					"settings" => $settings
				);
				$api_request = 'admin/apipartnersettings.json';
				return $this->put_request($api_request, $data);
			}
		}
	}

	function getApiPartnerSettings($partner_id)
	{
		return $this->get_request('branding/apipartnersettings.json/' . $this->buildPathUrl($partner_id), true);
	}

	function get_invoice_user($transaction_id)
	{
		return $this->get_request( 'billing/invoice.json/' . $this->od_session_id . '/' . $transaction_id, true);
	}

    function get_file_full_link($short_link)
    {
        return $this->get_request('file/fulllink.json/' . rawurlencode($short_link));
    }

    function get_countries()
    {
        return $this->get_request('billing/countries.json', true);
    }

	function verify_file_password($file_id, $password)
	{
		return $this->post_request(
			'file/verifypassword.json',
			array('file_id' => $file_id, 'password' => $password, 'session_id' => $this->od_session_id));
	}

	function check_file_exists_in_folder($folder_id, $name, $sharing_id)
	{
		return $this->post_request('upload/checkfileexistsbyname.json/' . rawurlencode($folder_id), array('name' => $name, 'session_id' => $this->od_session_id, 'sharing_id' => $sharing_id), null, true);
	}

	function get_subdomain_branding($partner_name, $subdomain)
	{
		return $this->get_request('branding/subdomainbranding.json/' . $this->buildPathUrl($partner_name, $subdomain));
	}

	function check_user_subdomain_exists($subdomain)
	{
		return $this->get_request('branding/checkusersubdomainexists.json/' . $this->buildPathUrl($this->od_session_id, $subdomain));
	}

	function admin_send_trial_reminder($userId)
	{
		return $this->post_request('admin/sendtrialreminder.json/' . $this->buildPathUrl($this->od_session_id, $userId), array());
	}

	function admin_send_payment_reminder($userId)
	{
		return $this->post_request('admin/sendpaymentreminder.json/' . $this->buildPathUrl($this->od_session_id, $userId), array());
	}

	function admin_add_payment($userId, $trans_date, $trans_proc, $amount, $trans_status, $cc_id, $next_payment_due, $trans_proc_id, $note)
	{
		$trans_proc_id = trim($trans_proc_id);
		if ($trans_proc_id == '') $trans_proc_id = null;
		if ($trans_status == '') $trans_status = null;
		if ($cc_id == '') $cc_id = null;
		return $this->post_request('billing/addpayment.json',
			array('session_id'       => $this->od_session_id,
				  'user_id'          => $userId,
				  'trans_date'       => $trans_date,
				  'trans_proc'       => $trans_proc,
				  'amount'           => $amount,
				  'cc_id'            => $cc_id,
				  'next_payment_due' => (int)$next_payment_due,
				  'trans_proc_id'    => $trans_proc_id,
				  'trans_status'     => $trans_status,
				  'note'             => $note
			));
	}

	function admin_get_plans_history($userId)
	{
		return $this->get_request('admin/planshistory.json/' . $this->buildPathUrl($this->od_session_id, $userId), true);
	}

	function admin_get_user_files_stat($userId)
	{
		return $this->get_request('admin/userfilesstat.json/' . $this->buildPathUrl($this->od_session_id, $userId), true);
	}


	function admin_get_api_partners()
	{
		return $this->get_request('admin/apipartnerslist.json/' . $this->od_session_id, true);
	}

	function admin_get_partner_stats($year, $month, $partner_id, $stat_type = null)
	{
		return $this->get_request('admin/partnerstats.json/' . $this->od_session_id . '/' . $year . '/' . $month .
			'?' . http_build_query(array('partner_id' => $partner_id, 'stat_type' => $stat_type)), true);
	}

	// Notes API
	function get_notes($item_type, $item_id)
	{
		return $this->get_request('notes.json/' . $this->buildPathUrl($this->od_session_id, $item_type, $item_id));
	}

	function get_notelists_in_notepad($notepad_id)
	{
		return $this->get_request('notes/notelists.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id));
	}

	function get_archived_notelists_notepads()
	{
		return $this->get_request('notes/archived.json/' . $this->od_session_id);
	}

	function get_trashed_notelists_notepads()
	{
		return $this->get_request('notes/trashed.json/' . $this->od_session_id);
	}

	function get_notepads()
	{
		return $this->get_request('notes/notepads.json/' . $this->od_session_id);
	}

	function create_note($list_id, $text)
	{
		return $this->post_request('notes.json',
			array('session_id' => $this->od_session_id, 'list_id' => $list_id, 'text' => $text)
		);
	}

	function create_notes_list($notepad_id, $name)
	{
		return $this->post_request('notes/notelist.json',
			array('session_id' => $this->od_session_id, 'notepad_id' => $notepad_id, 'name' => $name)
		);
	}

	function create_notepad($name)
	{
		return $this->post_request('notes/notepad.json',
			array('session_id' => $this->od_session_id, 'name' => $name)
		);
	}

	function update_note($note_id, $text =  null, $status = null)
	{
		return $this->put_request('notes.json',
			array('session_id' => $this->od_session_id, 'note_id' => $note_id, 'text' => $text, 'status' => $status)
		);
	}

	function archive_notelist($list_id)
	{
		return $this->put_request('notes/archivenotelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id), array());
	}

	function archive_notepad($notepad_id)
	{
		return $this->put_request('notes/archivenotepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id), array());
	}

	function update_notelist($list_id, $name = null, $order = null, $color = null, $size = null)
	{
		return $this->put_request('notes/notelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id),
			array('name' => $name, 'order' => $order, 'color' => $color, 'size' => $size));
	}

	function update_multiple_notelist_order(array $data)
	{
		return $this->put_request('notes/ordernotelists.json/' . $this->od_session_id,
			$data);
	}

	function update_notepad($notepad_id, $name)
	{
		return $this->put_request('notes/notepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id),
			array('name' => $name));
	}

	function delete_note($note_id)
	{
		return $this->delete_request('notes.json/' . $this->buildPathUrl($this->od_session_id, $note_id));
	}

	function delete_notelist($list_id)
	{
		return $this->delete_request('notes/notelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function trash_notepad($notepad_id)
	{
		return $this->delete_request('notes/trashnotepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id));
	}

	function delete_trashed_notepad($notepad_id)
	{
		return $this->delete_request('notes/notepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id));
	}

	function trash_notelist($list_id)
	{
		return $this->delete_request('notes/trashnotelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function restore_archived_notepad($notepad_id)
	{
		return $this->put_request('notes/restorearchivednotepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id), array());
	}

	function restore_archived_notelist($list_id)
	{
		return $this->put_request('notes/restorearchivednotelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id), array());
	}

	function restore_trashed_notelist($list_id)
	{
		return $this->put_request('notes/restoretrashednotelist.json/' . $this->buildPathUrl($this->od_session_id, $list_id), array());
	}

	function restore_trashed_notepad($notepad_id)
	{
		return $this->put_request('notes/restoretrashednotepad.json/' . $this->buildPathUrl($this->od_session_id, $notepad_id), array());
	}

	function empty_notes_trash()
	{
		return $this->delete_request('notes/trash.json/' . $this->od_session_id);
	}

	function notes_search_items($search_query)
	{
		return $this->get_request('notes/search.json/' . $this->od_session_id . '?' .
			http_build_query(array('search_query' => $search_query)));
	}


	// Tasks API

	function tasks_get_project_lists($with_projects, $project_list_id = null, $task_id = null, $filter = null)
	{
		$data = array(
			'with_projects' => $with_projects,
			'session_id' => $this->od_session_id
		);

		if ($project_list_id) $data['project_list_id'] = $project_list_id;
		if ($task_id) $data['task_id'] = $task_id;
		if ($filter) $data['filter'] = $filter;

		return $this->get_request('tasks/projectlists.json/?' .
			http_build_query($data));
	}

	function tasks_get_projects($project_id = null)
	{
		$data = array('session_id' => $this->od_session_id, 'project_id' => $project_id);
		$this->removeNulls($data);
		return $this->get_request('tasks/projects.json/?' .
			http_build_query($data));

	}

	function tasks_search_items($search_query)
	{
		return $this->get_request('tasks/search.json/' . $this->od_session_id . '?' .
			http_build_query(array('search_query' => $search_query)));
	}

	function tasks_add_projects_list($list_name)
	{
		return $this->post_request('tasks/projectlist.json/' . $this->od_session_id,
			array('list_name' => $list_name));
	}

	function tasks_update_projects_list($list_id, $list_name)
	{
		return $this->put_request('tasks/projectlist.json/' . $this->buildPathUrl($this->od_session_id, $list_id),
			array('list_name' => $list_name));
	}
	function tasks_archive_project_list($list_id)
	{
		return $this->put_request('tasks/archiveprojectlist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function tasks_trash_project_list($list_id)
	{
		return $this->delete_request('tasks/trashprojectlist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function tasks_add_project($list_id, $project_name, $email_assign_to = null, $start_date = null,
							   $due_date = null, $status = null)
	{
		$data = array(
			'project_name' => $project_name,
			'email_assign_to' => $email_assign_to,
			'start_date' => $start_date,
			'due_date' => $due_date,
			'status' => $status,
		);

		return $this->post_request('tasks/project.json/' . $this->buildPathUrl($this->od_session_id, $list_id),
			$data);
	}

	function tasks_update_project($project_id, $data)
	{
		return $this->put_request('tasks/project.json/' . $this->buildPathUrl($this->od_session_id, $project_id), $data);
	}

	function tasks_add_project_permission($project_id, $access_user_email, $mode)
	{
		return $this->post_request('tasks/addprojectpermission.json/' . $this->buildPathUrl($this->od_session_id, $project_id),
			array('access_user_email' => $access_user_email, 'mode' => $mode));
	}

	function tasks_get_tasks_list($project_id, $task_list_id = null, $with_tasks = null, $filter = null, $item_type = null)
	{
		$data = array(
			'session_id' => $this->buildPathUrl($this->od_session_id),
			'task_list_id' => $task_list_id,
			'project_id' => $project_id,
			'with_tasks' => $with_tasks,
			'filter' => $filter,
			'item_type' => $item_type,
		);

		$this->removeNulls($data);

		return $this->get_request('tasks/tasklists.json/?' . http_build_query($data));
	}

	function tasks_add_task_list($project_id, $list_name, $due_date = null)
	{
		return $this->post_request('tasks/tasklist.json/' . $this->buildPathUrl($this->od_session_id, $project_id),
			array('list_name' => $list_name, 'due_date' => $due_date));
	}

	function tasks_update_task_list($list_id, $list_name = null, $due_date = null, $complete_all_tasks = null)
	{
		$data = array('list_name' => $list_name, 'due_date' => $due_date, 'complete_all_tasks' => $complete_all_tasks);
		return $this->put_request('tasks/tasklist.json/' . $this->buildPathUrl($this->od_session_id, $list_id),
			$data);
	}

	function tasks_archive_task_list($list_id)
	{
		return $this->put_request('tasks/archivetasklist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function tasks_trash_task_list($list_id)
	{
		return $this->delete_request('tasks/trashtasklist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function tasks_restore_task_list($list_id)
	{
		return $this->put_request('tasks/restoretasklist.json/' . $this->buildPathUrl($this->od_session_id, $list_id));
	}

	function tasks_get_tasks($search_query = '', $task_id = null, $task_list_id = null, $with_comments = false)
	{
		$data = array('session_id' => $this->od_session_id);
		if ($search_query !== '' && $search_query !== null ) $data['search_query'] = $search_query;
		if ($task_id !== null) $data['task_id'] = $task_id;
		if ($task_list_id !== null) $data['task_list_id'] = $task_list_id;
		if ($with_comments !== null) $data['with_comments'] = $with_comments;

		return $this->get_request('tasks.json/?'.
			http_build_query($data));
	}

	/**
	 * @param $task_id
	 * @param array $data ($task_name, $task_description, $order_no, $task_list_id, $email_assign_to, $start_date,
	 					$due_date, $private, $priority, $tag_id, $progress, $status, $color)
	 * @return object
	 */
	function tasks_update_task($task_id, array $data)
	{
		return $this->put_request('tasks.json/' . $this->buildPathUrl($this->od_session_id, $task_id), $data);
	}

	function tasks_archive_task($task_id)
	{
		return $this->put_request('tasks/archive.json/' . $this->buildPathUrl($this->od_session_id, $task_id));
	}

	function tasks_trash_task($task_id)
	{
		return $this->delete_request('tasks/trash.json/' . $this->buildPathUrl($this->od_session_id, $task_id));
	}

	function tasks_restore_task($task_id)
	{
		return $this->put_request('tasks/restore.json/' . $this->buildPathUrl($this->od_session_id, $task_id));
	}

	function tasks_add_task($task_list_id, $data)
	{
		return $this->post_request('tasks.json/' . $this->buildPathUrl($this->od_session_id, $task_list_id), $data);
	}

	function tasks_add_comment($task_id, $comment_text)
	{
		return $this->post_request('tasks.json/comment.json/' . $this->buildPathUrl($this->od_session_id, $task_id),
			array('comment_text' => $comment_text));
	}

	function tasks_get_tags()
	{
		return $this->get_request('tasks/tags.json/' . $this->od_session_id, true);
	}

	function tasks_get_assigned_users($project_id = null)
	{
		return $this->get_request('tasks/users.json/' . $this->od_session_id . (
			$project_id ? '?' . http_build_query(array('project_id' => $project_id)) : ''
			), true);
	}

	function tasks_update_comment($comment_id, $comment_text, $tag_id)
	{
		$data = array('comment_text' => $comment_text, 'tag_id' => $tag_id);
		return $this->put_request('tasks/comment.json/' . $this->buildPathUrl($this->od_session_id, $comment_id),
			$data);
	}

	function tasks_trash_comment($comment_id)
	{
		return $this->delete_request('tasks/trashcomment.json/' . $this->buildPathUrl($this->od_session_id, $comment_id));
	}

	function tasks_get_archived_items($item_type)
	{
		return $this->get_request('tasks/archiveditems.json/' . $this->buildPathUrl($this->od_session_id, $item_type));
	}

	function tasks_get_trashed_items($item_type)
	{
		return $this->get_request('tasks/trasheditems.json/' . $this->buildPathUrl($this->od_session_id, $item_type));
	}

	function tasks_empty_trash()
	{
		return $this->delete_request('tasks/emptytrash.json/' . $this->od_session_id);
	}

	function tasks_archive_project($project_id)
	{
		return $this->put_request('tasks/archiveproject.json/' . $this->buildPathUrl($this->od_session_id, $project_id));
	}

	function tasks_trash_project($project_id)
	{
		return $this->delete_request('tasks/trashproject.json/' . $this->buildPathUrl($this->od_session_id, $project_id));
	}

	function tasks_add_subcomment($comment_id, $subcomment_text)
	{
		return $this->post_request('tasks.json/subcomment.json/' . $this->buildPathUrl($this->od_session_id, $comment_id),
			array('subcomment_text' => $subcomment_text));
	}

	function tasks_update_subcomment($subcomment_id, $subcomment_text)
	{
		$data = array('subcomment_text' => $subcomment_text);

		return $this->put_request('tasks/subcomment.json/' . $this->buildPathUrl($this->od_session_id, $subcomment_id),
			$data);
	}

	function tasks_trash_subcomment($subcomment_id)
	{
		return $this->delete_request('tasks/trashsubcomment.json/' . $this->buildPathUrl($this->od_session_id, $subcomment_id));
	}

	function tasks_list_trash()
	{
		return $this->get_request('tasks/trashlist.json/' . $this->od_session_id);
	}

	function tasks_list_archive()
	{
		return $this->get_request('tasks/archivelist.json/' . $this->od_session_id);
	}

	function tasks_move_task($task_id, $insert_after_taskid, $task_list_id, $project_id, $item_type)
	{
		$data = array('task_id' => $task_id, 'insert_after_taskid' => $insert_after_taskid,
			'task_list_id' => $task_list_id, 'project_id' => $project_id, 'item_type' => $item_type);
		return $this->put_request('tasks/move.json/' . $this->od_session_id, $data);
	}

	function tasks_delete_attachment($item_type, $item_id, $file_id)
	{
		return $this->delete_request('tasks/attachedfile.json/' . $this->buildPathUrl($this->od_session_id, $item_type, $item_id, $file_id));
	}

	function list_shared_users()
	{
		return $this->get_request('sharing/listsharedusers.json/' . $this->buildPathUrl($this->od_session_id));
	}

	function list_shared_folders($sharing_id)
	{
		return $this->get_request('sharing/ListSharedFolders.json/' . $this->buildPathUrl($this->od_session_id, $sharing_id));
	}

    public function generateExpiringLink($date, $counter, $file_id, $enable)
    {
        return $this->get_request('file/ExpiringLink.json/' . $this->buildPathUrl($this->od_session_id,$date, $counter, $file_id, $enable));

    }

    public function generateExpiringFolderLink($date, $counter, $folder_id, $enable)
    {
        return $this->get_request('folder/ExpiringLink.json/' . $this->buildPathUrl($this->od_session_id,$date, $counter, $folder_id, $enable));
    }

    public function get_file_expiring_links($file_id)
    {
        return $this->get_request('file/FileExpiringLinks.json/'.$this->buildPathUrl($this->od_session_id, $file_id));
    }

    public function get_folder_expiring_links($folder_id)
    {
        return $this->get_request('folder/FolderExpiringLinks.json/'.$this->buildPathUrl($this->od_session_id, $folder_id));
    }

    public function enable2fa($email,$country, $cellphone)
    {
        $data = array(
            'email' => $email,
            'country' => $country,
            'cellphone' => $cellphone
        );
        return $this->post_request('users/enabletwofactorauth/', $data);
    }

	public function session_info( $userSessionCookieName ) {
		return $this->get_request('session/info.json/'.$userSessionCookieName);

	}

    public function authy_login($user_token)
    {
        return $this->get_request('users/authylogin.json/'.$this->buildPathUrl($this->od_session_id, $user_token));

    }

    public function authy_token_via_message()
    {
        return $this->get_request('users/authytokenviamessage.json/'.$this->buildPathUrl($this->od_session_id));
    }

    public function disable2fa()
    {
        return $this->post_request('users/disabletwofactorauth.json/'.$this->buildPathUrl($this->od_session_id));
    }

    public function update_popUp($UserID, $AccessUserID)
    {
        return $this->post_request('users/updatePopUp.json/'.$this->buildPathUrl($this->od_session_id, $UserID, $AccessUserID));
    }

    protected function apiCallHook($result)
	{
		if ((is_object($result) && !empty($result->error) && ($result->error->code == 401 || $result->error->code == 402)) ||
			(is_array($result) && !empty($result['error']) && ($result['error']['code'] == 401 || $result['error']['code'] == 402))
		) {
			$code = is_object($result) ? $result->error->code : $result['error']['code'];
			if ($code == 402) do_action('od_payment_required_hook');
			if($this->isAuthorization) return;
			do_action('od_api_call_error_hook');
		}
	}


}
