<?php

namespace od_includes;
if (!defined('ABSPATH')) exit;

class OpenDriveFiles
{
    static $editableExtensions = null;
    static function formatFolderContent(&$data, $folderId, $search_query)
    {
        $userInfo = \OpenDrive::i()->getUserInfo(0, 1);
        $sharingID = isset($data->SharingID) ? $data->SharingID : null;
        $tz = $userInfo ? $userInfo->TimeZone : '';
        $od_online_editor = \OpenDrive::i()->getPluginSetting('od_online_editor');
        $od_online_editor = $od_online_editor == 'true' || $od_online_editor == 1;

        if($folderId == 'trash') $data->Name = __('Trash', 'opendrive');
        if($folderId == '0') $data->Name = \OpenDrive::i()->getDriveName();
        $data->RealName = $data->Name;
        if ($search_query != '') $data->Name = __('Search', 'opendrive') . ' - ' . ($data->Name == '' ? \OpenDrive::i()->getDriveName() : $data->Name);

        if (isset($data->UserAccessMode) && $data->UserAccessMode == 0 || !$userInfo) $data->FolderReadOnly = true;
        if (isset($data->Folders)) foreach ($data->Folders as &$folder) {
            if (isset($folder->DateModified)) {
                if(empty($folder->DateModified))
                    $folder->DateModified = $folder->DateCreated;

                $folder->DateModifiedText = \OpenDrive::formatTimeTZ($folder->DateModified, 'M d, Y, h:ia', $tz);
            }

            if (isset($folder->DateTrashed)) {
                $folder->DateTrashedText = \OpenDrive::formatTimeTZ($folder->DateTrashed, 'M d, Y, h:ia', $tz);
            }
        }

        if ($sharingID && isset($data->Breadcrumbs)) {
            foreach ($data->Breadcrumbs as &$item) {
                $item->FolderID .= '-' . $sharingID;
            }
        }

        $folderReadOnly = isset($data->UserAccessMode) && $data->UserAccessMode == 0;

        $sharingParam = '&' . http_build_query(array('sharing_id' => $sharingID));

        if (isset($data->Files)) foreach ($data->Files as &$file) {
            $file->SizeText = od_size_format($file->Size);
            if ($sharingID && isset($file->ThumbLink)) {
                $file->ThumbLink .= $sharingParam;
            }

            if (isset($file->EditLink)) {
                if ($od_online_editor && !$folderReadOnly && self::isFileEditable($file->Extension)) {
                    $file->EditLink = $file->Access == 0
                        ? 'https://' . $_SERVER['HTTP_HOST'] . '/e/' . $file->FileId
                        : ($file->EditOnline ? $file->EditLink : __('Please enable the "Edit file online" option in file properties', 'opendrive'));
                } else {
                    $file->EditLink = null;
                }
            }

            static::setFileType($file);

            $file->Link = ($file->Access == 0 || $file->Password != '') ? 'https://' . $_SERVER['HTTP_HOST'] . '/f/' . $file->FileId : $file->Link;

            if (isset($file->DateTrashed)) {
                $file->DateTrashedText = \OpenDrive::formatTimeTZ($file->DateTrashed, 'M d, Y, h:ia', $tz);
            }

            if (isset($file->DateModified)) {
                $file->DateModifiedText = \OpenDrive::formatTimeTZ($file->DateModified, 'M d, Y, h:ia', $tz);
                if (time() - $file->DateModified < 60) $file->RecentlyUploaded = true;
            }
        }

        if ($userInfo && $userInfo->AccessUserID && isset($data->UserAccessMode) && $data->UserAccessMode == 0) $data->FolderReadOnly = true;
    }

    static function formatSharedUsers(&$data)
    {
        $data->Name = __('Shared Folders', 'opendrive');
        $data->FolderReadOnly = true;
    }

    static function formatSharedFolders(&$data)
    {
        $userInfo = \OpenDrive::i()->getUserInfo(0, 1);
        $tz = $userInfo ? $userInfo->TimeZone : '';
        if (isset($data->SharedFolders)) foreach ($data->SharedFolders as &$folder) {
            if (isset($folder->DateModified)) {
                $folder->DateModifiedText = \OpenDrive::formatTimeTZ($folder->DateModified, 'M d, Y, h:ia', $tz);
            }
        }
        $data->Name = __('Shared Folders', 'opendrive');
    }

    static function setFileType(&$file)
    {
        $od_online_editor = \OpenDrive::i()->getPluginSetting('od_online_editor');
        $od_online_editor = $od_online_editor == 'true' || $od_online_editor == 1;

        if (isset($file->EditLink)) {
            if($od_online_editor) {
                $file->EditLink = $file->Access == 0
                    ? 'https://' . $_SERVER['HTTP_HOST'] . '/e/' . $file->FileId
                    : ($file->EditOnline ? $file->EditLink : null);
            } else {
                $file->EditLink = null;
            }
        }

        $file->KnownFile = \OpenDrive::isKnownFile($file->Extension);
        if (\OpenDrive::isImageFile($file->Extension)) {
            $file->FileTypeClass = 'type-img';
            $file->IsImageFile = true;
        } elseif (\OpenDrive::isVideoFile($file->Extension)) {
            $file->FileTypeClass = 'type-video type-media';
        } elseif (\OpenDrive::isAudioFile($file->Extension)) {
            $file->FileTypeClass = 'type-audio type-media';
        } elseif( strtolower($file->Extension) == 'pdf'){
            $file->FileTypeClass = 'type-pdf';
        } else {
            if (!$file->KnownFile) $file->FileTypeClass = 'type-unknown';
        }

        if(isset($file->EditLink) && $file->EditLink != '') {
            if (!isset($file->FileTypeClass)) $file->FileTypeClass = '';
            $file->FileTypeClass .= ' type-document';
            $file->FileTypeClass = trim($file->FileTypeClass);
        }
    }

    static function formatFileVersions(&$versions)
    {
        $userInfo = \OpenDrive::i()->getUserInfo();
        foreach ($versions as &$version) {
            $version->DateModifiedText = convert_to_user_date(date('M d, Y, h:ia', $version->DateModified), 'M d, Y, h:ia', $userInfo->TimeZone);
            $version->DateUploadedText = convert_to_user_date(date('M d, Y, h:ia', $version->DateUploaded), 'M d, Y, h:ia', $userInfo->TimeZone);
            $version->SizeText = od_size_format($version->Size);
        }
    }

    protected static function isFileEditable($ext)
    {
        if (!self::$editableExtensions) {
            $od_zoho_ext = strtolower(\OpenDrive::i()->getPluginSetting('od_zoho_ext'));
            self::$editableExtensions = array_map('trim', explode(',', $od_zoho_ext));
        }
        return in_array(strtolower($ext), self::$editableExtensions);
    }
}