<?php
/*
*Template Name: Settings Plan New
*/

if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$user_info = OpenDrive::i()->getUserInfo();

if ( ! ($user_info && ($user_info->IsPartner >= 2 || ($user_info->AccessUserID && $user_info->AccessAdminLevel >= 95))) ) {
    OpenDrive::redirectToFiles();
}

$selectedPartnerId = rawurldecode(get_query_var('show'));
$selectedPartner = null;

$ApiPartners = OpenDrive::i()->apiClient()->admin_get_api_partners();
if (OpenDrive::i()->apiClient()->error) $ApiPartners = array();

if ($selectedPartnerId == '' && count($ApiPartners) == 1) {
    wp_redirect('/admin/partners/' . rawurlencode($ApiPartners[0]['PartnerId']));
    exit;
}
$total_account_users = 0;

$usergroups = OpenDrive::i()->apiClient()->get_user_groups();
if ( !isset($usergroups->error) && is_array($usergroups) && sizeof($usergroups) > 0 )
{
    foreach ( $usergroups as $one_group )
    {
        $total_account_users += $one_group->NumUsers;
    }
}

if ($selectedPartnerId) {
    foreach ($ApiPartners as $partner)
        if ($partner['PartnerId'] == $selectedPartnerId) {
            $selectedPartner = $partner;
            break;
        }
} elseif ($selectedPartnerId == '' && count($ApiPartners) == 1 && $user_info->Level < 95) {
    foreach ($ApiPartners as $partner)
        if ($partner['IsCurrent']) {
            $selectedPartner = $partner;
            break;
        }
}

$dateTime = new DateTime();
$dateTime->setTimezone(new DateTimeZone('UTC'));
$month = $dateTime->format('n');
$year = $dateTime->format('Y');

$partnerStats = OpenDrive::i()->apiClient()->admin_get_partner_stats($year, $month, $selectedPartnerId, 'summary');
if (OpenDrive::i()->apiClient()->error) {
    wp_redirect('/admin/partners');
    exit;
}

OpenDrive::enqueueScript(array(
    'vendor/chart.min.js' => '1.0.2',
    'vendor/chart.line.min.js?ver' => '1.0.2',
    'jquery.monthselector.js',
    'od_helpers.js',
    'od_settings.js',
    'od/admin/od_admin_partners.js'
));

$page_title = __('Dashboard', 'opendrive');

require_once('template-header.php');

?>
    <div class="fill">

        <?php echo od_get_sidebar(); ?>

        <div class="breadcrumb-and-buttons">
            <h2 class="has-menu"><span><a href="/admin"><?php _e('Admin', 'opendrive')?></a> / </span><a href="/admin/partners"><?php _e('Partners', 'opendrive')?></a>
                <span class="delimiter">/ </span>
                <ul class="dropdown">
                    <li><?php esc_html_e($selectedPartner ? $selectedPartner['DriveName'] : __('All', 'opendrive')) ?>
                        <?php if($user_info->Level >= 95):?>
                        <span class="caret"></span>
                            <div class="dropdown-menu2 scrollable">
                                <ol>
                                    <?php if (count($ApiPartners) > 1): ?>
                                        <li><a href="/admin/partners/"><?php _e('All', 'opendrive')?></a></li>
                                    <?php endif; ?>
                                    <?php foreach ($ApiPartners as $partner): ?>
                                        <li>
                                            <a href="/admin/partners/<?php echo rawurlencode($partner['PartnerId']) ?>" title="<?php esc_attr_e($partner['PartnerId']) ?>">
                                                <?php esc_html_e($partner['PartnerId']) ?>
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ol>
                            </div>
                        <?php endif;?>
                    </li>
                </ul>
            </h2>

        </div>

        <div class="tabs-container">
            <div class="js-tab-content tab-content scrollable">
                <div class="settings">
                    <div class="scroll-pane">
                        <div class="plan-badge plan-info col-md-3 col-sm 6">
                            <div class="box">
                                <i class="fa fa-info"></i>
                                <?php if ($selectedPartner): ?>
                                    <h3><?php esc_html_e($selectedPartner['DriveName']) ?></h3>
                                    <b>
                                        <?php if ($selectedPartner['PartnerRole'] == 2): ?>
                                            <?php _e('Partner account', 'opendrive')?>
                                        <?php elseif ($selectedPartner['PartnerRole'] == 9): ?>
                                            <?php _e('Administrator account', 'opendrive')?>
                                        <?php else: ?>
                                            <?php _e('Unknow account', 'opendrive')?>
                                        <?php endif; ?>
                                    </b><br>
                                    <?php _e('User name', 'opendrive')?>: <?php esc_html_e($selectedPartner['PartnerId']) ?><br>
                                    <?php _e('Since', 'opendrive')?>: <?php echo OpenDrive::formatTimeTZ($selectedPartner['UserSince'], 'M j, Y'); ?>
                                <?php else: ?>
                                    <h3><?php _e('All Partners', 'opendrive')?></h3>
                                <?php endif; ?>
                                <div class="clearfix"></div>
                            </div>
                        </div>

                        <div class="plan-badge space-info col-md-3 col-sm 6">
                            <div class="box">
                                <i class="fa fa-hdd-o"></i>

                                <h3><?php echo od_size_format($partnerStats['storage_used']) ?></h3>
                                <b><?php echo od_size_format($partnerStats['premium_storage_used']) ?> <?php _e('Premium', 'opendrive')?></b><br>
                                <?php echo od_size_format($partnerStats['free_storage_used']) ?> <?php _e('Free', 'opendrive')?><br>
                                <?php echo od_size_format($partnerStats['suspended_storage_used']) ?> <?php _e('Suspended', 'opendrive')?><br>
                                <?php echo od_size_format($partnerStats['storage_used'] - $partnerStats['free_storage_used'] - $partnerStats['premium_storage_used'] - $partnerStats['suspended_storage_used']) ?>
                                <?php _e('Closed', 'opendrive')?>
                                <div class="clearfix"></div>
                            </div>
                        </div>

                        <div class="plan-badge bw-info col-md-3 col-sm 6">
                            <div class="box">
                                <i class="fa fa-download"></i>

                                <h3><?php echo od_size_format($partnerStats['total_bw_uploaded'] + $partnerStats['total_bw_downloaded']) ?>
                                    <?php _e('used', 'opendrive')?></h3>
                                <b><?php echo od_size_format($partnerStats['total_bw_uploaded']) ?> <?php _e('Uploads', 'opendrive')?></b><br>
                                <?php echo od_size_format($partnerStats['total_bw_downloaded']) ?> <?php _e('Downloads', 'opendrive')?>
                                <div class="clearfix"></div>
                            </div>
                        </div>

                        <div class="plan-badge users-info col-md-3 col-sm 6">
                            <div class="box">
                                <i class="fa fa-users"></i>

                                <h3><?php esc_html_e($partnerStats['users_count']  + $total_account_users)?> <?php _e('Users', 'opendrive')?></h3>
                                <b><?php echo $partnerStats['users_count'] - $partnerStats['free_users_count'] + $total_account_users?>
                                    <?php _e('Premium Users', 'opendrive')?></b><br>
                                <?php esc_html_e($partnerStats['free_users_count']) ?> <?php _e('Free Users', 'opendrive')?>
                                <div class="clearfix"></div>
                            </div>
                        </div>

                        <div class="clearfix"></div>

                        <div class="chart-head users-chart-head col-md-6 col-sm-12">
                            <div class="box">
                                <h3><?php _e('Users Stats', 'opendrive')?></h3>
                                <span class="js-month_users_count"><i class="fa fa-refresh fa-spin"></i></span> <?php _e('New Users', 'opendrive')?>
                                | <span class="js-month_premium_users_count">0</span> <?php _e('Premium Users', 'opendrive')?>
                                <input data-item-id="<?php esc_attr_e($selectedPartnerId)?>"
                                       data-item-type="users"
                                       type="text" class="monthselector" value="<?php echo $month . '/' . $year ?>">
                            </div>
                            <div id="users-chartjs-tooltip"></div>
                            <div class="chart">
                                <i class="fa fa-refresh fa-2x fa-spin spin-loading abs js-loading"></i>
                                <canvas id="usersChart" data-free-users-line="<?php _e('Free users', 'opendrive')?>" data-premium-users-line="<?php _e('Premium Users', 'opendrive')?>"></canvas>
                            </div>
                        </div>

                        <div class="chart-head bw-chart-head col-md-6 col-sm-12">
                            <div class="box">
                                <h3><?php _e('Bandwidth Stats', 'opendrive')?></h3>
                                <?php _e('Uploads and downloads', 'opendrive')?> (<span
                                    id="monthly-uploaded"><i class="fa fa-refresh fa-spin"></i></span>
                                <?php _e('UP', 'opendrive')?> | <span
                                    id="monthly-downloaded"><i class="fa fa-refresh fa-spin"></i></span>
                                <?php _e('DL', 'opendrive')?>)
                                <input data-item-id="<?php esc_attr_e($selectedPartnerId)?>"
                                       data-item-type="bw"
                                       type="text" class="monthselector" value="<?php echo $month . '/' . $year ?>">
                            </div>
                            <div id="bw-chartjs-tooltip"></div>
                            <div class="chart">
                                <i class="fa fa-refresh fa-2x fa-spin spin-loading abs js-loading"></i>
                                <canvas id="bwChart" data-upload-bw-title="<?php _e('Upload Bandwidth', 'opendrive')?>" data-dl-bw-title="<?php _e('Download Bandwidth', 'opendrive')?>"></canvas>
                            </div>
                        </div>


                        <div class="clearfix"></div>
                    </div>
                </div>
            </div>
        </div>
        <script type="text/x-handlebars-template" data-name="ChartDataTooltip">
            <div class="chartjs-tooltip-section">
                <span class="chartjs-tooltip-key" style="background-color:{{Color}}"></span>
                <span class="chartjs-tooltip-value">{{Label}} -
                    {{#if Downloads}}
                        <?php _e('Downloads in GB', 'opendrive')?>
                    {{else}}
                        <?php _e('Uploads in GB', 'opendrive')?>
                    {{/if}}
                </span>
            </div>
        </script>
        <script type="text/x-handlebars-template" data-name="ChartUsersTooltip">
            <div class="chartjs-tooltip-section">
                <span class="chartjs-tooltip-key" style="background-color:{{Color}}"></span>
                <span class="chartjs-tooltip-value">{{Label}} -
                    {{#if Premium}}
                        <?php _e('Premium Users', 'opendrive')?>
                    {{else}}
                        <?php _e('Free Users', 'opendrive')?>
                    {{/if}}
                </span>
            </div>
        </script>
    </div>

<?php require_once('template-footer.php') ?>
