<?php
/*
*Template Name: Settings Plan New
*/

if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$user_info = OpenDrive::i()->getUserInfo();

if ( ! ($user_info->IsPartner >= 2 || ($user_info->AccessUserID && $user_info->AccessAdminLevel >= 90)) ) {
    OpenDrive::redirectToFiles();
}


OpenDrive::enqueueScript(array(
//    'vendor/chart.min.js' => '1.0.2',
//    'vendor/chart.line.min.js?ver' => '1.0.2',
//    'jquery.monthselector.js',
//    'od_helpers.js',
//    'od_settings.js',
    'od/admin/od_admin_stats.js'
));

OpenDrive::enqueueStyle(array(
    'vendor/jquery-ui-1.11.4.custom/jquery-ui.min.css' => '1.11.4'
));

$page_title = __('Bandwidth Statistic', 'opendrive');
$initData = array(
    'start_date' => date('M d, Y', strtotime('first day of this month')),
);
require_once('template-header.php');
$statsType = array(
    'top_daily_dl_bw' => __('Top Daily Download Bandwidth', 'opendrive'),
    'top_daily_up_bw' => __('Top Daily Upload Bandwidth', 'opendrive'),
    'top_monthly_dl_bw' => __('Top Monthly Download Bandwidth', 'opendrive'),
    'top_monthly_up_bw' => __('Top Monthly Upload Bandwidth', 'opendrive'),

    'top_monthly_file_uploads' => __('Top Monthly File Uploads', 'opendrive'),
    'top_monthly_file_downloads' => __('Top Monthly File Downloads', 'opendrive'),
    'top_daily_file_uploads' => __('Top Daily File Uploads', 'opendrive'),
    'top_daily_file_downloads' => __('Top Daily File Downloads', 'opendrive'),
);
?>
    <script id="js-init-data" type="x-text/plain"><?php echo json_encode($initData) ?></script>
    <div class="fill">

        <?php echo od_get_sidebar(); ?>

        <div class="breadcrumb-and-buttons js-breadcrumbs-container">
            <h2 class="has-menu"><span><a href="/admin"><?php _e('Admin', 'opendrive')?></a> / </span><a href="/admin/stats"><?php _e('Bandwidth Statistic', 'opendrive')?></a>
                <span class="delimiter">/ </span>
                <ul class="dropdown">
                    <li><span class="js-current-stat-name"><?php _e('Please Select', 'opendrive')?></span>
                        <span class="caret"></span>
                            <div class="dropdown-menu2 scrollable">
                                <ol>
                                    <?php foreach($statsType as $typeId => $typeName):?>
                                        <li data-type="<?php esc_attr_e($typeId)?>"><?php esc_html_e($typeName)?></li>
                                    <?php endforeach;?>
                                </ol>
                            </div>

                    </li>
                </ul>
                <span class="delimiter">/ </span>
                <ul class="dropdown due-filter">
                    <li>
                        <span class="js-date" data-type="start_date"><?php esc_html_e($initData['start_date'])?></span>
                        <span class="caret"></span>
                        <ul class="due-datepicker" style="width: auto">
                            <div class="js-datepicker"></div>
                        </ul>
                    </li>
                </ul>
            </h2>

        </div>

        <div class="tabs-container">
            <div class="js-tab-content tab-content scrollable">

            </div>
        </div>
        <i class="fa fa-refresh fa-2x fa-spin js-loading spin-loading"></i>
        <script type="text/x-handlebars-template" data-name="StatUsersList">
            {{#if users}}
            <table class="table od-table va-middle">
                <thead>
                    <th style="width: 10ch"><?php _e('User ID', 'opendrive')?></th>
                    <th style="width: 24ch">
                        {{#if_eq units 'BW'}}<?php _e('Used Bandwidth', 'opendrive')?>{{/if_eq}}
                        {{#if_eq units 'FilesCount'}}<?php _e('Files Count', 'opendrive')?>{{/if_eq}}
                    </th>
                    <th style="width: 24ch"><?php _e('Used Storage', 'opendrive')?></th>
                    <th style="width: 24ch"><?php _e('Account Type', 'opendrive')?></th>
                    <th>Plan</th>
                </thead>
                <tbody>
                    {{#each users}}
                    <tr {{#if DLWarning}}style="background: rgba(255, 0, 0, 0.15)"{{/if}}>
                        <td><a href="/admin/users?search={{userid}}" target="_blank">{{userid}}</a></td>
                        <td>{{bw}}{{count}}</td>
                        <td>{{storage_used}}</td>
                        <td>{{acc_type}}</td>
                        <td>{{plan}} {{{suspended}}}</td>
                    </tr>
                    {{/each}}
                </tbody>

            </table>
            <p>Users, marked as red have downloaded bigger amount of data than amount of data stored in their accounts.</p>
            {{else}}
                <div class="alert alert-danger">
                    <?php esc_html_e('No statistics for selected date', 'opendrive')?>
                </div>
            {{/if}}
        </script>
    </div>

<?php require_once('template-footer.php') ?>