<?php
/*
*Template Name: Admin Users
*/
if (!defined('ABSPATH')) exit;
if (!$od_subpage) {
    wp_redirect('/admin/users');
    exit;
}
if (!function_exists('is_plugin_active')) require_once(ABSPATH . 'wp-admin/includes/plugin.php');
require_once('template-functions.php');

$first_load = false;
$user_info = OpenDrive::i()->getUserInfo();
if(!$user_info) OpenDrive::redirectToLoginPage();

if ( ! ($user_info->IsPartner >= 2 || ($user_info->AccessUserID && $user_info->AccessAdminLevel >= 90)) ) {
    OpenDrive::redirectToFiles();
}

$adminLevel = $user_info->IsPartner ? $user_info->Level : ($user_info->AccessUserID ? $user_info->AccessAdminLevel : 0);

$items_on_page_values = array(10, 25, 50, 100, 1000);
$items_on_page = OpenDrive::getQueryValue('items_on_page');
if (!in_array($items_on_page, $items_on_page_values)) $items_on_page = 25;
$page = (int)OpenDrive::getQueryValue('page');
if($page < 1) $page = 1;

$user_type = OpenDrive::getQueryValue('user_type');
$due_filter = OpenDrive::getQueryValue('due_filter');
$suspended_filter = OpenDrive::getQueryValue('suspended');
$search_term = OpenDrive::getQueryValue('search', '', false);


if (!in_array($user_type, array('all', 'premium', 'free', 'suspended', 'trials'))) $user_type = '';
$order_by = OpenDrive::getQueryValue('order_by');
if (!in_array($order_by, array('Level__asc', 'Level__desc', 'Time__asc', 'Time__desc', 'payment_due__asc', 'payment_due__desc', 'StorageUsed__asc', 'StorageUsed__desc', 'BwUsed__asc', 'BwUsed__desc'))) $order_by = '';
if (!in_array($suspended_filter, array('all', 'm90'))) $suspended_filter = '';

$filterOptions = null;

if ($user_type != '' || $due_filter != '' && $suspended_filter != '' || $search_term != '') {
    $query_array = array('items_on_page' => $items_on_page, 'page' => $page, 'filter' => $user_type);
    $order_by_field = false;
    $order_by_asc = false;
    if ($order_by) {
        list($order_by_field, $order_by_asc) = explode('__', $order_by);
    }
    if ($search_term != '') {
        $query_array['search_query'] = $search_term;
    } else {
        if ($order_by_field != '') {
            $query_array['order'] = $order_by_asc;
            $query_array['order_by'] = $order_by_field;
        }

        if ($due_filter != '' && ($user_type == 'premium' || $user_type == 'trials')) {
            $query_array['search_by'] = 'due_date';
            switch ($due_filter) {
                case 'today':
                    $query_array['search_query'] = strtotime('today');
                    break;
                case 'tomorrow':
                    $query_array['search_query'] = strtotime('tomorrow');
                    break;
                case 'all':
                    $query_array['search_query'] = 0;
                    break;
                case 'past':
                    $query_array['search_query'] = -strtotime('today');
                    break;
                default:
                    $query_array['search_query'] = (int)strtotime($due_filter);
            }
            if (!$query_array['search_query']) $due_filter = 'all';
        }
        if ($user_type == 'suspended' && $suspended_filter == 'm90')
            $query_array['filter'] = 'suspended_90d';
    }
    $users = OpenDrive::i()->apiClient()->admin_get_all_users($query_array);
    $filterOptions = array('items_on_page' => $items_on_page, 'page' => $page, 'user_type' => $user_type,
        'due_filter' => $due_filter, 'suspended' => $suspended_filter, 'search' => $search_term, 'order_by' => $order_by);
}

$errorMessage = '';
if (empty($users) || OpenDrive::i()->apiClient()->error) {
    $errorMessage = OpenDrive::i()->apiClient()->error_message;
    $total_users = 0;
    $users_count = 0;
    $users = null;
} else {
    $total_users = intval($users['TotalUsers']);
    $users_count = intval(sizeof($users['Users']));
    $users = $users['Users'];
}
$total_pages = ceil($total_users / $items_on_page);

$billingPlans = apply_filters('od_extension_get_billing_plans', array());
$planKeys = array('max_storage' => null, 'max_bandwidth' => null, 'file_versions' => null);
foreach ($billingPlans as &$plan) {
    $plan = array_intersect_key($plan, $planKeys);
}

OpenDrive::enqueueStyle(array(
    'od_admin_tabs.css',
    'vendor/magnific-popup.css' => '1.1.0',
    'vendor/jquery-ui-1.11.4.custom/jquery-ui.min.css' => '1.11.4'
));
OpenDrive::enqueueScript(array(
    'jquery.lazyload.od.js',
    'vendor/jquery.magnific-popup.min.js' => '1.1.0',
    'od_helpers.js',
    'vendor/jquery.inputmask.bundle.min.js' => '3.2.5-2',
    'od/admin/od_admin_tabs.js',
));
$page_title = __('Admin Users', 'opendrive');
require_once('template-header.php');
$initData = array(
    'SessionToken' => OpenDrive::i()->sessionToken(),
    'FilterOptions' => $filterOptions
);
?>
    <script id="js-init-data" type="x-text/plain"><?php echo json_encode($initData) ?></script>
    <script id="js-billing-plans" type="x-text/plain"><?php echo json_encode($billingPlans) ?></script>
    <div class="fill">
        <?php
        require_once 'items/admin/admin-lightboxes.php';
        require_once 'items/tabs.php';
        require_once 'items/admin/admin-templates.php';
        echo od_get_sidebar();
        ?>

        <div class="breadcrumb-and-buttons js-breadcrumbs-container no-fadeout"></div>
        <i class="fa fa-refresh fa-2x fa-spin spin-loading js-loading"></i>
        <div class="tabs-container">
            <div class="js-scroll-content scroll-content"></div>
        </div>
    </div>

<?php require_once('template-footer.php') ?>