<?php 
/*
*Template Name: Settings Activity Logs
*/

if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$error = false;
$message = false;

$user_info = OpenDrive::i()->getUserInfo();

if ( empty($user_info) )
{
    OpenDrive::redirectToLoginPage('permission-denied');
	exit;
}

$log_types = OpenDrive::i()->getConfigItem('log_type');

$owner_id = $user_info->UserID;
$activity_start_date = OpenDrive::i()->formatTimeUserTZ(time() - 86400, 'M d, Y');
$activity_end_date = OpenDrive::i()->formatTimeUserTZ(time(), 'M d, Y');;

$all_account_users = OpenDrive::i()->apiClient()->get_search_account_users();
if(OpenDrive::i()->apiClient()->error) $all_account_users = array();

$page_title = __('Activity Logs', 'opendrive');
OpenDrive::enqueueScript(array('jquery.monthselector.js', 'od_settings.js'));
OpenDrive::enqueueStyle(array(
	'vendor/jquery-ui-1.11.4.custom/jquery-ui.min.css' => '1.11.4'
));

require_once('template-header.php');

?>
<div class="fill">

    <?php echo od_get_sidebar(); ?>

			
		<div class="breadcrumb-and-buttons">
			<div class="buttons">
				<i title="<?php _e('Export logs to CSV', 'opendrive')?>" data-href="/settings/export_logs" id="download-logs-btn" class="fa fa-download view-mode"></i>
			</div>
			<h2><span><a href="/settings"><?php _e('Settings', 'opendrive')?></a> / </span><a href="/settings/activity"><?php _e('Activity Logs', 'opendrive')?></a></h2>
		</div>

		<div class="tabs-container">
			<div class="js-tab-content tab-content scrollable">
				<div class="branding">
					<i class="fa fa-refresh fa-2x fa-spin js-loading spin-loading"></i>
					<div class="items-count js-items_count">0 <?php _e('rows', 'opendrive')?> </div>
						<form id="activity-logs-form">
								<div class="label-input-cont">
									<label for="activity_start_date"><?php _e('Start Date', 'opendrive')?></label>
									<div class="datepicker-wrapper"><input type="text" class="withdatepicker" name="activity_start_date" id="activity_start_date" value="<?php esc_attr_e($activity_start_date)?>"></div>
								</div>
								<div class="label-input-cont">
									<label for="activity_end_date"><?php _e('End Date', 'opendrive')?></label>
									<div class="datepicker-wrapper"><input type="text" class="withdatepicker" name="activity_end_date" id="activity_end_date" value="<?php esc_attr_e($activity_end_date)?>"></div>
								</div>
								<div class="label-input-cont">
									<label for="activity_user"><?php _e('Users', 'opendrive')?></label>
									<select name="activity_user" id="activity_user">
										<?php if ($user_info->AccessUserID == 0 || $user_info->AccessUserID > 0 && $user_info->AdminMode == 1): ?>
											<option value=""><?php _e('All', 'opendrive')?></option>
											<option value="0" ><?php esc_html_e($user_info->UserFirstName . ' ' . $user_info->UserLastName); ?>
												(<?php _e('Admin', 'opendrive')?>)
											</option>
											<option value="anonymous"><?php _e('Anonymous', 'opendrive')?></option>
										<?php endif; ?>
											<?php
												foreach ( $all_account_users as $one_acc_user )
												{
													?><option value="<?php esc_attr_e($one_acc_user->AccessUserID)?>"><?php esc_html_e($one_acc_user->FirstName.' '.$one_acc_user->LastName) ?></option><?php
												}
											?>
									</select>
								</div>
								<div class="label-input-cont">
									<label for="activity_log_type"><?php _e('Log Type', 'opendrive')?></label>
									<select name="activity_log_type" id="activity_log_type">
										<option value="0"><?php _e('All', 'opendrive')?></option>
										<?php
										if ( sizeof($log_types) > 0 )
										{
											foreach ($log_types as $type_id => $type_name )
											{
												?><option value="<?php echo $type_id?>"><?php esc_html_e($type_name)?></option><?php
											}
										}
										?>
									</select>
								</div>
								<div class="label-input-cont">
									<label>&nbsp;</label>
									<a class="blue-button js-load-logs"><?php _e('Show Logs', 'opendrive')?></a>
								</div>
						</form>
					<div>
						<table class="table od-table gray-table no-wrap activity-logs-table">
							<thead>
								<th><?php _e('Time', 'opendrive') ?></th>
								<th><?php _e('User', 'opendrive') ?></th>
								<th><?php _e('Log Type', 'opendrive') ?></th>
								<th><?php _e('IP', 'opendrive') ?></th>
								<th><?php _e('Name', 'opendrive') ?></th>
								<th><?php _e('File Size', 'opendrive') ?></th>
								<th><?php _e('Details', 'opendrive') ?></th>
								<th><?php _e('App', 'opendrive') ?></th>
							</thead>
							<tbody class="js-userlogs"></tbody>
						</table>
					</div>
				</div>
			</div>
		</div>
	<form id="export-logs-form" method="post"></form>
<script type="text/x-handlebars-template" data-name="UserLogs">
	{{#each Logs}}
	<tr>
		<td>{{Time}}</td>
		<td class="user-name"><div class="ellipsis_overflow" title="{{User}}">{{User}}</div></td>
		<td>{{LogType}}</td>
		<td>{{IP}}</td>
		<td class="file-name"><div class="ellipsis_overflow" title="{{FileName}}">{{FileName}}</div></td>
		<td>{{FileSize}}</td>
		<td class="details"><div class="ellipsis_overflow" title="{{Details}}">{{Details}}</div></td>
		<td>{{App}}</td>
	</tr>
	{{/each}}
</script>
</div>
<?php require_once('template-footer.php')?> 