<?php 
/*
*Template Name: Branding Settings
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$error = false;
$message = false;

if ( postValue('form_action') == 'update_branding' )
{
	if (wp_verify_nonce(postValue('_wpnonce', null, false), 'update_branding_csrf') !== 1) {
		wp_redirect(site_url('/settings/branding'));
		exit;
	}
	$branding_drive_name = postValue('branding_drive_name');
	$branding_host_mapping = postValue('branding_host_mapping');
	$branding_subdomain = postValue('subdomain', '');
	$bg_color = postValue('bg_color');
	$font_color = postValue('font_color');
	$login_page_html = postValue('login_page_html', null, false);
	$white_labeled = postValue('white_labeled');

	$result = OpenDrive::i()->apiClient()->save_user_branding($branding_host_mapping, $branding_drive_name, $bg_color, $font_color, $login_page_html, $white_labeled, $branding_subdomain);
	
	if ( isset($result->error->message) )
	{
		$error = true;
		$message = $result->error->message;
	}
	else
	{
		$error = false;
		$message = __('Branding updated.', 'opendrive');
		$user_info = OpenDrive::i()->getUserInfo(0, 1, 1);
	}
}


$user_info = OpenDrive::i()->getUserInfo(0, 1);
if(!$user_info) OpenDrive::redirectToLoginPage();
$user_branding = OpenDrive::i()->apiClient()->get_user_branding();

if(OpenDrive::i()->apiClient()->error){
	OpenDrive::redirectToFiles();
}

$default_logo = false;
$logo_url = $user_branding->Logo;

if ( $logo_url == '' )
{
	$logo_url = wp_make_link_relative(plugins_url('/opendrive/images/dark-od-logo.png'));
	$default_logo = true;
}


$default_favicon = false;
$brand_fav_icon_url = $user_branding->FavIcon;
if( $brand_fav_icon_url == '' )
{ 
	$brand_fav_icon_url = wp_make_link_relative(plugins_url('/opendrive/images/favicon.ico'));
	$default_favicon = true;
} else {
	$brand_fav_icon_url = 'data:image/x-icon;base64,' . $brand_fav_icon_url;
}

$upload_branding_url = OpenDrive::i()->apiClient()->upload_avatar_url();

$page_title = __('Branding', 'opendrive');
OpenDrive::enqueueStyle(array('vendor/colorpicker.css' => '1.0.0', 'od_profile.css'));
OpenDrive::enqueueScript(array(
	'vendor/colorpicker.js',
	'od_settings.js',
	'vendor/jquery.inputmask.bundle.min.js' => '3.2.5-2'
));
require_once('template-header.php');

?>
<div class="fill">

    <?php echo od_get_sidebar(); ?>

			
		<div class="breadcrumb-and-buttons"> 
			<h2><span><a href="/settings"><?php _e('Settings', 'opendrive')?></a> / </span><a href="/settings/branding"><?php _e('Branding', 'opendrive')?></a></h2>
		</div>

		<div class="tabs-container">
			<div class="js-tab-content tab-content scrollable">
				<div class="branding settings">
						<div class="col-md-3 col-sm-12 no-left-padding">
							<div class="ava-container logo-container <?php if ($default_logo) echo 'default-avatar'?>">
									<h3><?php _e('Logo', 'opendrive')?></h3>
									<i class="fa fa-trash-o" title="<?php _e('Delete logo', 'opendrive')?>" id="trash-logo-btn"></i>
									<i class="fa fa-upload" title="<?php _e('Upload logo', 'opendrive')?>" id="upload-logo-btn"></i>
									<img src="<?php echo esc_attr($logo_url)?>" alt="Logo">
									<span class="notice"><?php _e('Optimal size', 'opendrive')?>: 160x45<?php _e('px', 'opendrive')?><br>JPG, PNG, GIF</span>
									<input type="file" id="btn-browse-logo-file">
									<input type="hidden" name="upload_logo_user_type" id="upload_logo_user_type" value="logo">
									<input type="hidden" name="upload_logo_session_id" id="upload_logo_session_id" value="<?php echo OpenDrive::i()->apiClient()->get_od_session_id()?>">
									<input type="hidden" name="upload_logo_url" id="upload_logo_url" value="<?php echo esc_attr( $upload_branding_url)?>">
							</div>
							
							<div class="ava-container favicon-container <?php if ($default_favicon) echo 'default-avatar'?>">
									<h3><?php _e('Favicon', 'opendrive')?></h3>
									<i class="fa fa-trash-o" title="<?php _e('Delete favicon', 'opendrive')?>" id="trash-favicon-btn"></i>
									<i class="fa fa-upload" title="<?php _e('Upload favicon', 'opendrive')?>" id="upload-favicon-btn"></i>
									<img src="<?php echo esc_attr($brand_fav_icon_url)?>" alt="<?php _e('Favicon', 'opendrive')?>">
									<span class="notice"><?php _e('Optimal size', 'opendrive')?>: 16x16<?php _e('px', 'opendrive')?><br>ICO, JPG, PNG, GIF</span>
									<input type="file" id="btn-browse-favicon-file">
									<input type="hidden" name="upload_favicon_user_type" id="upload_favicon_user_type" value="favicon">
									<input type="hidden" name="upload_favicon_session_id" id="upload_favicon_session_id" value="<?php echo esc_attr(OpenDrive::i()->apiClient()->get_od_session_id())?>">
									<input type="hidden" name="upload_favicon_url" id="upload_favicon_url" value="<?php echo esc_attr($upload_branding_url)?>">
							</div>
						</div>
						<div class="col-md-9 col-sm-12">
							<div class="row">
								<?php
								if ( $message != false && $message != '' )
								{
									OpenDrive::showPopupMessage($error ? 'error' : 'notification', $message);
								}
								?>
							</div>
							<?php 
							if ( $user_info->AccessUserID == 0 )
							{
								?>
								<form id="user-branding-form" method="POST">
									<?php wp_nonce_field('update_branding_csrf', '_wpnonce', false) ?>
									<h3><?php _e('Drive Name', 'opendrive')?></h3>
									<input type="text" maxlength="35" name="branding_drive_name" id="branding_drive_name" placeholder="<?php echo esc_attr(OpenDrive::i()->getDriveName())?>" value="<?php echo esc_attr($user_branding->DriveName)?>"><br>
									<!--<h3><?php _e('Host Mapping', 'opendrive')?></h3>
									<input type="text" name="branding_host_mapping" id="branding_host_mapping" placeholder="www.opendrive.com" value="<?php echo esc_attr($user_branding->HostMapping)?>"><br>
									<p><?php _e('Use this setting to map one of your own domain names to OpenDrive (for example use filestorage.mybusiness.com, instead of www.opendrive.com). The domain name you enter here is also used in the file links and the email notifications sent from your account.', 'opendrive')?> <a target="_blank" href="http://www.opendrive.com/opendrive-branding-white-labeling/"><?php _e('more', 'opendrive')?>...</a></p>
									<p><b><?php _e('Important', 'opendrive')?></b><br><?php _e('Once you enter a domain name here, it will be used immediately. You must create the proper CNAME DNS record before adding the domain. Your system administrator knows how to do this.', 'opendrive')?> </p>
									<br>-->
									<h3><?php _e('Your subdomain', 'opendrive')?></h3>

									<div class="subdomain">
										<input class="no-bottom-margin js-user-subdomain" placeholder="Your subdomain" maxlength="32"
											   type="text" name="subdomain"
											   value="<?php esc_attr_e($user_branding->Subdomain) ?>"/><strong><?php esc_html_e($user_info->PartnerUsersDomain) ?></strong>
										<div class="used-domain js-used-domain invisible"><?php _e('This subdomain is already used', 'opendrive')?></div>
									</div>

									<h3><?php _e('COLORS', 'opendrive')?></h3>
									<p><b><?php _e('Menu Background Color', 'opendrive')?></b></p>
									<div>
										<div class="colorpicker_parent">
											<div id="customWidget">
												<div id="colorSelector1"><div style="background-color: #<?php echo esc_attr($user_branding->MenuColor); ?>" ></div></div>
												<div id="colorpickerHolder1">
												</div>
											</div>
										</div>
										<input type="text" class="text-field color-field" name="bg_color" id="bg_color" value="<?php echo esc_attr($user_branding->MenuColor); ?>" />
										<a href="#" class="white-button" id="reset_bg_color"><?php _e('Reset to Default', 'opendrive')?></a>
									</div>	
									<p><b><?php _e('Menu Font Color', 'opendrive')?></b></p>
									<div>
										<div class="colorpicker_parent">
											<div id="customWidget">
												<div id="colorSelector2"><div style="background-color: #<?php echo esc_attr($user_branding->FontColor); ?>"></div></div>
												<div id="colorpickerHolder2">
												</div>

											</div>
										</div>
										<input type="text" class="text-field color-field" name="font_color" id="font_color" value="<?php echo esc_attr($user_branding->FontColor); ?>" />
										<a href="#" class="white-button" id="reset_font_color"><?php _e('Reset to Default', 'opendrive')?></a>
									</div>
									<input type="hidden" name="login_page_html" value="<?php echo esc_attr($user_branding->LoginPageHtml)?>">
									<input type="hidden" name="white_labeled" value="<?php echo esc_attr($user_branding->WhiteLabeled)?>">
									<input type="hidden" name="form_action" value="update_branding"><br><br>
									<input id="update-branding-btn" class="blue-button" type="submit" value="<?php _e('Save Changes', 'opendrive')?>">
								</form>
								<div class="clearfix"></div>	
								<?php
							}
							?>
						</div> 
					
				</div>
			</div>
		</div>
			
</div>
<?php require_once('template-footer.php')?> 