<?php 
/*
*Template Name: Settings Plan New
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$error = false;
$message = false;

$page_title = __('Dashboard', 'opendrive');
OpenDrive::enqueueScript(array(
	'vendor/chart.min.js'          => '1.0.2',
	'vendor/chart.line.min.js?ver' => '1.0.2',
	'vendor/jquery.inputmask.bundle.min.js' => '3.2.5-2',
	'jquery.monthselector.js',
	'od_helpers.js',
	'od_settings.js',
	'od_settings_dashboard.js',
));
$user_info = OpenDrive::i()->getUserInfo(1);
require_once('template-header.php');

$month = date('n');
$year = date('Y');

$stat = OpenDrive::i()->apiClient()->get_user_bw_stats($month, $year);

$montly_uploaded = $stat['montly_uploaded'];
$montly_downloaded = $stat['montly_downloaded'];
$up_num_dataset = $stat['up_num_dataset'];
$dl_num_dataset = $stat['dl_num_dataset'];
$upload_bw_dataset = $stat['upload_bw_dataset'];
$download_bw_dataset = $stat['download_bw_dataset'];

$dataset_keys = array_keys($up_num_dataset);


$used_storage = $user_info->StorageUsed;

$used_bw = $user_info->BwUsed;
$max_bw = $user_info->BwMax * 1024 * 1024;

$bw_used_percent = $max_bw > 0 ? ceil( $used_bw * 100 / $max_bw ) : 100;
if ( $bw_used_percent > 100 ) $bw_used_percent = 100;

$total_account_users = 0;

$usergroups = OpenDrive::i()->apiClient()->get_user_groups();
if ( !isset($usergroups->error) && is_array($usergroups) && sizeof($usergroups) > 0 )
{
	foreach ( $usergroups as $one_group )
	{
		$total_account_users += $one_group->NumUsers;
	}
}
$plan_name = OpenDrive::i()->getPlanName($user_info->Level);
?>
<div class="fill">

    <?php echo od_get_sidebar(); ?>

		<div class="breadcrumb-and-buttons">
			<?php
			if ( $user_info->Level > 1 && $user_info->DueDate !== '0000-00-00')
			{
				?><div class="buttons"><?php _e('Next billing date', 'opendrive')?>: <b class="due-date-text"><?php echo date('M d, Y', strtotime($user_info->DueDate))?></b></div><?php
			}
			?>
			<h2><span><a href="/settings"><?php _e('Settings', 'opendrive')?></a> / </span><a href="/settings/dashboard"><?php _e('Dashboard', 'opendrive')?></a></h2>
		</div>

		<div class="tabs-container">
			<div class="js-tab-content tab-content scrollable">
				<div class="settings">
						<div class="plan-badge plan-info col-md-3 col-sm 6">
							<div class="box" aria-label="<?php _e('Drive Information', 'opendrive')?>">
								<i class="fa fa-info" aria-hidden="true"></i>
								<h3 class="ellipsis_overflow" title="<?php esc_attr_e($drive_name)?>"><?php echo esc_html($drive_name)?></h3>
								<b><?php echo OpenDrive::i()->getAccountType($user_info->AccType)?></b>
								<?php if ( $user_info->Trial == 1 ):?><span class="trial">(<?php _e('Trial', 'opendrive')?>)</span><?php endif?>
								<br>
                                <?php if(in_array($plan_name, ["Unlimited/Reseller/Month", "Unlimited/Reseller/Year"], true) && $user_info->AccessUserID > 0) {
                                    echo esc_html("i-User");
                                }
                                else{
                                echo esc_html($plan_name);
                                }
                                ?>
								 <?php if ($user_info->Level == 1 && class_exists('OpenDriveExtension', false)) { ?> <a href="/billing/upgrade"><?php _e('Upgrade', 'opendrive')?></a> <?php }?><br>
								<?php _e('Since', 'opendrive')?>: <?php if ( $user_info->AccessUserID == 0 ) echo date('M j, Y', $user_info->UserSince); else echo date('M j, Y', $user_info->UserSince);?>
								<div class="clearfix"></div>
							</div>
						</div>	
						
						<div class="plan-badge space-info col-md-3 col-sm 6">
							<div class="box" aria-label="<?php _e('Storage Space', 'opendrive')?>">
								<i class="fa fa-hdd-o" aria-hidden="true"></i>
								<h3><?php echo od_size_format($used_storage);?> <?php _e('used', 'opendrive')?></h3>
								<b><?php _e('Storage Space', 'opendrive')?></b><br>
								<?php if ((($user_info->Level > 9 && $user_info->Level < 18
								) || $user_info->level > 30) AND $user_info->AccessUserID == 0) echo __('Unlimited', 'opendrive'); else  echo size_format($user_info->MaxStorage*1024*1024);?><br>
								<?php _e('File size', 'opendrive')?>: <?php if ( $user_info->Level > 1 ) echo __('Unlimited', 'opendrive'); else echo size_format($user_info->MaxFileSize*1024);?>
								<div class="clearfix"></div>
							</div>
						</div>	
						
						<div class="plan-badge bw-info col-md-3 col-sm 6">
							<div class="box" aria-label="<?php _e('Downloads', 'opendrive')?>">
								<i class="fa fa-download" aria-hidden="true"></i>
								<h3><?php if ( $user_info->Level > 9 ) {echo od_size_format($used_bw);?> used <?php } else {echo $bw_used_percent;?>% <?php _e('used', 'opendrive')?><?php } ?></h3>
								<b><?php _e('Downloads', 'opendrive')?></b><br>
								<?php if ((($user_info->Level > 9 && $user_info->Level < 18
								) || $user_info->level > 30) AND $user_info->AccessUserID == 0) echo __('Unlimited', 'opendrive');
								else {
									echo od_size_format($used_bw); ?> <?php _e('of', 'opendrive')?> <?php echo ($max_bw > 0) ? size_format($max_bw) : '0 B'; ?> <?php _e('used', 'opendrive')?><?php } ?><br>
								<?php _e('Since', 'opendrive')?>: <?php echo empty($user_info->BwResetLast) ? __('N/A', 'opendrive') : date('M j, Y', $user_info->BwResetLast)?>
								<div class="clearfix"></div>
								<div class="clearfix"></div>
							</div>
						</div>	
						<?php
						if ( $user_info->AccessUserID == 0 )
						{
							?>
							<div class="plan-badge users-info col-md-3 col-sm 6">
								<div class="box" aria-label="<?php _e('Account Users', 'opendrive')?>">
									<i class="fa fa-users" aria-hidden="true"></i>
									<h3><?php echo intval($total_account_users);?> <?php _e('used', 'opendrive')?></h3>
									<b><?php _e('Account Users', 'opendrive')?></b><br>
									<?php echo intval($total_account_users);?> <?php _e('of', 'opendrive')?> <?php esc_attr_e($user_info->MaxAccountUsers)?> <?php _e('used', 'opendrive')?><br>
									<div class="clearfix"></div>
								</div>
							</div>	
							<?php
						}
						?>
						<div class="clearfix"></div>
						
						<div class="chart-head files-chart-head col-md-6 col-sm-12">
							<div class="box" aria-label="<?php _e('Files Stats', 'opendrive')?>">
								<h3><?php _e('Files Stats', 'opendrive')?></h3>
								<?php _e('Uploaded and downloaded files', 'opendrive')?>
								<input type="text" class="monthselector" value="<?php echo $month.'/'.$year?>">
							</div>
							<div id="files-chartjs-tooltip"></div>
							<div class="chart">
								<canvas id="filesChart"></canvas>
							</div>
						</div>
						
						<div class="chart-head bw-chart-head col-md-6 col-sm-12">
							<div class="box" aria-label="<?php _e('Bandwidth Stats', 'opendrive')?>">
								<h3><?php _e('Bandwidth Stats', 'opendrive')?></h3>
								<?php _e('Uploads and downloads in GB', 'opendrive')?> (<span id="monthly-uploaded"><?php echo od_size_format($montly_uploaded);?></span> <?php _e('UP', 'opendrive')?> | <span id="monthly-downloaded"><?php echo od_size_format($montly_downloaded);?></span> <?php _e('DL', 'opendrive')?>
								<input type="text" class="monthselector" value="<?php echo $month.'/'.$year?>">
							</div>
							<div id="bw-chartjs-tooltip"></div>
							<div class="chart">
								<canvas id="bwChart"></canvas>
							</div>
						</div>
						
					
						<div class="clearfix"></div>
				</div>
			</div>
		</div>
			
</div>
	
	
<?php require_once('template-footer.php')?>
