<?php 
/*
*Template Name: Export Logs CSV
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');
header('Content-type: text/csv');
header('Content-Disposition: attachment; filename=activity_logs.csv');
header('Pragma: no-cache');
header('Expires: 0');


$user_info = OpenDrive::i()->getUserInfo();
if (!$user_info) {
	wp_redirect('/settings/activity');
	exit;
}

$owner_id = $user_info->UserID;

$activity_start_date = OpenDrive::requestValue('activity_start_date', date('M d, Y', strtotime('-1 day')));
$activity_end_date = OpenDrive::requestValue('activity_end_date', date('M d, Y'));
$activity_user_id = OpenDrive::requestValue('activity_user', '');
$activity_log_type = (int)OpenDrive::requestValue('activity_log_type', 0);

$params = array('start_date' => $activity_start_date, 'end_date' => $activity_end_date);
if ( $activity_log_type ) $params['log_type'] = $activity_log_type;

$buffer = @fopen('php://output', 'w');
if (!$buffer) exit;

fputcsv($buffer, array(
	__('Time', 'opendrive'), __('User', 'opendrive'), __('Log Type', 'opendrive'), __('IP', 'opendrive'),
	__('Name', 'opendrive'), __('File Size', 'opendrive'), __('Details', 'opendrive'), __('App', 'opendrive')));

$page = 0;
do {
	$timezone = "America/Los_Angeles";

	$logs = OpenDrive::i()->apiClient()->get_user_logs($activity_user_id, strtotime($activity_start_date. " $timezone"), strtotime($activity_end_date . " $timezone"), $activity_log_type, $page);
	if (OpenDrive::i()->apiClient()->error) break;
	$page = $logs->CurrentPage + 1;

	if (is_array($logs->Logs)) {
		foreach ($logs->Logs as $one_log) {

			$dt = new DateTime();
			$dt->setTimezone(new DateTimeZone($timezone));
			$dt->setTimestamp($one_log->Time);

			fputcsv($buffer, array(
				$dt->format('M d, Y, h:ia'),
				$one_log->User,
				$one_log->LogType,
				$one_log->IP,
				$one_log->FileName,
				size_format($one_log->FileSize, 1),
				$one_log->Details,
				$one_log->App
			));
		}
	}

} while ($logs->TotalPages > $logs->CurrentPage);

fclose($buffer);