<?php
/*
*Template Name: Settings My Profile New
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$error = false;
$message = false;

$formAction = postValue('form_action', null, false);

// update and verify email
$verification_stage = 1;

if ( isset($formAction) && $formAction == 'update_email' )
{
	if (wp_verify_nonce(postValue('_wpnonce'), 'user-email-form_csrf') !== 1) {
		wp_redirect(site_url('/settings/profile'));
		exit;
	}
	$ver_code = postValue('user_info_email_verification');
	if ( $ver_code != '' )
	{
		// verify email

		if ( $ver_code == '' )
		{
			$error = true;
			$message = __('Verification code empty.', 'opendrive');
		}

		if ( !$error )
		{
			OpenDrive::i()->apiClient()->user_verify_email($ver_code);

			if ( OpenDrive::i()->apiClient()->error )
			{
				$error = true;
				$message = OpenDrive::i()->apiClient()->error_message;
				$stage = 2;
			}
			else
			{
				$error = false;
				$message = __('Profile updated.', 'opendrive');
				$user_info = OpenDrive::i()->getUserInfo(0, 1, true);
				$stage = 1;
			}
		}
		else
		{
			$stage = 2;
		}
	}
	else if ( postValue('user_info_email') != '' )
	{
		// request verification code
		$email = postValue('user_info_email');
		OpenDrive::i()->apiClient()->user_update_email($email);

		if ( OpenDrive::i()->apiClient()->error )
		{
			$error = true;
			$message = OpenDrive::i()->apiClient()->error_message;
			$verification_stage = 1;
		}
		else
		{
			$error = false;
			$message = __('Verification code was sent to your current email address.', 'opendrive');
			$user_info = OpenDrive::i()->getUserInfo(0, 1, true);
			$verification_stage = 2;
		}

	}
}

$user_info = OpenDrive::i()->getUserInfo();

$time_zones = OpenDrive::i()->getTimezones();

$default_avatar = true;

$avatar = $user_info->Avatar;

if ( $avatar != '' )
{
	$default_avatar = false;
}
$upload_avatar_url = OpenDrive::i()->apiClient()->upload_avatar_url();
OpenDrive::enqueueStyle('od_profile.css');
OpenDrive::enqueueScript('od_settings.js');
$page_title = __('Profile', 'opendrive');
require_once('template-header.php');

?>
<div class="fill">

    <?php echo od_get_sidebar(); ?>

			
		<div class="breadcrumb-and-buttons">
			<h2><span><a href="/settings"><?php _e('Settings', 'opendrive')?></a> / </span><a href="/settings/profile"><?php _e('Profile', 'opendrive')?></a></h2>
		</div>

		<div class="tabs-container">
			<div class="js-tab-content tab-content scrollable">
				<div class="my-profile">
						<div class="col-md-3 col-sm-12 no-left-padding">
							<div class="ava-container <?php if ($default_avatar) echo 'default-avatar'?>">
								<i class="fa fa-trash-o" title="<?php _e('Delete avatar', 'opendrive')?>" id="trash-avatar-btn" data-image_type="<?php echo $user_info->AccessUserID == 0?'user':'account_user'; ?>"></i>
								<i class="fa fa-upload" title="<?php _e('Upload avatar', 'opendrive')?>" id="upload-avatar-btn"></i>
								<?php
								if ($default_avatar)
								{
									?><div class="avatar-container avatar-default" style="background-color: #<?php echo $userInfo->AvatarColor?>">
									<?php echo strtoupper(mb_substr($userInfo->UserFirstName,0, 1).mb_substr($userInfo->UserLastName,0, 1))?></div><?php
								}
								else
								{
									?><img alt="<?php _e('Avatar', 'opendrive')?>" src="<?php echo esc_attr($avatar)?>"><?php
								}
								?>
								<span class="notice"><?php _e('Maximum size', 'opendrive')?>: 150<?php _e('KB', 'opendrive')?><br>JPG, PNG, GIF</span>
								<input type="file" id="btn-browse-file" class="hidden">
								<input type="hidden" name="upload_avatar_user_type" id="upload_avatar_user_type" value="<?php if ( $user_info->AccessUserID == 0 ) echo 'user'; else  echo 'account_user';?>">
								<input type="hidden" name="upload_avatar_session_id" id="upload_avatar_session_id" value="<?php echo OpenDrive::i()->apiClient()->get_od_session_id()?>">
								<input type="hidden" name="upload_avatar_url" id="upload_avatar_url" value="<?php echo esc_attr($upload_avatar_url)?>">
							</div>
						</div>
						<div class="col-md-9 col-sm-12">
							<div class="row">
								<?php
								if ( $message != false && $message != '' )
								{
									OpenDrive::showPopupMessage($error ? 'warning': 'notification', $message);
								}
								?>
							</div>
							<?php 
							if ( $user_info->AccessUserID == 0 )
							{
								?>
								<form id="user-profile-form" method="POST" autocomplete="off">
									<h3><?php _e('User Details', 'opendrive')?></h3>
									<input type="text" name="user_info_first_name" id="user_info_first_name" placeholder="<?php _e('First Name', 'opendrive')?>" value="<?php echo esc_attr($user_info->UserFirstName)?>" maxlength="50"><br>
									<input type="text" name="user_info_last_name" id="user_info_last_name" placeholder="<?php _e('Last Name', 'opendrive')?>" value="<?php echo esc_attr($user_info->UserLastName)?>" maxlength="50"><br>
									<input type="text" name="user_info_company" id="user_info_company" placeholder="<?php _e('Company', 'opendrive')?>" value="<?php echo esc_attr($user_info->CompanyName)?>" maxlength="255"><br>
									<input type="text" name="user_info_phone" id="user_info_phone" placeholder="<?php _e('Phone', 'opendrive')?>" value="<?php echo esc_attr($user_info->Phone)?>" maxlength="20"><br>
									<input type="text" name="user_info_address_1" id="user_info_address_1" placeholder="<?php _e('Address 1', 'opendrive')?>" value="<?php echo esc_attr($user_info->Address1)?>" maxlength="100"><br>
									<input type="text" name="user_info_address_2" id="user_info_address_2" placeholder="<?php _e('Address 2', 'opendrive')?>" value="<?php echo esc_attr($user_info->Address2)?>" maxlength="100"><br>
									<select name="user_info_time_zone" id="user_info_time_zone">
										<?php
										if ( sizeof($time_zones) > 0 )
										{
											foreach ($time_zones as $time_zone_id => $time_zone_name)
											{
												?><option value="<?php echo esc_attr($time_zone_id)?>" <?php if ($time_zone_id == $user_info->TimeZone) echo 'selected'?>><?php echo esc_html($time_zone_name)?></option><?php
											}
										}
										?>
									</select><br><br>

                                    <h3>INVOICE ADDRESS</h3>
                                    <select name="user_info_invoice_address" id="user_info_invoice_address">
                                        <?php
                                            if($user_info->InvoiceAddress == 1){
                                                echo $user_info->CardAddress == "" ? "" : "<option value='1'>CARD ADDRESS: $user_info->CardAddress</option>";
                                                echo $user_info->UserAddress == "" ? "" : "<option value='0'>USER ADDRESS: $user_info->UserAddress</option>";
                                            }
                                            else{
                                                echo $user_info->UserAddress == "" ? "" : "<option value='0'>USER ADDRESS: $user_info->UserAddress</option>";
                                                echo $user_info->CardAddress == "" ? "" : "<option value='1'>CARD ADDRESS: $user_info->CardAddress</option>";
                                            }
                                        ?>
                                    </select>
                                    <br><br>

                                    <div class="profile-options">

                                        <div class="pull-left btn-group-vertical">
                                            <input type="checkbox"
                                                   name="user_info_daily_stat" <?php if ($user_info->DailyStat == 1) echo 'checked';?>
                                                   id="user_info_daily_stat">
                                        </div>
                                        <label for="user_info_daily_stat"><?php _e('Daily statistics', 'opendrive')?></label>
                                        <div class="clearfix form-group row-vertical">
                                            <div class="pull-right btn-group-vertical">
                                            <select
                                                name="user_info_versions" id="user_info_versions" class="small"
                                                <?php echo $user_info->Level < 2 ? 'disabled' : ''?>
                                                >
                                                <?php
                                                for ($i = 0; $i <= 99; $i++) {
                                                    ?>
                                                    <option
                                                    value="<?php echo $i ?>" <?php if ($i == $user_info->FVersions) echo 'selected'; ?>><?php echo $i ?></option><?php
                                                }
                                                ?>
                                            </select>
                                            </div>
                                            <label
                                                class="for-small <?php echo $user_info->Level < 2 ? 'disabled' : ''?>" for="user_info_versions"
                                                   id="for_user_info_versions"><?php _e('Max Versions', 'opendrive')?></label>

                                            <div class="pull-left btn-group-vertical">
                                            <input type="checkbox"
                                                <?php echo ($user_info->Level < 2 || $user_info->FVersioning)? 'disabled' : ''?>
                                                <?php echo empty($user_info->FVersioning) ? '' : 'checked'?>
                                                   name="user_info_file_versioning"
                                                   id="user_info_file_versioning">
                                            </div>
                                            <label
                                                class="<?php echo $user_info->Level < 2 ? 'disabled' : ''?>"
                                                for="user_info_file_versioning"><?php _e('File Versioning', 'opendrive')?></label>
                                            <?php if ($user_info->Level < 2 && class_exists('OpenDriveExtension', false)):?>
                                                <a class="btn-group-vertical upgrade-link" href="/billing/upgrade"><?php _e('Upgrade', 'opendrive')?></a>
                                            <?php endif;?>
                                        </div>
										<div class="clearfix form-group row-vertical default_file_perm">
											<div class="btn-group-vertical">
												<label
													data-toggle="tooltip"
													title="
													<p><b class='pull-left'><?php _e('Public', 'opendrive')?></b><?php _e('Anyone can access this file/folder.', 'opendrive')?></p>
													<p><b class='pull-left'><?php _e('Hidden', 'opendrive')?></b><?php _e('Anyone can access this file/folder if they know the URL.', 'opendrive')?></p>
													<p><b class='pull-left'><?php _e('Private', 'opendrive')?></b><?php _e('Only my shared contacts may access this file.', 'opendrive')?></p>"
													for="default_file_perm"><?php _e('Default File Permissions', 'opendrive')?></label>
												<select name="default_file_perm" id="default_file_perm"
														class="small pull-right">
													<?php foreach (array(0 => __('Private', 'opendrive'), 2 => __('Hidden', 'opendrive'), 1 => __('Public', 'opendrive')) as $permId => $permName ): ?>
														<option <?php if ($user_info->RootFolderPermission == $permId) echo 'selected'; ?> value="<?php echo $permId ?>"><?php echo esc_html($permName) ?></option>
													<?php endforeach; ?>
												</select>
											</div>
										</div>
									<input type="hidden" name="action" value="settings.update-profile">
									<button class="blue-button" type="submit"><?php _e('Save Changes', 'opendrive')?></button>
									</div>
								</form>
								<div class="clearfix"></div>
                                <form id="user-email-form" method="POST">
									<?php wp_nonce_field('user-email-form_csrf', '_wpnonce', false) ?>
									<br>
									<br>
									<div id="new-email-form" <?php if ( $verification_stage == 2 ) echo 'style="display: none;"';?>>
										<h3><?php _e('Email Address (USERNAME)', 'opendrive')?></h3>
										<input type="text" name="user_info_email" id="user_info_email" placeholder="<?php _e('Email Address', 'opendrive')?>" value="<?php echo esc_attr($user_info->Email)?>"><br>
										<input type="submit" class="white-button" id="get-verification-btn" value="<?php _e('Get Verification Code', 'opendrive')?>"><br>
									</div>
									<div id="verify-email-form" <?php if ( $verification_stage == 1 ) echo 'style="display: none;"';?>>
										<h3><?php _e('Email Address', 'opendrive')?></h3>
										<input type="text" name="user_info_email_verification" id="user_info_email_verification" placeholder="<?php _e('Email Verification Code', 'opendrive')?>" value=""><br>
										<input id="update-user-email" class="blue-button" type="submit" value="<?php _e('Save Changes', 'opendrive')?>">
									</div>
									<input type="hidden" name="form_action" value="update_email">
								</form>
								
								<div class="clearfix"></div>	
								<form method="POST" autocomplete="off" id="user-password-form">
									<br>
									<br>
									<h3><?php _e('Password', 'opendrive')?></h3>
									<input type="password" name="user_info_old_password" id="user_info_old_password" placeholder="<?php _e('Old Password', 'opendrive')?>"><br>
									<input type="password" name="user_info_new_password" id="user_info_new_password" placeholder="<?php _e('New Password', 'opendrive')?>"><br>
									<input type="password" name="user_info_repeat_password" id="user_info_repeat_password" placeholder="<?php _e('Repeat Password', 'opendrive')?>"><br>
									<br>
									<input type="hidden" name="action" value="settings.update-password">
									<button class="blue-button" type="submit"><?php _e('Change Password', 'opendrive')?></button>
								</form>
								<?php
							}
							else
							{
								?>
								<form id="user-profile-form" method="POST" autocomplete="off">
									<h3><?php _e('User Details', 'opendrive')?></h3>
									<input type="text" name="user_access_first_name" id="user_access_first_name" placeholder="<?php _e('First Name', 'opendrive')?>" value="<?php echo esc_attr($user_info->UserFirstName)?>" maxlength="50"><br>
									<input type="text" name="user_access_last_name" id="user_access_last_name" placeholder="<?php _e('Last Name', 'opendrive')?>" value="<?php echo esc_attr($user_info->UserLastName)?>" maxlength="50"><br>
									<input type="text" name="user_access_phone" id="user_access_phone" placeholder="<?php _e('Phone', 'opendrive')?>" value="<?php echo esc_attr($user_info->Phone)?>" maxlength="20"><br>
									<input type="text" name="user_access_new_email" id="user_access_new_email" placeholder="<?php _e('Email Address', 'opendrive')?>" value="<?php echo esc_attr($user_info->Email)?>" disabled="disabled" maxlength="255"><br>
									<input type="hidden" name="action" value="settings.update-profile-access_user">
									<button class="blue-button" type="submit"><?php _e('Save Changes', 'opendrive')?></button>
								</form>

								<?php if ($user_info->CanChangePwd): ?>
								<form method="POST" autocomplete="off" id="user-password-form">
									<br><br>
									<h3><?php _e('Password', 'opendrive')?></h3>
									<input type="password" name="user_info_old_password" id="user_info_old_password"
										   placeholder="<?php _e('Old Password', 'opendrive')?>"><br>
									<input type="password" name="user_info_new_password" id="user_info_new_password"
										   placeholder="<?php _e('New Password', 'opendrive')?>"><br>
									<input type="password" name="user_info_repeat_password"
										   id="user_info_repeat_password" placeholder="<?php _e('Repeat Password', 'opendrive')?>"><br>
									<input type="hidden" name="action" value="settings.update-password">
									<button class="blue-button" type="submit"><?php _e('Change Password', 'opendrive')?></button>
								</form>
								<?php endif;?>
								<?php
							}
							?>

							<div class="clearfix"></div>	
							<form method="POST" autocomplete="off" id="user-affiliate-form">
								<br>
								<br>
								<h3><?php _e('Affiliate ID', 'opendrive')?></h3>
	
<?php
	$enabled = (int)$user_info->Affiliation;
	$newState = (int)!$enabled;

	$affiliate_url = "";
	if($enabled)
		$affiliate_url = get_site_url() . '/?od=' . $user_info->UserUID;
?>
								<input type="hidden" name="action" value="settings.affiliate">
								<input type="hidden" name="enabled" id="affiliate_state" value="<?php echo $newState; ?>">
								<button class="blue-button <?php if($enabled) echo 'hidden'; ?>" type="submit" id="affiliate_enable"><?php _e('Get Affiliate Link', 'opendrive')?></button>
								<input type="text" class="<?php if(!$enabled) echo 'hidden'; ?>" id="affiliate_url" value="<?php echo htmlspecialchars($affiliate_url); ?>" readonly="true">
								<br>
								<button class="blue-button <?php if(!$enabled) echo 'hidden'; ?>" type="submit" id="affiliate_disable" ><?php _e('Disable Affiliate Link', 'opendrive')?></button>
							</form>
						</div> 
				</div>
			</div>
		</div>
			
</div>

<?php require_once('template-footer.php')?> 