<?php
/*
*Template Name: File Preview New
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

$file_id = ( get_query_var( 'file_id' ) ) ? get_query_var( 'file_id' ) : false;
$hide_header = OpenDrive::getQueryValue('previewmode', false, false);

if ( !$file_id || $file_id == '' )
{
	OpenDrive::redirectToLoginPage('file-is-not-available-anonymous-user');
}
$full_folder_id = OpenDrive::getQueryValue('folder_id');
$folder_query_params = ($full_folder_id ? '?' . http_build_query(array('folder_id' => $full_folder_id)) : '');
$sharing_id = '';
if (strpos($full_folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $full_folder_id);

$user_info = OpenDrive::i()->getUserInfo();

$file_exists = true;
$file_exists_message = '';

$file_name = '';
$file = OpenDrive::i()->apiClient()->get_file($file_id, $sharing_id);

if ( OpenDrive::i()->apiClient()->error )
{
	$file_id = '';
	$file_exists = false;
	$file_exists_message = OpenDrive::i()->apiClient()->error_message ? OpenDrive::i()->apiClient()->error_message : __('Unknown file error. Please contact support.', 'opendrive');
} else {
	$branding_user_id = $file->Owner;
	$BrandingMenuBgColor = '';
	$BrandingMenuFontColor = '';
	if (Opendrive::checkColor($file->BrandingMenuBgColor)) $BrandingMenuBgColor = $file->BrandingMenuBgColor;
	if (Opendrive::checkColor($file->BrandingMenuFontColor)) $BrandingMenuFontColor = $file->BrandingMenuFontColor;
}
$fileErrorMessage = '';
$downloadInfo = OpenDrive::i()->apiClient()->check_file_download($file_id, $sharing_id);

if($file_exists && getValue('file_error') != '' ){
    $fileErrorMessage = (is_object($downloadInfo) && isset($downloadInfo->error)) ? esc_attr($downloadInfo->error->message) : '';
    if($fileErrorMessage == '' && isset($downloadInfo->dl_stream_status) && !$downloadInfo->dl_stream_status)
		$fileErrorMessage = __('Not supported operation for your account type.', 'opendrive');
    if($fileErrorMessage == '') $fileErrorMessage = __('Unknown file error. Please contact support.', 'opendrive');
	header("Error-Message: $fileErrorMessage", true, isset($downloadInfo->error->code) ? $downloadInfo->error->code : 404);
}

$file_type = 'unknown';
$editable = false;
$is_private = false;
$is_password_protected = false;
$entered_password = false;

if ( $file_exists )
{
	$is_private = $file->Access == 0 && empty($user_info);
	if ( $file->Password != '' && (!$user_info || $user_info->UserID != $file->Owner) )
	{
		if ( postValue('file_password', null, false) != '' )
		{
			$response = OpenDrive::i()->apiClient()->verify_file_password($file_id, postValue('file_password', null, false));
			if (isset($response->result) && $response->result) {
				$is_password_protected = false;
				$entered_password = postValue('file_password', null, false);
			} else {
				$is_password_protected = true;
			}
		}
		else
		{
			$is_password_protected = true;
		}
	}

//	if ( !$is_private )
//	{
//        $file_download_link = file_download_link($file_id);
//		if ( $entered_password )
//		{
//			$file_download_link .= '/'.urlencode($entered_password);
//		}
//
//	}

	$file_name = $file->Name;

	$filepath = pathinfo($file_name);
	$file_filename = $filepath['filename'];
	$file_ext = ( isset($filepath['extension'])) ? strtolower($filepath['extension']) : '';
	$file_size = od_size_format($file->Size);
	$file_created = date('M d, Y', $file->DateUploaded);
	$file_description = $file->Description;

	$file_username = $file->OwnerName;
	$file_downloads = $file->Downloads;

	if (OpenDrive::isImageFile($file_ext) && !OpenDrive::unsupportedBrowserImages($file_ext)) {
		$file_type = 'image';
	} elseif (OpenDrive::isVideoFile($file_ext)) {
		$file_type = 'video';
	} elseif (OpenDrive::isAudioFile($file_ext)) {
		$file_type = 'audio';
	} elseif(!strcasecmp($file_ext, 'pdf'))
		$file_type = 'pdf';

	$od_online_editor  = trim(OpenDrive::i()->getPluginSetting('od_online_editor'));
	$od_zoho_ext  = array_map('trim', explode(',', OpenDrive::i()->getPluginSetting('od_zoho_ext')));

	$editable = $od_online_editor == 'true' && in_array($file_ext, $od_zoho_ext);

	$page_title = $file_name;

}

if ( $file_exists && $file_type == 'image')
{
	OpenDrive::enqueueScript('vendor/jquery.rotate.js');
}
OpenDrive::enqueueScript('file_preview.js');

OpenDrive::enqueueStyle('od_file_preview.css');
if ( isset($file->BWExceeded) && $file->BWExceeded == 1 && getValue('file_error') == '' && $file_type == 'image')
{
	$params = array('file_error' => __( 'Bandwidth limit has exceeded', 'opendrive' ));
	if($hide_header) $params['previewmode'] = 1;
	wp_redirect('/f/' . $file_id . '?' . http_build_query($params));
	exit;
}
$file_error = getValue('file_error');
$popupTitle = __('Download error', 'opendrive');
if( $file_error !== null ) header('Error', true, 403);
$previewErrorMessage = getValue('view_error');
$editorError = getValue('editor_error');

$msgSign = getValue('es');
if ($previewErrorMessage && $msgSign === md5($previewErrorMessage . ':' . wp_get_session_token())) {
	$fileErrorMessage = $previewErrorMessage;
	if($editorError) $popupTitle = __('Online Editor Error', 'opendrive');
}
if (!$editorError && !$file_error && $file_exists && !$is_password_protected && OpenDrive::getQueryValue('from_editor', null, false) !== null) {
	setcookie('File-pwd-' . $file_id, $entered_password, null, '/', null, true, true);
	wp_redirect('/e/' . $file_id);
	exit;
};
require_once('template-header.php');
?>
	<?php
	if($previewErrorMessage) OpenDrive::showPopupMessage('notification', $previewErrorMessage);
	elseif($fileErrorMessage != '') OpenDrive::showPopupMessage('error', $fileErrorMessage, $popupTitle);
	if ( $file_exists && $is_password_protected )
	{
		?>
		<div class="lightbox modal" id="password-protected">
			<div class="lightbox-overlay"></div>
			<div class="lightbox-container">
				<div class="lightbox-header">
					<h2><?php _e('File is Password Protected', 'opendrive')?></h2>
				</div>
				<form method="POST">
				<div class="lightbox-body">
						<input type="password" name="file_password" placeholder="<?php _e('Enter Password', 'opendrive')?>"><br>
						<div class="clearfix"></div>
				</div>
				<div class="lightbox-buttons">
					<input class="btn save-btn" type="submit" value="<?php _e('Get Access', 'opendrive')?>">
					<div class="clearfix"></div>
				</div>
				</form>
			</div>
		</div>

		<?php
	}

	?>
	<input type="hidden" id="preview-file-type" value="<?php esc_attr_e($file_type)?>">
	<input type="hidden" id="file_id" value="<?php esc_attr_e($file_id)?>">

	<div class="fill <?php if($hide_header):?>no-padding<?php endif;?>">
        <?php if ( !isset($hide_header) || isset($hide_header) && !$hide_header ):?>
		<div class="breadcrumb-and-buttons">
			<?php if(!$hide_header):?>
				<div class="buttons">
					<?php
					if ( !$is_private && !$is_password_protected && $file_exists )
					{
						?>
						<i class="fa fa-info info-btn" title="File Info"></i>

						<?php
						if ( $file_type == 'image' )
						{
							?>
							<i class="fa fa-repeat rotate-right-btn rotate-btn" title="<?php _e('Rotate Right', 'opendrive')?>"></i>
							<i class="fa fa-undo rotate-left-btn rotate-btn" title="<?php _e('Rotate Left', 'opendrive')?>"></i>
							<?php
						}
						?>
						<i class="fa fa-share-alt share-btn" title="<?php _e('Share', 'opendrive')?>"></i>

						<?php
						if ( $editable )
						{
							?>
							<a class="fa fa-pencil" title="<?php _e('Edit', 'opendrive')?>" href="/e/<?php esc_attr_e($file_id)?>"></a>

							<?php

						}
						?>
						<a class="fa fa-download" href="<?php esc_attr_e(file_download_link($file_id, $full_folder_id, $entered_password)); ?>"></a>
						<?php
					}
					?>
				</div>
			<?php endif;?>
			<h2>
			<a href="#" title="<?php esc_attr_e( $file_name )?>">
			<?php
			if ( $file_exists )
			{
				if($is_private) echo __('Private', 'opendrive');
				else if ( $is_password_protected ) echo __('File is Password Protected', 'opendrive');
				else esc_html_e($file_name);
			}
			else
			{
				if ( $file_exists_message != '' )
				{
					esc_html_e($file_exists_message);
				}
				else
				{
					echo __('File not found', 'opendrive');
				}
			}
			?>
			</a>
			<?php
			if ( $file_exists )
			{
				?><i>
				<?php
				if ( $file->Version != '' )
				{
					?> (<?php _e('Ver.', 'opendrive')?> <?php echo  $file->Version?>) |<?php
				}
				?>
				<?php echo ' '.$file_size?> | </i><?php
				if ( $is_private )
				{
					?><?php _e('File is private and cannot be displayed', 'opendrive')?><?php
				}
				elseif ( $is_password_protected )
				{
					?><?php _e('Enter Password to Get Access', 'opendrive')?><?php
				}
				else
				{
					?><?php esc_html_e(sprintf(__('Created %s by %s', 'opendrive'), $file_created, $file_username)) ?><?php
				}
			}
			?></h2>
			<div class="clearfix"></div>
		</div>
        <?php endif;?>

		<div class="files-container <?php if($file_type =='pdf') echo 'pdf';?>" id="file-preview">
			<div class="file-content">
				<?php
				if ( !$is_private && !$is_password_protected && $file_exists )
				{
					if ( $file_type == 'image' )
					{
						?>
						<img class="image-preview" rotation="0" <?php if(is_object($downloadInfo) && isset($downloadInfo->error)) { echo 'oncontextmenu="return false;"'; } ?> src="<?php esc_attr_e(file_download_link($file_id, $full_folder_id, $entered_password, true))?>">
						<img class="image-preloading" src="<?php echo wp_make_link_relative(plugins_url('/opendrive/images/loading-bar.gif'))?>">
						<?php
					}
					elseif ( $file_type == 'video' )
					{
						?>
						<iframe class="video-player" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true" src="/player/<?php esc_attr_e($file_id);
						echo $folder_query_params ?>"></iframe>
						<?php
					}
					elseif ( $file_type == 'pdf' && !$file_error && $file->Size < 200 * 1048576)
					{
						?>
						<iframe class="pdf-viewer" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true" src="/pdf_viewer/<?php echo rawurlencode($file_id); echo $folder_query_params?>"></iframe>
						<?php
					}
					else
					{
						$image_icon = plugin_dir_path( __FILE__ ).'../images/icons/256px/'. sanitize_file_name($file_ext).'.png';

						if ( !file_exists($image_icon) )
						{
							$image_icon = wp_make_link_relative(plugins_url('/opendrive/images/icons/256px/uknown-doc.png'));
						}
						else
						{
							$image_icon = wp_make_link_relative(plugins_url('/opendrive/images/icons/256px/'.$file_ext.'.png'));
						}
						?>
						<img src="<?php esc_attr_e($image_icon)?>" class="file_icon">
						<?php
						if ( $file_type == 'audio' )
						{
							?>
							<iframe class="audio-player" src="/player/<?php esc_attr_e($file_id); echo $folder_query_params;?>"></iframe>
							<?php
						}
					}
					?>
					<div class="file-info">
						<i class="fa fa-info"></i>
						<h3><?php esc_html_e($file_name)?></h3>
						<p><?php esc_html_e($file_description)?></p>
						<div class="col-md-4 text-left no-padding">
							<?php _e('Size', 'opendrive')?>: <b><?php esc_html_e($file_size)?></b>
						</div>
						<div class="col-md-4 text-center no-padding">
							<?php _e('Created', 'opendrive')?>: <b><?php echo esc_html($file_created).' '.__('by', 'opendrive') . ' '. esc_html($file_username)?></b>
						</div>
						<div class="col-md-4 text-right no-padding">
							<?php _e('Downloads', 'opendrive')?>: <b><?php esc_html_e($file_downloads)?></b>
						</div>
					</div>
					<div class="file-share">
						<i class="fa fa-share-alt"></i>
						<h3><?php _e('Share file', 'opendrive')?></h3>
						<?php _e('File link (URL)', 'opendrive')?>: <input type="text" id="file_link" readonly value="<?php esc_attr_e(str_replace('/d/', '/f/', $file->Link))?>">
						<a href="#" class="copy-clipboard-btn"><?php _e('Copy link to clipboard', 'opendrive')?></a>
					</div>
					<?php
				}
				else
				{
					$image_icon = wp_make_link_relative(plugins_url('/opendrive/images/icons/256px/uknown-doc.png'));
					?><img src="<?php esc_attr_e($image_icon);?>" class="file_icon"><?php
				}
				?>
			</div>
		</div>

		<?php if(!$hide_header):?>
		<div class="col-md-12 file-footer">
		<?php endif;?>

		</div>
	</div>


<?php require_once('template-footer.php')?>