<?php
if (!defined('ABSPATH')) exit;

$sidebar_visible = isset($_COOKIE['od_sidebar_visible']) ? intval($_COOKIE['od_sidebar_visible']) : 1;

require_once('template-functions.php');

$user_info = OpenDrive::i()->getUserInfo();
if (!$user_info) OpenDrive::redirectToLoginPage();

$view_mode = (isset($_COOKIE['view_mode']) && $_COOKIE['view_mode'] != '') ? trim($_COOKIE['view_mode']) : 'grid';


$selected_folder = (get_query_var('folder')) ? get_query_var('folder') : 0;
$search_folder_id = null;
$searchterm = (get_query_var('searchterm')) ? urldecode(get_query_var('searchterm')) : 0;

$root_content = OpenDrive::i()->apiClient()->get_folder_content(0, null, true);
$root_folders = empty($root_content->Folders) ? array() : $root_content->Folders;
$selected_root_folder = false;
$breadcrumb = false;
$is_trash = false;
$is_search = false;
$is_root_folder = false;
$sharedUsers = array();
$selected_folder_sharing_id = null;
if (strpos($selected_folder, '-') > 0) {
    list($selected_folder_sharing_id, $selected_folder) = explode('-', $selected_folder);
}
if (!$user_info->AccessUserID) {
    $sharingInfo = OpenDrive::i()->apiClient()->list_shared_users();
    if (!OpenDrive::i()->apiClient()->error) $sharedUsers = isset($sharingInfo->SharedUsers) ? $sharingInfo->SharedUsers : array();
}


// redirect account users with no root folders to notes page
if ($user_info->AccessUserID > 0 && sizeof($root_folders) == 0) {
    wp_redirect('/notes');
    exit();
}

$folder_read_only_access = false;

// OD options
$od_enable_upload = OpenDrive::i()->getPluginSetting('od_enable_upload');
$od_enable_download = OpenDrive::i()->getPluginSetting('od_enable_download');
$od_create_folders = OpenDrive::i()->getPluginSetting('od_create_folders');
$od_create_txt = OpenDrive::i()->getPluginSetting('od_create_txt');
$od_create_doc = OpenDrive::i()->getPluginSetting('od_create_doc');
$od_create_xls = OpenDrive::i()->getPluginSetting('od_create_xls');
$od_create_ppt = OpenDrive::i()->getPluginSetting('od_create_ppt');
$od_files_versioning = OpenDrive::i()->getPluginSetting('od_versioning_enabled');


if (isset($user_info->FVersioning)) $od_files_versioning = $od_files_versioning && $user_info->FVersioning;

if ($selected_folder !== 0) {
    if ($selected_folder == 'trash') {
        if ($user_info->AccessUserID && $user_info->AdminMode != 1) {
            OpenDrive::redirectToFiles();
        }
        $page_title = __('Trash', 'opendrive');
        $is_trash = true;
        $is_root_folder = false;
    } elseif ($selected_folder == 'search') {
        $page_title = __('Search Results', 'opendrive');
        $is_root_folder = false;
        $is_search = true;
    } else {
        $is_root_folder = false;
        $breadcrumb = OpenDrive::i()->apiClient()->folder_breadcrumb($selected_folder, $selected_folder_sharing_id, true);
        $last_breadcrumb = null;
        if (!OpenDrive::i()->apiClient()->error && is_array($breadcrumb)) {
            $last_breadcrumb = end($breadcrumb);
            $page_title = $last_breadcrumb->Name;
            if (isset($breadcrumb[0])) {
                $selected_root_folder = $breadcrumb[0]->FolderID;
            }
        }
    }
} else {
    $is_root_folder = true;
    $folders = $root_folders;
}
$SelectedFolderName = '';
if($is_search) $SelectedFolderName = __('Search', 'opendrive');
elseif($is_trash) $SelectedFolderName = __('Trash', 'opendrive');
elseif($selected_folder && !$is_trash && !$is_search) {
    $folderInfo = OpenDrive::i()->apiClient()->get_folder($selected_folder);
    if(!OpenDrive::i()->apiClient()->error) $SelectedFolderName = $folderInfo->Name;
}
if($selected_folder === 0) $SelectedFolderName = OpenDrive::i()->getDriveName();
$initData = array(
    'SelectedFolder' => $selected_folder_sharing_id ? $selected_folder_sharing_id . '-' . $selected_folder : $selected_folder,
    'SelectedFolderName' => $SelectedFolderName,
    'UploadEnabled' => (bool)$od_enable_upload,
    'DownloadEnabled' => (bool)$od_enable_download,
    'CreateFolders' => (bool)$od_create_folders,
    'CreateTXT' => (bool)$od_create_txt,
    'CreateDOC' => (bool)$od_create_doc,
    'CreateXLS' => (bool)$od_create_xls,
    'CreatePPT' => (bool)$od_create_ppt,
    'ViewMode' => $view_mode,
    'FileVersioning' => (bool)$od_files_versioning,
    'DriveName' => OpenDrive::i()->getDriveName(),
    'SessionToken' => OpenDrive::i()->sessionToken(),
    'SessionId' => OpenDrive::i()->apiClient()->get_od_session_id(),
    'Shared' => 0,
    'EndPoint' => OpenDrive::i()->apiClient()->resumable_upload_url(),
    'ZipEndPoint' => OpenDrive::i()->apiClient()->zipDownloadUrl()
);

OpenDrive::enqueueScript(array(
    'od/files/root_menu.js',
    'od/files/lightboxes.js',
    'od/files/files.js' => '1.0.0',
    'jquery.lazyload.od.js',
));

OpenDrive::enqueueStyle(array(
    'vendor/jquery-ui-1.11.4.custom/jquery-ui.min.css' => '1.11.4',
    'od_files_tabs.css'
));

function appendChildMenu($breadcrumb, $level)
{
    ob_start();
    ?>
    <ul class="child-dir od-font-color js-child-dir" <?php if (count($breadcrumb) > $level + 1): ?> data-folders-loaded="1"<?php endif; ?>>
        <?php if (count($breadcrumb) > $level): ?>
            <?php foreach ($breadcrumb[$level]->SubFolders as $folder):
                $isCurrentPath = ($level + 1) < count($breadcrumb) && $folder->FolderID == $breadcrumb[$level + 1]->FolderID;
                $activeItem = $level + 2 >= count($breadcrumb) && $isCurrentPath;
                ?>
                <li class="folder-item dropdown
                <?php if ($level + 2 < count($breadcrumb) && $isCurrentPath) echo 'expanded-folder' ?>
                <?php if ($folder->ChildFolders): ?>has-child<?php endif; ?>
                <?php if ($isCurrentPath): ?>active<?php endif; ?>"
                    id="folder-<?php esc_attr_e($folder->FolderID) ?>"
                    data-directlink="<?php esc_attr_e($folder->Link) ?>">
                    <?php if ($folder->ChildFolders): ?>
                        <i class="fa fa-caret-down expand-folder od-font-color<?php if ($activeItem) echo '-active' ?>
				od-font-color-hover js-expand-folder" role="button" aria-label="Collapse Folder"></i>
                        <i class="fa fa-caret-right expand-folder od-font-color<?php if ($activeItem) echo '-active' ?>
				od-font-color-hover js-expand-folder" role="button" aria-label="Expand Folder"></i>
                    <?php endif; ?>
                    <a class="od-font-color od-font-color-hover ellipsis_overflow js-folder-link droppable"
                       href="/files/<?php esc_attr_e($folder->FolderID) ?>">
                        <i class="fa fa-folder pull-left" aria-hidden="true"></i>
                        <i class="fa fa-folder-open pull-left" aria-hidden="true"></i>

                        <span class="js-folder-name"><?php esc_html_e($folder->Name) ?></span>
                    </a>
                    <?php if ($isCurrentPath): ?>
                        <?php echo appendChildMenu($breadcrumb, ++$level); ?>
                    <?php else: ?>
                        <ul class="child-dir od-font-color js-child-dir"></ul>
                    <?php endif; ?>
                    <i class="fa fa-bars js-open-folder-menu" aria-label="<?php _e('Open Folder Menu', 'opendrive') ?>"
                       role="button" aria-haspopup="true" aria-expanded="false"></i>
                </li>
            <?php endforeach; ?>
        <?php endif; ?>
    </ul>
    <?php
    return ob_get_clean();
}

function getRootFolders($root_folders, $selected_folder, $selected_root_folder, $breadcrumb, $shared_users)
{
    $isAccountOwner = false;
    $user_info = OpenDrive::i()->getUserInfo();
    if ($user_info) {
        $isAccountOwner = ($user_info->AccessUserID == 0);
    }
    $sub_menu_items = '';

    foreach ($root_folders as $one_folder) {
        $isSelectedFolder = $one_folder->FolderID === $selected_folder || $one_folder->FolderID === $selected_root_folder;
        $class = $isSelectedFolder ? 'active ' : '';
        $colorClass = $isSelectedFolder ? '' : 'od-font-color';
        if ($isSelectedFolder && count($breadcrumb) > 1) $class .= 'expanded-folder';

        if ($one_folder->ChildFolders) $class .= ' has-child';
        $folder_name_attr_html = esc_attr($one_folder->Name);

        $sub_menu_items .= '<li class="' . $class .
            ' item folder-item js-root-item dropdown " id="folder-' . $one_folder->FolderID . '" data-directlink="' . esc_attr($one_folder->Link) . '" data-access="' . esc_attr($one_folder->Access) . '">';

        if ($one_folder->ChildFolders)
            $sub_menu_items .= '<i class="fa fa-caret-down expand-folder ' . $colorClass . ' od-font-color-hover js-expand-folder" role="button" aria-label="' . __('Collapse Folder', 'opendrive') . '"></i><i class="fa fa-caret-right ' . $colorClass . ' od-font-color-hover expand-folder js-expand-folder" role="button" aria-label="' . __('Expand Folder', 'opendrive') . '"></i>';

        $sub_menu_items .= '<a href="/files/' . $one_folder->FolderID . '" class="js-root-folder od_root_folders droppable" title="' . $folder_name_attr_html . '">';
        $sub_menu_items .= '<i class="fa fa-folder" aria-hidden="true"></i><i class="fa fa-folder-open" aria-hidden="true"></i>';
        $sub_menu_items .= '<span class="folder-name ellipsis_overflow js-folder-name">';
        $sub_menu_items .= esc_html($one_folder->Name);
        $sub_menu_items .= '</span></a><i class="fa fa-bars js-item-menu-btn dropdown-toggle" data-toggle="dropdown" aria-label="' . __('Open Folder Menu', 'opendrive') . '" role="button" aria-haspopup="true" aria-expanded="false"></i>';

        $sub_menu_items .= '<ul class="folder-menu dropdown-menu dropdown-menu-right">';
        $sub_menu_items .= '<li><a href="/files/' . $one_folder->FolderID . '">' . __('Open', 'opendrive') . '</a></li>';
        //$sub_menu_items .= '<li><a href="#">' . __('Download Shortcut', 'opendrive') . '</a></li>';

        if ($isAccountOwner)
            $sub_menu_items .= '<li><a href="#" class="js-context-move-link">' . __('Move', 'opendrive') . '</a></li>';

        $sub_menu_items .= '<li><a href="#" class="js-context-copy-link">' . __('Copy', 'opendrive') . '</a></li>';

        if ($isAccountOwner)
            $sub_menu_items .= '<li><a href="#" class="js-context-properties-link">' . __('Properties', 'opendrive') . '</a></li>';

        $sub_menu_items .= '<li><a href="#" class="js-context-links-link">' . __('Links', 'opendrive') . '</a></li>
                             <li><a href="#" class="js-context-expiring-links-link">' . __('Expiring Links', 'opendrive') . '</a></li>
							<!--<li><a href="#">' . __('Request Files', 'opendrive') . '</a></li>-->
							<li><a href="#" class="js-context-send-by-email">' . __('Send by Email', 'opendrive') . '</a></li>';

        if ($isAccountOwner)
            $sub_menu_items .= '<li><a href="#" class="js-context-trash-link orange-text">' . __('Trash', 'opendrive') . '</a></li>';

        $sub_menu_items .= '</ul>';

        if ($isSelectedFolder)
            $sub_menu_items .= appendChildMenu($breadcrumb, 0);
        else
            $sub_menu_items .= appendChildMenu(array(), 1);

        $sub_menu_items .= '</li>';
    }
    $class = $selected_folder == 'shared' ? 'active' : '';
    $colorClass = $selected_folder == 'shared' ? '' : 'od-font-color';

    if ($shared_users) {
        $sub_menu_items .=
            '<li class="' . $class . ' has-child item folder-item js-root-item dropdown " id="folder-shared_users">
                <i class="fa fa-caret-down expand-folder ' . $colorClass .
            ' od-font-color-hover js-expand-folder" role="button" aria-label="' . __('Collapse Folder', 'opendrive') .
            '"></i><i class="fa fa-caret-right ' . $colorClass . ' od-font-color-hover expand-folder js-expand-folder" role="button" aria-label="' . __('Expand Folder', 'opendrive') . '"></i><a href="/files/shared_users" class="js-root-folder od_root_folders" title="'
            . __('Shared Folders', 'opendrive') . '">
            <i class="fa fa-folder" aria-hidden="true"></i><i class="fa fa-folder-open" aria-hidden="true"></i>
            <span class="folder-name ellipsis_overflow">' . __('Shared Folders', 'opendrive') . '</span></a>
            <ul class="child-dir od-font-color js-child-dir"></ul></li>';
    }
    return $sub_menu_items;
}

$root_folders_html = getRootFolders($root_folders,$selected_folder, $selected_root_folder, $breadcrumb, $sharedUsers);

require_once('template-header.php');
?>
<?php require_once('template-lightboxes.php'); ?>

<script id="js-init-data" type="x-text/plain"><?php echo json_encode($initData) ?></script>
<div class="fill">

    <?php echo od_get_sidebar(array(
        'root_folders_html'         => $root_folders_html,
        'selected_folder'      => $selected_folder,
        'trash_info'           => null
    )); ?>

    <div class="breadcrumb-and-buttons js-breadcrumbs-container"></div>
    <div class="tabs-container">
        <div class="scroll-content js-scroll-content"></div>
    </div>
</div>
<?php
require_once 'items/upload.php';
require_once 'items/tabs.php';
require_once 'items/files/file-templates.php';
require_once 'template-footer.php';
