<?php
/*
*Template Name: Forgot
*/
if (!defined('ABSPATH')) exit;

$new_password_set = false;
$error = false;
$error_message = '';
$error_array = array();
if ( OpenDrive::postValue('action') == 'od_forgot' )
{
	if (wp_verify_nonce(OpenDrive::postValue('_wpnonce', null, false), 'forgot_pass_csrf') !== 1) {
		wp_redirect(site_url('/forgot'));
		exit;
	}
	$forgot_username = OpenDrive::postValue('login_username', null, false);
	$reset_result = OpenDrive::i()->apiClient()->password_restore($forgot_username);
	if ( !$reset_result )
	{
		$error = true;
		$error_message = OpenDrive::i()->apiClient()->error_message;
		if ( $error_message == '') $error_message = 'Invalid username.';
	}
	else
	{
		$new_password_set = true;
		$notification_message = __("Check your inbox for new password.\nIf you do not receive an email, please check your junk or spam folder.", 'opendrive');
	}
}

$forgotCode = OpenDrive::getQueryValue('reset_code', null, false);
$continueFlag = OpenDrive::getQueryValue('continue');
$resetError = false;
$resetResult = null;
if ($forgotCode !== null) {
	if (!$continueFlag) {
		OpenDrive::i()->logout();
		wp_redirect(site_url('/forgot?' . http_build_query(array('reset_code' => $forgotCode, 'continue' => 1))));
		exit;
	}
	$resetResult = OpenDrive::i()->apiClient()->password_restore(null, $forgotCode);
	if (OpenDrive::i()->apiClient()->error) {
		$error = true;
		$error_message = __('The restore password link has expired, please try again', 'opendrive');
	} else {
		OpenDrive::i()->apiClient()->set_od_session_id($resetResult->SessionID);
		OpenDrive::i()->setUserSessionCookie($resetResult->SessionID);
	}
	OpenDrive::enqueueScript(array('od_common.js', 'od_forgot_pass.js'));
}

?>
<?php require_once('template-header-simple.php')?>
	<div id="login-content">
				<div class="col-md-4 col-sm-0">&nbsp;</div>
				<div class="col-md-4 col-md-12 form-col">
					<div id="login-form-container">
						<?php if($forgotCode !== null && $continueFlag && !$error):?>
							<form autocomplete="off" action="/forgot" id="login-form" method="POST" class="<?php if (!empty($error_array)) echo 'error-form'?>">
								<input type="hidden" name="action" value="forgot-change-password">
								<div class="row">
									<div class="col-md-2 col-sm-1 col-xs-1">&nbsp;</div>
									<div class="col-md-8 col-sm-10 col-xs-10">

										<a href="/"><img src="<?php echo $logo_url ?>" alt="<?php esc_attr_e($drive_name) ?>"></a>

										<h5><?php _e('Welcome back', 'opendrive')?>, <strong><?php esc_html_e($resetResult->FullName) ?></strong></h5>

										<div><?php _e('This is your new password', 'opendrive')?></div>
										<input autocomplete="off" type="text" readonly name="temp_password" value="<?php esc_attr_e($resetResult->NewPassword)?>"><br>

										<div><?php _e('Please enter your new password', 'opendrive')?>:</div>
										<input autocomplete="off" type="password" placeholder="<?php _e('New password', 'opendrive')?>" name="password" value=""><br>

										<div><?php _e('Please confirm your new password', 'opendrive')?>:</div>
										<input autocomplete="off" type="password" placeholder="<?php _e('Confirm new password', 'opendrive')?>" name="confirm_password" value=""><br>

										<div class="row text-center">
											<div class="col-md-7 col-sm-12"><a href="#" class="btn btn-primary js-change-pass"><?php _e('Change password', 'opendrive')?></a></div>
											<div class="col-md-5 col-sm-12"><a href="/files" class="btn btn-secondary"><?php _e('Go to My Account', 'opendrive')?></a></div>
										</div>
									</div>
									<div class="col-md-3 col-sm-1 col-xs-1">&nbsp;</div>
								</div>
							</form>
						<?php else:?>
							<form action="/forgot" id="login-form" method="POST" class="<?php if (!empty($error_array)) echo 'error-form'?>">
								<?php
								wp_nonce_field('forgot_pass_csrf', '_wpnonce', false);
								if ($error )
								{
									?>
									<div class="warning">
										<a href="#" class="close-warning fa fa-times"></a>
										<h2><i class="fa fa-exclamation-circle"></i><?php _e('Warning', 'opendrive')?></h2>
										<span><?php esc_html_e($error_message); ?></span>
									</div>
									<?php
								}
								elseif ( $new_password_set )
								{
									?>
									<div class="warning">
										<a href="#" class="close-warning fa fa-times"></a>
										<h2 class="notification"><i class="fa fa-info-circle"></i><?php _e('Notification', 'opendrive')?></h2>
										<span><?php echo $notification_message; ?></span>
									</div>
									<?php
								}
								?>
								<div class="row">
									<div class="col-md-2 col-sm-1 col-xs-1">&nbsp;</div>
									<div class="col-md-8 col-sm-10 col-xs-10">
										<a href="<?php bloginfo('url'); ?>"><img src="<?php echo $logo_url?>" alt="<?php bloginfo('name'); ?>"></a>

										<input type="text" name="login_username" id="login_username" placeholder="<?php _e('Email', 'opendrive')?>"><br>
										<input type="hidden" name="action" value="od_forgot">
										<span class="note"><?php _e('A new password will be sent to your email address.', 'opendrive')?></span>
										<br>
										<input type="submit" value="<?php _e('Email Password', 'opendrive')?>" class="btn btn-primary col-md-7 col-sm-12">
										<a href="/login"class="btn btn-secondary col-md-4 col-sm-12 pull-right"><?php _e('Login', 'opendrive')?></a>
									</div>
									<div class="col-md-3 col-sm-1 col-xs-1">&nbsp;</div>
								</div>
							</form>
						<?php endif;?>
					</div>
				</div>
				<div class="col-md-4 col-sm-0">&nbsp;</div>
	</div>

<?php require_once('template-footer.php')?>