<?php
if (!defined('ABSPATH')) exit;

function convert_to_user_date($date, $format = 'n/j/Y g:i A', $userTimeZone = 'America/Los_Angeles', $serverTimeZone = 'GMT')
{
	try {
		$dateTime = new DateTime ($date, new DateTimeZone($serverTimeZone));
		$dateTime->setTimezone(new DateTimeZone($userTimeZone));
		return $dateTime->format($format);
	} catch (Exception $e) {
		return $e->getMessage();
	}
}

function truncFileName($filename, $max_length = 20, $is_dir = false)
{
	mb_internal_encoding("UTF-8");
	$cut_end_length = 10;
	if ( $max_length <=25 ) $cut_end_length = 5;

	if ( mb_strlen($filename) > $max_length )
	{
		$fileinfo = pathinfo($filename);
		if ( isset($fileinfo['extension']) && !$is_dir )
		{
			$length = mb_strlen($fileinfo['extension']);
			$trunc_name1 = mb_substr($filename, 0, $max_length - $length - 3 - $cut_end_length );
			$trunc_name2 = mb_substr($filename, (-1 * ($length + $cut_end_length)) );
			$trunc_name = $trunc_name1.'...'.$trunc_name2;
		}
		else
		{
			$trunc_name = mb_substr($filename, 0, $max_length - 3 );
			$trunc_name = $trunc_name.'...';
		}
	}
	else
	{
		$trunc_name = $filename;
	}

	return $trunc_name;
}

function truncText($text, $max_length = 20)
{
	mb_internal_encoding("UTF-8");

	if ( mb_strlen($text) > $max_length )
	{
		$trunc_text = mb_substr($text, 0, $max_length - 3 );
		$trunc_text = $trunc_text.'...';
	}
	else
	{
		$trunc_text = $text;
	}

	return $trunc_text;
}

function prettyUsedSize($size, $precision = 0, $return_array = false, $basis_limit = null)
{
	$size_types = array(
		__('Bytes', 'opendrive'), __('KB', 'opendrive'), __('MB', 'opendrive'), __('GB', 'opendrive'),
		__('TB', 'opendrive'), __('PB', 'opendrive'), __('EB', 'opendrive'), __('ZB', 'opendrive'),
		__('YB', 'opendrive'));
	$i = $size ? floor(log($size, 1024)) : 0;
	$multiplier = 1;
	if ($basis_limit !== null && $i > $basis_limit) {
		$multiplier = pow(1024, $i - $basis_limit - 1);
		$i = $basis_limit;
	}
	$result_size = round($size / pow(1024, $i), $precision) * $multiplier;
	$result_unit = $size_types[$i];

	return $return_array ? array('value' => $result_size, 'units' => $result_unit) : $result_size . ' ' . $result_unit;
}

function od_size_format($size, $unl = false, $decimals = 0)
{
	$size = floatval($size);
	if ( $size == 0 )	return '0 B';
	elseif ( $size >= 1125899906842624 && $unl ) return __('UNL', 'opendrive');
	else
	{
		$result = size_format($size, $decimals);
		return $result;
	}
}

if (!function_exists('od_get_user_permission_name'))
{
	function od_get_user_permission_name($permission_id = "", $access_user_id = null)
	{
		if($permission_id === '')
		{
			$permission_id = 1;
		}
		switch( $permission_id )
		{
			case 0:
				$result = __('Users', 'opendrive');
				break;
			case 1:
				$result = $access_user_id ? __('Admin', 'opendrive') : __('Owner', 'opendrive');
				break;
			case 2:
				$result = __('Basic', 'opendrive');
				break;
			default:
				$result = __('Unknown', 'opendrive');
		}
		return $result;
	}
}

function od_get_sidebar($params = array())
{
	global $wp;
	$od_page = OpenDrive::i()->getODPage();

	$od_user_settings = OpenDrive::i()->getPluginSetting(null, true);

	$is_mobile = wp_is_mobile();

	$sidebar_visible = isset($_COOKIE['od_sidebar_visible']) ? intval($_COOKIE['od_sidebar_visible']) : !$is_mobile;

	$permission_id = 2;
	$isAccountOwner = false;
	$user_info = OpenDrive::i()->getUserInfo();
    if(preg_match("/^[A-Za-z0-9]+\.opendrive\.com$/",$_SERVER['HTTP_HOST']) || $_SERVER['HTTP_HOST'] === 'sandbox.opendrive.com' || $_SERVER['HTTP_HOST'] === 'opendrive.local') {
        if ($user_info->PopUp == 0) {
            OpenDrive::showPopupMessage(
                'notification',
                __('To get started with creating backup and sync tasks, click on the Apps icon on the left side bar. User guides will help you get set up easily and quickly.'), 'Welcome to OpenDrive');
            OpenDrive::i()->apiClient()->update_popUp($user_info->UserID, $user_info->AccessUserID);
        }
    }
	if($user_info)
	{
		$permission_id = $user_info->AdminMode;
		$isAccountOwner = ($user_info->AccessUserID == 0);
	}

	$query_vars = $wp->query_vars;
	$od_subpage = (isset($query_vars['od_subpage'])) ? $query_vars['od_subpage'] : '';

	$menu = '';

	$menu .= '<div class="sidebar hidden-anonymous">';
	$menu .= '<div class="pages-buttons">';

	$items = '';

	$items = apply_filters('od_sidebar_menu_prepend_item', $items, $permission_id, $isAccountOwner);

	if($user_info && !$user_info->Suspended ) {
		$appendFilesMenuItem = false;
		if ( $user_info->AccessUserID > 0 ) {
			$root_content = OpenDrive::i()->apiClient()->get_folder_content(0);
			$root_folders = empty($root_content->Folders) ? array() : $root_content->Folders;
			if (sizeof($root_folders) > 0) {
				$appendFilesMenuItem = true;
			}
		}
		else
		{
			$appendFilesMenuItem = true;
		}
		if($appendFilesMenuItem) {
			$items .= '<a href="/files" class="fa fa-hdd-o' . ($od_page == 'files' ? ' active' : '') . '" title="' . __('Files', 'opendrive') . '" aria-label="' . __('Files', 'opendrive') . '"></a>';
		}

		if ( $od_user_settings['od_enable_notes'] == 'true' || $od_user_settings['od_enable_notes'] == '1' )
		{
			$items .= '<a href="/notes" class="fa fa-sticky-note-o' . ($od_page == 'notes' ? ' active' : '') . '" title="' . __('Notes', 'opendrive') . '" aria-label="' . __('Notes', 'opendrive') . '"></a>';
		}

		if ( OpenDrive::i()->hasTasksAccess() )
		{
			$addTasksMenuItem = false;
			if ( $user_info->AccessUserID > 0 ) {
				$projectLists = OpenDrive::i()->apiClient()->tasks_get_project_lists(true);

				if (!OpenDrive::i()->apiClient()->error && sizeof($projectLists) )
					$addTasksMenuItem = true;;
			}
			else
			{
				$addTasksMenuItem = true;
			}

			if($addTasksMenuItem)
				$items .= '<a href="/tasks" class="fa fa-tasks' . ($od_page == 'tasks' ? ' active' : '') . '" title="' . __('Tasks', 'opendrive') . '" aria-label="' . __('Tasks', 'opendrive') . '"></a>';
		}

	}
	if($permission_id < 2 && (!isset($user_info->Suspended) || !$user_info->Suspended) &&
		($od_user_settings['od_enable_account_users'] == 'true' || $od_user_settings['od_enable_account_users'] == 1)
	)
	{
		$items .= '<a href="/users" class="fa fa-users'.($od_page=='users'?' active':'').'" title="' . __('Users', 'opendrive') . '" aria-label="' . __('Users', 'opendrive') . '"></a>';
	}

    if(preg_match("/^[A-Za-z0-9]+\.opendrive\.com$/",$_SERVER['HTTP_HOST']) || $_SERVER['HTTP_HOST'] === 'sandbox.opendrive.com' || $_SERVER['HTTP_HOST'] === 'opendrive.local') {
    	if($user_info->PopUp == 0)
	        $items .= '<a href="/opendrive-apps" style="font-size: 30px; background-color:#337AB7"  class="fa fa-tablet" title="' . __('OpenDrive Apps', 'opendrive') . '" aria-label="' . __('OpenDrive Apps', 'opendrive') . '"></a>';
	    else
        	$items .= '<a href="/opendrive-apps" style="font-size: 30px;"  class="fa fa-tablet" title="' . __('OpenDrive Apps', 'opendrive') . '" aria-label="' . __('OpenDrive Apps', 'opendrive') . '"></a>';
    }

	$items .= '<div class="bottom-aligned">';
	if(!isset($user_info->Suspended) || !$user_info->Suspended) {
		$items .= '<a href="/settings" class="fa fa-cog' . (($od_page == 'settings' || $od_page == 'billing' || $od_page == 'free')? ' active' : '') . '" title="' . __('Settings', 'opendrive') . '" aria-label="' . __('Settings', 'opendrive') . '"></a>';
	}
	$items .= '<a href="/support-center" target="_blank" class="fa fa-life-ring" title="' . __('Support', 'opendrive') . '" aria-label="' . __('Support', 'opendrive') . '"></a>';

	if( $user_info && ($user_info->IsPartner >= 2 || ($user_info->AccessUserID && $user_info->AccessAdminLevel >= 90)) ) {
		$items .= '<a href="/admin" class="fa fa-user-secret' . ($od_page == 'admin' ? ' active' : '') . '" title="Admin" aria-label="' . __('Admin', 'opendrive') . '"></a>';
	}

	$items .= '</div>';

	//append items
	$items = apply_filters('od_sidebar_menu_append_item', $items, $permission_id, $isAccountOwner);

	$menu .= $items;
	$menu .= '</div>';
	$menu .= '</div>';


	$menu_wrapper_class = '';
	switch($od_page)
	{
		case 'users':
		case 'useraffiliates':
			$menu_wrapper_class = 'usergroups';
			break;
		case 'notes':
			$menu_wrapper_class = 'notepads';
			break;
		case 'tasks':
			$menu_wrapper_class = 'tasks';
			break;
		case 'desktop':
		{
			$result = $menu;
			return $result;
		}
	}


	$sub_menu = '<div class="dirs js-left-sidebar '.$menu_wrapper_class.'" '.($sidebar_visible==0?'style="display: none;"':'').'>';

	if( in_array($od_page, array('tasks', 'files', 'notes', 'users')) || ($od_page == 'admin' && in_array($od_subpage, array('users', 'useraffiliates')) ) ) {
		$placeholder = $od_page;
		if($od_page == 'admin') $placeholder = __('Users', 'opendrive');
		$titles = array('admin' => __('Enter User ID, E-mail, Username, First/Last Name, File/Folder ID or Last 4 digits of CC', 'opendrive'));
		$sub_menu .=
			'<div class="items-search-container">
			<input type="text" class="search-field js-item-search-field" placeholder="' . __('Search', 'opendrive') . ' ' .
			ucfirst($placeholder) .'"
			title="' .
			(isset($titles[$od_page]) ? $titles[$od_page] : '') .'"
			>
        	<i class="fa fa-search search-icon js-item-search-icon"></i>
		</div>';
	}

	$sub_menu .= '<ul class="root-menu js-root-menu" aria-label="' . __('Root Menu', 'opendrive') . '"><li class="root js-first-menu-item first-menu-item">';

	$root_item = '';
	$sub_menu_items = '';

	$sub_menu_items = apply_filters('od_sidebar_submenu_prepend_item', $sub_menu_items, $permission_id, $isAccountOwner);
	switch($od_page)
	{
		case 'settings':
			add_filter('od_sidebar_submenu_root_item', function () {
				return '<a href="' . wp_make_link_relative(site_url('settings')) . '" class="root-dir">' . __('Settings', 'opendrive') . '</a>';
			});
			ob_start();
			require_once('template-settingsgroups.php');
			$sub_menu_items .= ob_get_contents();
			ob_end_clean();

			break;

		case 'admin':
			add_filter('od_sidebar_submenu_root_item', function () {
				return '<a href="' . wp_make_link_relative(site_url('admin')) . '" class="root-dir">' . __('Admin', 'opendrive') . '</a>';
			});
			ob_start();
			require_once 'items/admin/sub_menu_tabs.php';
			$sub_menu_items .= ob_get_clean();

			break;
		case 'notes':
			$is_trash = ( isset($params['is_trash']) ) ? $params['is_trash'] : false;
			$is_archive = ( isset($params['is_archive']) ) ? $params['is_archive'] : false;

			add_filter('od_sidebar_submenu_root_item', function() use ($is_trash, $is_archive){

				if ( $is_trash )
				{
					return '<a href="' . wp_make_link_relative(site_url('notes/trash')) . '" class="root-dir">' . __('Trash', 'opendrive') . '</a>';
				}
				elseif ( $is_archive )
				{
					return '<a href="' . wp_make_link_relative(site_url('notes/archive')) . '" class="root-dir">' . __('Archive', 'opendrive') . '</a>';
				}
				else
				{
					return '<a href="'.wp_make_link_relative(site_url('notes')).'" class="root-dir">'.__('Notes', 'opendrive').'</a><a href="#" title="' . __('Create Notepad', 'opendrive') . '" class="fa fa-plus root-plus-btn" id="new-notpad-btn" role="button" aria-label="' . __('Create Notepad', 'opendrive') . '"></a>';
				}

			});
			ob_start();
			require_once('items/menu/notepads.php');
			$sub_menu_items .= ob_get_clean();

			break;
		case 'tasks':
			add_filter('od_sidebar_submenu_root_item', function () {
				$user_info = OpenDrive::i()->getUserInfo();
				$isAdmin = $user_info && !$user_info->AccessUserID;
				return
					'<a href="/tasks" class="root-dir root-dir-tasks">' . __('Tasks', 'opendrive') . '</a>' .
					($isAdmin ? '<a href="#" title="' . __('Create Project List', 'opendrive') . '" class="fa fa-plus js-new-project-list root-plus-btn" role="button" aria-label="' . __('Create Project List', 'opendrive') . '"></a>' : '') .
					'<a href="/tasks/archive" class="root-dir root-dir-archive">' . __('Archive', 'opendrive') . '</a>' .
					'<a href="/tasks/trash" class="root-dir root-dir-trash">' . __('Trash', 'opendrive') . '</a>';
			});
			ob_start();
			require_once('items/menu/tasks.php');
			$sub_menu_items .= ob_get_clean();

			break;
		case 'users':
			$usergroups = $params['usergroups'];
			$selected_group = $params['selected_group'];
			$total_account_users = $params['total_account_users'];


			add_filter('od_sidebar_submenu_root_item', function() use($user_info){
				$html = '<a href="/users" class="root-dir">'.__('Account Users', 'opendrive').'</a>';
				if ( $user_info->AccessUserID == 0 || ( $user_info->AccessUserID > 0 && $user_info->AdminMode == 1 ))
				{
					$html .= '<a href="#" role="button" aria-label="' . __('Create User Group', 'opendrive') . '" title="' . __('Create User Group', 'opendrive') . '" class="fa fa-plus create-group-btn root-plus-btn"></a>';
				}

				return $html;
			});

			if ( sizeof($usergroups) > 0 )
			{
				foreach ( $usergroups as $one_group )
				{
					$class = ( intval($one_group->GroupID) ==  intval($selected_group) ) ? ' active' : '';
					$total_account_users += $one_group->NumUsers;

					if ( $one_group->NumUsers == 0 ) $class .= ' empty-group';

					$sub_menu_items .= '<li id="group-'.$one_group->GroupID.'" class="item droppable group-item'.$class.' dropdown">';
					$sub_menu_items .= '<a href="'.wp_make_link_relative(site_url('users/'.$one_group->GroupID)).'">';
					$sub_menu_items .= '<i class="fa fa-users js-users-icon" aria-hidden="true"></i>';
					$sub_menu_items .= '<div class="group-name js-folder-name" title="' . esc_attr($one_group->GroupName.' ('.$one_group->NumUsers.')') .'">';
					$sub_menu_items .= "<div class=\"pull-right js-users-count\">&nbsp;({$one_group->NumUsers})</div>";
					$sub_menu_items .= '<div class="js-group-name ellipsis_overflow">';
					$sub_menu_items .= esc_html($one_group->GroupName);
					$sub_menu_items .= '</div>';
					$sub_menu_items .= '<div class="clearfix"></div>';
					$sub_menu_items .= '</div>';
					$sub_menu_items .= '</a>';

					if ( $permission_id == 1 )
					{
						$sub_menu_items .= '<i class="fa fa-refresh fa-spin loading-icon" aria-hidden="true"></i>';
						$sub_menu_items .= '<i class="fa fa-bars js-item-menu-btn dropdown-toggle" data-toggle="dropdown" aria-label="' . __('Open group menu', 'opendrive') . '" role="button"></i>';
						$sub_menu_items .= '<ul class="menu group-menu dropdown-menu dropdown-menu-right">';
						$sub_menu_items .= '<li><a href="' . wp_make_link_relative(site_url('/users/' . $one_group->GroupID)) . '">' . __('Open', 'opendrive') . '</a></li>';
						$sub_menu_items .= '<li><a href="#" class="contex-group-edit-link">'.__('Edit', 'opendrive').'</a></li>';
						$sub_menu_items .= '<li><a href="#" class="context-group-delete-link orange-text">'.__('Delete', 'opendrive').'</a></li>';
						$sub_menu_items .= '</ul>';
					}
					$sub_menu_items .= '</li>';
				}
			}
			break;

		case 'files':
			$root_folders_html = $params['root_folders_html'];
			$trash_info = $params['trash_info'];
			$selected_folder = $params['selected_folder'];

			//root item of sub menu
			if ( $user_info->AccessUserID > 0 )
			{
				add_filter('od_sidebar_submenu_root_item', function () use ($selected_folder) {
					$html = '<a href="/files" class="root-dir js-root-dir ellipsis_overflow droppable">' . esc_html(OpenDrive::i()->getDriveName()) . '</a><a href="#" title="' . __('Create Folder', 'opendrive') . '" role="button" aria-label="' . __('Create Folder', 'opendrive') . '" class="fa fa-plus root-plus-btn js-create-subfolder"></a>';
					return $html;
				});
			}
			else
			{
				add_filter('od_sidebar_submenu_root_item', function () use($user_info) {
					return
						'<a href="/files" class="root-dir js-root-dir ellipsis_overflow droppable">' . esc_html(OpenDrive::i()->getDriveName()) . '</a>
							<a href="#" title="' . __('Create Folder', 'opendrive') . '" role="button" aria-label="' . __('Create Folder', 'opendrive') . '" class="fa fa-plus root-plus-btn js-create-subfolder"></a>
							<i data-toggle="dropdown" class="fa fa-bars js-item-menu-btn dropdown-toggle" aria-label="' . __('Open Drive Menu', 'opendrive') . '" role="button" aria-haspopup="true" aria-expanded="false"></i>
							<ul class="folder-menu dropdown-menu dropdown-menu-right">
								<li><a href="/files">' . __('Open', 'opendrive') . '</a></li>
								<li><a class="js-context-folder-create-link" href="#">' . __('New Folder', 'opendrive') . '</a></li>
								' .
						($user_info->AccType == 2 ? '<li><a class="contex-root-rename-link" href="/settings/branding">' . __('Rename Drive', 'opendrive') . '</a></li>' : '') .
						'<li><a href="/files/export_csv" title="' . __('Export file list to CSV', 'opendrive') . '">' . __('Export CSV', 'opendrive') . '</a></li>
						<!-- <li><a href="#" class="js-open-shared-folders" title="' . __('Shared Folders', 'opendrive') . '">' . __('Shared Folders', 'opendrive') . '</a></li> -->
								</ul>';
				});
			}

			$sub_menu_items .= $root_folders_html;
			break;
	}

	//append items
	$sub_menu_items = apply_filters('od_sidebar_submenu_append_item', $sub_menu_items, $permission_id, $isAccountOwner);

	$sub_menu .= apply_filters('od_sidebar_submenu_root_item', $root_item);
	$sub_menu .= '<div class="clearfix"></div>';
	$sub_menu .= '</li><li><ul class="folders-in-root items-container js-root-menu-items">';

	$sub_menu .= $sub_menu_items;
	$sub_menu .= '</ul></li></ul>';


	if($od_page=='files') {
		$sub_menu .= '<div class="clearfix"></div>';

		if ($isAccountOwner || $user_info && $user_info->AccessUserID && $user_info->AdminMode == 1) {
			$sub_menu .= '<div class="bottom-aligned js-bottom-panel-actions"><div class="trash droppable">';
			$sub_menu .= '<a href="' . wp_make_link_relative(site_url('files/trash')) . '" class="trash-btn js-trash-btn"><i class="fa fa-trash-o" aria-hidden="true"></i>' . __('Trash', 'opendrive') . '<br>';
			$sub_menu .= '<span class="trash-items"><span class="js-trash-items-counter">0 </span> ' . __('items', 'opendrive') . '</span></a>';


			$sub_menu .= '<a href="#" id="trash-clear-btn" class="trash-clear js-trash-clear-btn">' . __('Empty', 'opendrive') . '</a>';
			$sub_menu .= '<div class="clearfix"></div></div>';
			$sub_menu .= '</div>';
		}
	}
	elseif ( $od_page == 'notes' )
	{
		$trash_info = $params['trash_info'];
		$trash_count = sizeof($trash_info->Notepads) + sizeof($trash_info->Notelists);

		$sub_menu .= '<div class="clearfix"></div>';
		$sub_menu .= '<div class="bottom-aligned js-bottom-panel-actions"><div class="trash droppable">';
		$sub_menu .= '<a href="' . wp_make_link_relative(site_url('notes/archive')) . '" class="archive-btn"><i class="fa fa-archive" aria-hidden="true"></i>' . __('Archive', 'opendrive') .'</a>';
		$sub_menu .= '<div class="clearfix"></div>';
		$sub_menu .= '<a href="' . wp_make_link_relative(site_url('notes/trash')) . '" class="trash-btn js-trash-btn"><i class="fa fa-trash-o" aria-hidden="true"></i>' . __('Trash', 'opendrive') . '<br>';
		$sub_menu .= '<span class="trash-items"><span class="js-trash-items-counter">'.intval($trash_count).'</span> ' . __('items', 'opendrive') . '</span></a>';
		$sub_menu .= '<a href="#" id="trash-clear-btn" class="trash-clear js-trash-clear-btn">' . __('Empty', 'opendrive') . '</a>';
		$sub_menu .= '<div class="clearfix"></div></div>';
		$sub_menu .= '</div>';
		
	}
	elseif ( $od_page == 'tasks' )
	{
		$trash_count = 0;
		$isAnonymous = !$user_info;
		$sub_menu .= '<div class="clearfix"></div>';
		if(!$isAnonymous && $user_info && !$user_info->AccessUserID) $sub_menu .=
				'<div class="bottom-aligned js-bottom-panel-actions">
					<div class="trash droppable">
					<a href="/tasks/archive" class="archive-btn">
						<i class="fa fa-archive" aria-hidden="true"></i>
						' . __('Archive', 'opendrive') . '
					</a>
					<div class="clearfix"></div>
					<a href="/tasks/trash" class="trash-btn js-trash-btn"><i class="fa fa-trash-o" aria-hidden="true"></i>' . __('Trash', 'opendrive') . '
						<br>
						<span class="trash-items js-trash-items-count">' . $trash_count . ' ' . __('items', 'opendrive') . '</span>
					</a>
					<a href="#" id="trash-clear-btn" class="trash-clear js-trash-clear-btn">' . __('Empty', 'opendrive') . '<i class="fa fa-refresh rotate-fast-animation" aria-hidden="true"></i></a>
					<div class="clearfix"></div>
				</div>
				</div>';
	}

	$sub_menu .= '</div>';

	$result = $menu . $sub_menu;

	return $result;
}

function file_download_link($fileId, $folder_id = '', $passw = false, $preview = false )
{
	if($preview)
		$url = '/s/' . $fileId;
	else
		$url = '/download/' . $fileId;
	if ( $passw !== false )
	{
		$url .= '/'. rawurlencode(base64_encode($passw));
	}
	$params = array();
	if ($preview) $params['preview'] = 1;
	if ($folder_id) $params['folder_id'] = $folder_id;
	return $url . '?' . http_build_query($params);
}

function format_space($level, $value)
{
	return $level > 9 ? __('Unlimited', 'opendrive') : size_format($value);
}

function getValue($key, $default = null, $sanitize = true, $maxLength = 0)
{
	return call_user_func_array(array('OpenDrive', 'getValue'), func_get_args());
}

function getArrayValue($key, $default = array(), $sanitize = true)
{
	if (array_key_exists($key, $_GET) && is_array($_GET[$key])) {
		$data = wp_unslash($_GET[$key]);
		if ($sanitize)
		foreach ($data as &$value) $value = sanitize_text_field($value);
		return $data;
	}
	return $default;
}

function postValue($key, $default = null, $sanitize = true, $maxLength = 0)
{
	return call_user_func_array(array('OpenDrive', 'postValue'), func_get_args());
}

function postArrayValue($key, $default = array(), $sanitize = true)
{
	return call_user_func_array(array('OpenDrive', 'postArrayValue'), func_get_args());
}

function od_time_ago($tm, $rcs = 0) {
   $cur_tm = time(); $dif = $cur_tm-$tm;
	$pds = array(
		__('second', 'opendrive'), __('minute', 'opendrive'), __('hour', 'opendrive'), __('day', 'opendrive'),
		__('week', 'opendrive'), __('month', 'opendrive'), __('year', 'opendrive'), __('decade', 'opendrive')
	);
   $lngh = array(1,60,3600,86400,604800,2630880,31570560,315705600);
   for($v = sizeof($lngh)-1; ($v >= 0)&&(($no = $dif/$lngh[$v])<=1); $v--); if($v < 0) $v = 0; $_tm = $cur_tm-($dif%$lngh[$v]);

   $no = floor($no); if($no <> 1) $pds[$v] .='s'; $x=sprintf("%d %s ",$no,$pds[$v]);
   if(($rcs == 1)&&($v >= 1)&&(($cur_tm-$_tm) > 0)) $x .= od_time_ago($_tm);
   return $x;
}

function od_days_diff($target_date, $negative_class = false, $return_diff_only = false, $return_text = false)
{
	$user_tz = get_option('timezone_string');
	if ($user_tz == '') $user_tz = 'America/Los_Angeles';
	$tz = new DateTimeZone($user_tz);
	if (is_int($target_date) || ctype_digit($target_date)) {
		$target_date_time = (new DateTime('now', new DateTimeZone('UTC')))->setTimestamp($target_date);
	}
	else {
		$target_date_time = new DateTime($target_date, $tz);
	}

	$today = (new DateTime('now', $tz))->setTime(0, 0, 0);
	$interval = $today->diff( $target_date_time );
	$days_diff = $interval->format('%a');
	if ( $interval->invert ) $days_diff *= -1;
	$str = '';
	$custom_class = '';
	if ( $days_diff == 0 )
	{
		$str = __('Today', 'opendrive');
		$custom_class = 'today-date';
	}
	elseif ( $days_diff == 1 )
	{
		$str = __('Tomorrow', 'opendrive');
		$custom_class = 'tomorrow-date';
	}
	elseif ( $days_diff == -1 )
	{
		$str = __('Yesterday', 'opendrive');
		$custom_class = 'yesterday-date';
	}
	elseif ( $days_diff < -1 )
	{
		$str = abs($days_diff) . __(' days ago', 'opendrive');
		$custom_class = 'in-past-date';
	}
	elseif ( $days_diff > 1 )
	{
		$str = sprintf(__('In %s days', 'opendrive'), abs($days_diff));
		$custom_class = 'in-future-date';
	}
	if ( $return_diff_only )
	{
		return $days_diff;
	} elseif ($return_text) {
		return $str;
	}
	else
	{
		$class = ( $negative_class && $days_diff <= 0 ) ? $negative_class : '';
		return '<span class="'.$class. ' ' . $custom_class . '">' .$str.'</span>';
	}


}