<?php
if (!defined('ABSPATH')) exit;

$userInfo = OpenDrive::i()->getUserInfo();
$od_page = OpenDrive::i()->getODPage();
if ( in_array($od_page, OpenDrive::i()->getConfigItem('login_protected_pages')) )
{
	if ( !$userInfo )
	{
		OpenDrive::redirectToLoginPage();
	}
}

if($userInfo && isset($_SERVER['HTTP_HOST']) && property_exists($userInfo, 'BrandingSubdomain') &&
	property_exists($userInfo, 'PartnerUsersDomain') && $userInfo->PartnerUsersDomain != '') {
	$scheme = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') ? 'https' : 'http';
	$url = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '/files';
	if( $userInfo->BrandingSubdomain != '' &&
		$userInfo->BrandingSubdomain . $userInfo->PartnerUsersDomain != $_SERVER['HTTP_HOST']) {
		wp_redirect( $scheme . '://' . $userInfo->BrandingSubdomain . $userInfo->PartnerUsersDomain . $url );
		exit;
	}

	if($userInfo->BrandingSubdomain == '' && strpos($_SERVER['HTTP_HOST'], $userInfo->PartnerUsersDomain) > 0) {
		$siteUrl = get_option( 'siteurl' );
		if($siteUrl != '') {
			$urlData = parse_url($siteUrl);
			if(!empty($urlData['host']) && strtolower($urlData['host'] != $_SERVER['HTTP_HOST'])) {
				wp_redirect(site_url($url));
				exit;
			}
		}
	}
}

$fav_icon = OpenDrive::i()->getPluginSetting('od_favicon_path');
if ( $fav_icon == '' ) $fav_icon = wp_make_link_relative(plugins_url('/opendrive/images/favicon.ico'));
$fav_icon_encoded = false;

$logo_url = OpenDrive::i()->getPluginSetting('od_logo_path');
if ( $logo_url == '' ) $logo_url = wp_make_link_relative(plugins_url('/opendrive/images/dark-od-logo.png'));

$drive_name = OpenDrive::i()->getDriveName();

$brandingColors = null;
$brandingColorsVars = array();

if(isset($branding_user_id) && $branding_user_id) {
	if(isset($BrandingMenuBgColor) && isset($BrandingMenuFontColor)){
		if($BrandingMenuBgColor != '' || $BrandingMenuFontColor != '') {
			$partnerSettings = OpenDrive::i()->partnerSettings();
			if($BrandingMenuBgColor == '') {
				$BrandingMenuBgColor = str_replace('#', '', $partnerSettings['Colors']['od_scheme_background']);
			}
			if($BrandingMenuFontColor == '') {
				$BrandingMenuFontColor = str_replace('#', '', $partnerSettings['Colors']['od_font_color']);
			}
		}
		if($BrandingMenuBgColor != '') $brandingColorsVars['menu_color'] = $BrandingMenuBgColor;
		if($BrandingMenuFontColor != '') $brandingColorsVars['font_color'] = $BrandingMenuFontColor;
	}
	$user_branding = OpenDrive::i()->apiClient()->get_user_branding($branding_user_id);
	if(!OpenDrive::i()->apiClient()->error){
		if($user_branding->FavIcon != '') {
			$fav_icon = $user_branding->FavIcon;
			$fav_icon_encoded = true;
		}
		if ( trim($user_branding->DriveName) != '' ) $drive_name = $user_branding->DriveName;
		if ( $user_branding->Logo != '' ) $logo_url = $user_branding->Logo;
	}
} else if($userInfo && property_exists($userInfo, 'BrandingLogo') && property_exists($userInfo, 'BrandingFavIcon')){
	if($userInfo->BrandingLogo != '') $logo_url = $userInfo->BrandingLogo;
	if($userInfo->BrandingFavIcon != '') {
			$fav_icon = $userInfo->BrandingFavIcon;
			$fav_icon_encoded = true;
	}
	if(isset($userInfo->BrandingMenuFontColor) && isset($userInfo->BrandingMenuBgColor)){
		if (Opendrive::checkColor($userInfo->BrandingMenuFontColor)) $brandingColorsVars['menu_color'] = $userInfo->BrandingMenuBgColor;
		if (Opendrive::checkColor($userInfo->BrandingMenuBgColor)) $brandingColorsVars['font_color'] = $userInfo->BrandingMenuFontColor;
	}
}
if($brandingColorsVars) $brandingColors = '?' . http_build_query($brandingColorsVars);
OpenDrive::enqueueStyle('od_load_styles.php' . $brandingColors, true);
if ( isset($page_title) && $page_title != '' ) $page_title .= ' - ' . $drive_name;
else $page_title = $drive_name;
?>
<!DOCTYPE html>
<!--[if IE 7]>
<html class="ie ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html class="ie ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<title><?php esc_html_e($page_title); ?></title>
	<meta name="author" content="OpenDrive">
	<link rel="icon" href="<?php if($fav_icon_encoded) echo 'data:image/x-icon;base64,'; echo $fav_icon?>" type="image/x-icon"/>
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<link rel="dns-prefetch" href="<?php esc_attr_e(OpenDrive::i()->getAPIUrl())?>">
	<link rel="prefetch" type="application/l10n" href="<?php echo wp_make_link_relative(plugins_url('opendrive/lang/l10n/en_US.viewer.properties'))?>" />
	<?php wp_print_styles()?>
	<?php wp_print_head_scripts()?>
</head>

<body <?php if(!$userInfo):?>class="anonymous" <?php endif;?> data-drivename="<?php echo esc_attr($drive_name)?>" data-csrftoken="<?php echo OpenDrive::i()->createCSRFToken()?>">

<?php require_once 'items/popups.php';?>

	<div id="container" class="page-<?php esc_attr_e($od_page)?>">
		<?php if ( !isset($hide_header) || isset($hide_header) && !$hide_header )
		{
			?>
				<header>
	                 <a href="#" aria-label="Toggle the sidebar" role="button" class="sidebar-menu-hide js-sidebar-menu-hide hidden-anonymous"><i class="fa fa-bars" aria-hidden="true"></i></a>
	
					 <a class="navbar-brand" href="<?php echo home_url(); if ( isset($userInfo) && isset($userInfo->UserID) ) echo '/files';?>" title="<?php bloginfo('description'); ?>">
						<div class="logo" title="<?php bloginfo('name'); ?>" style="background-image: url('<?php echo $logo_url?>')"></div>                     
					 </a>	
					 <div class="col-offset-240">

						<?php
						if ( !empty($userInfo) && isset($userInfo->UserID) && $userInfo->UserID != 0 )
						{
							$full_name = $userInfo->UserFirstName.' '.$userInfo->UserLastName;
							if ( mb_strlen($full_name) > 15 )
							{
								$full_name = $userInfo->UserFirstName;
							}
							?>

							<div class="user-controls">
								 <div class="dropdown">
								    <a href="#" class="dropdown-toggle has-caret" id="user-controls-menu" data-toggle="dropdown"><?php echo esc_html($full_name)?></a>
									<ul class="dropdown-menu dropdown-menu-right" aria-labelledby="user-controls-menu">
										<li><a href="/settings"><?php _e('Settings', 'opendrive')?></a></li>
										<li><a class="js-logout" href="<?php echo wp_nonce_url('/logout', 'logout_csrf')?>"><?php _e('Log Out', 'opendrive')?></a></li>
									</ul>
								</div>
								<span class="role"><?php echo od_get_user_permission_name($userInfo->AdminMode, $userInfo->AccessUserID); ?></span>
							</div>
							<?php
							?>
							<div class="user-header-avatar">
								<?php
								 if ( $userInfo->Avatar != '' )
								 {
								 	?><div class="avatar-container" style="background-color: #<?php echo $userInfo->AvatarColor?>"><img src="<?php echo $userInfo->Avatar?>"></div><?php
								 }
								 else
								 {
								 	?><div class="avatar-container avatar-default" style="background-color: #<?php echo $userInfo->AvatarColor?>"><?php echo strtoupper(mb_substr($userInfo->UserFirstName,0, 1).mb_substr($userInfo->UserLastName,0, 1))?></div><?php
								 }
								 ?>
							</div>

							<?php do_action('od_extension_insert_item', 'free_space_link')?>

							<?php /*require 'items/bar-bw-space.php'*/?>

							<?php
						}
						?>

						<?php
						if(in_array($od_page, array('tasks', 'files', 'admin'))):?>
							<div class="item-tabs"><ul class="js-item-tabs"></ul></div>
						<?php endif;?>
					</div>
	
				</header>
			
			
			<?php
		}
		
		