<?php 
/*
*Template Name: Login
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');
$ref_url = '';
if ( isset($wp_query->query_vars['ref']) )
{
	$ref_url = urldecode($wp_query->query_vars['ref']);
	$ref_url = parse_url($ref_url, PHP_URL_PATH);
	$nonce = OpenDrive::getValue('s');
	if(!wp_verify_nonce($nonce, 'redirect_url' . $ref_url)) $ref_url = '';
}

$error = OpenDrive::requestValue('error');
if ($error == 'session-expired' && isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'GET') OpenDrive::deleteSessionCookie();

if (OpenDrive::hasSessionCookie()) {
	$existingSession = OpenDrive::i()->apiClient()->session_exists($_COOKIE[OpenDrive::userSessionCookieName]);
	if (is_object($existingSession) && isset($existingSession->result) && $existingSession->result) {
		wp_redirect($ref_url == '' ? '/files' : $ref_url);
		exit;
	} else
		OpenDrive::deleteSessionCookie();
}

$partner_settings = OpenDrive::i()->partnerSettings();
if ($partner_settings && isset($partner_settings['Domain']) && isset($_SERVER['HTTP_HOST'])) {
	$host = parse_url(strtolower($partner_settings['Domain']), PHP_URL_HOST);
	if($host === $_SERVER['HTTP_HOST'] && OpenDrive::getQueryValue('ref', null, false) === null) {
		OpenDrive::redirectToLoginPage();
	}
}

$error_codes = OpenDrive::i()->getConfigItem('login_errors');
$error = array_key_exists($error, $error_codes) ? $error_codes[$error] : null;
$error_array = (!empty($error)) ? array($error) : array();
$tmpSessionId = OpenDrive::getQueryValue('__sn');
if (ctype_digit($tmpSessionId)) {
	OpenDrive::i()->setUserSessionCookie($tmpSessionId);
	OpenDrive::redirectToFiles();
}

if ( postValue('action', null, false) == 'od_login' )
{
	$untrusted_origin = false;
	if(isset($_SERVER['HTTP_ORIGIN'])) {
		$site_url = parse_url(site_url(), PHP_URL_HOST);
		$origin_site_url = parse_url($_SERVER['HTTP_ORIGIN'], PHP_URL_HOST);
		$untrusted_origin = $site_url !== $origin_site_url;
	}

	if ($untrusted_origin || wp_verify_nonce(OpenDrive::requestValue('_wpnonce', null, false), 'login_csrf') !== 1) {
		wp_redirect(site_url('/login'));
		exit;
	}
	$od_username = trim(postValue('login_username', '', false));
	$od_password = postValue('login_password', '', false);
	$remember_me = trim(postValue('remember_me'));
	$captcha_response = postValue('captcha_response');
	if($od_username && $od_password){
		// auth sets session_id manually
		$result = OpenDrive::i()->apiClient()->auth($od_username,$od_password, OpenDrive::i()->plugin_version, $captcha_response );
		if(!OpenDrive::i()->apiClient()->error){
			OpenDrive::i()->setUserSessionCookie($result->SessionID, $remember_me == 'on', $result->PartnerUsersDomain);
			Opendrive::deleteAffiliateCookie();
			if($result->Enable2FA && !$result->IsAccountUser) {
                wp_redirect(site_url('/settings/authorize'));
                exit;
			}
			//redirect to zendesk if user comes from it
			$returnTo = OpenDrive::getQueryValue('return_to');
			if (strpos($returnTo, 'https://opendrive.zendesk.com/') === 0) {
				wp_redirect(OpenDrive::i()->getSupportURL($returnTo));
				exit;
			}

			if ( $ref_url != '' )
			{
				wp_redirect($ref_url);
			}
			else
			{
				if ($result->UserDomain != '') {
					wp_redirect('https://' . $result->UserDomain . ($ref_url == '' ? '/files' : $ref_url));
					exit;
				}
				wp_redirect( '/files' );
			}
			exit;
		}else{
			// api wrong username  or error
			$error_array[] = OpenDrive::i()->apiClient()->error_message;
			if (OpenDrive::i()->apiClient()->system_error) $error_array[] = __('Please try again later.', 'opendrive');

			if(isset($result->error->captcha_key))
				$captcha_key = $result->error->captcha_key;
		}

	}else{
		// input validation here
		$error_array[] = __('Empty username or password','opendrive');
	}
    if(!$remember_me && OpenDrive::hasSessionCookie()) OpenDrive::deleteSessionCookie();
}

?>
<?php require_once('template-header-simple.php') ?>
	<script type="text/javascript">
      var onloadCallback = function() {
        grecaptcha.render('g-recaptcha');
        document.getElementById('g-recaptcha-response').setAttribute('name', 'captcha_response')
       }
    </script>

	<div id="login-content">
				<div class="col-md-4 col-sm-0">&nbsp;</div>
				<div class="col-md-4 col-md-12 form-col">
					<div id="login-form-container">
						<form aria-label="Login Form" autocomplete="off" action="" id="login-form" method="POST" class="<?php if (!empty($error_array)) echo 'error-form'?>">
							<?php
							if (!empty($error_array))
							{
								$error_array = array_map('esc_attr', $error_array);
								$errorMessage = implode('<br>', $error_array);
								OpenDrive::showPopupMessage('error', $errorMessage, '', true);
							}
							?>
							<div class="row">
								<div class="col-md-2 col-sm-1 col-xs-1">&nbsp;</div>
								<div class="col-md-8 col-sm-10 col-xs-10">
									<a href="/"><img src="<?php esc_attr_e($logo_url)?>" alt="<?php esc_attr_e($drive_name); ?>"></a>
								
									<input autofocus type="text" name="login_username" id="login_username" placeholder="<?php _e('Email', 'opendrive')?>" required>
									<input type="password" name="login_password" id="login_password" placeholder="<?php _e('Password', 'opendrive')?>" required>
									<input type="hidden" name="action" value="od_login">

									<?php wp_nonce_field('login_csrf', '_wpnonce', false) ?>
							<?php
							if(isset($captcha_key))
							{ ?>
									<script src="https://www.google.com/recaptcha/api.js?hl=en&onload=onloadCallback&render=explicit" async defer></script><div id="g-recaptcha" data-sitekey="<?php echo $captcha_key; ?>"></div>
							<?php
							} ?>

									<input type="checkbox" class="nice-checkbox" id="remember_me" name="remember_me">
									<label for="remember_me">
										<i class="fa" aria-label="Remember me" role="checkbox" aria-checked="false"></i><?php _e('Remember me', 'opendrive')?></label>

									<span class="pull-right"><a href="/forgot"><?php _e('Forgot', 'opendrive')?>?</a></span><br>
									<br>
									<input type="submit" value="Login" class="btn btn-primary col-md-6 col-sm-12 col-xs-10 centered">
								</div>
								<div class="col-md-2 col-sm-1 col-xs-1">&nbsp;</div>
							</div>
						</form>
					</div>
				</div>
				<div class="col-md-4 col-sm-0">&nbsp;</div>
	</div>
<?php require_once('template-footer.php')?>
