<?php
/*
*Template Name: Notes
*/
if (!defined('ABSPATH')) exit;

$notelist_colors = array('color-default', 'color-yellow', 'color-red', 'color-green', 'color-blue');

$sidebar_visible = isset($_COOKIE['od_sidebar_visible']) ? intval($_COOKIE['od_sidebar_visible']) : 1;

require_once('template-functions.php');

$od_user_settings = OpenDrive::i()->getPluginSetting(null, true);
if ( $od_user_settings['od_enable_notes'] == 'false' || $od_user_settings['od_enable_notes'] == '0')
{
	OpenDrive::redirectToFiles();
}

$user_info = OpenDrive::i()->getUserInfo();

$view_mode = ( isset($_COOKIE['view_mode']) && $_COOKIE['view_mode'] != '' ) ? trim($_COOKIE['view_mode']) : 'grid';

$selected_notepad = ( get_query_var( 'notepad' ) ) ? get_query_var( 'notepad' ) : 0;


// get notepads for sidebar
$notepads = OpenDrive::i()->apiClient()->get_notepads();

$this_notepad = false;
$notelists = array();

if ( isset($notepads->error) )
{
	$error = true;
	$error_message = $notepads->error->message;
	$notepads = array();
}
if( $notepads === false )
{
	$notepads = array();
}

if ( $selected_notepad === 0 && sizeof($notepads) > 0 )
{
	$selected_notepad = $notepads[0]->NotepadId;
	wp_redirect('/notes/' . $selected_notepad);
	exit;
}

if ( sizeof($notepads) == 0 )
{
	$notice = __('Please create notepad first.', 'opendrive');
}

$is_trash = false;
$is_archive = false;

$trash_info = OpenDrive::i()->apiClient()->get_trashed_notelists_notepads();


if ( $selected_notepad === 'trash' )
{
	$is_trash = true;

	$trashed_notepad_id = ( get_query_var( 'notepad_id' ) ) ? get_query_var( 'notepad_id' ) : 0;

	$notepads = $trash_info->Notepads;
	if ( $trashed_notepad_id !== 0 )
	{
		$notelists = OpenDrive::i()->apiClient()->get_notelists_in_notepad($trashed_notepad_id);

		if ( sizeof($notepads) > 0 )
		{
			foreach ( $notepads as $one_notepad )
			{
				if ( $one_notepad->NotepadId === $trashed_notepad_id )
				{
					$this_notepad = $one_notepad;
					break;
				}
			}
		}
	}
	else
	{
		$notelists = $trash_info->Notelists;
	}
}
elseif ( $selected_notepad === 'archive' )
{
	$is_archive = true;

	$archive_info = OpenDrive::i()->apiClient()->get_archived_notelists_notepads();
	$archived_notepad_id = ( get_query_var( 'notepad_id' ) ) ? get_query_var( 'notepad_id' ) : 0;

	$notepads = $archive_info->Notepads;
	if ( $archived_notepad_id !== 0 )
	{
		$notelists = OpenDrive::i()->apiClient()->get_notelists_in_notepad($archived_notepad_id);

		if ( sizeof($notepads) > 0 )
		{
			foreach ( $notepads as $one_notepad )
			{
				if ( $one_notepad->NotepadId === $archived_notepad_id )
				{
					$this_notepad = $one_notepad;
					break;
				}
			}
		}
	}
	else
	{
		$notelists = $archive_info->Notelists;
	}
}
elseif ( $selected_notepad !== 0 ) {
	$notelists = OpenDrive::i()->apiClient()->get_notelists_in_notepad($selected_notepad);

	if ( sizeof($notepads) > 0 )
	{
		foreach ( $notepads as $one_notepad )
		{
			if ( $one_notepad->NotepadId == $selected_notepad )
			{
				$this_notepad = $one_notepad;
				break;
			}
		}
	}
	if (OpenDrive::i()->apiClient()->error) {
		wp_redirect('/notes');
		exit;
	}
}


if ( sizeof($notepads) > 0 && isset($this_notepad->Name) )
{
	$page_title = $this_notepad->Name;
}
else
{
	$page_title = '';
}

OpenDrive::enqueueScript(array(
	'vendor/linkify.js',
	'od_notes.js'
));

OpenDrive::enqueueStyle('od_notes.css');

require_once('template-header.php');
?>
<input type="hidden" name="notepad_id" id="notepad_id" value="<?php echo $selected_notepad; ?>">
<input type="hidden" name="api_session_id" id="api_session_id" value="<?php esc_attr_e(OpenDrive::i()->apiClient()->get_od_session_id()); ?>">
<input type="hidden" name="api_url" id="api_url" value="<?php esc_attr_e(OpenDrive::i()->getAPIUrl()) ?>">
<input type="hidden" name="upload_url" id="upload_url" value="<?php esc_attr_e(OpenDrive::i()->apiClient()->resumable_upload_url())?>">
<div class="fill notes-page">

	<?php
		$sidebar_params = array('notepads' => $notepads, 'selected_notepad' => $selected_notepad, 'trash_info' => $trash_info);
		if ( $is_trash )
		{
			$sidebar_params['is_trash'] = $is_trash;
			$sidebar_params['trashed_notepad_id'] = $trashed_notepad_id;
		}
		if ( $is_archive )
		{
			$sidebar_params['is_archive'] = $is_archive;
			$sidebar_params['archived_notepad_id'] = $archived_notepad_id;
		}


		echo od_get_sidebar($sidebar_params);
	?>

		<div class="breadcrumb-and-buttons">
			<?php
			if ( !$is_archive && !$is_trash )
			{
				?>
				<div class="buttons">
					<?php
					if ( $user_info->Level == 1)
					{
						?><?php echo sprintf(__('Basic account up to %u note lists', 'opendrive'), 5)?> - <a href="<?php echo apply_filters('od_extension_get_upgrade_link', '#')?>" ><?php _e('Upgrade to unlimited', 'opendrive')?></a>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<?php
					}
					?>

					<a href="#" class="br-btn" id="new-notelist-btn" title="<?php _e('Create Note', 'opendrive')?>"><i class="fa fa-plus" aria-hidden="true"></i><?php _e('New Note', 'opendrive')?></a>
				</div>
				<?php
			}
			?>
			<h2>
				<?php
				if ( $is_archive )
				{
					?>
					<span><a href="/notes/"><?php _e('Notes', 'opendrive')?></a>&nbsp;&nbsp;/</span>
					<a href="/notes/archive"><?php _e('Archive', 'opendrive')?></a>
					<?php
					if ( isset($this_notepad) && is_object($this_notepad) )
					{
						?>
						<span class="delimiter">/ </span>
						<a href="/notes/archive/<?php echo $this_notepad->NotepadId?>"><?php echo esc_html($this_notepad->Name)?></a>
						<?php
					}
				}
				else if ( $is_trash )
				{
					?>
					<span><a href="/notes/"><?php _e('Notes', 'opendrive')?></a>&nbsp;&nbsp;/</span>
					<a href="/notes/trash"><?php _e('Trash', 'opendrive')?></a>
					<?php
					if ( isset($this_notepad) && is_object($this_notepad) )
					{
						?>
						<span class="delimiter">/ </span>
						<a href="/notes/trash/<?php echo $this_notepad->NotepadId?>"><?php echo esc_html($this_notepad->Name)?></a>
						<?php
					}
				}
				else 
				{
					?>
					<span><a href="/notes"><?php _e('Notes', 'opendrive')?></a>&nbsp;&nbsp;/</span>
					<?php
					if ( isset($this_notepad) && is_object($this_notepad) )
					{
						?>
						<a href="/notes/<?php echo $this_notepad->NotepadId?>"><?php echo esc_html($this_notepad->Name)?></a>
						<?php
					}
					else
					{
						?>
						<ul class="dropdown">
							<li><?php _e('Notepad', 'opendrive')?></li>
						</ul>
						<?php
					}
				}
				?>
			 </h2>
		</div>
        <div class="notegroups-container <?php if ( $is_archive ) echo 'archive-container'?> <?php if ( $is_trash ) echo 'trash-container'?>">
        		<div class="scrollable gray-skin">
					<div class="notelist-container col-md-3 col-sm-6" id="standard-notelist">
						<div class="notelist-square">
							<div class="notelist-content">
								<div style="background-color: #f2f2f2" class="notelist single-note empty-list">
									<div class="notelist-head">
										<div class="background"></div>
										<div class="over-bg">
											<span class="notelist-title ellipsis_overflow"><?php _e('Note', 'opendrive')?> 1</span>
											<a title="<?php _e('Menu', 'opendrive')?>" class="fa fa-bars notelist-menu-btn" href="#" role="button" aria-label="<?php _e('Menu', 'opendrive')?>"></a>
											<a title="<?php _e('New List Item', 'opendrive')?>" class="fa fa-plus notelist-new-note-btn" href="#" role="button" aria-label="<?php _e('New List Item', 'opendrive')?>"></a>
											<a title="<?php _e('Cancel', 'opendrive')?>" class="fa fa-minus notelist-hide-new-note-btn" href="#" role="button" aria-label="<?php _e('Cancel', 'opendrive')?>"></a>
											<div class="notelist-buttons">
												<a title="<?php _e('Resize', 'opendrive')?>" class="fa fa-arrows-alt notelist-resize-btn" href="#" role="button" aria-label="<?php _e('Resize', 'opendrive')?>"></a>
												<a title="<?php _e('Delete', 'opendrive')?>" class="fa fa-trash-o notelist-trash-btn" href="#" role="button" aria-label="<?php _e('Delete', 'opendrive')?>"></a>
												<a title="<?php _e('Archive', 'opendrive')?>" class="fa fa-archive notelist-archive-btn" href="#" role="button" aria-label="<?php _e('Archive', 'opendrive')?>"></a>
												<a title="<?php _e('Upload', 'opendrive')?>" class="fa fa-upload notelist-upload-btn" href="#" role="button" aria-label="<?php _e('Upload', 'opendrive')?>"></a>
												<a title="<?php _e('Change Color', 'opendrive')?>" class="fa fa-paint-brush notelist-color-btn" href="#" role="button" aria-label="<?php _e('Change Color', 'opendrive')?>"></a>
											</div>
											<div class="new-note">
												<i class="fa fa-plus" aria-hidden="true"></i>
												<textarea placeholder="<?php _e('List Item', 'opendrive')?>" class="new-note-text"></textarea>
											</div>
										</div>
									</div>
									<div class="notes-container">
										<div class="notes-scrollable">
											<div class="new-single-note">
												<div class="new-single-note-text" contenteditable="true" placeholder="<?php _e('Write Note', 'opendrive')?>..."></div>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
        		
        			<?php
        			if ( sizeof($notelists) > 0 )
        			{
        				foreach ( $notelists as $one_notelist )
        				{
        					if ( $one_notelist->Size == 2 )
        					{
        						$cols_classes = 'col-md-6 col-sm-12';
        						$shape_class = 'rect-h';
        					}
        					elseif ( $one_notelist->Size == 4 )
        					{
        						$cols_classes = 'col-md-6 col-sm-12';
        						$shape_class = 'square';
        					}
        					else
        					{
        						$cols_classes = 'col-md-3 col-sm-6';
        						$shape_class = 'square';
        					}
        					
        					$notes = OpenDrive::i()->apiClient()->get_notes('notelist', $one_notelist->NoteListId);

							$single_note_class = ( sizeof($notes) <= 1 ) ? 'single-note' : '';
							$empty_list_class = ( sizeof($notes) == 0 ) ? 'empty-list' : '';

        					?>
        					<div class="notelist-container <?php echo $cols_classes?>"> 
			        			<div class="notelist-<?php echo $shape_class?>">
				        			<div class="notelist-content">
				        				<div class="notelist <?php echo $single_note_class?> <?php echo $empty_list_class?>" <?php if ( $one_notelist->Color != '' ) { ?> style="background-color: #<?php echo $one_notelist->Color?>" <?php } ?> data-notelistid="<?php echo $one_notelist->NoteListId?>" data-notelistorder="<?php echo $one_notelist->Order?>">
				        					<div class="notelist-head">
				        						<div class="background"></div>
				        						<div class="over-bg">
					        						<span class="notelist-title ellipsis_overflow"><?php echo esc_html($one_notelist->Name)?></span>
													<?php
													if ( $is_archive )
													{
														?>
															<a href="#" class="fa fa-trash-o notelist-trash-btn" title="<?php _e('Trash', 'opendrive')?>"></a>
														<?php
													}
													else if ( $is_trash )
													{
														if ( $trashed_notepad_id === 0 )
														{
															?><a href="#" class="fa fa-undo notelist-restore-btn" title="<?php _e('Restore', 'opendrive')?>"></a><?php
														}
														?>
														<a href="#" class="fa fa-trash-o notelist-remove-btn" title="<?php _e('Remove', 'opendrive')?>"></a>
														<?php
													}
													else
													{
														?>
															<a href="#" class="fa fa-bars notelist-menu-btn" title="<?php _e('Menu', 'opendrive')?>" role="button" aria-label="<?php _e('Menu', 'opendrive')?>"></a>
															<a href="#" class="fa fa-plus notelist-new-note-btn" title="<?php _e('New List Item', 'opendrive')?>" role="button" aria-label="<?php _e('New List Item', 'opendrive')?>"></a>
															<a title="<?php _e('Cancel', 'opendrive')?>" class="fa fa-minus notelist-hide-new-note-btn" href="#" role="button" aria-label="<?php _e('Cancel', 'opendrive')?>"></a>
															<div class="notelist-buttons">
																<a href="#" class="fa fa-arrows-alt notelist-resize-btn" title="<?php _e('Resize', 'opendrive')?>" role="button" aria-label="<?php _e('Resize', 'opendrive')?>"></a>
																<a href="#" class="fa fa-trash-o notelist-trash-btn" title="<?php _e('Trash', 'opendrive')?>" role="button" aria-label="<?php _e('Trash', 'opendrive')?>"></a>
																<a href="#" class="fa fa-archive notelist-archive-btn" title="<?php _e('Archive', 'opendrive')?>" role="button" aria-label="<?php _e('Archive', 'opendrive')?>"></a>
																<a href="#" class="fa fa-upload notelist-upload-btn" title="<?php _e('Upload', 'opendrive')?>" role="button" aria-label="<?php _e('Upload', 'opendrive')?>"></a>
																<a href="#" class="fa fa-paint-brush notelist-color-btn" title="<?php _e('Change Color', 'opendrive')?>" role="button" aria-label="<?php _e('Change Color', 'opendrive')?>"></a>
															</div>
														<?php
													}
													?>
						        					<div class="new-note">
														<i class="fa fa-plus"></i>
						        						<textarea class="new-note-text" placeholder="<?php _e('List Item', 'opendrive')?>"></textarea>
						        					</div>
					        					</div>
				        					</div>
				        					<div class="notes-container">
				        						<div class="notes-scrollable">
													<?php if (!$is_archive && !$is_trash): ?>
													<div class="new-single-note">
														<div class="new-single-note-text" contenteditable="true" placeholder="<?php _e('Write Note', 'opendrive')?>..."></div>
													</div>
													<?php
													endif;
					        						if ( sizeof($notes) > 0 )
					        						{
					        							foreach ($notes as $one_note) {
															$checked_class = '';
															if ($one_note->Status == 'done')
															{
																$checked_class = 'checked';
															}
					        								?>
					        								<div class="one-note drop-file <?php echo $checked_class?>" data-noteid="<?php echo $one_note->NoteId?>">
																<i class="checkmark fa fa-square-o"></i>
																<i class="checkmark fa fa-check-square-o"></i>
					        									<div class="note-hover">
					        										<span class="note-time-ago"><?php echo od_time_ago($one_note->Created)?> ago</span>
					        										<div class="note-buttons">
					        											<a href="#" class="fa fa-remove one-note-delete" title="<?php _e('Delete', 'opendrive')?>" role="button" aria-label="<?php _e('Delete the note', 'opendrive')?>"></a>
					        										</div>
					        									</div>
					        									<div class="one-note-text"><?php
																	if ( isset($one_note->ThumbLink) && $one_note->ThumbLink != '' )
																	{
																		?><a href="<?php echo $one_note->FileLink?>" target="_blank"><img class="note-thumb" src="<?php echo $one_note->ThumbLink?>"></a><?php
																	}
																	?>
																	<div class="one-note-text-editable"
																		<?php if (!$is_archive && !$is_trash): ?>
																		 contenteditable="true" placeholder="<?php _e('Write Note', 'opendrive')?>..."
																		<?php endif;?>
																		><?php echo $one_note->Text;?></div>
																</div>
					        								</div>
					        								<?php
					        							}
					        						}
					        						?>
				        						</div>
				        					</div>
				        				</div>
				        			</div>
			        			</div>
			        		</div>
        					<?php
        				}
        			}
					else
					{
						if ( !$is_trash && !$is_archive )
						{
							?>
							<div class="notelist-container col-md-3 col-sm-6" id="ghost-notelist">
								<div class="notelist-square">
									<div class="notelist-content">
										<div style="background-color: #f2f2f2" class="notelist single-note empty-list">
											<div class="notelist-head">
												<div class="background"></div>
												<div class="over-bg">
													<span class="notelist-title ellipsis_overflow">New Note</span>
													<a title="Menu" class="fa fa-bars notelist-menu-btn" href="#"></a>
													<a title="New List Item" class="fa fa-plus notelist-new-note-btn" href="#"></a>
													<a title="Cancel" class="fa fa-minus notelist-hide-new-note-btn" href="#"></a>
													<div class="notelist-buttons">
														<a title="Resize" class="fa fa-arrows-alt notelist-resize-btn" href="#"></a>
														<a title="Delete" class="fa fa-trash-o notelist-trash-btn" href="#"></a>
														<a title="Archive" class="fa fa-archive notelist-archive-btn" href="#"></a>
														<a title="Upload" class="fa fa-upload notelist-upload-btn" href="#"></a>
														<a title="Change Color" class="fa fa-paint-brush notelist-color-btn" href="#"></a>
													</div>
													<div class="new-note">
														<i class="fa fa-plus"></i>
														<textarea placeholder="List Item" class="new-note-text"></textarea>
													</div>
												</div>
											</div>
											<div class="notes-container">
												<div class="notes-scrollable">
													<div class="new-single-note">
														<div class="new-single-note-text" contenteditable="true" placeholder="Write Note..."></div>
													</div>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
							<?php
						}
					}

        			?>
					<div class="clearfix"></div>

        		</div>
		</div>


	<script type="text/x-handlebars-template" data-name="SearchResults">
		<ul class="od-font-color">
			{{#if NoResults}}
			<li><?php _e('No results found', 'opendrive')?></li>
			{{else}}
			{{#each Notepads}}
			<li class="clearfix">
				<a href="/notes/{{NotepadId}}">
					<div class="item-icon"><i class="fa fa-sticky-note"></i></div>
					<div class="ellipsis_overflow search-result">{{Name}}</div>
				</a>
			</li>
			{{/each}}
			{{#each Notes}}
			<li class="clearfix">
				<a href="/notes/{{NotepadId}}">
					<div class="item-icon"><i class="fa fa-sticky-note-o"></i></div>
					<div class="ellipsis_overflow search-result">{{NoteText}}</div>
				</a>
			</li>
			{{/each}}
			{{/if}}
		</ul>
	</script>

	<script type="text/x-handlebars-template" data-name="NotepadMenuItem">
		<li id="notepad-{{NotepadId}}" data-notepadid="{{NotepadId}}" class="active item notepad-item dropdown droppable ui-droppable">
			<a title="{{NotepadName}}" class="od_root_notepads" href="/notes/{{NotepadId}}">
				<i class="fa fa-sticky-note"></i>
				<span class="pull-left notepad-name ellipsis_overflow">{{NotepadName}}</span>
				<div class="pull-left js-notelists-count">&nbsp;(1)</div>
				<div class="clearfix"></div>
			</a>
			<i data-toggle="dropdown" class="fa fa-bars js-item-menu-btn dropdown-toggle" aria-label="<?php _e('Open Notepad Menu', 'opendrive')?>" role="button" aria-haspopup="true" aria-expanded="false"></i>
			<i class="fa fa-refresh fa-spin loading-icon"></i>
			<ul class="notepad-menu dropdown-menu dropdown-menu-right">
				<li><a class="contex-notepad-rename" href="#"><?php _e('Rename', 'opendrive')?></a></li>
				<li><a class="contex-notepad-achive" href="#"><?php _e('Archive', 'opendrive')?></a></li>
				<li><a class="context-notepad-trash orange-text" href="#"><?php _e('Trash', 'opendrive')?></a></li>
			</ul>
		</li>
	</script>

	<script type="text/x-handlebars-template" data-name="NewNote">
		<div class="one-note drop-file"><i class="checkmark fa fa-square-o"></i>
			<i class="checkmark fa fa-check-square-o"></i>
			<div class="note-hover"><span class="note-time-ago"><?php _e('just now...', 'opendrive')?></span>
				<div class="note-buttons">
					<a title="<?php _e('Delete', 'opendrive')?>" class="fa fa-remove one-note-delete" href="#"></a>
				</div>
			</div>
			<div class="one-note-text">
				<div contenteditable="true" placeholder="<?php _e('Write Note...', 'opendrive')?>" class="one-note-text-editable"></div>
			</div>
		</div>
	</script>

	<script type="text/x-handlebars-template" data-name="NewNotepadItem">
		<li class="active item notepad-item dropdown droppable ui-droppable">
			<a href="/notes/{{NotepadId}}" class="od_root_notepads">
				<i class="fa fa-sticky-note"></i>
				<span class="notepad-name ellipsis_overflow"></span></a>
			<i class="fa fa-bars js-item-menu-btn dropdown-toggle" data-toggle="dropdown"></i>
			<ul class="notepad-menu dropdown-menu dropdown-menu-right">
				<li><a href="#" class="contex-notepad-rename"><?php _e('Rename', 'opendrive')?></a></li>
				<li><a href="#" class="contex-notepad-achive"><?php _e('Archive', 'opendrive')?></a></li>
				<li><a href="#" class="context-notepad-trash orange-text"><?php _e('Trash', 'opendrive')?></a></li>
			</ul>
		</li>
	</script>

	<script type="text/x-handlebars-template" data-name="NewEmptyNotepad">
		<li class="item notepad-item dropdown droppable ui-droppable">
			<a href="" class="od_root_notepads">
				<i class="fa fa-sticky-note"></i>
				<span class="notepad-name ellipsis_overflow"></span>
			</a>
			<i class="fa fa-refresh fa-spin loading-icon"></i>
			<i class="fa fa-bars js-item-menu-btn dropdown-toggle" data-toggle="dropdown"></i>
			<ul class="notepad-menu dropdown-menu dropdown-menu-right">
				<li><a href="#" class="contex-notepad-rename"><?php _e('Rename', 'opendrive')?></a></li>
				<li><a href="#" class="contex-notepad-achive"><?php _e('Archive', 'opendrive')?></a></li>
				<li><a href="#" class="context-notepad-trash orange-text"><?php _e('Trash', 'opendrive')?></a></li>
			</ul>
		</li>
	</script>

	<script type="text/x-handlebars-template" data-name="NoteFileItem">
		<div class="one-note drop-file">
			<i class="checkmark fa fa-square-o"></i>
			<i class="checkmark fa fa-check-square-o"></i>
			<div class="note-hover"><span class="note-time-ago"></span>
				<div class="note-buttons"><a title="<?php _e('Delete', 'opendrive') ?>" class="fa fa-remove one-note-delete" href="#"></a></div>
			</div>
			<div class="one-note-text">
				<div class="one-note-text-editable" contenteditable="true"></div>
			</div>
		</div>
	</script>
</div>
<?php require_once('template-footer.php')?>
