<?php 
/*
*Template Name: File Player
*/
if (!defined('ABSPATH')) exit;

$file_id = get_query_var('file_id');
$autoplay = OpenDrive::getQueryValue('autoplay') !== null;
$full_folder_id = OpenDrive::getQueryValue('folder_id');
$sharing_id = '';
if (strpos($full_folder_id, '-') > 0) list($folder_id, $sharing_id) = explode('-', $full_folder_id);
$file = OpenDrive::i()->apiClient()->get_file($file_id, $sharing_id);
$errorMessage = null;
$file_ext = null;

$suppliedFormat = null;
if (OpenDrive::i()->apiClient()->error) {
	$errorMessage = OpenDrive::i()->apiClient()->error_message ? OpenDrive::i()->apiClient()->error_message : __('File is not available, please try later.', 'opendrive');
	header("Error-Message: $errorMessage", true, 404);
} else {
    $downloadInfo = OpenDrive::i()->apiClient()->check_file_download($file_id, $sharing_id);

	$file_name = $file->Name;
	$filepath = pathinfo($file_name);
	$file_ext = isset($filepath['extension']) ? strtolower($filepath['extension']) : null;
	$suppliedFormat = $file_ext;
	$file_size = size_format($file->Size);
	$file_created = date('M d, Y', $file->DateUploaded);
	$file_description = $file->Description;
	$file_download_link = $file->DownloadLink;


	$file_type = 'unknown';
	if (OpenDrive::isVideoFile($file_ext)) {
		$videoFormat = $file_ext;
		if($file_ext == 'mp4') $suppliedFormat = 'm4v';
		if($file_ext == 'mp4') $videoFormat = 'mp4';
		if($file_ext == 'ogv') $videoFormat = 'ogg';
		$file_type = 'video';
	} else if (OpenDrive::isAudioFile($file_ext)) {
		$file_type = 'audio';
	} else $errorMessage = __('This format is not supported.', 'opendrive');
}
if ($errorMessage == '') {
	OpenDrive::enqueueStyle('od_player_' . ($file_type == 'audio' ? 'audio' : 'video') . '.css');
	if ($file_type == 'audio') {
		OpenDrive::enqueueScript(array(
				'vendor/jquery.jplayer.js' => '2.9.2'
			)
		);
	} elseif ($file_type == 'video') {
		OpenDrive::enqueueScript(array(
			'/wp-includes/js/mediaelement/mediaelement-and-player.min.js',

		), false);

		OpenDrive::enqueueStyle('/wp-includes/js/mediaelement/mediaelementplayer.min.css', false);
	}
	OpenDrive::enqueueScript(array(
			'od_player.js')
	);
}
?>

<!DOCTYPE html>
<!--[if IE 7]>
<html class="ie ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html class="ie ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<title><?php bloginfo('name'); ?>  <?php is_front_page() ? bloginfo('description') : wp_title(''); ?></title>
	<meta name="author" content="OpenDrive">
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<?php
	wp_print_styles();
	wp_print_head_scripts();
	?>
</head>

<body>
	<!-- Container -->
	<div id="container">
		<?php if ($errorMessage == '') { ?>
        <div id="media-data"
             data-file-ext="<?php echo esc_attr($suppliedFormat);?>"
             data-stream-link="<?php esc_attr_e(OpenDrive::i()->apiClient()->download_file($file->FileId, true, false, $sharing_id));?>"
             data-file-type="<?php esc_attr_e($file_type)?>"
             data-plugins-url="<?php echo wp_make_link_relative(plugins_url('/opendrive/js/vendor'))?>"
             data-meplugins-url="<?php echo includes_url( 'js/mediaelement/', 'relative' )?>"
             data-autoplay="<?php echo $autoplay?>"
            ></div>
		<?php
		if ( $file_type == 'video' )
		{
            require 'items/player-video.php';
		}
		elseif ( $file_type == 'audio' )
		{
			require 'items/player-audio.php';
		}
		?>
		<?php } else {?>
			<?php echo esc_html($errorMessage); ?>
		<?php } ?>
<?php


require_once 'template-footer.php';