<?php
/*
*Template Name: Notes
*/
if (!defined('ABSPATH')) exit;

require_once('template-functions.php');

if ( OpenDrive::i()->getPluginSetting('od_enable_tasks') != 'true' )
{
    OpenDrive::redirectToFiles();
}
$page_title = __('Tasks', 'opendrive');
$user_info = OpenDrive::i()->getUserInfo();
if ($user_info && !OpenDrive::i()->hasTasksAccess()) {
    OpenDrive::redirectToFiles();
}
OpenDrive::enqueueScript(array(
    'vendor/jquery.magnific-popup.min.js' => '1.1.0',
    'vendor/bootstrap/bootstrap-select.min.js' => '1.10.0',
    'vendor/ckeditor/ckeditor.js' => '4.5.7',
    'vendor/ckeditor/config.js' => '4.5.7',
    'od_helpers.js',
    'od/tasks/searchbox.js',
    'od/tasks/widgets.js',
    'od_tasks.js',
));

OpenDrive::enqueueStyle(
    array(
        'vendor/jquery-ui-1.11.4.custom/jquery-ui.min.css' => '1.11.4',
        'vendor/bootstrap/bootstrap-select-od.css' => '1.10.0',
        'vendor/magnific-popup.css' => '1.1.0',
        'od_tasks.css'
    )
);

$currentProjectListId = get_query_var('project_list_id');
$currentProjectId =  get_query_var('project_id');;
$currentTaskId =  get_query_var('task_id');

$filter = '';

if ($currentTaskId == 'archive' || $currentTaskId == 'trash') {
    $filter = $currentTaskId;
}

if ($filter && $user_info && $user_info->AccessUserID) {
    wp_redirect('/tasks');
    exit;
}

$isAnonymous = !$user_info;

$projectLists = array();

$initialData = array(
    'ProjectList' => null,
    'Project' => null,
    'Task' => null
);

$notify_msg = '';

$projectListsLoaded = false;
$projectVars = array('ArchiveTrashItemFilter' => null);

if ($filter) {
    $currentTaskId = null;
    $projectListsLoaded = true;

    switch ($filter) {
        case 'trash':
            $projectLists = OpenDrive::i()->apiClient()->tasks_get_trashed_items('project_list');
            break;

        case 'archive':
            $projectLists = OpenDrive::i()->apiClient()->tasks_get_archived_items('project_list');
            break;
    }
    if (OpenDrive::i()->apiClient()->error) $projectLists = array();
    $projectVars['ArchiveTrashItemFilter'] = $filter;
}

if($user_info && !$projectListsLoaded) {
    $projectLists = OpenDrive::i()->apiClient()->tasks_get_project_lists(true);
    if (!OpenDrive::i()->apiClient()->error) $projectListsLoaded = true;
}

// redirect account users with no projects to notes page
if ( $user_info && $user_info->AccessUserID > 0 && sizeof($projectLists) == 0 )
{
    wp_redirect( '/notes' );
    exit();
}

if($currentProjectListId) {
    if($projectListsLoaded) {
        foreach($projectLists as $projectList) {
            if($projectList->ProjectListId == $currentProjectListId){
                $initialData['ProjectList'] = $projectList->Name;
                break;
            }
        }
    } else {
        OpenDrive::redirectToLoginPage();
        exit;
    }

    $currentProjectId = null;
    $currentTaskId = null;
} elseif($currentProjectId) {
    $project = OpenDrive::i()->apiClient()->tasks_get_projects($currentProjectId);
    if(OpenDrive::i()->apiClient()->error || !$project) {
        $currentProjectId = null;
        $currentProjectListId = null;
        $currentTaskId = null;
    } else {
        $initialData['ProjectList'] = $project[0]->ProjectListName;
        $initialData['Project'] = $project[0]->Name;
        $currentProjectListId = $project[0]->ProjectListId;
    }
} elseif ($currentTaskId) {
    $task = OpenDrive::i()->apiClient()->tasks_get_tasks('', $currentTaskId);
    if(OpenDrive::i()->apiClient()->error || !$task) {
        $currentTaskId = null;
        $currentProjectId = null;
        $currentProjectListId = null;
    } else {
        $initialData['ProjectList'] = $task[0]->ProjectListName;
        $initialData['Project'] = $task[0]->ProjectName;
        $initialData['Task'] = $task[0]->Name;
        $currentProjectId = $task[0]->ProjectId;
        $currentProjectListId = $task[0]->ProjectListId;
    }
    if(OpenDrive::i()->apiClient()->error &&
        (OpenDrive::i()->apiClient()->error_code == 403  || OpenDrive::i()->apiClient()->error_code == 404) &&
        isset($task->error->task_access_error) ) {
        if ($isAnonymous) {
            OpenDrive::redirectToLoginPage();
        }
        $notify_msg = OpenDrive::i()->apiClient()->error_message;
    }
}

$initialData['ProjectListId'] = $currentProjectListId;
$initialData['ProjectId'] = $currentProjectId;
$initialData['TaskId'] = $currentTaskId;

if (!$projectListsLoaded) {
    $projectLists = OpenDrive::i()->apiClient()->tasks_get_project_lists(true, $currentProjectListId, $currentTaskId);
    if (OpenDrive::i()->apiClient()->error) $projectLists = array();
    if(!$projectLists && !$notify_msg ) $notify_msg = 'Create your first <a href="#" class="js-new-project-list">Project List</a>.';
}

$tags = array();

if (!$isAnonymous) {
    $tags = OpenDrive::i()->apiClient()->tasks_get_tags();
    if(OpenDrive::i()->apiClient()->error) $tags = array();
}
if ($isAnonymous && !$currentTaskId) {
    OpenDrive::redirectToLoginPage();
}

$currentUser = (object)null;
if ($user_info)
    $currentUser = array(
        'UserId' => $user_info->UserID,
        'AccessUserId' => $user_info->AccessUserID,
        'Avatar' => $user_info->Avatar,
        'AvatarColor' => $user_info->AvatarColor,
        'FirstName' => $user_info->UserFirstName,
        'LastName' => $user_info->UserLastName,
        'SessionToken' => OpenDrive::i()->sessionToken()
    );

if (OpenDrive::i()->apiClient()->error && !$isAnonymous) {
    OpenDrive::redirectToFiles();
}
$initialData['AlertMessage'] = $notify_msg;
require_once('template-header.php');
?>

<input type="hidden" name="api_session_id" id="api_session_id"
       value="<?php esc_attr_e(OpenDrive::i()->apiClient()->get_od_session_id()); ?>">
<input type="hidden" name="upload_url" id="upload_url" value="<?php esc_attr_e(OpenDrive::i()->apiClient()->resumable_upload_url())?>">

<div class="fill tasks-page <?php echo $filter?> <?php echo $isAnonymous ? 'anonymous' : ''?>">

    <?php
    echo od_get_sidebar(array('project_lists' => $projectLists, 'filter' => $filter, 'selected_project_list' => $currentProjectListId));
    require_once 'items/tasks/tasks-breadcrumbs.php';
    require_once 'items/tabs.php';
    require_once 'items/tasks/tasks-templates-mobile.php'
    ?>

    <script id="js-tags-data" type="x-text/plain"><?php echo json_encode($tags) ?></script>
    <script id="js-current-user-data" type="x-text/plain"><?php echo json_encode($currentUser) ?></script>
    <script id="js-project-vars" type="x-text/plain"><?php echo json_encode($projectVars) ?></script>
    <script id="js-initial-data" type="x-text/plain"><?php echo json_encode($initialData) ?></script>

    <div class="tabs-container">
        <div class="js-scroll-content scroll-content"></div>
    </div>
</div>
<?php require_once('template-footer.php') ?>
