<?php
/*
*Template Name: Users New
*/
if (!defined('ABSPATH')) exit;

$sidebar_visible = isset($_COOKIE['od_sidebar_visible']) ? intval($_COOKIE['od_sidebar_visible']) : 1;

require_once('template-functions.php');

$user_info = OpenDrive::i()->getUserInfo();
if(!$user_info) OpenDrive::redirectToLoginPage();
$od_user_settings = OpenDrive::i()->getPluginSetting(null, true);

if ($user_info->AccessUserID > 0 && $user_info->AdminMode != 1 && $user_info->AdminMode != 0 ||
    ($od_user_settings['od_enable_account_users'] == 'false' || $od_user_settings['od_enable_account_users'] == '0')) {
    OpenDrive::redirectToFiles();
}

$notice = false;

$selected_group = ( get_query_var( 'group' ) ) ? get_query_var( 'group' ) : 0;
$searchterm = ( get_query_var( 'searchterm' ) ) ? urldecode(get_query_var( 'searchterm' )) : null;


$max_account_user = 0;
if($user_info !== false)
{
    $max_account_user = $user_info->MaxAccountUsers;
}
$total_account_users = 0;

$usergroups = OpenDrive::i()->apiClient()->get_user_groups();

$users = false;
$this_group = false;

if ( isset($usergroups->error) )
{
    $error = true;
    $error_message = $usergroups->error->message;
    $usergroups = array();
}
if( $usergroups === false )
{
    $usergroups = array();
}
if ( $selected_group == 0 && sizeof($usergroups) > 0 && !$searchterm )
{
    $selected_group = $usergroups[0]->GroupID;
    wp_redirect('/users/' . $selected_group);
    exit;
}

if ( sizeof($usergroups) == 0 )
{
    $notice = __('Please create group for new user.', 'opendrive');
}


$users = array();
if($searchterm != null){
    $users = OpenDrive::i()->apiClient()->get_search_account_users($searchterm);
}elseif ( $selected_group > 0 ) {
    $users = OpenDrive::i()->apiClient()->get_users_in_group($selected_group);
    $this_group = OpenDrive::i()->apiClient()->get_group($selected_group);
    if (OpenDrive::i()->apiClient()->error) {
        OpenDrive::redirectToFiles();
    }
    $allUsers = OpenDrive::i()->apiClient()->get_search_account_users($searchterm);
    $total_account_users = count($allUsers);
}


if ( $user_info ) {
    $space_used = ($user_info->MaxStorage > 0) ? ceil(($user_info->StorageUsed/1024/1024) * 100 / $user_info->MaxStorage) : 0;
    $bw_used = ($user_info->BwMax > 0) ? ceil(($user_info->BwUsed/1024/1024) * 100 / $user_info->BwMax) : 0;
    if ( $space_used > 100) $space_used = 100;
    if ( $bw_used > 100) $bw_used = 100;

    $storage_text = od_size_format($user_info->MaxStorage*1024*1024);
    $used_text = od_size_format($user_info->BwMax*1024*1024, 0);
}

if ( $searchterm !== null )
{
    $page_title = $searchterm;
}
elseif ( sizeof($usergroups) > 0 && isset($this_group->GroupName) )
{
    $page_title = $this_group->GroupName;
}
else
{
    $page_title = '';
}

if ( sizeof($usergroups) == 0 )
{
    if ( $user_info->AccessUserID == 0 || ( $user_info->AccessUserID > 0 && $user_info->AdminMode == 1 ))
    {
        $notify_msg = sprintf(__('Create your first %s Group %s', 'opendrive'), '<a href="#" class="create-group-btn">', '</a>.');
    }
} elseif (!$users) {
    if($searchterm !== null) $notify_msg = __('No user found.', 'opendrive');
    else {
        $notify_msg = __('This group has no account users yet.', 'opendrive');
        $notify_msg .=  sprintf(__('Create first %s Account User %s.', 'opendrive'),
            '<a href="#" aria-label="' . __('Create first Account User', 'opendrive') . '" class="create-first-account-user">',
            '</a>'
        );
    }
}

OpenDrive::enqueueScript(array(
    'od_helpers.js',
    'od_users.js'
));

OpenDrive::enqueueStyle('od_users.css');

require_once('template-header.php');
?>
<input type="hidden" name="group_id" id="group_id" value="<?php echo $selected_group; ?>">
<input type="hidden" name="user_acc_type" id="user_acc_type" value="<?php echo $user_info->AccType; ?>">
<input type="hidden" name="user_level" id="user_level" value="<?php echo $user_info->Level; ?>">
<div class="fill users-new-page">
    <div class="lightbox" id="edit-group">
        <div class="lightbox-overlay"></div>
        <div class="lightbox-container">
            <div class="lightbox-header">
                <h2><?php _e('Edit Group', 'opendrive')?></h2>
                <a class="lightbox-close-btn fa fa-times" role="button" aria-label="<?php _e('Close', 'opendrive')?>" href="#"></a>
            </div>
            <div class="lightbox-body">
                <div class="row">
                    <div class="col-sm-3"><?php _e('Group Name', 'opendrive')?>:</div>
                    <div class="col-sm-9"><input type="text" id="edit-group-name"></div>
                </div>

                <div class="row">
                    <div class="col-sm-3"><?php _e('Space', 'opendrive')?>:</div>
                    <div class="col-sm-9">
                        <?php
                        $space_formatted = str_replace(',', '', size_format($user_info->MaxStorage*1024*1024, 0));
                        $space_exploded = explode(' ', $space_formatted);

                        $space_value = $space_exploded[0];
                        $space_unit = $space_exploded[1];
                        ?>
                        <input id="group_space_spinner" type="number" min="1" max="1024" step="1" value="<?php echo $space_value?>" size="5" class="spinner-input">
                        <select id="group_space_unit" class="spinner-units">
                            <option value="MB" <?php if ($space_unit == 'MB' || $space_unit == '' ) echo 'selected'?>><?php _e('MB', 'opendrive')?></option>
                            <option value="GB" <?php if ($space_unit == 'GB') echo 'selected'?>><?php _e('GB', 'opendrive')?></option>
                            <option value="TB" <?php if ($space_unit == 'TB') echo 'selected'?>><?php _e('TB', 'opendrive')?></option>
                        </select>
                    </div>
                </div>


                <div class="row">
                    <div class="col-sm-3"><?php _e('Bandwidth', 'opendrive')?>:</div>
                    <div class="col-sm-9">
                        <?php
                        $bw_formatted = str_replace(',', '', size_format($user_info->BwMax * 1024 * 1024, 0));
                        $bw_exploded = explode(' ', $bw_formatted);

                        $bw_value = $bw_exploded[0];
                        $bw_unit = $bw_exploded[1];
                        ?>
                        <input id="group_bw_spinner" type="number" min="1" max="1024" step="1" value="<?php echo $bw_value?>" size="5" class="spinner-input">
                        <select id="group_bw_unit" class="spinner-units">
                            <option value="MB" <?php if ($bw_unit == 'MB' || $bw_unit == '') echo 'selected'?>><?php _e('MB', 'opendrive')?></option>
                            <option value="GB" <?php if ($bw_unit == 'GB') echo 'selected'?>><?php _e('GB', 'opendrive')?></option>
                            <option value="TB" <?php if ($bw_unit == 'TB') echo 'selected'?>><?php _e('TB', 'opendrive')?></option>
                        </select>
                    </div>
                </div>

                <div class="row">
                    <div class="col-sm-3"><label for="group_settings_enable" style="min-width: auto"><?php _e('Enforce Group Limits', 'opendrive')?></label>:</div>
                    <div class="col-sm-9">
                        <?php if($this_group->GroupSettingsEnable):?>
                        <input type="checkbox" value="1" id="group_settings_enable" checked>
                        <?php else:?>
                        <input type="checkbox" value="1" id="group_settings_enable">
<?php endif; ?>
                    </div>
                </div>



                <input type="hidden" id="edit_max_storage" value="<?php echo  $user_info->MaxStorage?>">
                <input type="hidden" id="edit_max_bandwidth" value="<?php echo  $user_info->BwMax?>">
                <input type="hidden" id="edit_group_bw_max" value="<?php echo  $user_info->BwMax?>">
                <input type="hidden" id="edit_group_max_storage" value="<?php echo  $user_info->MaxStorage?>">
                <input type="hidden" id="edit_group_id" value="">
            </div>
            <div class="lightbox-buttons">
                <input id="save-group-btn" class="save-btn" type="button" value="<?php _e('Save Group', 'opendrive')?>">
                <input class="js-cancel-btn cancel-btn" type="button" value="<?php _e('Cancel', 'opendrive')?>">
                <div class="clearfix"></div>
            </div>
        </div>
    </div>

    <?php
        if ( $user_info->AccessUserID == 0 || ( $user_info->AccessUserID > 0 && $user_info->AdminMode == 1 ))
        {
            ?>
            <div class="users-dropdown dropdown-menu top-left-arrow" id="user-details-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Account User Details', 'opendrive')?></h3>
                    <input type="text" class="js-account_user_first_name" placeholder="<?php _e('First Name', 'opendrive')?>" maxlength="50"><br>
                    <input type="text" class="js-account_user_last_name" placeholder="<?php _e('Last Name', 'opendrive')?>" maxlength="50"><br>
                    <input type="text" class="js-account_user_email" placeholder="<?php _e('Email', 'opendrive')?>" maxlength="255"><br>
                    <input autocomplete="off" type="text" class="js-account_user_position" placeholder="<?php _e('Position', 'opendrive')?>" value=""  maxlength="50"><br>
                    <input autocomplete="off" type="password" class="js-account_user_password" placeholder="<?php _e('Enter New Password', 'opendrive')?>" value=""><br>
                    <div class="dropdown-row">
                        <label for="account_user_change_password">
                            <input type="checkbox" id="account_user_change_password" value="1">
                            <?php _e('Enable account user to change password', 'opendrive')?></label>
                    </div>
                </div>
                <div class="dropdown-buttons">
                    <input type="hidden" id="access-email" value="">
                    <input type="button" value="<?php _e('Save', 'opendrive')?>" class="save-btn" id="save-user-details-btn">
                    <input type="button" value="<?php _e('Cancel', 'opendrive')?>" class="cancel-btn">
                    <div class="clearfix"></div>
                </div>
            </div>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="new-user-details-dropdown">
                <form autocomplete="off">
                    <div class="dropdown-content">
                        <i class="fa fa-times close-btn"></i>
                        <h3><?php _e('Account User Details', 'opendrive')?></h3>
                        <input type="text" class="js-account_user_first_name" placeholder="<?php _e('First Name', 'opendrive')?>" value="" maxlength="50"><br>
                        <input type="text" class="js-account_user_last_name" placeholder="<?php _e('Last Name', 'opendrive')?>" value="" maxlength="50"><br>
                        <input type="text" class="js-account_user_email" placeholder="<?php _e('Email', 'opendrive')?>" maxlength="255"><br>
                        <input type="text" class="js-account_user_position" placeholder="<?php _e('Position', 'opendrive')?>" maxlength="50"><br>
                        <input type="password" class="js-account_user_password" placeholder="<?php _e('Password', 'opendrive')?>"><br>
                        <div class="dropdown-row">
                            <label><input type="checkbox" name="account_user_change_password" id="account_user_change_password_new" value="1"><?php _e('Enable account user to change password', 'opendrive')?></label>
                        </div>
                        <div class="dropdown-row">
                            <label><input type="checkbox" name="account_user_send_email_invitation" id="account_user_send_email_invitation" value="1"><?php _e('Send email invitation', 'opendrive')?></label>
                        </div>
                        <div class="dropdown-row disabled with-padding">
                            <label for="account_user_email_password"><input disabled type="checkbox" name="account_user_email_password" id="account_user_email_password" value="1"><?php _e('Send password by email', 'opendrive')?></label>
                        </div>
                    </div>
                    <div class="dropdown-buttons">
                        <input type="button" value="<?php _e('Save', 'opendrive')?>" class="save-btn" id="save-new-user-btn">
                        <input type="button" value="<?php _e('Cancel', 'opendrive')?>" class="cancel-btn">
                        <div class="clearfix"></div>
                    </div>
                </form>
            </div>

    <div class="users-dropdown dropdown-menu top-left-arrow" id="access-permissions-dropdown">
        <div class="dropdown-content">
            <i class="fa fa-times close-btn"></i>
            <h3><?php _e('Access Permissions', 'opendrive')?></h3>
            <input type="hidden" id="access-email" value="">

            <div class="dropdown-row">
                <input type="radio" name="user_access_permissions" value="2"
                       data-perm-name="<?php echo od_get_user_permission_name(2, true) ?>"
                       id="user_access_permissions_basic">
                <label class="with-radio"
                       for="user_access_permissions_basic"><b><?php echo od_get_user_permission_name(2, true) ?></b>
                    - <?php _e('User can access permitted projects or folders', 'opendrive') ?></label>
            </div>
            <div class="dropdown-row">
                <input type="radio" name="user_access_permissions" value="0" data-perm-name="<?php echo od_get_user_permission_name(0, true)?>" id="user_access_permissions_users">
                <label class="with-radio" for="user_access_permissions_users"><b>+ <?php echo od_get_user_permission_name(0, true)?></b> -
                    <?php _e('User can see users in his group', 'opendrive')?></label>
            </div>
            <div class="dropdown-row">
                <input type="radio" name="user_access_permissions" value="1" data-perm-name="<?php echo od_get_user_permission_name(1, true)?>" id="user_access_permissions_admin">
                <label class="with-radio"
                       title="<?php _e('User can administrate other account users', 'opendrive')?>, <?php _e('Trash', 'opendrive')?>"
                       for="user_access_permissions_admin"><b>+ <?php echo od_get_user_permission_name(1, true)?></b> -
                    <?php _e('User can administrate other account users', 'opendrive')?>, <?php _e('Trash', 'opendrive')?></label>
            </div>
        </div>
    </div>

            <?php if($user_info->IsPartner):
                $adminPlans = OpenDrive::i()->getConfigItem('plan_name_array');
            ?>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="admin-permissions-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Admin Permissions', 'opendrive')?></h3>
                    <input type="hidden" id="access-email" value="">
                    <div class="dropdown-row">
                        <label for="admin_plan"><?php _e('Account user admin mode', 'opendrive')?></label>
                    </div>
                    <select id="admin_plan">
                        <option value="0" selected><?php _e('None', 'opendrive')?></option>
                        <?php foreach($adminPlans as $planId => $planName):
                            if($planId < 90 || $planId > $user_info->Level) continue;
                            ?>
                            <option value="<?php esc_attr_e($planId)?>"><?php esc_html_e($planName)?></option>
                        <?php endforeach;?>
                    </select>

                </div>
            </div>
            <?php endif;?>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="folders-permissions-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Folder Permissions', 'opendrive')?></h3>
                    <input type="hidden" id="access-email" value="">
                    <div class="scrollable access-folders-content">

                    </div>
                </div>
                <div class="dropdown-buttons">
                    <input type="button" value="<?php _e('Save', 'opendrive')?>" class="save-btn" id="save-folders-permissions-btn">
                    <input type="button" value="<?php _e('Cancel', 'opendrive')?>" class="cancel-btn">
                    <div class="clearfix"></div>
                </div>
            </div>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="projects-permissions-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Project Permissions', 'opendrive')?></h3>
                    <div class="scrollable access-projects-content">

                    </div>
                </div>
                <div class="dropdown-buttons">
                    <input type="hidden" id="access-email" name="access_email">
                    <input type="button" value="<?php _e('Save', 'opendrive')?>" class="save-btn" id="save-projects-permissions-btn">
                    <input type="button" value="<?php _e('Cancel', 'opendrive')?>" class="cancel-btn">
                    <div class="clearfix"></div>
                </div>
            </div>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="user-storage-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Storage Limit', 'opendrive')?></h3>
                    <input type="hidden" id="access_email" name="access_email">
                    <input type="hidden" id="edit_group_max_storage" value="<?php echo  $user_info->MaxStorage?>">
                    <input class="spinner-input" type="number" name="account_user_storage" id="account_user_storage" min="1" max="1024" step="1">
                    <label class="spinner-dropdown">
                        <select id="account_user_storage_units" name="account_user_storage_units">
                            <option value="MB" selected ><?php _e('MB', 'opendrive')?></option>
                            <option value="GB"><?php _e('GB', 'opendrive')?></option>
                            <option value="TB"><?php _e('TB', 'opendrive')?></option>
                        </select>
                    </label>
                 </div>
            </div>

            <div class="users-dropdown dropdown-menu top-left-arrow" id="user-bandwidth-dropdown">
                <div class="dropdown-content">
                    <i class="fa fa-times close-btn"></i>
                    <h3><?php _e('Bandwidth Limit', 'opendrive')?></h3>
                    <input type="hidden" id="access_email" name="access_email">
                    <input class="spinner-input" type="number" name="account_user_bandwidth" id="account_user_bandwidth" min="1" max="1024" step="1">
                    <label class="spinner-dropdown">
                        <select id="account_user_bandwidth_units" name="account_user_bandwidth_units">
                            <option value="MB" selected><?php _e('MB', 'opendrive')?></option>
                            <option value="GB"><?php _e('GB', 'opendrive')?></option>
                            <option value="TB"><?php _e('TB', 'opendrive')?></option>
                        </select>
                    </label>
                    /<?php _e('Day', 'opendrive')?>
                </div>
            </div>
            <?php
        }
    ?>

    <?php echo od_get_sidebar(array(
        'usergroups'          => $usergroups,
        'selected_group'      => $selected_group,
        'total_account_users' => $total_account_users
    )); ?>

    <div class="breadcrumb-and-buttons no-fadeout">
        <?php if(!empty($this_group)):?>
            <?php
            if ( $user_info->AdminMode == 1 )
            {
                ?>
                <div class="buttons">
                    <?php
                    if ( $user_info->Level > 1 )
                    {
                        ?><span class="item">
                        <b><span id="account-users-counter-value"><?php echo $total_account_users?></span> <?php _e('users', 'opendrive')?></b> <?php _e('of', 'opendrive')?> <span id="account-users-max-count"><?php echo $max_account_user?></span> <?php _e('used', 'opendrive')?> <?php
                        if ($user_info->MaxAccountUsers > 0 && $user_info->Level > 1 && $user_info->AccessUserID == 0) do_action('od_extension_insert_item', 'buy_users_link');
                        ?>
                        </span><?php
                    }
                    else
                    {
                        ?>
                        <span class="item"><b><span id="account-users-counter-value"><?php echo $total_account_users?></span> <?php _e('users', 'opendrive')?></b> <?php _e('of', 'opendrive')?> <span id="account-users-max-count"><?php echo $max_account_user?></span> <?php _e('used', 'opendrive')?> <?php
                            if ( $user_info->AccessUserID == 0 )
                            {
                                ?>- <a href="/billing/upgrade"><?php _e('Get More Users', 'opendrive')?></a><?php
                            }
                            ?>
                    </span>
                        <?php
                    }
                    ?>
                    <?php
                    $disabled_class = ( $total_account_users >= $max_account_user || $searchterm !== null) ? 'disabled' : '';
                    ?><a href="#" role="button" class="br-btn <?php echo $disabled_class?>" id="new-user-btn" title="<?php _e('Create New User', 'opendrive')?>"><i class="fa fa-plus" aria-hidden="true"></i><?php _e('Create New User', 'opendrive')?></a><?php
                    ?>
                </div>
                <?php
            }
            ?>
            <h2 class="has-menu">
                <span><a href="/users"><?php _e('Groups', 'opendrive')?></a></span>
                <span class="delimiter">/ </span>
                <ul class="dropdown" aria-haspopup="true">
                    <li><?php esc_html_e($this_group->GroupName)?><span class="caret"></span>
                        <div class="dropdown-menu2 scrollable">
                            <ol>
                            <?php
                            if ( sizeof($usergroups) > 0 )
                            {
                                foreach ( $usergroups as $one_user_group )
                                {
                                    ?><li class="<?php if( $one_user_group->GroupID == $this_group->GroupID ) echo 'active';?>" title="<?php esc_attr_e($one_user_group->GroupName);?>"><a href="/users/<?php echo rawurlencode($one_user_group->GroupID);?>"><i class="fa fa-users" aria-hidden="true"></i>&nbsp;<?php esc_html_e($one_user_group->GroupName);?></a></li><?php
                                }
                            }
                            ?>
                            </ol>
                        </div>
                    </li>
                </ul>
            </h2>

        <?php endif;?>
    </div>
    <?php
    if($user_info->MaxAccountUsers > 0) {
            do_action('od_extension_insert_item', 'buy_users_template');
    }


    ?>
    <div class="users-container tabs-container js-tabs-container">

        <div class="users-content scroll-content">
            <div class="users col-md-12 col-sm-12 no-padding">

                    <?php if ( isset($notify_msg) && $notify_msg != ''): ?>
                        <div class="alert alert-info js-alerts"><?php echo $notify_msg?></div>
                    <?php endif; ?>

                    <div class="user-row col-md-12 col-sm-12 heading-row js-heading-row <?php if(!$users) echo 'hidden'?>">
                        <div class="user-row-username col-md-2 col-sm-2 no-left-padding">
                            <div class="user-row-avatar no-padding">
                                <?php
                                if ( $user_info->AdminMode == 1 )
                                {
                                    ?>
                                    <i class="fa fa-square-o checkbox" title="<?php _e('Select All Users', 'opendrive')?>" role="checkbox" aria-label="<?php _e('Select All Users', 'opendrive')?>" aria-checked="false"></i>
                                    <i class="fa fa-check-square-o checkbox" aria-label="<?php _e('Deselect All Users', 'opendrive')?>" role="checkbox" aria-checked="true"></i>

                                    <ul class="dropdown top-left-arrow">
                                        <li><i class="fa fa-caret-down" aria-haspopup="true" aria-expanded="true" aria-label="<?php _e('Open popup menu', 'opendrive')?>"></i>
                                            <ul>
                                                <li><a href="#" aria-label="<?php _e('Block Selected Users', 'opendrive')?>" title="<?php _e('Block Selected Users', 'opendrive')?>" id="users-block-btn" class="disabled"><i class="fa fa-lock" aria-hidden="true"></i> <?php _e('Block', 'opendrive')?></a></li>
                                                <li><a href="#" aria-label="<?php _e('Unblock Selected Users', 'opendrive')?>" title="<?php _e('Unblock Selected Users', 'opendrive')?>" id="users-unblock-btn" class="disabled"><i class="fa fa-unlock-alt" aria-hidden="true"></i><?php _e('UnBlock', 'opendrive')?></a></li>
                                                <li><a href="#" aria-label="<?php _e('Delete Selected Users', 'opendrive')?>" title="<?php _e('Delete Selected Users', 'opendrive')?>" id="users-delete-btn" class="disabled"><i class="fa fa-trash" aria-hidden="true"></i><?php _e('Delete', 'opendrive')?></a></li>
                                            </ul>
                                        </li>
                                    </ul>
                                    <?php
                                }
                                ?>
                            </div>
                            <h3 title="<?php _e('Name', 'opendrive')?>"><?php _e('Name', 'opendrive')?></h3>
                        </div>
                        <div class="user-row-position col-md-1 col-sm-1">
                            <h3 title="<?php _e('Position', 'opendrive')?>"><?php _e('Position', 'opendrive')?></h3>
                        </div>
                        <div class="user-row-email col-md-2 col-sm-2">
                            <h3 title="<?php _e('Email', 'opendrive')?>"><?php _e('Email', 'opendrive')?></h3>
                        </div>
                        <?php
                        if ( $user_info->AccessUserID == 0 || ($user_info->AccessUserID > 0 && $user_info->AdminMode != 0 ) )
                        {
                            ?>
                            <div class="user-row-permissions col-md-3 col-sm-3">
                                <h3 title="<?php _e('Permissions', 'opendrive')?>"><?php _e('Permissions', 'opendrive')?></h3>
                            </div>
                            <?php
                        }
                        ?>

                        <div class="user-row-storage col-md-2">
                            <h3 title="<?php _e('Storage Used', 'opendrive')?>"><?php _e('Storage Usage', 'opendrive')?></h3>
                        </div>
                        <div class="user-row-bandwidth col-md-2 col-sm-2">
                            <h3 title="<?php _e('Bandwidth Used', 'opendrive')?>"><?php _e('Bandwidth Usage', 'opendrive')?></h3>
                        </div>
                    </div>
                    <?php
                    if ( sizeof($usergroups) > 0 )
                    {
                        ?>
                        <?php
                        if ( is_array($users) && sizeof($users) > 0 )
                        {
                            ?>

                        <?php

                            foreach ($users as $one_user)
                            {
                                $space_used = $one_user->StorageUsed;
                                $space_max = $one_user->StorageMax * 1024 * 1024;
                                $downloads_used = $one_user->BWUsed;
                                $downloads_max = $one_user->BWMax * 1024 * 1024;

                                $avatar = $one_user->Avatar;

                                $class_blocked = ( $one_user->AccessActive == 2 ) ? 'blocked' : '';

                                ?>
                                <div class="user-row draggable col-md-12 col-sm-12 <?php echo $class_blocked?>" data-user-email="<?php echo esc_attr($one_user->Email)?>"
                                     aria-label="User <?php esc_attr_e($one_user->FirstName . ' ' . $one_user->LastName) ?>">

                                    <div class="user-row-username col-md-2 col-sm-2 no-left-padding" aria-label="<?php _e('Edit user', 'opendrive')?>">
                                        <div class="user-row-avatar">
                                            <?php
                                            if ( $user_info->AdminMode == 1 )
                                            {
                                                ?>
                                                <i class="fa fa-square-o checkbox" role="checkbox" aria-checked="false" aria-label="<?php _e('Select user', 'opendrive')?> <?php esc_attr_e($one_user->FirstName . ' ' . $one_user->LastName) ?>"></i>
                                                <i class="fa fa-check-square-o checkbox" role="checkbox" aria-checked="true" aria-label="<?php _e('Deselect user', 'opendrive')?> <?php esc_attr_e($one_user->FirstName . ' ' . $one_user->LastName) ?>"></i>
                                                <?php
                                            }
                                            ?>

                                            <?php if(!empty( $avatar )): ?>
                                                <div class="user-list-avatar-wrapper">
                                                    <div class="avatar-container">
                                                        <img src="<?php esc_attr_e($avatar); ?>"/>
                                                    </div>
                                                </div>

                                            <?php else: ?>
                                                <div class="user-list-avatar-wrapper">
                                                    <div class="avatar-container avatar-default" style="background-color: #<?php echo $one_user->AvatarColor?>">
                                                        <?php esc_html_e(strtoupper(mb_substr($one_user->FirstName,0, 1,'utf-8').mb_substr($one_user->LastName,0, 1,'utf-8')))?>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                        <span class="username" role="button" aria-label="<?php _e('Edit user', 'opendrive')?>"><?php esc_html_e($one_user->FirstName.' '.$one_user->LastName)?></span>
                                        <i class="fa fa-lock lock-icon" aria-label="<?php _e('User is locked', 'opendrive')?>" title="<?php _e('User is locked', 'opendrive')?>"></i>
                                    </div>

                                    <div class="user-row-position col-md-1 col-sm-1" aria-label="<?php _e('Position', 'opendrive')?>">
                                        <span><?php esc_html_e($one_user->Position)?></span>
                                    </div>

                                    <div class="user-row-email col-md-2 col-sm-2">
                                        <a class="user-row-email-link" href="mailto:<?php esc_attr_e($one_user->Email)?>"><?php esc_html_e( $one_user->Email)?></a>
                                        <?php
                                        if ( $user_info->AccessUserID == 0 || ( $user_info->AccessUserID > 0 && $user_info->AdminMode == 1 ))
                                        {
                                            $notification_icon_class = 'notifications-off';
                                            if ( isset($one_user->AccessNotification) && $one_user->AccessNotification == 1 ) $notification_icon_class = 'notifications-on';
                                            ?>
                                            <a href="#" role="button" class="email-notification-btn <?php echo $notification_icon_class?>">
                                                <i class="fa fa-envelope"
                                                   data-toggle="tooltip"
                                                   aria-label="<?php _e('Activity Notifications ON', 'opendrive')?>"
                                                   title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.', 'opendrive')?></p><?php _e('Activity Notifications <strong>ON</strong>', 'opendrive')?>"></i>
                                                <i class="fa fa-ban" data-toggle="tooltip"
                                                   aria-label="<?php _e('Activity Notifications OFF', 'opendrive')?>"
                                                   title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.</p>Activity Notifications <strong>OFF</strong>', 'opendrive')?>"></i>
                                            </a>
                                            <?php
                                        }
                                        ?>
                                    </div>

                                    <?php
                                    if ( $user_info->AccessUserID == 0 || ($user_info->AccessUserID > 0 && $user_info->AdminMode != 0 ) )
                                    {
                                        ?>
                                            <div class="user-row-permissions col-md-3 col-sm-3">
                                                <span class="access-permissions" role="button" aria-label="<?php _e('User permissionss', 'opendrive')?>: <?php echo od_get_user_permission_name($one_user->AdminMode, true); ?>">
                                                    <?php echo od_get_user_permission_name($one_user->AdminMode, true); ?></span>
                                                <?php if($user_info->IsPartner >= 2):?>
                                                    <span class="admin-permissions"><?php echo $one_user->AccessAdminLevel ? OpenDrive::i()->getPlanName($one_user->AccessAdminLevel) : __('None', 'opendrive'); ?></span>
                                                <?php endif;?>

                                                <span class="folders-permissions" role="button" aria-label="<?php _e('Folders permissions', 'opendrive')?>">
                                                    <span class="counter">
                                                        <?php
                                                        $folders_counter = 0;
                                                        if ( isset($one_user->UserFolders->view) ) $folders_counter += intval($one_user->UserFolders->view);
                                                        if ( isset($one_user->UserFolders->edit) ) $folders_counter += intval($one_user->UserFolders->edit);

                                                        echo intval($folders_counter);
                                                        ?>
                                                    </span> <?php _e('Folders', 'opendrive')?>
                                                </span>
                                                <?php
                                                if ( OpenDrive::i()->hasTasksAccess() )
                                                {
                                                    ?>

                                                    <span class="projects-permissions" role="button" aria-label="<?php _e('Projects permissions', 'opendrive')?>">
                                                    <span class="counter">
                                                        <?php
                                                        $projects_counter = 0;
                                                        if ( isset($one_user->AccessProjects->view) ) $projects_counter += intval($one_user->AccessProjects->view);
                                                        if ( isset($one_user->AccessProjects->edit) ) $projects_counter += intval($one_user->AccessProjects->edit);

                                                        echo intval($projects_counter);
                                                        ?>
                                                    </span> <?php _e('Projects', 'opendrive')?>
                                                </span>
                                                    <?php
                                                }

                                                ?>
                                            </div>
                                        <?php
                                    }
                                    ?>


                                    <?php
                                    $storage_full_class = '';
                                    if ( size_format($space_used) == size_format($space_max) ) $storage_full_class = 'full';
                                    ?>
                                    <div class="user-row-storage <?php echo $storage_full_class ?> col-md-2 col-sm-2" role="button">
                                        <b><?php echo od_size_format($space_used)?></b> of <span class="max-storage"><?php echo od_size_format($space_max); ?></span>
                                    </div>

                                    <?php
                                    $bw_full_class = '';
                                    if ( size_format($downloads_used) == size_format($downloads_max) ) $bw_full_class = 'full';
                                    ?>
                                    <div class="user-row-bandwidth <?php echo $bw_full_class?> col-md-2 col-sm-2">
                                        <b><?php echo od_size_format($downloads_used)?></b> <?php _e('of', 'opendrive')?> <span class="max-bw"><?php echo od_size_format($downloads_max)?></span>
                                    </div>

                                </div>
                                <?php
                            }
                        }
                    }
                    ?>


            </div>
        </div>
    </div>
</div>

<script type="text/x-handlebars-template" data-name="NewAccountUser">
    <div class="user-row draggable col-md-12 col-sm-12 user-color-default new-user-row">

        <div class="user-row-username col-md-2 col-sm-2 no-left-padding" aria-label="<?php _e('Edit new user', 'opendrive')?>">
            <div class="user-row-avatar">
                <?php
                if ( $user_info->AdminMode == 1 )
                {
                    ?>
                    <i class="fa fa-square-o checkbox" role="checkbox" aria-checked="false" aria-label="<?php _e('Select User', 'opendrive')?>"></i>
                    <i class="fa fa-check-square-o checkbox" role="checkbox" aria-checked="true" aria-label="<?php _e('Selected User', 'opendrive')?>"></i>
                    <?php
                }
                ?>


                    <div class="user-list-avatar-wrapper">
                        <div class="avatar-container avatar-default">
                            <?php _e('NU', 'opendrive')?>
                        </div>
                    </div>
            </div>
            <span class="username" role="button" aria-label="<?php _e('Edit user', 'opendrive')?>"><?php _e('New User', 'opendrive')?></span><i class="fa fa-lock lock-icon"></i>
        </div>

        <div class="user-row-position col-md-1 col-sm-1">
            <span></span>
        </div>

        <div class="user-row-email col-md-2 col-sm-2"><?php _e('no email', 'opendrive')?></div>

        <div class="user-row-permissions col-md-3 col-sm-3">
            <span class="access-permissions"><?php echo od_get_user_permission_name(0, true); ?></span>
            <?php if($user_info->IsPartner >= 2):?>
                <span class="admin-permissions"><?php _e('None', 'opendrive')?></span>
            <?php endif;?>

            <span class="folders-permissions">
                                            <span class="counter">0</span> <?php _e('Folders', 'opendrive')?>
                                        </span>
            <?php
            if ( OpenDrive::i()->hasTasksAccess() )
            {
                ?>

                <span class="projects-permissions">
                                                <span class="counter">0</span> <?php _e('Projects', 'opendrive')?>
                                            </span>
                <?php
            }
$bw_sufix = 'MB';
$storage_sufix = 'MB';
$bw =  $this_group->GroupMaxBw;
$storage =  $this_group->GroupMaxStorage;
            if ($bw >= 1048576){
                $bw /= 1048576;
                $bw_sufix = 'TB';
            }
            if ($bw >= 1024){
                $bw /= 1024;
                $bw_sufix = 'GB';
            }
            if ($storage >= 1048576){
                $storage /= 1048576;
                $storage_sufix = 'TB';
            }
            if ($storage >= 1024){
                $storage /= 1024;
                $storage_sufix = 'GB';
            }
            ?>
        </div>
<?php if($this_group->GroupSettingsEnable == 1){ ?>
        <div class="user-row-storage  col-md-2 col-sm-2"><b>0 B</b> <?php _e('of', 'opendrive')?> <span class="max-storage"><?php echo $storage ?> <?php _e($storage_sufix, 'opendrive')?></span></div>
        <div class="user-row-bandwidth  col-md-2 col-sm-2"><b>0 B</b> <?php _e('of', 'opendrive')?> <span class="max-bw"><?php echo $bw ?> <?php _e($bw_sufix, 'opendrive')?></span></div>
   <?php } else {?>
    <div class="user-row-storage  col-md-2 col-sm-2"><b>0 B</b> <?php _e('of', 'opendrive')?> <span class="max-storage">1<?php _e('GB', 'opendrive')?></span></div>
    <div class="user-row-bandwidth  col-md-2 col-sm-2"><b>0 B</b> <?php _e('of', 'opendrive')?> <span class="max-bw">1<?php _e('GB', 'opendrive')?></span></div>


<?php } ?>
    </div>
</script>


<script type="text/x-handlebars-template" data-name="ActivityNotificationsON">
    <a href="#" class="email-notification-btn notifications-on">
        <i class="fa fa-envelope" data-toggle="tooltip" aria-label="<?php _e('Activity Notifications OFF', 'opendrive')?>" title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.', 'opendrive')?></p><?php _e('Activity Notifications <strong>ON</strong>', 'opendrive')?>"></i>
        <i class="fa fa-ban" data-toggle="tooltip" title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.', 'opendrive')?></p><?php _e('Activity Notifications <strong>OFF</strong>', 'opendrive')?>"></i></a>
</script>

<script type="text/x-handlebars-template" data-name="ActivityNotificationsOFF">
    <a class="email-notification-btn notifications-off" href="#">
        <i data-toggle="tooltip"
           aria-label="<?php _e('Activity Notifications ON', 'opendrive') ?>"
           title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.', 'opendrive') ?></p><?php _e('Activity Notifications <strong>ON</strong>', 'opendrive') ?>"
           class="fa fa-envelope"></i><i data-toggle="tooltip"
                                         title="<p><?php _e('Owner will get notifications once this user has uploaded a file or saved a document in Zoho editor.', 'opendrive') ?></p><?php _e('Activity Notifications <strong>OFF</strong>', 'opendrive') ?>"
                                         class="fa fa-ban"></i>
    </a>
</script>

<script type="text/x-handlebars-template" data-name="NewGroup">
    <li class="item droppable group-item empty-group dropdown" id="group-{{group_id}}">
        <a href="/users/{{group_id}}">
            <i class="fa fa-users js-users-icon"></i>
            <div title="{{new_group_name}} (0)" class="folder-name js-folder-name">
                <div class="pull-left js-group-name ellipsis_overflow" style="max-width: 101px;">{{new_group_name}}</div>
                <div class="pull-left js-users-count">&nbsp;(0)</div>
                <div class="clearfix"></div></div>
        </a>
        <i class="fa fa-refresh fa-spin loading-icon"></i>
        <i data-toggle="dropdown" class="fa fa-bars js-item-menu-btn dropdown-toggle"></i>
        <ul class="menu group-menu dropdown-menu dropdown-menu-right">
            <li><a href="/users/{{group_id}}"><?php _e('Open', 'opendrive')?></a></li>
            <li><a class="contex-group-edit-link" href="#"><?php _e('Edit', 'opendrive')?></a>
            </li><li><a class="context-group-delete-link orange-text" href="#"><?php _e('Delete', 'opendrive')?></a></li>
        </ul>
    </li>
</script>
<?php require_once('template-footer.php')?>
